within ;
model MY_FINAL_HEAT_PUMP "Heat Pump Cycle CO2"

  TIL.LiquidComponents.Boundaries.Boundary SH_inlet(
    liquidType=sim.liquidType1,
    use_massFlowRateInput=false,
    V_flowFixed(
      displayUnit="m3/s",
      min=5e-5,
      max=15e-5) = 10e-5,
    m_flowFixed=-0.1,
    boundaryType="p",
    TFixed=273.15 + 29,
    use_temperatureInput=true,
    pFixed=300000) "Variable water inlet temperature" annotation (Placement(
        transformation(extent={{-74,74},{-66,94}}, rotation=0)));
  inner TIL.SystemInformationManager sim(
    redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
    redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
    redeclare TILMedia.GasTypes.TILMedia_MoistAir gasType1)    annotation (
      Placement(transformation(extent={{2,16},{22,36}},    rotation=0)));

  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_hp(
      pressureStateID=1,
    vleFluidType=sim.vleFluidType1,
    fixedInitialPressure=true,
    pInitial=9000000)                      annotation (Placement(transformation(
          extent={{-6,-6},{6,6}},   rotation=90,
        origin={80,28})));

  TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX GasCooler_SHW(
    pressureStateID=1,
    redeclare model PressureDropModel_a =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
    redeclare model PressureDropModel_b =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
    heatCapacityInputType="m, solid",
    thermalResistanceInputType="R",
    heatCapacity=1,
    solidMass=6,
    redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
    hInitialVLEFluid_a=350e3,
    initLiquid_b="linearTemperatureDistribution",
    vleFluidType=sim.vleFluidType1,
    liquidType=sim.liquidType1,
    pressureDropInitialVLEFluid_a=0,
    fixedPressureDropInitialVLEFluid_a=true,
    initHeatTransfer_a="alphaA",
    initVLEFluid_a="linearEnthalpyDistribution",
    thermalResistance=6e-5,
    hInitialVLEFluid_a_CellN=300e3,
    m_flowStart_a=0.05,
    hInitialVLEFluid_a_Cell1=500e3,
    m_flowStart_b=0.09,
    redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
      hxGeometry(
      crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
      crossSectionType_b=TIL.Internals.CrossSectionType.Circular,
      length_a=0.5,
      length_b=0.5,
      nParallelTubes_a=40,
      innerDiameter_a=0.015,
      nParallelTubes_b=40,
      innerDiameter_b=0.015),
    redeclare model HeatTransferModel_a =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlphaA
        (constantAlphaA=1300),
    alphaAInitialVLEFluid_a=1300,
    redeclare model HeatTransferModel_b =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlphaA
        (constantAlphaA=1300),
    nCells=5,
    TInitialLiquid_b_Cell1=307.15,
    TInitialLiquid_b_CellN=297.15,
    pStart_a=9000000) annotation (Placement(transformation(extent={{16,62},{-12,
            90}}, rotation=0)));

  TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=3)
    annotation (Placement(transformation(extent={{-48,48},{-38,58}}, rotation=0)));
  TIL.VLEFluidComponents.Valves.OrificeValve expansionValve(
                                        effectiveFlowAreaFixed=0.4e-6,
      use_effectiveFlowAreaInput=true,
    vleFluidType=sim.vleFluidType1)
    annotation (Placement(transformation(
        origin={-80,-31},
        extent={{-9,4},{9,-4}},
        rotation=270)));

  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_lp(
      pressureStateID=2,
    vleFluidType=sim.vleFluidType1,
    fixedInitialPressure=true,
    pInitial=2501000)                      annotation (Placement(transformation(
          extent={{28,-56},{40,-44}}, rotation=0)));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint5(stateViewerIndex=5)
    annotation (Placement(transformation(
        origin={-55.5,-11},
        extent={{5.49999,5.0001},{-5.50001,-4.99998}},
        rotation=180)));
  TIL.VLEFluidComponents.Separators.IdealSeparator separator(pressureStateID=2,
    vleFluidType=sim.vleFluidType1,
    delta_h=10,
    initialFillingLevel=0.4,
    mdotStart=0.05,
    hStart=450e3,
    V(displayUnit="m3") = 10e-3)
                annotation (Placement(transformation(extent={{46,-64},{58,-44}},
          rotation=0)));

  TIL.VLEFluidComponents.Sensors.StatePoint statePoint6(stateViewerIndex=6)
    annotation (Placement(transformation(
        extent={{-6,-6},{6,6}},
        rotation=0,
        origin={-32,-38})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint7(stateViewerIndex=7)
    annotation (Placement(transformation(extent={{8,-44},{20,-32}}, rotation=0)));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint8(stateViewerIndex=8)
    annotation (Placement(transformation(extent={{60,-44},{70,-34}}, rotation=0)));
  TIL.VLEFluidComponents.Tubes.Tube SLHX_before_evaporation(
    nCells=4,
    redeclare model WallHeatConductionModel =
        TIL.VLEFluidComponents.Tubes.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
    redeclare model PressureDropModel =
        TIL.VLEFluidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
    redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
    enableHeatPorts=true,
    wallCellStateType="state north",
    m_flowStart=0.03,
    hInitialVLEFluid=300e3,
    initVLEFluid="linearEnthalpyDistribution",
    hInitialVLEFluid_Cell1=300e3,
    hInitialVLEFluid_CellN=280e3,
    fixedTInitialWall=false,
    redeclare TIL.VLEFluidComponents.Tubes.Geometry.Tube6x1 tubeGeometry(length=
         0.5, nParallelTubes=4),
    redeclare model TubeSideHeatTransferModel =
        TIL.VLEFluidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlphaA
        (constantAlphaA=0),
    vleFluidType=sim.vleFluidType1,
    pressureStateID=1,
    TInitialWall=303.15,
    pStart=10000000) annotation (Placement(transformation(
        extent={{-8,-2},{8,2}},
        rotation=270,
        origin={-80,12})));

  TIL.VLEFluidComponents.Tubes.Tube SLHX_after_evaporation(
    nCells=4,
    redeclare model WallHeatConductionModel =
        TIL.VLEFluidComponents.Tubes.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
    redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
    enableHeatPorts=true,
    wallCellStateType="state north",
    pressureStateID=2,
    m_flowStart=-0.03,
    hInitialVLEFluid=430e3,
    initVLEFluid="linearEnthalpyDistribution",
    redeclare model PressureDropModel =
        TIL.VLEFluidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
    hInitialVLEFluid_Cell1(
      min=420e3,
      max=470e3) = 450e3,
    hInitialVLEFluid_CellN(
      min=400e3,
      max=450e3) = 430e3,
    redeclare TIL.VLEFluidComponents.Tubes.Geometry.Tube6x1 tubeGeometry(length=
         0.5, nParallelTubes=4),
    redeclare model TubeSideHeatTransferModel =
        TIL.VLEFluidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlphaA
        (constantAlphaA=0),
    vleFluidType=sim.vleFluidType1,
    TInitialWall=274.15,
    pStart=3000000) annotation (Placement(transformation(
        extent={{-8,2},{8,-2}},
        rotation=270,
        origin={80,-20})));

  TIL.VLEFluidComponents.Sensors.StatePoint statePoint9(stateViewerIndex=9)
    annotation (Placement(transformation(
        extent={{-5,-5},{5,5}},
        rotation=0,
        origin={51,1})));
  Modelica.Blocks.Continuous.LimPID PID2(
    initType=Modelica.Blocks.Types.InitPID.InitialOutput,
    Ti=1,
    y_start=0.3e-6,
    controllerType=Modelica.Blocks.Types.SimpleController.PI,
    yMax=7e-6,
    k=10e-15,
    yMin=0.01e-6,
    strict=true)
    annotation (Placement(transformation(extent={{-124,-40},{-106,-22}})));
  TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p(vleFluidType=sim.vleFluidType1)
    annotation (Placement(transformation(extent={{-102,2},{-110,-6}})));
  TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC1
    annotation (Placement(transformation(extent={{162,44},{172,54}})));
  TIL.VLEFluidComponents.Sensors.Sensor_T sensor_T(vleFluidType=sim.vleFluidType1)
    annotation (Placement(transformation(extent={{-96,-50},{-88,-42}})));
  Modelica.Blocks.Sources.RealExpression COP_of_HP(y=-(Preheater_DHW.summary.Q_flow
         + Reheater_DHW.summary.Q_flow + GasCooler_SHW.summary.tube_a.Q_flow_vle)
        /max(1e-10, simpleCompressor.summary.P_flow_vle))
    annotation (Placement(transformation(extent={{-246,154},{-206,170}})));
  TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC2
    annotation (Placement(transformation(extent={{-62,94},{-52,104}})));
  TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Reheater_DHW(
    pressureStateID=1,
    vleFluidType=sim.vleFluidType1,
    liquidType=sim.liquidType1,
    thermalResistanceInputType="R",
    thermalResistance=6e-5,
    redeclare model PressureDropModel_a =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
    redeclare model PressureDropModel_b =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
    heatCapacityInputType="m, solid",
    solidMass=6,
    initVLEFluid_a="linearEnthalpyDistribution",
    pressureDropInitialVLEFluid_a=0,
    initLiquid_b="linearTemperatureDistribution",
    redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
    m_flowStart_a=0.05,
    hInitialVLEFluid_a_Cell1=500e3,
    m_flowStart_b=0.006,
    hInitialVLEFluid_a_CellN=550e3,
    redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
      hxGeometry(
      crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
      crossSectionType_b=TIL.Internals.CrossSectionType.Circular,
      length_a=0.5,
      length_b=0.5,
      innerDiameter_a=0.015,
      nParallelTubes_b=40,
      innerDiameter_b=0.015,
      nParallelTubes_a=40),
    redeclare model HeatTransferModel_b =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlphaA
        (constantAlphaA=1300),
    alphaAInitialVLEFluid_a=1300,
    redeclare model HeatTransferModel_a =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlphaA
        (constantAlphaA=1300),
    nCells=5,
    TInitialLiquid_b_Cell1=303.15,
    TInitialLiquid_b_CellN=343.15,
    pStart_a=300000)
    annotation (Placement(transformation(extent={{90,70},{118,98}})));

  TIL.VLEFluidComponents.Sensors.Sensor_T_degC t_gas_coolers_out(vleFluidType=
        sim.vleFluidType1)
    annotation (Placement(transformation(extent={{-178,88},{-168,98}})));
  TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC4
    annotation (Placement(transformation(extent={{-122,94},{-112,104}})));
  TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC5
    annotation (Placement(transformation(extent={{24,106},{36,118}})));
  TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC6
    annotation (Placement(transformation(extent={{176,102},{188,114}})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
    annotation (Placement(transformation(extent={{102,44},{112,54}}, rotation=0)));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=2)
    annotation (Placement(transformation(extent={{50,62},{60,72}}, rotation=0)));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint4(stateViewerIndex=4,
      vleFluidType=sim.vleFluidType1) annotation (Placement(transformation(
          extent={{-156,106},{-146,116}},rotation=0)));
  TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX Preheater_DHW(
    pressureStateID=1,
    vleFluidType=sim.vleFluidType1,
    liquidType=sim.liquidType1,
    thermalResistanceInputType="R",
    thermalResistance=6e-5,
    redeclare model PressureDropModel_a =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
    redeclare model PressureDropModel_b =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
    heatCapacityInputType="m, solid",
    solidMass=6,
    initVLEFluid_a="linearEnthalpyDistribution",
    pressureDropInitialVLEFluid_a=0,
    initLiquid_b="linearTemperatureDistribution",
    redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
    m_flowStart_a=0.05,
    m_flowStart_b=0.006,
    hInitialVLEFluid_a_Cell1=220e3,
    hInitialVLEFluid_a_CellN=300e3,
    alphaAInitialVLEFluid_a=1300,
    redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
      hxGeometry(
      crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
      crossSectionType_b=TIL.Internals.CrossSectionType.Circular,
      length_a=0.5,
      length_b=0.5,
      nParallelTubes_a=40,
      innerDiameter_a=0.015,
      nParallelTubes_b=40,
      innerDiameter_b=0.015),
    redeclare model HeatTransferModel_a =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlphaA
        (constantAlphaA=1300),
    redeclare model HeatTransferModel_b =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlphaA
        (constantAlphaA=1300),
    nCells=5,
    TInitialLiquid_b_Cell1=282.15,
    TInitialLiquid_b_CellN=303.15,
    pStart_a=9000000)
    annotation (Placement(transformation(extent={{-112,64},{-84,92}})));

  TIL.LiquidComponents.Sensors.Sensor_T sensor_T2(liquidType=sim.liquidType1)
    annotation (Placement(transformation(extent={{158,120},{170,132}})));
  Modelica.Blocks.Continuous.LimPID PID4(
    initType=Modelica.Blocks.Types.InitPID.InitialOutput,
    Ti=1,
    controllerType=Modelica.Blocks.Types.SimpleController.PI,
    yMax=100,
    yMin=0,
    y_start=50,
    k=0.1,
    strict=true)
    annotation (Placement(transformation(extent={{12,250},{-8,270}})));
  Modelica.Blocks.Sources.RealExpression Real_value_DHW_T_out(y=273.15 + 70)
    annotation (Placement(transformation(extent={{78,236},{30,250}})));
  TIL.LiquidComponents.Boundaries.Boundary DHW_inlet(
    boundaryType="p",
    liquidType=sim.liquidType1,
    streamVariablesInputType="T",
    use_pressureInput=false,
    use_temperatureInput=false,
    pFixed=300000,
    TFixed=282.15)
    annotation (Placement(transformation(extent={{-162,208},{-154,228}})));
  TIL.LiquidComponents.Boundaries.Boundary DHW_outlet(
    liquidType=sim.liquidType1,
    streamVariablesInputType="T",
    boundaryType="m_flow",
    m_flowFixed=-0.05,
    use_massFlowRateInput=true,
    TFixed=343.15) "variable mass flow rate"
    annotation (Placement(transformation(extent={{190,82},{182,102}})));
  Modelica.Blocks.Sources.RealExpression Q_Evaporator(y=evaporator.summary.Q_flow)
    annotation (Placement(transformation(extent={{-246,134},{-206,150}})));
  Modelica.Blocks.Sources.RealExpression Q_GasCoolers(y=-(Preheater_DHW.summary.Q_flow
         + Reheater_DHW.summary.Q_flow + GasCooler_SHW.summary.tube_a.Q_flow_vle))
    annotation (Placement(transformation(extent={{-246,114},{-206,130}})));
  Modelica.Blocks.Sources.RealExpression Q_SLHX(y=-SLHX_before_evaporation.summary.Q_flow_vle)
    annotation (Placement(transformation(extent={{-246,94},{-206,110}})));
  Modelica.Blocks.Sources.RealExpression P_Compressor(y=simpleCompressor.summary.P_flow_vle)
    annotation (Placement(transformation(extent={{-246,74},{-206,90}})));
  TIL.LiquidComponents.Pumps.Pump2ndOrder pump2ndOrder1(
    nFixed=50,
    liquidType=sim.liquidType1,
    includeDefaultSummary=true,
    steadyStateContinuity=true,
    n0=50,
    eta0=0.45,
    use_mechanicalPort=true,
    steadyStateMomentum=true,
    volume(displayUnit="m3") = 0.0002,
    V_flow0(displayUnit="l/min") = 4.1666666666667e-06,
    dp0=160000,
    T0=298.15,
    TInitialLiquid=302.15) annotation (Placement(transformation(
        extent={{-8,-8},{8,8}},
        rotation=-90,
        origin={-24,234})));
  TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundary2(
                                                                   boundaryType=
       "n", use_nInput=true) annotation (Placement(transformation(
        extent={{4,-10},{-4,10}},
        rotation=90,
        origin={-24,248})));
  TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC7
    annotation (Placement(transformation(extent={{-70,242},{-58,254}})));
  TIL.LiquidComponents.Boundaries.Boundary SH_outlet(
    liquidType=sim.liquidType1,
    streamVariablesInputType="T",
    boundaryType="m_flow",
    m_flowFixed=-0.05,
    use_massFlowRateInput=true,
    TFixed=307.15) "variable mass flow rate"
    annotation (Placement(transformation(extent={{80,82},{72,102}})));
  TIL.LiquidComponents.Pumps.Pump2ndOrder pump2ndOrder2(
    nFixed=50,
    liquidType=sim.liquidType1,
    includeDefaultSummary=true,
    steadyStateContinuity=true,
    n0=50,
    eta0=0.45,
    use_mechanicalPort=true,
    steadyStateMomentum=true,
    volume(displayUnit="m3") = 0.0002,
    V_flow0(displayUnit="l/min") = 8.3333333333333e-05,
    dp0=160000,
    T0=298.15,
    TInitialLiquid=302.15) annotation (Placement(transformation(
        extent={{-8,-8},{8,8}},
        rotation=-90,
        origin={-34,144})));
  Modelica.Blocks.Continuous.LimPID PID5(
    initType=Modelica.Blocks.Types.InitPID.InitialOutput,
    Ti=1,
    y_start=50,
    yMax=100,
    k=5,
    controllerType=Modelica.Blocks.Types.SimpleController.PI,
    yMin=0,
    strict=true)
    annotation (Placement(transformation(extent={{0,154},{-20,174}})));
  Modelica.Blocks.Sources.RealExpression Real_value_SH_T_out(y=273.15 + 34)
    annotation (Placement(transformation(extent={{48,142},{8,156}})));
  TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundary3(
                                                                   boundaryType=
       "n", use_nInput=true) annotation (Placement(transformation(
        extent={{4,-10},{-4,10}},
        rotation=90,
        origin={-34,158})));
  TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC8
    annotation (Placement(transformation(extent={{-54,166},{-42,178}})));
  TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC9
    annotation (Placement(transformation(extent={{26,208},{38,220}})));
  TIL.LiquidComponents.Sensors.Sensor_T sensor_T3
    annotation (Placement(transformation(extent={{60,106},{72,118}})));
  TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC10
    annotation (Placement(transformation(extent={{-32,94},{-20,106}})));
  TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC11
    annotation (Placement(transformation(extent={{126,108},{138,120}})));
  TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC12
    annotation (Placement(transformation(extent={{-156,226},{-144,238}})));
  TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX evaporator(
    redeclare model PressureDropModel_a =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
    redeclare model PressureDropModel_b =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
    thermalResistanceInputType="R",
    thermalResistance=6e-5,
    heatCapacityInputType="m, solid",
    solidMass=6,
    redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
    redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
      hxGeometry(
      length_a=0.5,
      nParallelTubes_a=40,
      crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
      innerDiameter_a=0.015,
      length_b=0.5,
      nParallelTubes_b=40,
      crossSectionType_b=TIL.Internals.CrossSectionType.Circular,
      innerDiameter_b=0.015),
    redeclare model HeatTransferModel_b =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlphaA
        (constantAlphaA=2000),
    pressureStateID=2,
    vleFluidType=sim.vleFluidType1,
    liquidType=sim.liquidType1,
    steadyStateContinuity_b=true,
    wallCellStateType="state center",
    includeDefaultSummary=true,
    cellOrientation_a="A",
    alphaAStateChoice_a=TIL.Internals.AlphaAStateChoice.definedByHeatTransferCorrelation,
    useFalseDynamics_a=false,
    pressureDropInitialVLEFluid_a=0,
    alphaAInitialVLEFluid_a=2000,
    m_flowStart_a=0.05,
    m_flowStart_b=0.5,
    initVLEFluid_a="linearEnthalpyDistribution",
    hInitialVLEFluid_a_Cell1=200e3,
    hInitialVLEFluid_a_CellN=450e3,
    initLiquid_b="linearTemperatureDistribution",
    redeclare model HeatTransferModel_a =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlphaA
        (constantAlphaA=2000),
    nCells=5,
    TInitialLiquid_b_Cell1=274.15,
    TInitialLiquid_b_CellN=280.15,
    pStart_a=2501000)
    annotation (Placement(transformation(extent={{-24,-44},{4,-72}})));

  TIL.LiquidComponents.Boundaries.Boundary boundary3(
    liquidType=sim.liquidType1,
    boundaryType="m_flow",
    pFixed=300000,
    use_massFlowRateInput=true,
    TFixed=274.15)
    annotation (Placement(transformation(extent={{-58,-88},{-50,-68}})));
  TIL.LiquidComponents.Boundaries.Boundary boundary6(
    liquidType=sim.liquidType1,
    boundaryType="p",
    use_temperatureInput=false,
    pFixed=300000,
    TFixed=281.15)
    annotation (Placement(transformation(extent={{62,-94},{70,-74}})));
  Modelica.Blocks.Sources.RealExpression realExpression1(y=90e5)
    annotation (Placement(transformation(extent={{-162,-60},{-132,-42}})));
  TIL.VLEFluidComponents.Sensors.Sensor_T_degC t_evaporation
    annotation (Placement(transformation(extent={{-62,-44},{-52,-34}})));
  TIL.LiquidComponents.JunctionElements.VolumeJunction junction(liquidType=sim.liquidType1,
      TInitial=282.15) annotation (Placement(transformation(
        extent={{-5,5},{5,-5}},
        rotation=-90,
        origin={-131,217})));
  TIL.LiquidComponents.JunctionElements.VolumeJunction junction1(liquidType=sim.liquidType1,
      TInitial=297.15) annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=0,
        origin={-48,84})));
  TIL.LiquidComponents.JunctionElements.VolumeJunction junction2(TInitial=
        307.15) annotation (Placement(transformation(extent={{44,88},{52,96}})));
  TIL.LiquidComponents.JunctionElements.VolumeJunction junction3(TInitial=
        343.15)
    annotation (Placement(transformation(extent={{144,88},{152,96}})));
  TIL.VLEFluidComponents.Compressors.SimpleCompressor simpleCompressor(
    vleFluidType=sim.vleFluidType1,
    T_out(displayUnit="degC") = 388.15,
    includeDefaultSummary=true,
    dischargeConditionType="T",
    use_volumeFlowRateInput=false,
    presetVariableType="m_flow",
    use_dpInput=false,
    use_massFlowRateInput=true,
    dpFixed=7500000)
    annotation (Placement(transformation(extent={{72,0},{88,16}})));
  Modelica.Blocks.Sources.CombiTimeTable combiTimeTable_SH_temperature_in(
      smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[
        0,297.05; 3600,297.35; 7200,296.75; 10800,295.85; 14400,296.25; 18000,
        296.45; 21600,296.35; 25200,296.25; 28800,296.05; 32400,296.75; 36000,
        298.15; 39600,298.05; 43200,297.15; 46800,296.75; 50400,296.35; 54000,
        296.45; 57600,297.25; 61200,297.75; 64800,297.25; 68400,297.45; 72000,
        297.05; 75600,296.55; 79200,297.25; 82800,297.45; 86400,297.05; 90000,
        298.65; 93600,300.05; 97200,300.15; 100800,299.55; 104400,298.95;
        108000,298.85; 111600,298.55; 115200,299.05; 118800,299.55; 122400,
        299.75; 126000,299.25; 129600,298.45; 133200,298.85; 136800,299.15;
        140400,298.05; 144000,298.25; 147600,298.75; 151200,298.55; 154800,
        298.15; 158400,298.25; 162000,298.65; 165600,298.55; 169200,298.45;
        172800,298.65; 176400,298.65; 180000,298.45; 183600,298.65; 187200,
        298.85; 190800,298.35; 194400,298.15; 198000,298.35; 201600,299.25;
        205200,299.35; 208800,298.35; 212400,298.55; 216000,298.25; 219600,
        298.15; 223200,299.25; 226800,298.45; 230400,298.05; 234000,298.85;
        237600,298.95; 241200,298.45; 244800,298.25; 248400,298.65; 252000,
        298.95; 255600,298.55; 259200,298.45; 262800,298.45; 266400,298.35;
        270000,298.55; 273600,298.55; 277200,298.35; 280800,298.25; 284400,
        297.95; 288000,298.65; 291600,299.95; 295200,299.95; 298800,299.85;
        302400,299.15; 306000,298.75; 309600,298.85; 313200,298.95; 316800,
        298.85; 320400,298.65; 324000,298.85; 327600,299.05; 331200,298.75;
        334800,298.35; 338400,298.45; 342000,298.15; 345600,297.65; 349200,
        297.65; 352800,298.25; 356400,297.95; 360000,297.65; 363600,297.65;
        367200,297.95; 370800,297.35; 374400,297.95; 378000,298.65; 381600,
        298.75; 385200,298.35; 388800,297.65; 392400,297.95; 396000,297.85;
        399600,297.45; 403200,297.85; 406800,297.55; 410400,297.95; 414000,
        298.15; 417600,297.85; 421200,297.15; 424800,297.05; 428400,297.15;
        432000,296.45; 435600,296.75; 439200,297.45; 442800,296.95; 446400,
        296.65; 450000,297.05; 453600,296.75; 457200,297.45; 460800,296.95;
        464400,297.25; 468000,297.75; 471600,297.45; 475200,297.25; 478800,
        297.35; 482400,297.25; 486000,297.45; 489600,297.35; 493200,297.55;
        496800,297.25; 500400,297.65; 504000,297.85; 507600,297.45; 511200,
        296.65; 514800,297.15; 518400,296.45; 522000,296.35; 525600,296.95;
        529200,296.65; 532800,296.45; 536400,296.85; 540000,296.65; 543600,
        297.35; 547200,296.35; 550800,296.95; 554400,297.35; 558000,297.25;
        561600,296.95; 565200,297.15; 568800,296.95; 572400,297.05; 576000,
        297.35; 579600,297.35; 583200,297.15; 586800,297.15; 590400,297.35;
        594000,296.75; 597600,296.65; 601200,296.55; 604800,296.45; 608400,
        296.45; 612000,296.65; 615600,296.75; 619200,297.15; 622800,297.65;
        626400,298.05; 630000,297.95; 633600,297.55; 637200,298.45; 640800,
        299.05; 644400,299.25; 648000,298.65; 651600,298.55; 655200,298.55;
        658800,298.15; 662400,298.65; 666000,299.25; 669600,299.35; 673200,
        298.65; 676800,298.15; 680400,297.65; 684000,298.05; 687600,297.95;
        691200,298.75; 694800,299.65; 698400,300.15; 702000,300.25; 705600,
        300.35; 709200,299.95; 712800,299.85; 716400,300.25; 720000,300.55;
        723600,300.25; 727200,300.05; 730800,299.85; 734400,298.85; 738000,
        299.25; 741600,299.85; 745200,299.25; 748800,298.65; 752400,299.65;
        756000,299.75; 759600,298.85; 763200,298.85; 766800,298.85; 770400,
        299.65; 774000,298.95; 777600,298.45; 781200,298.75; 784800,298.75;
        788400,298.35; 792000,298.55; 795600,298.55; 799200,298.35; 802800,
        298.55; 806400,298.75; 810000,299.05; 813600,298.45; 817200,298.35;
        820800,297.95; 824400,298.05; 828000,298.55; 831600,297.85; 835200,
        298.15; 838800,298.35; 842400,297.85; 846000,297.85; 849600,298.25;
        853200,298.05; 856800,297.75; 860400,298.05; 864000,297.85; 867600,
        297.55; 871200,297.65; 874800,297.95; 878400,297.75; 882000,297.65;
        885600,297.85; 889200,298.35; 892800,297.25; 896400,298.65; 900000,
        298.75; 903600,298.45; 907200,298.25; 910800,298.05; 914400,297.95;
        918000,298.15; 921600,298.05; 925200,297.75; 928800,297.75; 932400,
        298.25; 936000,298.05; 939600,297.85; 943200,297.85; 946800,297.65;
        950400,297.15; 954000,297.45; 957600,298.15; 961200,297.65; 964800,
        297.45; 968400,297.85; 972000,297.95; 975600,298.15; 979200,297.45;
        982800,298.65; 986400,298.95; 990000,298.55; 993600,298.05; 997200,
        298.15; 1000800,298.25; 1004400,297.75; 1008000,298.05; 1011600,297.85;
        1015200,297.55; 1018800,297.45; 1022400,297.45; 1026000,297.35; 1029600,
        297.45; 1033200,297.45; 1036800,297.55; 1040400,296.55; 1044000,296.95;
        1047600,296.75; 1051200,296.45; 1054800,296.85; 1058400,297.05; 1062000,
        297.25; 1065600,296.45; 1069200,297.15; 1072800,297.15; 1076400,296.95;
        1080000,296.65; 1083600,296.55; 1087200,296.85; 1090800,297.15; 1094400,
        297.45; 1098000,296.65; 1101600,296.45; 1105200,296.55; 1108800,296.25;
        1112400,296.25; 1116000,297.45; 1119600,297.45; 1123200,296.35; 1126800,
        295.95; 1130400,296.45; 1134000,296.45; 1137600,296.45; 1141200,296.65;
        1144800,296.35; 1148400,296.95; 1152000,296.25; 1155600,296.95; 1159200,
        296.95; 1162800,296.55; 1166400,296.55; 1170000,296.55; 1173600,296.65;
        1177200,296.55; 1180800,296.85; 1184400,296.95; 1188000,296.95; 1191600,
        296.85; 1195200,297.05; 1198800,296.45; 1202400,296.55; 1206000,296.65;
        1209600,296.85; 1213200,297.15; 1216800,297.65; 1220400,297.25; 1224000,
        297.55; 1227600,297.65; 1231200,297.35; 1234800,297.35; 1238400,297.35;
        1242000,298.85; 1245600,298.95; 1249200,298.35; 1252800,297.65; 1256400,
        297.45; 1260000,297.05; 1263600,296.85; 1267200,297.95; 1270800,297.75;
        1274400,297.25; 1278000,297.25; 1281600,297.45; 1285200,297.15; 1288800,
        297.35; 1292400,297.85; 1296000,297.75; 1299600,297.75; 1303200,299.05;
        1306800,299.25; 1310400,299.15; 1314000,299.25; 1317600,299.05; 1321200,
        298.65; 1324800,299.35; 1328400,299.85; 1332000,299.95; 1335600,299.95;
        1339200,299.55; 1342800,298.15; 1346400,298.65; 1350000,298.55; 1353600,
        298.65; 1357200,299.25; 1360800,300.05; 1364400,300.25; 1368000,299.95;
        1371600,299.55; 1375200,299.85; 1378800,300.65; 1382400,300.45; 1386000,
        300.55; 1389600,300.65; 1393200,300.55; 1396800,300.65; 1400400,301.05;
        1404000,300.75; 1407600,300.55; 1411200,300.85; 1414800,301.05; 1418400,
        301.05; 1422000,300.85; 1425600,300.35; 1429200,300.25; 1432800,300.85;
        1436400,299.95; 1440000,299.25; 1443600,300.55; 1447200,301.15; 1450800,
        300.95; 1454400,300.55; 1458000,300.45; 1461600,300.55; 1465200,300.95;
        1468800,300.85; 1472400,300.75; 1476000,300.85; 1479600,301.15; 1483200,
        301.35; 1486800,301.15; 1490400,301.55; 1494000,300.35; 1497600,300.55;
        1501200,301.15; 1504800,300.75; 1508400,300.55; 1512000,299.95; 1515600,
        299.75; 1519200,299.45; 1522800,299.45; 1526400,299.45; 1530000,299.65;
        1533600,299.25; 1537200,298.95; 1540800,298.75; 1544400,298.55; 1548000,
        299.25; 1551600,299.25; 1555200,298.35; 1558800,298.55; 1562400,299.15;
        1566000,298.85; 1569600,298.35; 1573200,298.75; 1576800,298.95; 1580400,
        298.65; 1584000,298.25; 1587600,299.15; 1591200,299.35; 1594800,298.75;
        1598400,298.35; 1602000,298.55; 1605600,298.35; 1609200,298.15; 1612800,
        298.45; 1616400,298.55; 1620000,298.65; 1623600,297.95; 1627200,297.75;
        1630800,297.55; 1634400,298.15; 1638000,298.25; 1641600,297.85; 1645200,
        298.05; 1648800,298.85; 1652400,298.65; 1656000,298.05; 1659600,298.35;
        1663200,298.45; 1666800,298.95; 1670400,297.75; 1674000,299.05; 1677600,
        298.55; 1681200,297.55; 1684800,297.35; 1688400,297.25; 1692000,297.65;
        1695600,296.75; 1699200,296.85; 1702800,297.25; 1706400,297.05; 1710000,
        296.55; 1713600,296.65; 1717200,296.75; 1720800,296.55; 1724400,296.95;
        1728000,296.65; 1731600,297.75; 1735200,297.85; 1738800,297.05; 1742400,
        296.95; 1746000,297.15; 1749600,295.85; 1753200,296.35; 1756800,295.85;
        1760400,297.45; 1764000,297.65; 1767600,296.75; 1771200,296.85; 1774800,
        296.65; 1778400,296.75; 1782000,296.55; 1785600,296.45; 1789200,297.65;
        1792800,298.15; 1796400,297.15; 1800000,296.05; 1803600,296.35; 1807200,
        296.45; 1810800,296.55; 1814400,296.05; 1818000,296.45; 1821600,296.75;
        1825200,296.65; 1828800,296.45; 1832400,296.85; 1836000,297.75; 1839600,
        298.35; 1843200,297.55; 1846800,297.75; 1850400,297.95; 1854000,297.45;
        1857600,296.85; 1861200,296.75; 1864800,296.25; 1868400,296.55; 1872000,
        296.45; 1875600,296.35; 1879200,296.95; 1882800,297.55; 1886400,297.55;
        1890000,297.35; 1893600,297.45; 1897200,297.65; 1900800,296.85; 1904400,
        297.65; 1908000,298.25; 1911600,297.25; 1915200,296.95; 1918800,297.35;
        1922400,297.85; 1926000,298.25; 1929600,298.25; 1933200,299.05; 1936800,
        298.35; 1940400,297.15; 1944000,296.75; 1947600,298.05; 1951200,297.95;
        1954800,299.65; 1958400,299.45; 1962000,298.45; 1965600,298.45; 1969200,
        296.75; 1972800,297.15; 1976400,297.45; 1980000,296.85; 1983600,297.05;
        1987200,297.65; 1990800,297.05; 1994400,297.05; 1998000,297.55; 2001600,
        297.75; 2005200,297.45; 2008800,297.45; 2012400,297.85; 2016000,297.95;
        2019600,298.45; 2023200,297.75; 2026800,296.55; 2030400,296.35; 2034000,
        297.65; 2037600,297.15; 2041200,296.75; 2044800,296.55; 2048400,296.25;
        2052000,296.15; 2055600,297.45; 2059200,296.45; 2062800,297.25; 2066400,
        296.25; 2070000,296.75; 2073600,297.15; 2077200,296.55; 2080800,296.55;
        2084400,297.65; 2088000,296.95; 2091600,296.75; 2095200,297.35; 2098800,
        297.25; 2102400,298.25; 2106000,299.55; 2109600,299.85; 2113200,300.25;
        2116800,299.75; 2120400,299.25; 2124000,298.95; 2127600,298.25; 2131200,
        298.55; 2134800,298.85; 2138400,298.55; 2142000,298.05; 2145600,297.85;
        2149200,298.05; 2152800,298.05; 2156400,297.95; 2160000,297.45; 2163600,
        297.55; 2167200,297.95; 2170800,297.55; 2174400,297.45; 2178000,297.75;
        2181600,298.05; 2185200,297.85; 2188800,297.35; 2192400,298.65; 2196000,
        298.85; 2199600,298.15; 2203200,298.15; 2206800,297.95; 2210400,298.05;
        2214000,298.15; 2217600,297.95; 2221200,298.25; 2224800,299.55; 2228400,
        299.05; 2232000,298.85; 2235600,298.75; 2239200,298.05; 2242800,298.45;
        2246400,297.75; 2250000,297.55; 2253600,298.45; 2257200,298.15; 2260800,
        297.65; 2264400,298.15; 2268000,298.65; 2271600,298.55; 2275200,297.05;
        2278800,298.35; 2282400,298.85; 2286000,298.55; 2289600,298.35; 2293200,
        298.75; 2296800,298.25; 2300400,297.85; 2304000,298.25; 2307600,298.15;
        2311200,298.45; 2314800,298.45; 2318400,298.35; 2322000,298.65; 2325600,
        297.85; 2329200,298.25; 2332800,297.35; 2336400,297.45; 2340000,298.15;
        2343600,297.85; 2347200,297.55; 2350800,297.95; 2354400,297.95; 2358000,
        297.15; 2361600,297.05; 2365200,298.75; 2368800,299.05; 2372400,298.85;
        2376000,298.45; 2379600,298.45; 2383200,297.55; 2386800,297.95; 2390400,
        298.25; 2394000,298.25; 2397600,298.15; 2401200,298.05; 2404800,297.85;
        2408400,298.15; 2412000,299.55; 2415600,299.85; 2419200,299.25; 2422800,
        299.75; 2426400,300.05; 2430000,299.75; 2433600,300.25; 2437200,300.95;
        2440800,300.65; 2444400,299.65; 2448000,300.75; 2451600,301.25; 2455200,
        301.25; 2458800,301.55; 2462400,300.95; 2466000,299.95; 2469600,299.85;
        2473200,299.75; 2476800,299.85; 2480400,300.15; 2484000,300.35; 2487600,
        300.05; 2491200,299.45; 2494800,298.85; 2498400,299.55; 2502000,300.05;
        2505600,298.85; 2509200,298.95; 2512800,299.75; 2516400,299.75; 2520000,
        298.65; 2523600,298.85; 2527200,299.65; 2530800,298.65; 2534400,298.55;
        2538000,298.95; 2541600,298.95; 2545200,298.65; 2548800,298.35; 2552400,
        298.05; 2556000,298.55; 2559600,298.25; 2563200,297.95; 2566800,298.25;
        2570400,298.15; 2574000,297.95; 2577600,298.05; 2581200,298.35; 2584800,
        297.95; 2588400,297.55; 2592000,297.85; 2595600,297.75; 2599200,297.95;
        2602800,298.55; 2606400,298.45; 2610000,298.35; 2613600,299.25; 2617200,
        299.25; 2620800,299.85; 2624400,299.55; 2628000,298.55; 2631600,298.95;
        2635200,298.55; 2638800,297.55; 2642400,298.05; 2646000,297.45; 2649600,
        297.95; 2653200,298.55; 2656800,298.55; 2660400,298.15; 2664000,298.05;
        2667600,298.15; 2671200,297.85; 2674800,297.95; 2678400,297.85; 2682000,
        297.75; 2685600,297.55; 2689200,298.05; 2692800,297.85; 2696400,297.85;
        2700000,298.05; 2703600,297.55; 2707200,298.05; 2710800,299.55; 2714400,
        299.15; 2718000,298.55; 2721600,297.95; 2725200,297.75; 2728800,297.15;
        2732400,296.95; 2736000,297.25; 2739600,297.15; 2743200,297.55; 2746800,
        297.95; 2750400,297.65; 2754000,297.75; 2757600,297.05; 2761200,297.85;
        2764800,297.35; 2768400,297.05; 2772000,297.45; 2775600,297.75; 2779200,
        297.85; 2782800,297.75; 2786400,297.85; 2790000,297.55; 2793600,297.75;
        2797200,298.65; 2800800,298.55; 2804400,298.25; 2808000,297.75; 2811600,
        297.55; 2815200,297.15; 2818800,296.75; 2822400,297.25; 2826000,297.45;
        2829600,297.95; 2833200,297.95; 2836800,298.05; 2840400,297.95; 2844000,
        296.15; 2847600,297.05; 2851200,296.95; 2854800,297.15; 2858400,297.75;
        2862000,297.85; 2865600,298.45; 2869200,297.15; 2872800,296.75; 2876400,
        296.15; 2880000,295.75; 2883600,296.75; 2887200,297.35; 2890800,296.95;
        2894400,296.85; 2898000,296.65; 2901600,296.55; 2905200,296.45; 2908800,
        296.45; 2912400,296.75; 2916000,296.75; 2919600,297.05; 2923200,296.75;
        2926800,296.85; 2930400,296.65; 2934000,296.85; 2937600,296.95; 2941200,
        296.35; 2944800,297.15; 2948400,297.05; 2952000,296.05; 2955600,296.65;
        2959200,297.05; 2962800,296.75; 2966400,296.35; 2970000,296.75; 2973600,
        296.85; 2977200,296.85; 2980800,296.25; 2984400,298.15; 2988000,299.65;
        2991600,299.55; 2995200,298.35; 2998800,297.45; 3002400,298.15; 3006000,
        298.55; 3009600,298.05; 3013200,295.25; 3016800,295.65; 3020400,296.35;
        3024000,296.45; 3027600,296.75; 3031200,296.35; 3034800,296.55; 3038400,
        296.25; 3042000,296.05; 3045600,296.65; 3049200,297.15; 3052800,297.35;
        3056400,297.45; 3060000,297.55; 3063600,298.05; 3067200,298.75; 3070800,
        298.25; 3074400,297.45; 3078000,298.95; 3081600,298.65; 3085200,297.45;
        3088800,296.45; 3092400,295.85; 3096000,295.35; 3099600,295.85; 3103200,
        295.85; 3106800,296.15; 3110400,296.25; 3114000,296.45; 3117600,297.25;
        3121200,297.15; 3124800,296.65; 3128400,296.85; 3132000,297.15; 3135600,
        296.15; 3139200,296.25; 3142800,296.45; 3146400,296.85; 3150000,298.05;
        3153600,295.95; 3157200,296.05; 3160800,296.35; 3164400,296.25; 3168000,
        296.55; 3171600,296.65; 3175200,296.65; 3178800,297.05; 3182400,297.15;
        3186000,296.85; 3189600,296.65; 3193200,297.45; 3196800,297.45; 3200400,
        297.55; 3204000,297.55; 3207600,297.65; 3211200,297.95; 3214800,297.95;
        3218400,298.05; 3222000,298.15; 3225600,298.55; 3229200,298.85; 3232800,
        298.85; 3236400,299.45; 3240000,298.55; 3243600,296.55; 3247200,297.25;
        3250800,297.05; 3254400,297.35; 3258000,298.05; 3261600,298.25; 3265200,
        298.35; 3268800,298.55; 3272400,298.25; 3276000,297.95; 3279600,298.45;
        3283200,298.55; 3286800,298.45; 3290400,298.85; 3294000,299.35; 3297600,
        299.35; 3301200,298.85; 3304800,298.45; 3308400,298.45; 3312000,299.55;
        3315600,300.25; 3319200,300.05; 3322800,299.85; 3326400,299.15; 3330000,
        298.45; 3333600,298.05; 3337200,297.95; 3340800,297.85; 3344400,298.25;
        3348000,298.65; 3351600,298.75; 3355200,298.85; 3358800,298.75; 3362400,
        299.35; 3366000,299.85; 3369600,299.55; 3373200,299.95; 3376800,300.45;
        3380400,300.05; 3384000,299.85; 3387600,300.35; 3391200,299.75; 3394800,
        298.85; 3398400,299.85; 3402000,300.75; 3405600,300.65; 3409200,300.15;
        3412800,299.55; 3416400,299.45; 3420000,298.95; 3423600,298.75; 3427200,
        298.75; 3430800,298.75; 3434400,298.95; 3438000,298.85; 3441600,298.35;
        3445200,297.95; 3448800,298.55; 3452400,298.85; 3456000,297.85; 3459600,
        298.15; 3463200,299.35; 3466800,299.35; 3470400,299.45; 3474000,299.85;
        3477600,299.55; 3481200,298.65; 3484800,299.35; 3488400,300.55; 3492000,
        300.45; 3495600,300.05; 3499200,299.65; 3502800,299.35; 3506400,299.15;
        3510000,298.75; 3513600,298.85; 3517200,298.75; 3520800,298.85; 3524400,
        299.25; 3528000,299.25; 3531600,298.95; 3535200,299.45; 3538800,299.65;
        3542400,299.45; 3546000,300.05; 3549600,300.25; 3553200,299.85; 3556800,
        299.85; 3560400,300.45; 3564000,300.05; 3567600,299.15; 3571200,300.35;
        3574800,300.95; 3578400,300.95; 3582000,300.85; 3585600,299.95; 3589200,
        299.65; 3592800,299.45; 3596400,299.05; 3600000,298.75; 3603600,298.95;
        3607200,298.95; 3610800,299.05; 3614400,299.05; 3618000,298.75; 3621600,
        299.55; 3625200,300.05; 3628800,299.45; 3632400,299.85; 3636000,300.25;
        3639600,299.95; 3643200,299.05; 3646800,299.85; 3650400,299.75; 3654000,
        298.85; 3657600,300.25; 3661200,300.85; 3664800,300.55; 3668400,300.35;
        3672000,299.95; 3675600,298.75; 3679200,298.65; 3682800,298.05; 3686400,
        297.95; 3690000,298.15; 3693600,298.55; 3697200,298.65; 3700800,298.55;
        3704400,298.45; 3708000,298.85; 3711600,299.25; 3715200,299.05; 3718800,
        299.45; 3722400,299.75; 3726000,299.85; 3729600,299.65; 3733200,299.45;
        3736800,299.55; 3740400,299.45; 3744000,299.95; 3747600,300.05; 3751200,
        299.35; 3754800,300.05; 3758400,299.05; 3762000,297.45; 3765600,298.35;
        3769200,297.55; 3772800,297.35; 3776400,297.85; 3780000,298.35; 3783600,
        298.65; 3787200,298.95; 3790800,299.35; 3794400,298.35; 3798000,298.85;
        3801600,299.15; 3805200,298.95; 3808800,298.65; 3812400,298.65; 3816000,
        298.75; 3819600,298.45; 3823200,298.45; 3826800,298.45; 3830400,299.15;
        3834000,299.35; 3837600,298.15; 3841200,298.15; 3844800,297.45; 3848400,
        297.35; 3852000,296.55; 3855600,296.55; 3859200,296.45; 3862800,296.45;
        3866400,296.55; 3870000,297.35; 3873600,296.75; 3877200,296.75; 3880800,
        297.45; 3884400,298.25; 3888000,297.15; 3891600,296.05; 3895200,296.95;
        3898800,297.15; 3902400,296.75; 3906000,296.85; 3909600,296.95; 3913200,
        297.65; 3916800,296.35; 3920400,297.45; 3924000,297.05; 3927600,297.85;
        3931200,297.05; 3934800,296.55; 3938400,296.65; 3942000,297.05; 3945600,
        296.85; 3949200,296.45; 3952800,296.75; 3956400,296.75; 3960000,295.65;
        3963600,296.05; 3967200,298.45; 3970800,298.45; 3974400,296.55; 3978000,
        296.75; 3981600,295.95; 3985200,297.05; 3988800,298.05; 3992400,297.95;
        3996000,296.85; 3999600,297.35; 4003200,296.95; 4006800,297.35; 4010400,
        297.25; 4014000,296.95; 4017600,298.05; 4021200,297.65; 4024800,297.35;
        4028400,297.25; 4032000,297.05; 4035600,296.55; 4039200,296.95; 4042800,
        297.55; 4046400,297.45; 4050000,296.75; 4053600,296.95; 4057200,297.15;
        4060800,296.35; 4064400,296.75; 4068000,297.45; 4071600,297.25; 4075200,
        297.05; 4078800,297.15; 4082400,296.95; 4086000,296.85; 4089600,296.75;
        4093200,299.25; 4096800,298.75; 4100400,298.55; 4104000,297.35; 4107600,
        299.05; 4111200,298.85; 4114800,296.45; 4118400,297.05; 4122000,296.55;
        4125600,296.15; 4129200,296.55; 4132800,296.65; 4136400,295.85; 4140000,
        296.05; 4143600,296.15; 4147200,296.85; 4150800,296.85; 4154400,297.05;
        4158000,297.15; 4161600,296.95; 4165200,296.85; 4168800,296.95; 4172400,
        296.85; 4176000,297.25; 4179600,297.95; 4183200,297.95; 4186800,297.45;
        4190400,296.55; 4194000,295.95; 4197600,296.15; 4201200,296.25; 4204800,
        296.05; 4208400,296.45; 4212000,296.65; 4215600,296.75; 4219200,297.35;
        4222800,297.15; 4226400,296.95; 4230000,296.95; 4233600,297.45; 4237200,
        297.45; 4240800,297.75; 4244400,297.65; 4248000,297.35; 4251600,297.25;
        4255200,297.35; 4258800,298.05; 4262400,296.75; 4266000,297.55; 4269600,
        297.85; 4273200,297.35; 4276800,296.95; 4280400,296.55; 4284000,296.65;
        4287600,296.45; 4291200,296.45; 4294800,296.45; 4298400,296.65; 4302000,
        296.75; 4305600,297.05; 4309200,296.65; 4312800,295.95; 4316400,296.55;
        4320000,296.75; 4323600,297.55; 4327200,298.45; 4330800,298.35; 4334400,
        297.95; 4338000,298.15; 4341600,298.45; 4345200,297.85; 4348800,298.85;
        4352400,298.75; 4356000,297.45; 4359600,297.45; 4363200,296.45; 4366800,
        296.25; 4370400,295.95; 4374000,295.95; 4377600,295.85; 4381200,295.95;
        4384800,296.35; 4388400,296.65; 4392000,296.95; 4395600,297.65; 4399200,
        297.75; 4402800,296.95; 4406400,297.65; 4410000,297.95; 4413600,297.85;
        4417200,297.65; 4420800,297.55; 4424400,297.85; 4428000,297.75; 4431600,
        297.65; 4435200,297.65; 4438800,298.15; 4442400,297.25; 4446000,297.35;
        4449600,296.55; 4453200,296.75; 4456800,296.55; 4460400,296.65; 4464000,
        296.45; 4467600,296.35; 4471200,296.45; 4474800,296.55; 4478400,297.05;
        4482000,296.95; 4485600,296.55; 4489200,297.55; 4492800,297.25; 4496400,
        297.15; 4500000,296.65; 4503600,296.75; 4507200,296.55; 4510800,296.85;
        4514400,297.15; 4518000,297.75; 4521600,296.65; 4525200,297.25; 4528800,
        297.15; 4532400,296.75; 4536000,296.65; 4539600,296.75; 4543200,296.75;
        4546800,296.65; 4550400,296.55; 4554000,296.55; 4557600,296.55; 4561200,
        296.85; 4564800,297.35; 4568400,296.95; 4572000,296.65; 4575600,296.95;
        4579200,297.05; 4582800,297.25; 4586400,297.65; 4590000,297.95; 4593600,
        297.85; 4597200,298.05; 4600800,298.05; 4604400,297.55; 4608000,298.85;
        4611600,298.95; 4615200,297.85; 4618800,297.95; 4622400,297.35; 4626000,
        297.05; 4629600,297.15; 4633200,296.85; 4636800,296.85; 4640400,297.05;
        4644000,296.95; 4647600,297.05; 4651200,297.15; 4654800,296.75; 4658400,
        297.25; 4662000,297.85; 4665600,296.85; 4669200,297.05; 4672800,297.95;
        4676400,297.75; 4680000,297.45; 4683600,297.65; 4687200,297.35; 4690800,
        297.35; 4694400,297.25; 4698000,298.95; 4701600,298.45; 4705200,298.25;
        4708800,297.35; 4712400,297.35; 4716000,296.75; 4719600,296.45; 4723200,
        297.95; 4726800,296.55; 4730400,296.75; 4734000,297.65; 4737600,296.55;
        4741200,296.65; 4744800,296.95; 4748400,297.15; 4752000,297.15; 4755600,
        297.15; 4759200,298.35; 4762800,298.25; 4766400,298.25; 4770000,298.35;
        4773600,297.85; 4777200,297.15; 4780800,298.05; 4784400,299.05; 4788000,
        298.25; 4791600,298.25; 4795200,296.85; 4798800,296.55; 4802400,296.65;
        4806000,296.65; 4809600,296.95; 4813200,296.75; 4816800,297.25; 4820400,
        297.45; 4824000,297.15; 4827600,298.05; 4831200,297.05; 4834800,297.45;
        4838400,296.75; 4842000,296.65; 4845600,297.15; 4849200,296.75; 4852800,
        296.65; 4856400,297.05; 4860000,297.25; 4863600,298.15; 4867200,296.85;
        4870800,297.35; 4874400,297.05; 4878000,296.75; 4881600,295.85; 4885200,
        296.05; 4888800,296.45; 4892400,295.35; 4896000,295.85; 4899600,295.95;
        4903200,296.05; 4906800,295.95; 4910400,296.05; 4914000,296.65; 4917600,
        296.95; 4921200,296.85; 4924800,296.85; 4928400,296.45; 4932000,297.35;
        4935600,298.15; 4939200,298.15; 4942800,297.75; 4946400,297.75; 4950000,
        298.25; 4953600,298.45; 4957200,298.75; 4960800,298.15; 4964400,298.45;
        4968000,297.15; 4971600,297.15; 4975200,296.45; 4978800,296.35; 4982400,
        296.45; 4986000,296.75; 4989600,296.65; 4993200,296.55; 4996800,296.75;
        5000400,296.75; 5004000,296.65; 5007600,297.35; 5011200,297.15; 5014800,
        296.15; 5018400,296.55; 5022000,296.45; 5025600,296.35; 5029200,296.65;
        5032800,296.45; 5036400,297.15; 5040000,297.05; 5043600,296.45; 5047200,
        296.45; 5050800,296.75; 5054400,295.95; 5058000,295.95; 5061600,296.45;
        5065200,295.75; 5068800,295.65; 5072400,296.15; 5076000,296.05; 5079600,
        296.05; 5083200,296.25; 5086800,296.65; 5090400,297.05; 5094000,297.55;
        5097600,298.25; 5101200,298.75; 5104800,299.15; 5108400,300.05; 5112000,
        300.45; 5115600,300.55; 5119200,300.25; 5122800,299.35; 5126400,300.05;
        5130000,300.35; 5133600,300.05; 5137200,300.25; 5140800,299.05; 5144400,
        299.05; 5148000,298.65; 5151600,297.85; 5155200,298.55; 5158800,298.55;
        5162400,298.55; 5166000,298.45; 5169600,298.85; 5173200,299.15; 5176800,
        299.45; 5180400,300.05; 5184000,299.75; 5187600,299.55; 5191200,299.75;
        5194800,299.55; 5198400,299.25; 5202000,299.25; 5205600,298.85; 5209200,
        298.55; 5212800,299.55; 5216400,300.25; 5220000,299.95; 5223600,299.45;
        5227200,299.05; 5230800,298.75; 5234400,298.55; 5238000,298.65; 5241600,
        298.45; 5245200,298.15; 5248800,298.15; 5252400,298.35; 5256000,298.35;
        5259600,298.35; 5263200,298.35; 5266800,298.35; 5270400,297.85; 5274000,
        298.05; 5277600,298.65; 5281200,298.25; 5284800,298.25; 5288400,298.75;
        5292000,298.75; 5295600,298.25; 5299200,299.05; 5302800,299.45; 5306400,
        299.05; 5310000,298.65; 5313600,298.15; 5317200,297.85; 5320800,297.85;
        5324400,297.45; 5328000,297.85; 5331600,298.35; 5335200,298.55; 5338800,
        298.35; 5342400,298.05; 5346000,297.65; 5349600,297.65; 5353200,297.85;
        5356800,297.25; 5360400,297.35; 5364000,298.05; 5367600,297.45; 5371200,
        297.25; 5374800,297.85; 5378400,297.65; 5382000,297.55; 5385600,298.55;
        5389200,299.55; 5392800,298.85; 5396400,298.25; 5400000,297.15; 5403600,
        297.45; 5407200,297.05; 5410800,297.05; 5414400,297.15; 5418000,297.15;
        5421600,297.05; 5425200,296.95; 5428800,297.35; 5432400,296.95; 5436000,
        296.85; 5439600,297.35; 5443200,297.05; 5446800,296.95; 5450400,297.15;
        5454000,297.75; 5457600,297.55; 5461200,296.85; 5464800,297.75; 5468400,
        296.85; 5472000,295.65; 5475600,296.95; 5479200,297.95; 5482800,297.15;
        5486400,296.95; 5490000,296.85; 5493600,296.65; 5497200,296.75; 5500800,
        298.25; 5504400,298.95; 5508000,297.25; 5511600,296.75; 5515200,296.85;
        5518800,296.15; 5522400,296.75; 5526000,296.95; 5529600,295.55; 5533200,
        296.15; 5536800,296.95; 5540400,296.75; 5544000,296.85; 5547600,297.15;
        5551200,296.65; 5554800,296.85; 5558400,297.45; 5562000,296.85; 5565600,
        296.85; 5569200,296.85; 5572800,295.85; 5576400,296.25; 5580000,296.45;
        5583600,295.95; 5587200,295.55; 5590800,295.65; 5594400,295.75; 5598000,
        296.05; 5601600,296.65; 5605200,296.55; 5608800,296.35; 5612400,296.15;
        5616000,295.85; 5619600,295.65; 5623200,296.25; 5626800,296.55; 5630400,
        296.55; 5634000,296.55; 5637600,296.45; 5641200,296.15; 5644800,296.45;
        5648400,296.45; 5652000,296.55; 5655600,296.65; 5659200,296.35; 5662800,
        296.05; 5666400,296.05; 5670000,295.95; 5673600,295.65; 5677200,295.95;
        5680800,295.95; 5684400,295.95; 5688000,296.45; 5691600,296.75; 5695200,
        296.55; 5698800,296.55; 5702400,296.75; 5706000,296.15; 5709600,296.05;
        5713200,296.65; 5716800,296.45; 5720400,296.35; 5724000,296.85; 5727600,
        297.55; 5731200,296.35; 5734800,296.35; 5738400,296.85; 5742000,296.15;
        5745600,296.55; 5749200,296.45; 5752800,296.15; 5756400,296.15; 5760000,
        296.15; 5763600,296.05; 5767200,296.15; 5770800,295.75; 5774400,295.85;
        5778000,296.35; 5781600,295.65; 5785200,295.85; 5788800,295.85; 5792400,
        295.95; 5796000,296.55; 5799600,296.65; 5803200,296.25; 5806800,296.35;
        5810400,296.15; 5814000,295.75; 5817600,297.15; 5821200,296.85; 5824800,
        296.35; 5828400,296.15; 5832000,296.05; 5835600,296.05; 5839200,295.95;
        5842800,295.65; 5846400,295.65; 5850000,295.75; 5853600,295.55; 5857200,
        295.65; 5860800,295.65; 5864400,295.45; 5868000,295.85; 5871600,295.85;
        5875200,296.15; 5878800,295.95; 5882400,296.25; 5886000,296.55; 5889600,
        296.65; 5893200,296.25; 5896800,296.35; 5900400,296.55; 5904000,295.05;
        5907600,295.65; 5911200,297.15; 5914800,296.65; 5918400,295.55; 5922000,
        296.15; 5925600,296.45; 5929200,297.25; 5932800,297.35; 5936400,296.25;
        5940000,295.85; 5943600,295.45; 5947200,295.75; 5950800,296.35; 5954400,
        296.05; 5958000,295.95; 5961600,295.95; 5965200,295.35; 5968800,295.65;
        5972400,296.05; 5976000,296.75; 5979600,296.45; 5983200,296.65; 5986800,
        294.85; 5990400,294.75; 5994000,296.05; 5997600,297.05; 6001200,296.45;
        6004800,296.25; 6008400,296.45; 6012000,296.15; 6015600,295.95; 6019200,
        295.95; 6022800,296.05; 6026400,295.95; 6030000,295.75; 6033600,295.45;
        6037200,295.45; 6040800,295.85; 6044400,295.75; 6048000,296.85; 6051600,
        297.15; 6055200,296.05; 6058800,296.05; 6062400,296.45; 6066000,296.65;
        6069600,296.35; 6073200,296.55; 6076800,296.35; 6080400,296.25; 6084000,
        296.55; 6087600,296.45; 6091200,295.95; 6094800,295.75; 6098400,295.85;
        6102000,295.75; 6105600,295.85; 6109200,295.75; 6112800,295.55; 6116400,
        295.75; 6120000,296.05; 6123600,295.75; 6127200,295.75; 6130800,295.55;
        6134400,296.25; 6138000,296.65; 6141600,297.05; 6145200,297.35; 6148800,
        296.75; 6152400,297.25; 6156000,297.45; 6159600,295.95; 6163200,296.65;
        6166800,297.35; 6170400,297.95; 6174000,297.95; 6177600,297.75; 6181200,
        298.05; 6184800,298.05; 6188400,296.55; 6192000,296.15; 6195600,296.25;
        6199200,296.55; 6202800,296.45; 6206400,295.85; 6210000,295.35; 6213600,
        294.85; 6217200,295.55; 6220800,295.95; 6224400,296.65; 6228000,296.85;
        6231600,296.85; 6235200,296.65; 6238800,296.65; 6242400,297.85; 6246000,
        298.15; 6249600,298.15; 6253200,298.55; 6256800,297.15; 6260400,296.65;
        6264000,295.75; 6267600,295.65; 6271200,295.85; 6274800,295.95; 6278400,
        295.65; 6282000,295.55; 6285600,295.85; 6289200,295.75; 6292800,295.95;
        6296400,296.45; 6300000,296.75; 6303600,296.65; 6307200,295.45; 6310800,
        296.55; 6314400,297.35; 6318000,297.15; 6321600,296.75; 6325200,296.65;
        6328800,296.25; 6332400,296.65; 6336000,296.85; 6339600,296.15; 6343200,
        295.95; 6346800,296.95; 6350400,296.65; 6354000,295.45; 6357600,295.75;
        6361200,297.35; 6364800,298.05; 6368400,297.05; 6372000,295.95; 6375600,
        295.45; 6379200,295.15; 6382800,295.35; 6386400,295.75; 6390000,295.95;
        6393600,295.95; 6397200,295.35; 6400800,295.75; 6404400,296.15; 6408000,
        297.05; 6411600,296.75; 6415200,296.45; 6418800,296.85; 6422400,296.45;
        6426000,296.95; 6429600,296.45; 6433200,296.65; 6436800,295.45; 6440400,
        295.85; 6444000,296.15; 6447600,295.65; 6451200,296.05; 6454800,295.85;
        6458400,295.95; 6462000,296.15; 6465600,296.55; 6469200,296.65; 6472800,
        296.75; 6476400,296.95; 6480000,296.65; 6483600,296.35; 6487200,297.15;
        6490800,297.05; 6494400,296.65; 6498000,297.25; 6501600,298.05; 6505200,
        297.75; 6508800,297.85; 6512400,297.35; 6516000,296.65; 6519600,296.65;
        6523200,295.95; 6526800,295.65; 6530400,295.55; 6534000,295.85; 6537600,
        295.75; 6541200,295.55; 6544800,295.85; 6548400,295.55; 6552000,295.55;
        6555600,295.55; 6559200,295.65; 6562800,296.15; 6566400,296.65; 6570000,
        296.45; 6573600,297.55; 6577200,297.15; 6580800,296.75; 6584400,296.75;
        6588000,296.35; 6591600,296.25; 6595200,296.65; 6598800,297.75; 6602400,
        297.35; 6606000,296.85; 6609600,295.65; 6613200,296.05; 6616800,296.05;
        6620400,295.85; 6624000,296.05; 6627600,296.05; 6631200,296.15; 6634800,
        296.45; 6638400,296.75; 6642000,296.85; 6645600,296.75; 6649200,297.35;
        6652800,297.25; 6656400,297.75; 6660000,298.65; 6663600,298.25; 6667200,
        298.15; 6670800,298.65; 6674400,298.65; 6678000,298.15; 6681600,298.95;
        6685200,299.15; 6688800,297.95; 6692400,297.65; 6696000,296.45; 6699600,
        296.15; 6703200,295.95; 6706800,295.95; 6710400,296.15; 6714000,295.95;
        6717600,295.75; 6721200,296.65; 6724800,296.95; 6728400,297.05; 6732000,
        297.55; 6735600,297.45; 6739200,297.05; 6742800,297.95; 6746400,298.95;
        6750000,299.15; 6753600,298.85; 6757200,298.65; 6760800,298.95; 6764400,
        299.15; 6768000,299.35; 6771600,299.35; 6775200,298.35; 6778800,297.75;
        6782400,296.55; 6786000,296.55; 6789600,296.55; 6793200,296.55; 6796800,
        296.25; 6800400,296.75; 6804000,296.45; 6807600,296.25; 6811200,296.35;
        6814800,296.65; 6818400,296.85; 6822000,297.45; 6825600,298.15; 6829200,
        298.35; 6832800,298.15; 6836400,298.15; 6840000,298.45; 6843600,298.75;
        6847200,298.45; 6850800,298.25; 6854400,298.85; 6858000,299.15; 6861600,
        297.85; 6865200,297.65; 6868800,296.45; 6872400,296.45; 6876000,296.45;
        6879600,296.35; 6883200,296.35; 6886800,296.35; 6890400,296.25; 6894000,
        295.75; 6897600,295.65; 6901200,295.55; 6904800,295.85; 6908400,296.25;
        6912000,297.65; 6915600,298.15; 6919200,298.25; 6922800,298.65; 6926400,
        298.55; 6930000,298.75; 6933600,298.65; 6937200,298.75; 6940800,298.15;
        6944400,298.65; 6948000,297.95; 6951600,297.65; 6955200,296.85; 6958800,
        297.05; 6962400,296.95; 6966000,296.55; 6969600,296.45; 6973200,296.15;
        6976800,296.45; 6980400,296.25; 6984000,296.15; 6987600,296.05; 6991200,
        296.05; 6994800,295.65; 6998400,295.75; 7002000,295.55; 7005600,295.75;
        7009200,296.05; 7012800,296.15; 7016400,296.25; 7020000,296.25; 7023600,
        296.35; 7027200,296.25; 7030800,295.75; 7034400,295.65; 7038000,296.35;
        7041600,295.95; 7045200,295.95; 7048800,296.15; 7052400,295.85; 7056000,
        296.05; 7059600,296.05; 7063200,295.75; 7066800,295.75; 7070400,296.25;
        7074000,296.35; 7077600,296.25; 7081200,296.25; 7084800,296.15; 7088400,
        295.65; 7092000,296.05; 7095600,296.15; 7099200,296.05; 7102800,296.25;
        7106400,296.45; 7110000,296.65; 7113600,296.55; 7117200,295.55; 7120800,
        296.05; 7124400,296.35; 7128000,296.55; 7131600,296.15; 7135200,296.25;
        7138800,296.45; 7142400,296.25; 7146000,296.05; 7149600,295.85; 7153200,
        295.85; 7156800,295.85; 7160400,295.75; 7164000,295.75; 7167600,295.35;
        7171200,295.65; 7174800,295.85; 7178400,296.45; 7182000,296.75; 7185600,
        297.15; 7189200,297.65; 7192800,297.75; 7196400,297.85; 7200000,297.35;
        7203600,296.85; 7207200,295.45; 7210800,295.65; 7214400,295.85; 7218000,
        295.65; 7221600,295.65; 7225200,295.55; 7228800,295.45; 7232400,295.65;
        7236000,295.55; 7239600,295.25; 7243200,295.25; 7246800,295.55; 7250400,
        296.05; 7254000,296.75; 7257600,296.95; 7261200,296.55; 7264800,296.75;
        7268400,296.35; 7272000,296.95; 7275600,297.15; 7279200,296.85; 7282800,
        297.55; 7286400,296.25; 7290000,296.55; 7293600,297.65; 7297200,297.25;
        7300800,296.85; 7304400,296.75; 7308000,296.65; 7311600,295.85; 7315200,
        296.15; 7318800,295.25; 7322400,295.05; 7326000,295.15; 7329600,295.15;
        7333200,295.15; 7336800,295.15; 7340400,295.15; 7344000,295.35; 7347600,
        295.65; 7351200,296.15; 7354800,296.55; 7358400,297.15; 7362000,296.95;
        7365600,296.65; 7369200,296.05; 7372800,296.25; 7376400,296.15; 7380000,
        295.65; 7383600,295.65; 7387200,295.85; 7390800,295.45; 7394400,295.65;
        7398000,295.45; 7401600,295.15; 7405200,295.15; 7408800,295.15; 7412400,
        295.15; 7416000,295.15; 7419600,295.25; 7423200,295.55; 7426800,296.15;
        7430400,296.85; 7434000,297.45; 7437600,297.45; 7441200,297.45; 7444800,
        297.95; 7448400,297.75; 7452000,297.15; 7455600,296.55; 7459200,296.65;
        7462800,296.95; 7466400,296.45; 7470000,296.65; 7473600,295.75; 7477200,
        295.65; 7480800,295.85; 7484400,296.15; 7488000,295.85; 7491600,295.85;
        7495200,295.75; 7498800,295.75; 7502400,296.05; 7506000,296.05; 7509600,
        295.95; 7513200,295.65; 7516800,295.65; 7520400,296.25; 7524000,296.35;
        7527600,296.25; 7531200,296.45; 7534800,296.55; 7538400,296.65; 7542000,
        295.75; 7545600,295.75; 7549200,296.55; 7552800,296.15; 7556400,296.05;
        7560000,295.65; 7563600,295.75; 7567200,295.95; 7570800,296.05; 7574400,
        295.95; 7578000,295.45; 7581600,295.55; 7585200,295.65; 7588800,295.55;
        7592400,295.55; 7596000,295.55; 7599600,295.55; 7603200,295.55; 7606800,
        295.15; 7610400,295.75; 7614000,296.05; 7617600,295.95; 7621200,295.55;
        7624800,295.25; 7628400,295.35; 7632000,296.35; 7635600,296.35; 7639200,
        296.75; 7642800,295.55; 7646400,295.35; 7650000,295.35; 7653600,295.75;
        7657200,294.85; 7660800,295.45; 7664400,295.75; 7668000,295.55; 7671600,
        295.55; 7675200,295.55; 7678800,295.55; 7682400,294.95; 7686000,295.25;
        7689600,295.65; 7693200,295.95; 7696800,296.05; 7700400,295.75; 7704000,
        295.75; 7707600,295.85; 7711200,296.05; 7714800,296.05; 7718400,295.95;
        7722000,296.05; 7725600,295.95; 7729200,295.75; 7732800,295.65; 7736400,
        295.95; 7740000,295.85; 7743600,295.65; 7747200,295.65; 7750800,295.65;
        7754400,295.25; 7758000,295.15; 7761600,295.15; 7765200,295.45; 7768800,
        297.65; 7772400,296.85; 7776000,295.65; 7779600,295.85; 7783200,296.15;
        7786800,295.95; 7790400,296.25; 7794000,296.45; 7797600,296.85; 7801200,
        296.45; 7804800,297.65; 7808400,297.75; 7812000,296.65; 7815600,296.55;
        7819200,296.75; 7822800,297.05; 7826400,296.85; 7830000,296.95; 7833600,
        296.35; 7837200,296.35; 7840800,296.45; 7844400,296.15; 7848000,296.15;
        7851600,296.25; 7855200,296.75; 7858800,296.65; 7862400,296.35; 7866000,
        296.85; 7869600,296.45; 7873200,296.45; 7876800,296.45; 7880400,295.95;
        7884000,296.25; 7887600,298.15; 7891200,298.65; 7894800,298.35; 7898400,
        298.65; 7902000,297.05; 7905600,297.05; 7909200,297.65; 7912800,297.35;
        7916400,296.85; 7920000,296.75; 7923600,296.55; 7927200,296.25; 7930800,
        296.05; 7934400,296.15; 7938000,295.95; 7941600,296.65; 7945200,296.35;
        7948800,296.95; 7952400,297.55; 7956000,296.95; 7959600,296.75; 7963200,
        297.15; 7966800,296.75; 7970400,296.45; 7974000,296.55; 7977600,296.75;
        7981200,296.85; 7984800,297.25; 7988400,296.55; 7992000,296.45; 7995600,
        296.65; 7999200,296.45; 8002800,296.65; 8006400,296.15; 8010000,296.15;
        8013600,296.05; 8017200,296.55; 8020800,296.25; 8024400,296.25; 8028000,
        296.55; 8031600,296.55; 8035200,296.45; 8038800,296.55; 8042400,296.65;
        8046000,296.25; 8049600,296.55; 8053200,296.75; 8056800,296.35; 8060400,
        296.55; 8064000,296.25; 8067600,296.35; 8071200,296.45; 8074800,296.25;
        8078400,296.15; 8082000,296.05; 8085600,295.95; 8089200,295.85; 8092800,
        295.95; 8096400,295.85; 8100000,295.85; 8103600,296.25; 8107200,296.35;
        8110800,296.05; 8114400,296.35; 8118000,296.65; 8121600,296.25; 8125200,
        295.95; 8128800,296.45; 8132400,296.25; 8136000,295.95; 8139600,296.25;
        8143200,296.65; 8146800,295.85; 8150400,296.95; 8154000,296.85; 8157600,
        296.25; 8161200,296.35; 8164800,295.75; 8168400,295.75; 8172000,295.85;
        8175600,295.65; 8179200,295.95; 8182800,296.15; 8186400,296.15; 8190000,
        296.15; 8193600,295.95; 8197200,296.05; 8200800,296.25; 8204400,295.95;
        8208000,295.95; 8211600,296.55; 8215200,296.45; 8218800,296.35; 8222400,
        296.35; 8226000,296.35; 8229600,296.95; 8233200,296.75; 8236800,295.85;
        8240400,296.65; 8244000,296.45; 8247600,296.15; 8251200,295.55; 8254800,
        295.95; 8258400,295.95; 8262000,295.55; 8265600,295.75; 8269200,295.85;
        8272800,295.95; 8276400,296.05; 8280000,296.05; 8283600,296.05; 8287200,
        295.85; 8290800,295.85; 8294400,295.75; 8298000,296.35; 8301600,296.45;
        8305200,296.05; 8308800,296.25; 8312400,295.95; 8316000,296.25; 8319600,
        296.55; 8323200,295.95; 8326800,296.45; 8330400,296.55; 8334000,296.15;
        8337600,295.65; 8341200,295.85; 8344800,295.75; 8348400,295.25; 8352000,
        295.45; 8355600,295.65; 8359200,295.65; 8362800,295.65; 8366400,295.55;
        8370000,295.55; 8373600,296.05; 8377200,296.45; 8380800,296.25; 8384400,
        296.15; 8388000,296.05; 8391600,296.05; 8395200,296.35; 8398800,296.45;
        8402400,297.05; 8406000,296.85; 8409600,295.95; 8413200,296.45; 8416800,
        296.05; 8420400,295.95; 8424000,295.45; 8427600,295.65; 8431200,295.45;
        8434800,295.15; 8438400,295.15; 8442000,295.15; 8445600,295.15; 8449200,
        295.15; 8452800,295.15; 8456400,295.15; 8460000,295.25; 8463600,295.25;
        8467200,295.55; 8470800,296.45; 8474400,296.55; 8478000,296.35; 8481600,
        296.25; 8485200,296.15; 8488800,296.55; 8492400,296.75; 8496000,296.85;
        8499600,296.25; 8503200,295.85; 8506800,295.65; 8510400,295.25; 8514000,
        295.45; 8517600,295.35; 8521200,295.25; 8524800,295.45; 8528400,295.65;
        8532000,295.35; 8535600,295.35; 8539200,295.35; 8542800,295.35; 8546400,
        295.35; 8550000,295.25; 8553600,295.15; 8557200,295.45; 8560800,295.85;
        8564400,295.95; 8568000,295.85; 8571600,295.75; 8575200,295.65; 8578800,
        295.15; 8582400,294.55; 8586000,294.85; 8589600,295.75; 8593200,295.75;
        8596800,295.25; 8600400,295.65; 8604000,295.75; 8607600,295.35; 8611200,
        295.45; 8614800,295.25; 8618400,294.95; 8622000,294.95; 8625600,294.95;
        8629200,295.05; 8632800,295.45; 8636400,295.85; 8640000,295.75; 8643600,
        295.65; 8647200,295.85; 8650800,295.65; 8654400,295.95; 8658000,295.85;
        8661600,295.95; 8665200,295.95; 8668800,295.35; 8672400,295.45; 8676000,
        295.75; 8679600,295.65; 8683200,295.45; 8686800,295.15; 8690400,295.15;
        8694000,295.05; 8697600,295.05; 8701200,295.05; 8704800,295.05; 8708400,
        295.05; 8712000,295.15; 8715600,295.15; 8719200,295.15; 8722800,295.15;
        8726400,295.15; 8730000,294.95; 8733600,295.25; 8737200,295.75; 8740800,
        295.65; 8744400,295.35; 8748000,294.95; 8751600,294.95; 8755200,295.25;
        8758800,295.45; 8762400,295.45; 8766000,295.35; 8769600,295.45; 8773200,
        295.65; 8776800,295.35; 8780400,295.25; 8784000,295.05; 8787600,295.05;
        8791200,294.95; 8794800,295.05; 8798400,295.05; 8802000,295.05; 8805600,
        295.05; 8809200,295.05; 8812800,295.05; 8816400,294.95; 8820000,295.55;
        8823600,295.85; 8827200,295.95; 8830800,296.05; 8834400,295.95; 8838000,
        295.75; 8841600,295.25; 8845200,296.45; 8848800,296.25; 8852400,296.35;
        8856000,295.85; 8859600,296.15; 8863200,296.15; 8866800,296.65; 8870400,
        296.55; 8874000,296.45; 8877600,296.45; 8881200,296.45; 8884800,295.95;
        8888400,295.75; 8892000,295.75; 8895600,295.85; 8899200,295.55; 8902800,
        295.75; 8906400,295.75; 8910000,296.15; 8913600,296.25; 8917200,296.25;
        8920800,295.85; 8924400,295.75; 8928000,297.05; 8931600,297.15; 8935200,
        296.35; 8938800,296.15; 8942400,296.35; 8946000,296.35; 8949600,296.05;
        8953200,295.95; 8956800,296.05; 8960400,296.15; 8964000,296.45; 8967600,
        296.65; 8971200,296.55; 8974800,296.35; 8978400,296.25; 8982000,296.05;
        8985600,296.45; 8989200,296.95; 8992800,296.65; 8996400,296.85; 9000000,
        297.05; 9003600,297.45; 9007200,297.95; 9010800,296.75; 9014400,297.15;
        9018000,297.45; 9021600,296.75; 9025200,296.45; 9028800,297.35; 9032400,
        297.45; 9036000,296.65; 9039600,296.35; 9043200,296.95; 9046800,296.95;
        9050400,297.65; 9054000,297.75; 9057600,297.35; 9061200,296.85; 9064800,
        295.85; 9068400,295.25; 9072000,296.15; 9075600,297.05; 9079200,297.45;
        9082800,297.25; 9086400,297.25; 9090000,297.15; 9093600,296.75; 9097200,
        296.85; 9100800,298.65; 9104400,298.15; 9108000,296.85; 9111600,295.95;
        9115200,296.15; 9118800,296.65; 9122400,296.45; 9126000,296.05; 9129600,
        295.45; 9133200,295.45; 9136800,295.45; 9140400,295.45; 9144000,295.45;
        9147600,295.45; 9151200,295.55; 9154800,295.75; 9158400,296.15; 9162000,
        296.95; 9165600,297.25; 9169200,297.35; 9172800,297.95; 9176400,297.95;
        9180000,297.75; 9183600,297.65; 9187200,297.25; 9190800,295.95; 9194400,
        295.75; 9198000,295.55; 9201600,295.75; 9205200,295.65; 9208800,295.55;
        9212400,295.25; 9216000,295.25; 9219600,295.25; 9223200,295.25; 9226800,
        295.25; 9230400,295.25; 9234000,295.35; 9237600,295.35; 9241200,295.35;
        9244800,295.45; 9248400,295.65; 9252000,296.15; 9255600,296.25; 9259200,
        296.25; 9262800,296.35; 9266400,296.15; 9270000,295.85; 9273600,295.75;
        9277200,295.75; 9280800,295.85; 9284400,296.15; 9288000,295.35; 9291600,
        295.85; 9295200,296.25; 9298800,296.15; 9302400,295.35; 9306000,295.75;
        9309600,295.45; 9313200,295.45; 9316800,295.45; 9320400,295.25; 9324000,
        295.45; 9327600,295.45; 9331200,295.65; 9334800,295.85; 9338400,296.05;
        9342000,296.05; 9345600,296.55; 9349200,296.85; 9352800,297.25; 9356400,
        296.25; 9360000,295.75; 9363600,298.25; 9367200,297.35; 9370800,295.65;
        9374400,296.25; 9378000,297.05; 9381600,297.15; 9385200,295.95; 9388800,
        296.25; 9392400,296.15; 9396000,296.45; 9399600,295.45; 9403200,295.35;
        9406800,295.25; 9410400,295.35; 9414000,295.75; 9417600,295.75; 9421200,
        296.55; 9424800,296.55; 9428400,296.55; 9432000,296.55; 9435600,295.95;
        9439200,295.85; 9442800,295.45; 9446400,296.15; 9450000,296.55; 9453600,
        296.65; 9457200,296.45; 9460800,296.25; 9464400,296.45; 9468000,295.85;
        9471600,295.15; 9475200,295.25; 9478800,295.45; 9482400,295.55; 9486000,
        295.45; 9489600,295.45; 9493200,295.05; 9496800,295.35; 9500400,296.05;
        9504000,296.35; 9507600,296.25; 9511200,296.15; 9514800,296.25; 9518400,
        296.35; 9522000,296.35; 9525600,296.85; 9529200,296.15; 9532800,295.75;
        9536400,296.35; 9540000,295.15; 9543600,295.75; 9547200,295.35; 9550800,
        295.55; 9554400,295.65; 9558000,295.25; 9561600,295.35; 9565200,295.65;
        9568800,295.35; 9572400,295.25; 9576000,295.45; 9579600,295.75; 9583200,
        296.15; 9586800,296.55; 9590400,296.35; 9594000,296.55; 9597600,296.75;
        9601200,296.55; 9604800,296.55; 9608400,296.55; 9612000,296.75; 9615600,
        297.05; 9619200,295.45; 9622800,295.75; 9626400,295.45; 9630000,295.85;
        9633600,295.45; 9637200,295.45; 9640800,295.55; 9644400,295.25; 9648000,
        295.35; 9651600,295.75; 9655200,295.15; 9658800,295.05; 9662400,295.45;
        9666000,295.55; 9669600,295.85; 9673200,296.25; 9676800,296.15; 9680400,
        296.25; 9684000,296.35; 9687600,296.45; 9691200,296.35; 9694800,296.35;
        9698400,296.95; 9702000,296.75; 9705600,295.65; 9709200,295.95; 9712800,
        295.75; 9716400,295.85; 9720000,295.25; 9723600,295.65; 9727200,295.65;
        9730800,295.05; 9734400,295.25; 9738000,295.45; 9741600,295.35; 9745200,
        295.35; 9748800,295.35; 9752400,295.35; 9756000,295.35; 9759600,295.45;
        9763200,295.95; 9766800,296.35; 9770400,296.75; 9774000,296.45; 9777600,
        295.95; 9781200,296.95; 9784800,297.35; 9788400,297.15; 9792000,295.65;
        9795600,295.35; 9799200,295.75; 9802800,295.55; 9806400,295.55; 9810000,
        295.25; 9813600,295.45; 9817200,295.25; 9820800,295.15; 9824400,295.45;
        9828000,295.35; 9831600,295.25; 9835200,295.25; 9838800,295.25; 9842400,
        295.25; 9846000,295.25; 9849600,295.35; 9853200,295.55; 9856800,296.05;
        9860400,296.25; 9864000,296.25; 9867600,296.45; 9871200,296.45; 9874800,
        296.35; 9878400,296.45; 9882000,296.25; 9885600,295.75; 9889200,295.65;
        9892800,295.65; 9896400,295.65; 9900000,295.75; 9903600,295.35; 9907200,
        295.35; 9910800,295.35; 9914400,295.25; 9918000,295.45; 9921600,295.45;
        9925200,295.45; 9928800,295.65; 9932400,296.05; 9936000,296.05; 9939600,
        296.35; 9943200,296.45; 9946800,296.25; 9950400,296.05; 9954000,296.15;
        9957600,296.85; 9961200,296.95; 9964800,294.95; 9968400,295.25; 9972000,
        295.55; 9975600,295.75; 9979200,295.45; 9982800,295.15; 9986400,295.55;
        9990000,295.25; 9993600,295.45; 9997200,295.75; 10000800,295.55;
        10004400,295.45; 10008000,295.45; 10011600,295.45; 10015200,295.25;
        10018800,295.25; 10022400,295.25; 10026000,295.05; 10029600,295.45;
        10033200,295.65; 10036800,295.75; 10040400,296.05; 10044000,296.05;
        10047600,295.95; 10051200,295.85; 10054800,296.35; 10058400,295.75;
        10062000,295.75; 10065600,295.35; 10069200,295.35; 10072800,295.55;
        10076400,295.65; 10080000,295.65; 10083600,295.35; 10087200,295.05;
        10090800,295.05; 10094400,295.05; 10098000,295.05; 10101600,295.25;
        10105200,295.55; 10108800,295.35; 10112400,296.55; 10116000,296.25;
        10119600,295.35; 10123200,295.45; 10126800,295.85; 10130400,295.85;
        10134000,295.25; 10137600,294.45; 10141200,295.05; 10144800,295.05;
        10148400,295.15; 10152000,294.95; 10155600,295.15; 10159200,295.45;
        10162800,295.45; 10166400,295.25; 10170000,295.15; 10173600,294.85;
        10177200,294.85; 10180800,294.85; 10184400,295.05; 10188000,295.35;
        10191600,295.65; 10195200,295.85; 10198800,295.65; 10202400,295.85;
        10206000,296.05; 10209600,295.85; 10213200,295.65; 10216800,295.95;
        10220400,295.85; 10224000,295.95; 10227600,296.45; 10231200,296.05;
        10234800,295.75; 10238400,295.55; 10242000,295.95; 10245600,295.65;
        10249200,295.55; 10252800,295.85; 10256400,295.95; 10260000,295.95;
        10263600,295.75; 10267200,295.65; 10270800,295.45; 10274400,295.65;
        10278000,295.45; 10281600,295.65; 10285200,296.15; 10288800,296.35;
        10292400,296.25; 10296000,295.95; 10299600,296.05; 10303200,296.65;
        10306800,296.55; 10310400,296.35; 10314000,295.25; 10317600,295.65;
        10321200,295.75; 10324800,295.75; 10328400,296.35; 10332000,296.15;
        10335600,295.45; 10339200,295.35; 10342800,295.35; 10346400,295.35;
        10350000,295.35; 10353600,295.35; 10357200,295.35; 10360800,295.35;
        10364400,295.35; 10368000,295.25; 10371600,295.25; 10375200,295.95;
        10378800,295.75; 10382400,295.75; 10386000,295.65; 10389600,295.95;
        10393200,295.85; 10396800,295.55; 10400400,295.75; 10404000,295.75;
        10407600,295.65; 10411200,295.65; 10414800,295.85; 10418400,296.35;
        10422000,295.35; 10425600,295.15; 10429200,295.15; 10432800,295.15;
        10436400,295.15; 10440000,295.15; 10443600,295.15; 10447200,295.15;
        10450800,295.15; 10454400,294.95; 10458000,295.35; 10461600,295.85;
        10465200,296.15; 10468800,296.25; 10472400,296.15; 10476000,296.25;
        10479600,296.25; 10483200,296.15; 10486800,296.15; 10490400,295.05;
        10494000,295.55; 10497600,295.55; 10501200,295.05; 10504800,295.05;
        10508400,294.95; 10512000,294.95; 10515600,295.25; 10519200,295.15;
        10522800,295.15; 10526400,295.15; 10530000,295.15; 10533600,295.15;
        10537200,295.15; 10540800,295.15; 10544400,295.05; 10548000,295.35;
        10551600,295.65; 10555200,295.35; 10558800,294.75; 10562400,294.45;
        10566000,294.85; 10569600,295.65; 10573200,296.75; 10576800,296.15;
        10580400,295.25; 10584000,295.05; 10587600,295.15; 10591200,295.15;
        10594800,295.15; 10598400,295.15; 10602000,295.15; 10605600,295.15;
        10609200,295.15; 10612800,295.15; 10616400,295.15; 10620000,295.15;
        10623600,295.15; 10627200,294.95; 10630800,295.45; 10634400,296.25;
        10638000,295.95; 10641600,295.55; 10645200,295.95; 10648800,295.65;
        10652400,296.05; 10656000,297.55; 10659600,297.25; 10663200,296.15;
        10666800,295.55; 10670400,295.85; 10674000,295.75; 10677600,295.25;
        10681200,295.05; 10684800,294.85; 10688400,294.95; 10692000,295.15;
        10695600,295.35; 10699200,295.35; 10702800,295.35; 10706400,295.65;
        10710000,295.95; 10713600,296.05; 10717200,296.05; 10720800,296.15;
        10724400,296.15; 10728000,296.05; 10731600,296.15; 10735200,296.55;
        10738800,296.35; 10742400,295.45; 10746000,296.25; 10749600,296.15;
        10753200,295.75; 10756800,295.45; 10760400,295.95; 10764000,295.35;
        10767600,295.45; 10771200,295.85; 10774800,295.35; 10778400,295.25;
        10782000,295.25; 10785600,295.25; 10789200,295.25; 10792800,295.25;
        10796400,295.25; 10800000,295.15; 10803600,295.35; 10807200,295.75;
        10810800,295.95; 10814400,295.95; 10818000,296.15; 10821600,295.55;
        10825200,294.65; 10828800,295.35; 10832400,296.65; 10836000,296.45;
        10839600,295.75; 10843200,295.65; 10846800,295.95; 10850400,295.55;
        10854000,295.05; 10857600,294.95; 10861200,295.05; 10864800,295.05;
        10868400,295.05; 10872000,295.15; 10875600,295.15; 10879200,295.15;
        10882800,295.15; 10886400,295.15; 10890000,295.45; 10893600,295.95;
        10897200,295.95; 10900800,295.15; 10904400,295.45; 10908000,295.95;
        10911600,295.65; 10915200,295.65; 10918800,295.65; 10922400,295.15;
        10926000,295.45; 10929600,295.15; 10933200,294.85; 10936800,295.35;
        10940400,295.25; 10944000,295.05; 10947600,295.45; 10951200,295.25;
        10954800,295.25; 10958400,295.35; 10962000,295.35; 10965600,295.35;
        10969200,295.35; 10972800,295.35; 10976400,295.05; 10980000,295.75;
        10983600,295.95; 10987200,295.95; 10990800,295.25; 10994400,295.55;
        10998000,295.45; 11001600,295.45; 11005200,295.45; 11008800,295.45;
        11012400,295.45; 11016000,295.45; 11019600,295.35; 11023200,295.35;
        11026800,295.35; 11030400,295.35; 11034000,295.35; 11037600,295.35;
        11041200,295.35; 11044800,295.35; 11048400,295.35; 11052000,295.35;
        11055600,295.35; 11059200,295.35; 11062800,295.25; 11066400,295.15;
        11070000,295.65; 11073600,295.65; 11077200,295.45; 11080800,295.25;
        11084400,295.25; 11088000,295.25; 11091600,295.25; 11095200,295.25;
        11098800,295.25; 11102400,295.25; 11106000,295.25; 11109600,295.25;
        11113200,295.35; 11116800,295.35; 11120400,295.35; 11124000,295.35;
        11127600,295.35; 11131200,295.35; 11134800,295.35; 11138400,295.35;
        11142000,295.35; 11145600,295.35; 11149200,295.35; 11152800,295.05;
        11156400,295.15; 11160000,295.55; 11163600,295.25; 11167200,295.15;
        11170800,295.15; 11174400,295.15; 11178000,295.15; 11181600,295.15;
        11185200,295.15; 11188800,295.15; 11192400,294.85; 11196000,294.75;
        11199600,294.65; 11203200,294.65; 11206800,294.75; 11210400,294.75;
        11214000,294.75; 11217600,294.85; 11221200,294.85; 11224800,294.95;
        11228400,294.95; 11232000,294.95; 11235600,294.85; 11239200,294.95;
        11242800,295.25; 11246400,295.25; 11250000,295.35; 11253600,295.15;
        11257200,295.15; 11260800,294.55; 11264400,294.45; 11268000,294.55;
        11271600,294.55; 11275200,294.55; 11278800,294.65; 11282400,294.65;
        11286000,294.65; 11289600,294.65; 11293200,294.75; 11296800,294.75;
        11300400,294.75; 11304000,294.85; 11307600,294.85; 11311200,294.85;
        11314800,294.95; 11318400,294.95; 11322000,294.75; 11325600,295.05;
        11329200,295.45; 11332800,295.65; 11336400,294.85; 11340000,294.35;
        11343600,294.35; 11347200,294.45; 11350800,294.55; 11354400,294.55;
        11358000,294.55; 11361600,294.65; 11365200,294.65; 11368800,294.65;
        11372400,294.65; 11376000,294.65; 11379600,294.75; 11383200,294.75;
        11386800,294.75; 11390400,294.85; 11394000,294.85; 11397600,294.95;
        11401200,294.95; 11404800,294.95; 11408400,294.95; 11412000,294.75;
        11415600,294.95; 11419200,295.35; 11422800,295.25; 11426400,295.15;
        11430000,295.15; 11433600,295.15; 11437200,295.15; 11440800,295.15;
        11444400,295.15; 11448000,295.15; 11451600,295.15; 11455200,295.15;
        11458800,295.15; 11462400,295.15; 11466000,295.15; 11469600,295.15;
        11473200,295.15; 11476800,295.15; 11480400,295.15; 11484000,295.25;
        11487600,295.25; 11491200,295.25; 11494800,294.85; 11498400,295.25;
        11502000,295.75; 11505600,295.25; 11509200,294.75; 11512800,294.65;
        11516400,294.45; 11520000,294.45; 11523600,294.75; 11527200,294.85;
        11530800,294.75; 11534400,294.95; 11538000,295.15; 11541600,294.65;
        11545200,294.55; 11548800,294.55; 11552400,294.55; 11556000,294.65;
        11559600,294.65; 11563200,294.75; 11566800,294.75; 11570400,294.75;
        11574000,294.85; 11577600,294.85; 11581200,294.75; 11584800,295.35;
        11588400,295.75; 11592000,295.25; 11595600,295.05; 11599200,294.85;
        11602800,294.75; 11606400,295.15; 11610000,295.75; 11613600,295.05;
        11617200,294.85; 11620800,294.85; 11624400,294.95; 11628000,294.95;
        11631600,295.05; 11635200,295.05; 11638800,295.05; 11642400,295.05;
        11646000,295.05; 11649600,295.15; 11653200,295.15; 11656800,295.15;
        11660400,295.15; 11664000,295.15; 11667600,294.95; 11671200,295.35;
        11674800,295.55; 11678400,295.35; 11682000,294.65; 11685600,294.55;
        11689200,294.65; 11692800,295.05; 11696400,295.45; 11700000,295.55;
        11703600,295.55; 11707200,295.35; 11710800,294.85; 11714400,295.25;
        11718000,295.25; 11721600,295.05; 11725200,295.15; 11728800,294.95;
        11732400,294.85; 11736000,294.85; 11739600,294.75; 11743200,294.65;
        11746800,294.75; 11750400,294.75; 11754000,294.75; 11757600,294.75;
        11761200,294.75; 11764800,294.75; 11768400,294.75; 11772000,294.75;
        11775600,294.75; 11779200,294.75; 11782800,294.75; 11786400,294.75;
        11790000,294.75; 11793600,294.75; 11797200,294.75; 11800800,294.75;
        11804400,294.75; 11808000,294.75; 11811600,294.75; 11815200,294.75;
        11818800,294.75; 11822400,294.75; 11826000,294.75; 11829600,294.75;
        11833200,294.75; 11836800,294.75; 11840400,294.75; 11844000,294.75;
        11847600,294.75; 11851200,294.75; 11854800,294.75; 11858400,294.75;
        11862000,294.75; 11865600,294.75; 11869200,294.75; 11872800,294.75;
        11876400,294.75; 11880000,294.75; 11883600,294.75; 11887200,294.75;
        11890800,294.75; 11894400,294.75; 11898000,294.75; 11901600,294.75;
        11905200,294.75; 11908800,294.75; 11912400,294.75; 11916000,294.75;
        11919600,294.75; 11923200,294.75; 11926800,294.75; 11930400,294.75;
        11934000,294.75; 11937600,294.75; 11941200,294.75; 11944800,294.75;
        11948400,294.75; 11952000,294.75; 11955600,294.75; 11959200,294.75;
        11962800,294.75; 11966400,294.75; 11970000,294.75; 11973600,294.75;
        11977200,294.75; 11980800,294.75; 11984400,294.75; 11988000,294.75;
        11991600,294.75; 11995200,294.75; 11998800,294.75; 12002400,294.75;
        12006000,294.75; 12009600,294.75; 12013200,294.75; 12016800,294.75;
        12020400,294.75; 12024000,294.75; 12027600,294.75; 12031200,294.75;
        12034800,294.75; 12038400,294.75; 12042000,294.75; 12045600,294.75;
        12049200,294.75; 12052800,294.75; 12056400,294.75; 12060000,294.75;
        12063600,294.75; 12067200,294.75; 12070800,294.75; 12074400,294.75;
        12078000,294.75; 12081600,294.75; 12085200,294.75; 12088800,294.75;
        12092400,294.75; 12096000,294.75; 12099600,294.75; 12103200,294.75;
        12106800,294.75; 12110400,294.75; 12114000,294.75; 12117600,294.75;
        12121200,294.75; 12124800,294.75; 12128400,294.75; 12132000,294.75;
        12135600,294.75; 12139200,294.75; 12142800,294.75; 12146400,294.75;
        12150000,294.75; 12153600,294.75; 12157200,294.75; 12160800,294.75;
        12164400,294.75; 12168000,294.75; 12171600,294.75; 12175200,294.75;
        12178800,294.75; 12182400,294.75; 12186000,294.75; 12189600,294.75;
        12193200,294.75; 12196800,294.75; 12200400,294.75; 12204000,294.75;
        12207600,294.75; 12211200,294.75; 12214800,294.75; 12218400,294.75;
        12222000,294.75; 12225600,294.75; 12229200,294.75; 12232800,294.75;
        12236400,294.75; 12240000,294.75; 12243600,294.75; 12247200,294.75;
        12250800,294.75; 12254400,294.75; 12258000,294.75; 12261600,294.75;
        12265200,294.75; 12268800,294.75; 12272400,294.75; 12276000,294.75;
        12279600,294.75; 12283200,294.75; 12286800,294.75; 12290400,294.75;
        12294000,294.75; 12297600,294.75; 12301200,294.75; 12304800,294.75;
        12308400,294.75; 12312000,294.75; 12315600,294.75; 12319200,294.75;
        12322800,294.75; 12326400,294.75; 12330000,294.75; 12333600,294.75;
        12337200,294.75; 12340800,294.75; 12344400,294.75; 12348000,294.75;
        12351600,294.75; 12355200,294.75; 12358800,294.75; 12362400,294.75;
        12366000,294.75; 12369600,294.75; 12373200,294.75; 12376800,294.75;
        12380400,294.75; 12384000,294.75; 12387600,294.75; 12391200,294.75;
        12394800,294.75; 12398400,294.75; 12402000,294.75; 12405600,294.75;
        12409200,294.75; 12412800,294.75; 12416400,294.75; 12420000,294.75;
        12423600,294.75; 12427200,294.75; 12430800,294.75; 12434400,294.75;
        12438000,294.75; 12441600,294.75; 12445200,294.75; 12448800,294.75;
        12452400,294.75; 12456000,294.75; 12459600,294.75; 12463200,294.75;
        12466800,294.75; 12470400,294.75; 12474000,294.75; 12477600,294.75;
        12481200,294.75; 12484800,294.75; 12488400,294.75; 12492000,294.75;
        12495600,294.75; 12499200,294.75; 12502800,294.75; 12506400,294.75;
        12510000,294.75; 12513600,294.75; 12517200,294.75; 12520800,294.75;
        12524400,294.75; 12528000,294.75; 12531600,294.75; 12535200,294.75;
        12538800,294.75; 12542400,294.75; 12546000,294.75; 12549600,294.75;
        12553200,294.75; 12556800,294.75; 12560400,294.75; 12564000,294.75;
        12567600,294.75; 12571200,294.75; 12574800,294.75; 12578400,294.75;
        12582000,294.75; 12585600,294.75; 12589200,294.75; 12592800,294.75;
        12596400,294.75; 12600000,294.75; 12603600,294.75; 12607200,294.75;
        12610800,294.75; 12614400,294.75; 12618000,294.75; 12621600,294.75;
        12625200,294.75; 12628800,294.75; 12632400,294.75; 12636000,294.75;
        12639600,294.75; 12643200,294.75; 12646800,294.75; 12650400,294.75;
        12654000,294.75; 12657600,294.75; 12661200,294.75; 12664800,294.75;
        12668400,294.75; 12672000,294.75; 12675600,294.75; 12679200,294.75;
        12682800,294.75; 12686400,294.75; 12690000,294.75; 12693600,294.75;
        12697200,294.75; 12700800,294.75; 12704400,294.75; 12708000,294.75;
        12711600,294.75; 12715200,294.75; 12718800,294.75; 12722400,294.75;
        12726000,294.75; 12729600,294.75; 12733200,294.75; 12736800,294.75;
        12740400,294.75; 12744000,294.75; 12747600,294.75; 12751200,294.75;
        12754800,294.75; 12758400,294.75; 12762000,294.75; 12765600,294.75;
        12769200,294.75; 12772800,294.75; 12776400,294.75; 12780000,294.75;
        12783600,294.75; 12787200,294.75; 12790800,294.75; 12794400,294.75;
        12798000,294.75; 12801600,294.75; 12805200,294.75; 12808800,294.75;
        12812400,294.75; 12816000,294.75; 12819600,294.75; 12823200,294.75;
        12826800,294.75; 12830400,294.75; 12834000,294.75; 12837600,294.75;
        12841200,294.75; 12844800,294.75; 12848400,294.75; 12852000,294.75;
        12855600,294.75; 12859200,294.75; 12862800,294.75; 12866400,294.75;
        12870000,294.75; 12873600,294.75; 12877200,294.75; 12880800,294.75;
        12884400,294.75; 12888000,294.75; 12891600,294.75; 12895200,294.75;
        12898800,294.75; 12902400,294.75; 12906000,294.75; 12909600,294.75;
        12913200,294.75; 12916800,294.75; 12920400,294.75; 12924000,294.75;
        12927600,294.75; 12931200,294.75; 12934800,294.75; 12938400,294.75;
        12942000,294.75; 12945600,294.75; 12949200,294.75; 12952800,294.75;
        12956400,294.75; 12960000,294.75; 12963600,294.75; 12967200,294.75;
        12970800,294.75; 12974400,294.75; 12978000,294.75; 12981600,294.75;
        12985200,294.75; 12988800,294.75; 12992400,294.75; 12996000,294.75;
        12999600,294.75; 13003200,294.75; 13006800,294.75; 13010400,294.75;
        13014000,294.75; 13017600,294.75; 13021200,294.75; 13024800,294.75;
        13028400,294.75; 13032000,294.75; 13035600,294.75; 13039200,294.75;
        13042800,294.75; 13046400,294.75; 13050000,294.75; 13053600,294.75;
        13057200,294.75; 13060800,294.75; 13064400,294.75; 13068000,294.75;
        13071600,294.75; 13075200,294.75; 13078800,294.75; 13082400,294.75;
        13086000,294.75; 13089600,294.75; 13093200,294.75; 13096800,294.75;
        13100400,294.75; 13104000,294.75; 13107600,294.75; 13111200,294.75;
        13114800,294.75; 13118400,294.75; 13122000,294.75; 13125600,294.75;
        13129200,294.75; 13132800,294.75; 13136400,294.75; 13140000,294.75;
        13143600,294.75; 13147200,294.75; 13150800,294.75; 13154400,294.75;
        13158000,294.75; 13161600,294.75; 13165200,294.75; 13168800,294.75;
        13172400,294.75; 13176000,294.75; 13179600,294.75; 13183200,294.75;
        13186800,294.75; 13190400,294.75; 13194000,294.75; 13197600,294.75;
        13201200,294.75; 13204800,294.75; 13208400,294.75; 13212000,294.75;
        13215600,294.75; 13219200,294.75; 13222800,294.75; 13226400,294.75;
        13230000,294.75; 13233600,294.75; 13237200,294.75; 13240800,294.75;
        13244400,294.75; 13248000,294.75; 13251600,294.75; 13255200,294.75;
        13258800,294.75; 13262400,294.75; 13266000,294.75; 13269600,294.75;
        13273200,294.75; 13276800,294.75; 13280400,294.75; 13284000,294.75;
        13287600,294.75; 13291200,294.75; 13294800,294.75; 13298400,294.75;
        13302000,294.75; 13305600,294.75; 13309200,294.75; 13312800,294.75;
        13316400,294.75; 13320000,294.75; 13323600,294.75; 13327200,294.75;
        13330800,294.75; 13334400,294.75; 13338000,294.75; 13341600,294.75;
        13345200,294.75; 13348800,294.75; 13352400,294.75; 13356000,294.75;
        13359600,294.75; 13363200,294.75; 13366800,294.75; 13370400,294.75;
        13374000,294.75; 13377600,294.75; 13381200,294.75; 13384800,294.75;
        13388400,294.75; 13392000,294.75; 13395600,294.75; 13399200,294.75;
        13402800,294.75; 13406400,294.75; 13410000,294.75; 13413600,294.75;
        13417200,294.75; 13420800,294.75; 13424400,294.75; 13428000,294.75;
        13431600,294.75; 13435200,294.75; 13438800,294.75; 13442400,294.75;
        13446000,294.75; 13449600,294.75; 13453200,294.75; 13456800,294.75;
        13460400,294.75; 13464000,294.75; 13467600,294.75; 13471200,294.75;
        13474800,294.75; 13478400,294.75; 13482000,294.75; 13485600,294.75;
        13489200,294.75; 13492800,294.75; 13496400,294.75; 13500000,294.75;
        13503600,294.75; 13507200,294.75; 13510800,294.75; 13514400,294.75;
        13518000,294.75; 13521600,294.75; 13525200,294.75; 13528800,294.75;
        13532400,294.75; 13536000,294.75; 13539600,294.75; 13543200,294.75;
        13546800,294.75; 13550400,294.75; 13554000,294.75; 13557600,294.75;
        13561200,294.75; 13564800,294.75; 13568400,294.75; 13572000,294.75;
        13575600,294.75; 13579200,294.75; 13582800,294.75; 13586400,294.75;
        13590000,294.75; 13593600,294.75; 13597200,294.75; 13600800,294.75;
        13604400,294.75; 13608000,294.75; 13611600,294.75; 13615200,294.75;
        13618800,294.75; 13622400,294.75; 13626000,294.75; 13629600,294.75;
        13633200,294.75; 13636800,294.75; 13640400,294.75; 13644000,294.75;
        13647600,294.75; 13651200,294.75; 13654800,294.75; 13658400,294.75;
        13662000,294.75; 13665600,294.75; 13669200,294.75; 13672800,294.75;
        13676400,294.75; 13680000,294.75; 13683600,294.75; 13687200,294.75;
        13690800,294.75; 13694400,294.75; 13698000,294.75; 13701600,294.75;
        13705200,294.75; 13708800,294.75; 13712400,294.75; 13716000,294.75;
        13719600,294.75; 13723200,294.75; 13726800,294.75; 13730400,294.75;
        13734000,294.75; 13737600,294.75; 13741200,294.75; 13744800,294.75;
        13748400,294.75; 13752000,294.75; 13755600,294.75; 13759200,294.75;
        13762800,294.75; 13766400,294.75; 13770000,294.75; 13773600,294.75;
        13777200,294.75; 13780800,294.75; 13784400,294.75; 13788000,294.75;
        13791600,294.75; 13795200,294.75; 13798800,294.75; 13802400,294.75;
        13806000,294.75; 13809600,294.75; 13813200,294.75; 13816800,294.75;
        13820400,294.75; 13824000,294.75; 13827600,294.75; 13831200,294.75;
        13834800,294.75; 13838400,294.75; 13842000,294.75; 13845600,294.75;
        13849200,294.75; 13852800,294.75; 13856400,294.75; 13860000,294.75;
        13863600,294.75; 13867200,294.75; 13870800,294.75; 13874400,294.75;
        13878000,294.75; 13881600,294.75; 13885200,294.75; 13888800,294.75;
        13892400,294.75; 13896000,294.75; 13899600,294.75; 13903200,294.75;
        13906800,294.75; 13910400,294.75; 13914000,294.75; 13917600,294.75;
        13921200,294.75; 13924800,294.75; 13928400,294.75; 13932000,294.75;
        13935600,294.75; 13939200,294.75; 13942800,294.75; 13946400,294.75;
        13950000,294.75; 13953600,294.75; 13957200,294.75; 13960800,294.75;
        13964400,294.75; 13968000,294.75; 13971600,294.75; 13975200,294.75;
        13978800,294.75; 13982400,294.75; 13986000,294.75; 13989600,294.75;
        13993200,294.75; 13996800,294.75; 14000400,294.75; 14004000,294.75;
        14007600,294.75; 14011200,294.75; 14014800,294.75; 14018400,294.75;
        14022000,294.75; 14025600,294.75; 14029200,294.75; 14032800,294.75;
        14036400,294.75; 14040000,294.75; 14043600,294.75; 14047200,294.75;
        14050800,294.75; 14054400,294.75; 14058000,294.75; 14061600,294.75;
        14065200,294.75; 14068800,294.75; 14072400,294.75; 14076000,294.75;
        14079600,294.75; 14083200,294.75; 14086800,294.75; 14090400,294.75;
        14094000,294.75; 14097600,294.75; 14101200,294.75; 14104800,294.75;
        14108400,294.75; 14112000,294.75; 14115600,294.75; 14119200,294.75;
        14122800,294.75; 14126400,294.75; 14130000,294.75; 14133600,294.75;
        14137200,294.75; 14140800,294.75; 14144400,294.75; 14148000,294.75;
        14151600,294.75; 14155200,294.75; 14158800,294.75; 14162400,294.75;
        14166000,294.75; 14169600,294.75; 14173200,294.75; 14176800,294.75;
        14180400,294.75; 14184000,294.75; 14187600,294.75; 14191200,294.75;
        14194800,294.75; 14198400,294.75; 14202000,294.75; 14205600,294.75;
        14209200,294.75; 14212800,294.75; 14216400,294.75; 14220000,294.75;
        14223600,294.75; 14227200,294.75; 14230800,294.75; 14234400,294.75;
        14238000,294.75; 14241600,294.75; 14245200,294.75; 14248800,294.75;
        14252400,294.75; 14256000,294.75; 14259600,294.75; 14263200,294.75;
        14266800,294.75; 14270400,294.75; 14274000,294.75; 14277600,294.75;
        14281200,294.75; 14284800,294.75; 14288400,294.75; 14292000,294.75;
        14295600,294.75; 14299200,294.75; 14302800,294.75; 14306400,294.75;
        14310000,294.75; 14313600,294.75; 14317200,294.75; 14320800,294.75;
        14324400,294.75; 14328000,294.75; 14331600,294.75; 14335200,294.75;
        14338800,294.75; 14342400,294.75; 14346000,294.75; 14349600,294.75;
        14353200,294.75; 14356800,294.75; 14360400,294.75; 14364000,294.75;
        14367600,294.75; 14371200,294.75; 14374800,294.75; 14378400,294.75;
        14382000,294.75; 14385600,294.75; 14389200,294.75; 14392800,294.75;
        14396400,294.75; 14400000,294.75; 14403600,294.75; 14407200,294.75;
        14410800,294.75; 14414400,294.75; 14418000,294.75; 14421600,294.75;
        14425200,294.75; 14428800,294.75; 14432400,294.75; 14436000,294.75;
        14439600,294.75; 14443200,294.75; 14446800,294.75; 14450400,294.75;
        14454000,294.75; 14457600,294.75; 14461200,294.75; 14464800,294.75;
        14468400,294.75; 14472000,294.75; 14475600,294.75; 14479200,294.75;
        14482800,294.75; 14486400,294.75; 14490000,294.75; 14493600,294.75;
        14497200,294.75; 14500800,294.75; 14504400,294.75; 14508000,294.75;
        14511600,294.75; 14515200,294.75; 14518800,294.75; 14522400,294.75;
        14526000,294.75; 14529600,294.75; 14533200,294.75; 14536800,294.75;
        14540400,294.75; 14544000,294.75; 14547600,294.75; 14551200,294.75;
        14554800,294.75; 14558400,294.75; 14562000,294.75; 14565600,294.75;
        14569200,294.75; 14572800,294.75; 14576400,294.75; 14580000,294.75;
        14583600,294.75; 14587200,294.75; 14590800,294.75; 14594400,294.75;
        14598000,294.75; 14601600,294.75; 14605200,294.75; 14608800,294.75;
        14612400,294.75; 14616000,294.75; 14619600,294.75; 14623200,294.75;
        14626800,294.75; 14630400,294.75; 14634000,294.75; 14637600,294.75;
        14641200,294.75; 14644800,294.75; 14648400,294.75; 14652000,294.75;
        14655600,294.75; 14659200,294.75; 14662800,294.75; 14666400,294.75;
        14670000,294.75; 14673600,294.75; 14677200,294.75; 14680800,294.75;
        14684400,294.75; 14688000,294.75; 14691600,294.75; 14695200,294.75;
        14698800,294.75; 14702400,294.75; 14706000,294.75; 14709600,294.75;
        14713200,294.75; 14716800,294.75; 14720400,294.75; 14724000,294.75;
        14727600,294.75; 14731200,294.75; 14734800,294.75; 14738400,294.85;
        14742000,294.85; 14745600,294.85; 14749200,294.85; 14752800,294.85;
        14756400,294.85; 14760000,294.85; 14763600,294.85; 14767200,294.85;
        14770800,294.85; 14774400,294.85; 14778000,294.85; 14781600,294.85;
        14785200,294.85; 14788800,294.85; 14792400,294.85; 14796000,294.85;
        14799600,294.85; 14803200,294.85; 14806800,294.85; 14810400,294.85;
        14814000,294.85; 14817600,294.85; 14821200,294.85; 14824800,294.85;
        14828400,294.85; 14832000,294.85; 14835600,294.85; 14839200,294.85;
        14842800,294.85; 14846400,294.85; 14850000,294.85; 14853600,294.85;
        14857200,294.85; 14860800,294.85; 14864400,294.85; 14868000,294.85;
        14871600,294.85; 14875200,294.85; 14878800,294.85; 14882400,294.85;
        14886000,294.85; 14889600,294.85; 14893200,294.85; 14896800,294.85;
        14900400,294.85; 14904000,294.85; 14907600,294.85; 14911200,294.85;
        14914800,294.85; 14918400,294.85; 14922000,294.85; 14925600,294.85;
        14929200,294.85; 14932800,294.85; 14936400,294.85; 14940000,294.85;
        14943600,294.85; 14947200,294.85; 14950800,294.85; 14954400,294.85;
        14958000,294.85; 14961600,294.85; 14965200,294.85; 14968800,294.85;
        14972400,294.85; 14976000,294.85; 14979600,294.85; 14983200,294.85;
        14986800,294.85; 14990400,294.85; 14994000,294.85; 14997600,294.85;
        15001200,294.85; 15004800,294.85; 15008400,294.85; 15012000,294.85;
        15015600,294.85; 15019200,294.85; 15022800,294.85; 15026400,294.85;
        15030000,294.85; 15033600,294.85; 15037200,294.85; 15040800,294.85;
        15044400,294.85; 15048000,294.85; 15051600,294.85; 15055200,294.85;
        15058800,294.85; 15062400,294.85; 15066000,294.85; 15069600,294.85;
        15073200,294.85; 15076800,294.85; 15080400,294.85; 15084000,294.85;
        15087600,294.85; 15091200,294.85; 15094800,294.85; 15098400,294.85;
        15102000,294.85; 15105600,294.85; 15109200,294.85; 15112800,294.85;
        15116400,294.85; 15120000,294.85; 15123600,294.85; 15127200,294.85;
        15130800,294.85; 15134400,294.85; 15138000,294.85; 15141600,294.85;
        15145200,294.85; 15148800,294.85; 15152400,294.85; 15156000,294.85;
        15159600,294.85; 15163200,294.85; 15166800,294.85; 15170400,294.85;
        15174000,294.85; 15177600,294.85; 15181200,294.85; 15184800,294.85;
        15188400,294.85; 15192000,294.85; 15195600,294.85; 15199200,294.85;
        15202800,294.85; 15206400,294.85; 15210000,294.85; 15213600,294.85;
        15217200,294.85; 15220800,294.85; 15224400,294.85; 15228000,294.85;
        15231600,294.85; 15235200,294.85; 15238800,294.85; 15242400,294.85;
        15246000,294.85; 15249600,294.85; 15253200,294.85; 15256800,294.85;
        15260400,294.85; 15264000,294.85; 15267600,294.85; 15271200,294.85;
        15274800,294.85; 15278400,294.85; 15282000,294.85; 15285600,294.85;
        15289200,294.85; 15292800,294.85; 15296400,294.85; 15300000,294.85;
        15303600,294.85; 15307200,294.85; 15310800,294.85; 15314400,294.85;
        15318000,294.85; 15321600,294.85; 15325200,294.85; 15328800,294.85;
        15332400,294.85; 15336000,294.85; 15339600,294.85; 15343200,294.85;
        15346800,294.85; 15350400,294.85; 15354000,294.85; 15357600,294.85;
        15361200,294.85; 15364800,294.85; 15368400,294.85; 15372000,294.85;
        15375600,294.85; 15379200,294.85; 15382800,294.85; 15386400,294.85;
        15390000,294.85; 15393600,294.85; 15397200,294.85; 15400800,294.85;
        15404400,294.85; 15408000,294.85; 15411600,294.85; 15415200,294.85;
        15418800,294.85; 15422400,294.85; 15426000,294.85; 15429600,294.85;
        15433200,294.85; 15436800,294.85; 15440400,294.85; 15444000,294.85;
        15447600,294.85; 15451200,294.85; 15454800,294.85; 15458400,294.85;
        15462000,294.85; 15465600,294.85; 15469200,294.85; 15472800,294.85;
        15476400,294.85; 15480000,294.85; 15483600,294.85; 15487200,294.85;
        15490800,294.85; 15494400,294.85; 15498000,294.85; 15501600,294.85;
        15505200,294.85; 15508800,294.85; 15512400,294.85; 15516000,294.85;
        15519600,294.85; 15523200,294.85; 15526800,294.85; 15530400,294.85;
        15534000,294.85; 15537600,294.85; 15541200,294.85; 15544800,294.85;
        15548400,294.85; 15552000,294.85; 15555600,294.85; 15559200,294.85;
        15562800,294.85; 15566400,294.85; 15570000,294.85; 15573600,294.85;
        15577200,294.85; 15580800,294.85; 15584400,294.85; 15588000,294.85;
        15591600,294.85; 15595200,294.85; 15598800,294.85; 15602400,294.85;
        15606000,294.85; 15609600,294.85; 15613200,294.85; 15616800,294.85;
        15620400,294.85; 15624000,294.85; 15627600,294.85; 15631200,294.85;
        15634800,294.85; 15638400,294.85; 15642000,294.85; 15645600,294.85;
        15649200,294.85; 15652800,294.85; 15656400,294.85; 15660000,294.85;
        15663600,294.85; 15667200,294.85; 15670800,294.85; 15674400,294.85;
        15678000,294.85; 15681600,294.85; 15685200,294.85; 15688800,294.85;
        15692400,294.85; 15696000,294.85; 15699600,294.85; 15703200,294.85;
        15706800,294.85; 15710400,294.85; 15714000,294.85; 15717600,294.85;
        15721200,294.85; 15724800,294.85; 15728400,294.85; 15732000,294.85;
        15735600,294.85; 15739200,294.85; 15742800,294.85; 15746400,294.85;
        15750000,294.85; 15753600,294.85; 15757200,294.85; 15760800,294.85;
        15764400,294.85; 15768000,294.85; 15771600,294.85; 15775200,294.85;
        15778800,294.85; 15782400,294.85; 15786000,294.85; 15789600,294.85;
        15793200,294.85; 15796800,294.85; 15800400,294.85; 15804000,294.85;
        15807600,294.85; 15811200,294.85; 15814800,294.85; 15818400,294.85;
        15822000,294.85; 15825600,294.85; 15829200,294.85; 15832800,294.85;
        15836400,294.85; 15840000,294.85; 15843600,294.85; 15847200,294.85;
        15850800,294.85; 15854400,294.85; 15858000,294.85; 15861600,294.85;
        15865200,294.85; 15868800,294.85; 15872400,294.85; 15876000,294.85;
        15879600,294.85; 15883200,294.85; 15886800,294.85; 15890400,294.85;
        15894000,294.85; 15897600,294.85; 15901200,294.85; 15904800,294.85;
        15908400,294.85; 15912000,294.85; 15915600,294.85; 15919200,294.85;
        15922800,294.85; 15926400,294.85; 15930000,294.85; 15933600,294.85;
        15937200,294.85; 15940800,294.85; 15944400,294.85; 15948000,294.85;
        15951600,294.85; 15955200,294.85; 15958800,294.85; 15962400,294.85;
        15966000,294.85; 15969600,294.85; 15973200,294.85; 15976800,294.85;
        15980400,294.85; 15984000,294.85; 15987600,294.85; 15991200,294.85;
        15994800,294.85; 15998400,294.85; 16002000,294.85; 16005600,294.85;
        16009200,294.85; 16012800,294.85; 16016400,294.85; 16020000,294.85;
        16023600,294.85; 16027200,294.85; 16030800,294.85; 16034400,294.85;
        16038000,294.85; 16041600,294.85; 16045200,294.85; 16048800,294.85;
        16052400,294.85; 16056000,294.85; 16059600,294.85; 16063200,294.85;
        16066800,294.85; 16070400,294.85; 16074000,294.85; 16077600,294.85;
        16081200,294.85; 16084800,294.85; 16088400,294.85; 16092000,294.85;
        16095600,294.85; 16099200,294.85; 16102800,294.85; 16106400,294.85;
        16110000,294.85; 16113600,294.85; 16117200,294.85; 16120800,294.85;
        16124400,294.85; 16128000,294.85; 16131600,294.85; 16135200,294.85;
        16138800,294.85; 16142400,294.85; 16146000,294.85; 16149600,294.85;
        16153200,294.85; 16156800,294.85; 16160400,294.85; 16164000,294.85;
        16167600,294.85; 16171200,294.85; 16174800,294.85; 16178400,294.85;
        16182000,294.85; 16185600,294.85; 16189200,294.85; 16192800,294.85;
        16196400,294.85; 16200000,294.85; 16203600,294.85; 16207200,294.85;
        16210800,294.85; 16214400,294.85; 16218000,294.85; 16221600,294.85;
        16225200,294.85; 16228800,294.85; 16232400,294.85; 16236000,294.85;
        16239600,294.85; 16243200,294.85; 16246800,294.85; 16250400,294.85;
        16254000,294.85; 16257600,294.85; 16261200,294.85; 16264800,294.85;
        16268400,294.85; 16272000,294.85; 16275600,294.85; 16279200,294.85;
        16282800,294.85; 16286400,294.85; 16290000,294.85; 16293600,294.85;
        16297200,294.85; 16300800,294.85; 16304400,294.85; 16308000,294.85;
        16311600,294.85; 16315200,294.85; 16318800,294.85; 16322400,294.85;
        16326000,294.85; 16329600,294.85; 16333200,294.85; 16336800,294.85;
        16340400,294.85; 16344000,294.85; 16347600,294.85; 16351200,294.85;
        16354800,294.85; 16358400,294.85; 16362000,294.85; 16365600,294.85;
        16369200,294.85; 16372800,294.85; 16376400,294.85; 16380000,294.85;
        16383600,294.85; 16387200,294.85; 16390800,294.85; 16394400,294.85;
        16398000,294.85; 16401600,294.85; 16405200,294.85; 16408800,294.85;
        16412400,294.85; 16416000,294.85; 16419600,294.85; 16423200,294.85;
        16426800,294.85; 16430400,294.85; 16434000,294.85; 16437600,294.85;
        16441200,294.85; 16444800,294.85; 16448400,294.85; 16452000,294.85;
        16455600,294.85; 16459200,294.85; 16462800,294.85; 16466400,294.85;
        16470000,294.85; 16473600,294.85; 16477200,294.85; 16480800,294.85;
        16484400,294.85; 16488000,294.85; 16491600,294.85; 16495200,294.85;
        16498800,294.85; 16502400,294.85; 16506000,294.85; 16509600,294.85;
        16513200,294.85; 16516800,294.85; 16520400,294.85; 16524000,294.85;
        16527600,294.85; 16531200,294.85; 16534800,294.85; 16538400,294.85;
        16542000,294.85; 16545600,294.85; 16549200,294.85; 16552800,294.85;
        16556400,294.85; 16560000,294.85; 16563600,294.85; 16567200,294.85;
        16570800,294.85; 16574400,294.85; 16578000,294.85; 16581600,294.85;
        16585200,294.85; 16588800,294.85; 16592400,294.85; 16596000,294.85;
        16599600,294.85; 16603200,294.85; 16606800,294.85; 16610400,294.85;
        16614000,294.85; 16617600,294.85; 16621200,294.85; 16624800,294.85;
        16628400,294.85; 16632000,294.85; 16635600,294.85; 16639200,294.85;
        16642800,294.85; 16646400,294.85; 16650000,294.85; 16653600,294.85;
        16657200,294.85; 16660800,294.85; 16664400,294.85; 16668000,294.85;
        16671600,294.85; 16675200,294.85; 16678800,294.85; 16682400,294.85;
        16686000,294.85; 16689600,294.85; 16693200,294.85; 16696800,294.85;
        16700400,294.85; 16704000,294.85; 16707600,294.85; 16711200,294.85;
        16714800,294.85; 16718400,294.85; 16722000,294.85; 16725600,294.85;
        16729200,294.85; 16732800,294.85; 16736400,294.85; 16740000,294.85;
        16743600,294.85; 16747200,294.85; 16750800,294.85; 16754400,294.85;
        16758000,294.85; 16761600,294.85; 16765200,294.85; 16768800,294.85;
        16772400,294.85; 16776000,294.85; 16779600,294.85; 16783200,294.85;
        16786800,294.85; 16790400,294.85; 16794000,294.85; 16797600,294.85;
        16801200,294.85; 16804800,294.85; 16808400,294.85; 16812000,294.85;
        16815600,294.85; 16819200,294.85; 16822800,294.85; 16826400,294.85;
        16830000,294.85; 16833600,294.85; 16837200,294.85; 16840800,294.85;
        16844400,294.85; 16848000,294.85; 16851600,294.85; 16855200,294.85;
        16858800,294.85; 16862400,294.85; 16866000,294.85; 16869600,294.85;
        16873200,294.85; 16876800,294.85; 16880400,294.85; 16884000,294.85;
        16887600,294.85; 16891200,294.85; 16894800,294.85; 16898400,294.85;
        16902000,294.85; 16905600,294.85; 16909200,294.85; 16912800,294.85;
        16916400,294.85; 16920000,294.85; 16923600,294.85; 16927200,294.85;
        16930800,294.85; 16934400,294.85; 16938000,294.85; 16941600,294.85;
        16945200,294.85; 16948800,294.85; 16952400,294.85; 16956000,294.85;
        16959600,294.85; 16963200,294.85; 16966800,294.85; 16970400,294.85;
        16974000,294.85; 16977600,294.85; 16981200,294.85; 16984800,294.85;
        16988400,294.85; 16992000,294.85; 16995600,294.85; 16999200,294.85;
        17002800,294.85; 17006400,294.85; 17010000,294.85; 17013600,294.85;
        17017200,294.85; 17020800,294.85; 17024400,294.85; 17028000,294.85;
        17031600,294.85; 17035200,294.85; 17038800,294.85; 17042400,294.85;
        17046000,294.85; 17049600,294.85; 17053200,294.85; 17056800,294.85;
        17060400,294.85; 17064000,294.85; 17067600,294.85; 17071200,294.85;
        17074800,294.85; 17078400,294.85; 17082000,294.85; 17085600,294.85;
        17089200,294.85; 17092800,294.85; 17096400,294.85; 17100000,294.85;
        17103600,294.85; 17107200,294.85; 17110800,294.85; 17114400,294.85;
        17118000,294.85; 17121600,294.85; 17125200,294.85; 17128800,294.85;
        17132400,294.85; 17136000,294.85; 17139600,294.85; 17143200,294.85;
        17146800,294.85; 17150400,294.85; 17154000,294.85; 17157600,294.85;
        17161200,294.85; 17164800,294.85; 17168400,294.85; 17172000,294.85;
        17175600,294.85; 17179200,294.85; 17182800,294.85; 17186400,294.85;
        17190000,294.85; 17193600,294.85; 17197200,294.85; 17200800,294.85;
        17204400,294.85; 17208000,294.85; 17211600,294.85; 17215200,294.85;
        17218800,294.85; 17222400,294.85; 17226000,294.85; 17229600,294.85;
        17233200,294.85; 17236800,294.85; 17240400,294.85; 17244000,294.85;
        17247600,294.85; 17251200,294.85; 17254800,294.85; 17258400,294.85;
        17262000,294.85; 17265600,294.85; 17269200,294.85; 17272800,294.85;
        17276400,294.85; 17280000,294.85; 17283600,294.85; 17287200,294.85;
        17290800,294.85; 17294400,294.85; 17298000,294.85; 17301600,294.85;
        17305200,294.85; 17308800,294.85; 17312400,294.85; 17316000,294.85;
        17319600,294.85; 17323200,294.85; 17326800,294.85; 17330400,294.85;
        17334000,294.85; 17337600,294.85; 17341200,294.85; 17344800,294.85;
        17348400,294.85; 17352000,294.85; 17355600,294.85; 17359200,294.85;
        17362800,294.85; 17366400,294.85; 17370000,294.85; 17373600,294.85;
        17377200,294.85; 17380800,294.85; 17384400,294.85; 17388000,294.85;
        17391600,294.85; 17395200,294.85; 17398800,294.85; 17402400,294.85;
        17406000,294.85; 17409600,294.85; 17413200,294.85; 17416800,294.85;
        17420400,294.85; 17424000,294.85; 17427600,294.85; 17431200,294.85;
        17434800,294.85; 17438400,294.85; 17442000,294.85; 17445600,294.85;
        17449200,294.85; 17452800,294.85; 17456400,294.85; 17460000,294.85;
        17463600,294.85; 17467200,294.85; 17470800,294.85; 17474400,294.85;
        17478000,294.85; 17481600,294.85; 17485200,294.85; 17488800,294.85;
        17492400,294.85; 17496000,294.85; 17499600,294.85; 17503200,294.85;
        17506800,294.85; 17510400,294.85; 17514000,294.85; 17517600,294.85;
        17521200,294.85; 17524800,294.85; 17528400,294.85; 17532000,294.85;
        17535600,294.85; 17539200,294.85; 17542800,294.85; 17546400,294.85;
        17550000,294.85; 17553600,294.85; 17557200,294.85; 17560800,294.85;
        17564400,294.85; 17568000,294.85; 17571600,294.85; 17575200,294.85;
        17578800,294.85; 17582400,294.85; 17586000,294.85; 17589600,294.85;
        17593200,294.85; 17596800,294.85; 17600400,294.85; 17604000,294.85;
        17607600,294.85; 17611200,294.85; 17614800,294.85; 17618400,294.85;
        17622000,294.85; 17625600,294.85; 17629200,294.85; 17632800,294.85;
        17636400,294.85; 17640000,294.85; 17643600,294.85; 17647200,294.85;
        17650800,294.85; 17654400,294.85; 17658000,294.85; 17661600,294.85;
        17665200,294.85; 17668800,294.85; 17672400,294.85; 17676000,294.85;
        17679600,294.85; 17683200,294.85; 17686800,294.85; 17690400,294.85;
        17694000,294.85; 17697600,294.85; 17701200,294.85; 17704800,294.85;
        17708400,294.85; 17712000,294.85; 17715600,294.85; 17719200,294.85;
        17722800,294.85; 17726400,294.85; 17730000,294.85; 17733600,294.85;
        17737200,294.85; 17740800,294.85; 17744400,294.85; 17748000,294.85;
        17751600,294.85; 17755200,294.85; 17758800,294.85; 17762400,294.85;
        17766000,294.85; 17769600,294.85; 17773200,294.85; 17776800,294.85;
        17780400,294.85; 17784000,294.85; 17787600,294.85; 17791200,294.85;
        17794800,294.85; 17798400,294.85; 17802000,294.85; 17805600,294.85;
        17809200,294.85; 17812800,294.85; 17816400,294.85; 17820000,294.85;
        17823600,294.85; 17827200,294.85; 17830800,294.85; 17834400,294.85;
        17838000,294.85; 17841600,294.85; 17845200,294.85; 17848800,294.85;
        17852400,294.85; 17856000,294.85; 17859600,294.85; 17863200,294.85;
        17866800,294.85; 17870400,294.85; 17874000,294.85; 17877600,294.85;
        17881200,294.85; 17884800,294.85; 17888400,294.85; 17892000,294.85;
        17895600,294.85; 17899200,294.85; 17902800,294.85; 17906400,294.85;
        17910000,294.85; 17913600,294.85; 17917200,294.85; 17920800,294.85;
        17924400,294.85; 17928000,294.85; 17931600,294.85; 17935200,294.85;
        17938800,294.85; 17942400,294.85; 17946000,294.85; 17949600,294.85;
        17953200,294.85; 17956800,294.85; 17960400,294.85; 17964000,294.85;
        17967600,294.85; 17971200,294.85; 17974800,294.85; 17978400,294.85;
        17982000,294.85; 17985600,294.85; 17989200,294.85; 17992800,294.85;
        17996400,294.85; 18000000,294.85; 18003600,294.85; 18007200,294.85;
        18010800,294.85; 18014400,294.85; 18018000,294.85; 18021600,294.85;
        18025200,294.85; 18028800,294.85; 18032400,294.85; 18036000,294.85;
        18039600,294.85; 18043200,294.85; 18046800,294.85; 18050400,294.85;
        18054000,294.85; 18057600,294.85; 18061200,294.85; 18064800,294.85;
        18068400,294.85; 18072000,294.85; 18075600,294.85; 18079200,294.85;
        18082800,294.85; 18086400,294.85; 18090000,294.85; 18093600,294.85;
        18097200,294.85; 18100800,294.85; 18104400,294.85; 18108000,294.85;
        18111600,294.85; 18115200,294.85; 18118800,294.85; 18122400,294.85;
        18126000,294.85; 18129600,294.85; 18133200,294.85; 18136800,294.85;
        18140400,294.85; 18144000,294.85; 18147600,294.85; 18151200,294.85;
        18154800,294.85; 18158400,294.85; 18162000,294.85; 18165600,294.85;
        18169200,294.85; 18172800,294.85; 18176400,294.85; 18180000,294.85;
        18183600,294.85; 18187200,294.85; 18190800,294.85; 18194400,294.85;
        18198000,294.85; 18201600,294.85; 18205200,294.85; 18208800,294.85;
        18212400,294.85; 18216000,294.85; 18219600,294.85; 18223200,294.85;
        18226800,294.85; 18230400,294.85; 18234000,294.85; 18237600,294.85;
        18241200,294.85; 18244800,294.85; 18248400,294.85; 18252000,294.85;
        18255600,294.85; 18259200,294.85; 18262800,294.85; 18266400,294.85;
        18270000,294.85; 18273600,294.85; 18277200,294.85; 18280800,294.85;
        18284400,294.85; 18288000,294.85; 18291600,294.85; 18295200,294.85;
        18298800,294.85; 18302400,294.85; 18306000,294.85; 18309600,294.85;
        18313200,294.85; 18316800,294.85; 18320400,294.85; 18324000,294.85;
        18327600,294.85; 18331200,294.85; 18334800,294.85; 18338400,294.85;
        18342000,294.85; 18345600,294.85; 18349200,294.85; 18352800,294.85;
        18356400,294.85; 18360000,294.85; 18363600,294.85; 18367200,294.85;
        18370800,294.85; 18374400,294.85; 18378000,294.85; 18381600,294.85;
        18385200,294.85; 18388800,294.85; 18392400,294.85; 18396000,294.85;
        18399600,294.85; 18403200,294.85; 18406800,294.85; 18410400,294.85;
        18414000,294.85; 18417600,294.85; 18421200,294.85; 18424800,294.85;
        18428400,294.85; 18432000,294.85; 18435600,294.85; 18439200,294.85;
        18442800,294.85; 18446400,294.85; 18450000,294.85; 18453600,294.85;
        18457200,294.85; 18460800,294.85; 18464400,294.85; 18468000,294.85;
        18471600,294.85; 18475200,294.85; 18478800,294.85; 18482400,294.85;
        18486000,294.95; 18489600,294.95; 18493200,294.95; 18496800,294.95;
        18500400,294.95; 18504000,294.95; 18507600,294.95; 18511200,294.95;
        18514800,294.95; 18518400,294.95; 18522000,294.95; 18525600,294.95;
        18529200,294.95; 18532800,294.95; 18536400,294.95; 18540000,294.95;
        18543600,294.95; 18547200,294.95; 18550800,294.95; 18554400,294.95;
        18558000,294.95; 18561600,294.95; 18565200,294.95; 18568800,294.95;
        18572400,294.95; 18576000,294.95; 18579600,294.95; 18583200,294.95;
        18586800,294.95; 18590400,294.95; 18594000,294.95; 18597600,294.95;
        18601200,294.95; 18604800,294.95; 18608400,294.95; 18612000,294.95;
        18615600,294.95; 18619200,294.95; 18622800,294.95; 18626400,294.95;
        18630000,294.95; 18633600,294.95; 18637200,294.95; 18640800,294.95;
        18644400,294.95; 18648000,294.95; 18651600,294.95; 18655200,294.95;
        18658800,294.95; 18662400,294.95; 18666000,294.95; 18669600,294.95;
        18673200,294.95; 18676800,294.95; 18680400,294.95; 18684000,294.95;
        18687600,294.95; 18691200,294.95; 18694800,294.95; 18698400,294.95;
        18702000,294.95; 18705600,294.95; 18709200,294.95; 18712800,294.95;
        18716400,294.95; 18720000,294.95; 18723600,294.95; 18727200,294.95;
        18730800,294.95; 18734400,294.95; 18738000,294.95; 18741600,294.95;
        18745200,294.95; 18748800,294.95; 18752400,294.95; 18756000,294.95;
        18759600,294.95; 18763200,294.95; 18766800,294.95; 18770400,294.95;
        18774000,294.95; 18777600,294.95; 18781200,294.95; 18784800,294.95;
        18788400,294.95; 18792000,294.95; 18795600,294.95; 18799200,294.95;
        18802800,294.95; 18806400,294.95; 18810000,294.95; 18813600,294.95;
        18817200,294.95; 18820800,294.95; 18824400,294.95; 18828000,294.95;
        18831600,294.95; 18835200,294.95; 18838800,294.95; 18842400,294.95;
        18846000,294.95; 18849600,294.95; 18853200,294.95; 18856800,294.95;
        18860400,294.95; 18864000,294.95; 18867600,294.95; 18871200,294.95;
        18874800,294.95; 18878400,294.95; 18882000,294.95; 18885600,294.95;
        18889200,294.95; 18892800,294.95; 18896400,294.95; 18900000,294.95;
        18903600,294.95; 18907200,294.95; 18910800,294.95; 18914400,294.95;
        18918000,294.95; 18921600,294.95; 18925200,294.95; 18928800,294.95;
        18932400,294.95; 18936000,294.95; 18939600,294.95; 18943200,294.95;
        18946800,294.95; 18950400,294.95; 18954000,294.95; 18957600,294.95;
        18961200,294.95; 18964800,294.95; 18968400,294.95; 18972000,294.95;
        18975600,294.95; 18979200,294.95; 18982800,294.95; 18986400,294.95;
        18990000,294.95; 18993600,294.95; 18997200,294.95; 19000800,294.95;
        19004400,294.95; 19008000,294.95; 19011600,294.95; 19015200,294.95;
        19018800,294.95; 19022400,294.95; 19026000,294.95; 19029600,294.95;
        19033200,294.95; 19036800,294.95; 19040400,294.95; 19044000,294.95;
        19047600,294.95; 19051200,294.95; 19054800,294.95; 19058400,294.95;
        19062000,294.95; 19065600,294.95; 19069200,294.95; 19072800,294.95;
        19076400,294.95; 19080000,294.95; 19083600,294.95; 19087200,294.95;
        19090800,294.95; 19094400,294.95; 19098000,294.95; 19101600,294.95;
        19105200,294.95; 19108800,294.95; 19112400,294.95; 19116000,294.95;
        19119600,294.95; 19123200,294.95; 19126800,294.95; 19130400,294.95;
        19134000,294.95; 19137600,294.95; 19141200,294.95; 19144800,294.95;
        19148400,294.95; 19152000,294.95; 19155600,294.95; 19159200,294.95;
        19162800,294.95; 19166400,294.95; 19170000,294.95; 19173600,294.95;
        19177200,294.95; 19180800,294.95; 19184400,294.95; 19188000,294.95;
        19191600,294.95; 19195200,294.95; 19198800,294.95; 19202400,294.95;
        19206000,294.95; 19209600,294.95; 19213200,294.95; 19216800,294.95;
        19220400,294.95; 19224000,294.95; 19227600,294.95; 19231200,294.95;
        19234800,294.95; 19238400,294.95; 19242000,294.95; 19245600,294.95;
        19249200,294.95; 19252800,294.95; 19256400,294.95; 19260000,294.95;
        19263600,294.95; 19267200,294.95; 19270800,294.95; 19274400,294.95;
        19278000,294.95; 19281600,294.95; 19285200,294.95; 19288800,294.95;
        19292400,294.95; 19296000,294.95; 19299600,294.95; 19303200,294.95;
        19306800,294.95; 19310400,294.95; 19314000,294.95; 19317600,294.95;
        19321200,294.95; 19324800,294.95; 19328400,294.95; 19332000,294.95;
        19335600,294.95; 19339200,294.95; 19342800,294.95; 19346400,294.95;
        19350000,294.95; 19353600,294.95; 19357200,294.95; 19360800,294.95;
        19364400,294.95; 19368000,294.95; 19371600,294.95; 19375200,294.95;
        19378800,294.95; 19382400,294.95; 19386000,294.95; 19389600,294.95;
        19393200,294.95; 19396800,294.95; 19400400,294.95; 19404000,294.95;
        19407600,294.95; 19411200,294.95; 19414800,294.95; 19418400,294.95;
        19422000,294.95; 19425600,294.95; 19429200,294.95; 19432800,294.95;
        19436400,294.95; 19440000,294.95; 19443600,294.95; 19447200,294.95;
        19450800,294.95; 19454400,294.95; 19458000,294.95; 19461600,294.95;
        19465200,294.95; 19468800,294.95; 19472400,294.95; 19476000,294.95;
        19479600,294.95; 19483200,294.95; 19486800,294.95; 19490400,294.95;
        19494000,294.95; 19497600,294.95; 19501200,294.95; 19504800,294.95;
        19508400,294.95; 19512000,294.95; 19515600,294.95; 19519200,294.95;
        19522800,294.95; 19526400,294.95; 19530000,294.95; 19533600,294.95;
        19537200,294.95; 19540800,294.95; 19544400,294.95; 19548000,294.95;
        19551600,294.95; 19555200,294.95; 19558800,294.95; 19562400,294.95;
        19566000,294.95; 19569600,294.95; 19573200,294.95; 19576800,294.95;
        19580400,294.95; 19584000,294.95; 19587600,294.95; 19591200,294.95;
        19594800,294.95; 19598400,294.95; 19602000,294.95; 19605600,294.95;
        19609200,294.95; 19612800,294.95; 19616400,294.95; 19620000,294.95;
        19623600,294.95; 19627200,294.95; 19630800,294.95; 19634400,294.95;
        19638000,294.95; 19641600,294.95; 19645200,294.95; 19648800,294.95;
        19652400,294.95; 19656000,294.95; 19659600,294.95; 19663200,294.95;
        19666800,294.95; 19670400,294.95; 19674000,294.95; 19677600,294.95;
        19681200,294.95; 19684800,294.95; 19688400,294.95; 19692000,294.95;
        19695600,294.95; 19699200,294.95; 19702800,294.95; 19706400,294.95;
        19710000,294.95; 19713600,294.95; 19717200,294.95; 19720800,294.95;
        19724400,294.95; 19728000,294.95; 19731600,294.95; 19735200,294.95;
        19738800,294.95; 19742400,294.95; 19746000,294.95; 19749600,294.95;
        19753200,294.95; 19756800,294.95; 19760400,294.95; 19764000,294.95;
        19767600,294.95; 19771200,294.95; 19774800,294.95; 19778400,294.95;
        19782000,294.95; 19785600,294.95; 19789200,294.95; 19792800,294.95;
        19796400,294.95; 19800000,294.95; 19803600,294.95; 19807200,294.95;
        19810800,294.95; 19814400,294.95; 19818000,294.95; 19821600,294.95;
        19825200,294.95; 19828800,294.95; 19832400,294.95; 19836000,294.95;
        19839600,294.95; 19843200,294.95; 19846800,294.95; 19850400,294.95;
        19854000,294.95; 19857600,294.95; 19861200,294.95; 19864800,294.95;
        19868400,294.95; 19872000,294.95; 19875600,294.95; 19879200,294.95;
        19882800,294.95; 19886400,294.95; 19890000,294.95; 19893600,294.95;
        19897200,294.95; 19900800,294.95; 19904400,294.95; 19908000,294.95;
        19911600,294.95; 19915200,294.95; 19918800,294.95; 19922400,294.95;
        19926000,294.95; 19929600,294.95; 19933200,294.95; 19936800,294.95;
        19940400,294.95; 19944000,294.95; 19947600,294.95; 19951200,294.95;
        19954800,294.95; 19958400,294.95; 19962000,294.95; 19965600,294.95;
        19969200,294.95; 19972800,294.95; 19976400,294.95; 19980000,294.95;
        19983600,294.95; 19987200,294.95; 19990800,294.95; 19994400,294.95;
        19998000,294.95; 20001600,294.95; 20005200,294.95; 20008800,294.95;
        20012400,294.95; 20016000,294.95; 20019600,294.95; 20023200,294.95;
        20026800,294.95; 20030400,294.95; 20034000,294.95; 20037600,294.95;
        20041200,294.95; 20044800,294.95; 20048400,294.95; 20052000,294.95;
        20055600,294.95; 20059200,294.95; 20062800,294.95; 20066400,294.95;
        20070000,294.95; 20073600,294.95; 20077200,294.95; 20080800,294.95;
        20084400,294.95; 20088000,294.95; 20091600,294.95; 20095200,294.95;
        20098800,294.95; 20102400,294.95; 20106000,294.95; 20109600,294.95;
        20113200,294.95; 20116800,294.95; 20120400,294.95; 20124000,294.95;
        20127600,294.95; 20131200,294.95; 20134800,294.95; 20138400,294.95;
        20142000,294.95; 20145600,294.95; 20149200,294.95; 20152800,294.95;
        20156400,294.95; 20160000,294.95; 20163600,294.95; 20167200,294.95;
        20170800,294.95; 20174400,294.95; 20178000,294.95; 20181600,294.95;
        20185200,294.95; 20188800,294.95; 20192400,294.95; 20196000,294.95;
        20199600,294.95; 20203200,294.95; 20206800,294.95; 20210400,294.95;
        20214000,294.95; 20217600,294.95; 20221200,294.95; 20224800,294.95;
        20228400,294.95; 20232000,294.95; 20235600,294.95; 20239200,294.95;
        20242800,294.95; 20246400,294.95; 20250000,294.95; 20253600,294.95;
        20257200,294.95; 20260800,294.95; 20264400,294.95; 20268000,294.95;
        20271600,294.95; 20275200,294.95; 20278800,294.95; 20282400,294.95;
        20286000,294.95; 20289600,294.95; 20293200,294.95; 20296800,294.95;
        20300400,294.95; 20304000,294.95; 20307600,294.95; 20311200,294.95;
        20314800,294.95; 20318400,294.95; 20322000,294.95; 20325600,294.95;
        20329200,294.95; 20332800,294.95; 20336400,294.95; 20340000,294.95;
        20343600,294.95; 20347200,294.95; 20350800,294.95; 20354400,294.95;
        20358000,294.95; 20361600,294.95; 20365200,294.95; 20368800,294.95;
        20372400,294.95; 20376000,294.95; 20379600,294.95; 20383200,294.95;
        20386800,294.95; 20390400,294.95; 20394000,294.95; 20397600,294.95;
        20401200,294.95; 20404800,294.95; 20408400,294.95; 20412000,294.95;
        20415600,294.95; 20419200,294.95; 20422800,294.95; 20426400,294.95;
        20430000,294.95; 20433600,294.95; 20437200,294.95; 20440800,294.95;
        20444400,294.95; 20448000,294.95; 20451600,294.95; 20455200,294.95;
        20458800,294.95; 20462400,294.95; 20466000,294.95; 20469600,294.95;
        20473200,294.95; 20476800,294.95; 20480400,294.95; 20484000,294.95;
        20487600,294.95; 20491200,294.95; 20494800,294.95; 20498400,294.95;
        20502000,294.95; 20505600,294.95; 20509200,294.95; 20512800,294.95;
        20516400,294.95; 20520000,294.95; 20523600,294.95; 20527200,294.95;
        20530800,294.95; 20534400,294.95; 20538000,294.95; 20541600,294.95;
        20545200,294.95; 20548800,294.95; 20552400,294.95; 20556000,294.95;
        20559600,294.95; 20563200,294.95; 20566800,294.95; 20570400,294.95;
        20574000,294.95; 20577600,294.95; 20581200,294.95; 20584800,294.95;
        20588400,294.95; 20592000,294.95; 20595600,294.95; 20599200,294.95;
        20602800,294.95; 20606400,294.95; 20610000,294.95; 20613600,294.95;
        20617200,294.95; 20620800,294.95; 20624400,294.95; 20628000,294.95;
        20631600,294.95; 20635200,294.95; 20638800,294.95; 20642400,294.95;
        20646000,294.95; 20649600,294.95; 20653200,294.95; 20656800,294.95;
        20660400,294.95; 20664000,294.95; 20667600,294.95; 20671200,294.95;
        20674800,294.95; 20678400,294.95; 20682000,294.95; 20685600,294.95;
        20689200,294.95; 20692800,294.95; 20696400,294.95; 20700000,294.95;
        20703600,294.95; 20707200,294.95; 20710800,294.95; 20714400,294.95;
        20718000,294.95; 20721600,294.95; 20725200,294.95; 20728800,294.95;
        20732400,294.95; 20736000,294.95; 20739600,294.95; 20743200,294.95;
        20746800,294.95; 20750400,294.95; 20754000,294.95; 20757600,294.95;
        20761200,294.95; 20764800,294.95; 20768400,294.95; 20772000,294.95;
        20775600,294.95; 20779200,294.95; 20782800,294.95; 20786400,294.95;
        20790000,294.95; 20793600,294.95; 20797200,294.95; 20800800,294.95;
        20804400,294.95; 20808000,294.95; 20811600,294.95; 20815200,294.95;
        20818800,294.95; 20822400,294.95; 20826000,294.95; 20829600,294.95;
        20833200,294.95; 20836800,294.95; 20840400,294.95; 20844000,294.95;
        20847600,294.95; 20851200,294.95; 20854800,294.95; 20858400,294.95;
        20862000,294.95; 20865600,294.95; 20869200,294.95; 20872800,294.95;
        20876400,294.95; 20880000,294.95; 20883600,294.95; 20887200,294.95;
        20890800,294.95; 20894400,294.95; 20898000,294.95; 20901600,294.95;
        20905200,294.95; 20908800,294.95; 20912400,294.95; 20916000,294.95;
        20919600,294.95; 20923200,294.95; 20926800,294.95; 20930400,294.95;
        20934000,294.95; 20937600,294.95; 20941200,294.95; 20944800,294.95;
        20948400,294.95; 20952000,294.95; 20955600,294.95; 20959200,294.95;
        20962800,294.95; 20966400,294.95; 20970000,294.95; 20973600,294.95;
        20977200,294.95; 20980800,294.95; 20984400,294.95; 20988000,294.95;
        20991600,294.95; 20995200,298.15; 20998800,297.85; 21002400,297.15;
        21006000,296.05; 21009600,296.15; 21013200,295.65; 21016800,295.75;
        21020400,295.75; 21024000,295.85; 21027600,296.35; 21031200,296.05;
        21034800,295.45; 21038400,295.05; 21042000,295.55; 21045600,295.25;
        21049200,295.05; 21052800,295.35; 21056400,295.35; 21060000,295.25;
        21063600,295.45; 21067200,295.05; 21070800,294.95; 21074400,294.95;
        21078000,294.95; 21081600,294.85; 21085200,295.05; 21088800,295.45;
        21092400,295.65; 21096000,295.65; 21099600,295.45; 21103200,295.35;
        21106800,295.15; 21110400,295.25; 21114000,295.75; 21117600,295.45;
        21121200,295.35; 21124800,295.55; 21128400,295.55; 21132000,295.35;
        21135600,295.95; 21139200,296.15; 21142800,295.25; 21146400,295.25;
        21150000,294.75; 21153600,294.95; 21157200,295.15; 21160800,295.25;
        21164400,295.25; 21168000,294.85; 21171600,295.25; 21175200,295.55;
        21178800,295.85; 21182400,295.75; 21186000,295.45; 21189600,295.15;
        21193200,295.05; 21196800,295.35; 21200400,296.65; 21204000,296.45;
        21207600,295.25; 21211200,295.55; 21214800,295.75; 21218400,294.95;
        21222000,295.25; 21225600,295.35; 21229200,295.35; 21232800,295.35;
        21236400,295.35; 21240000,295.35; 21243600,295.35; 21247200,295.35;
        21250800,294.85; 21254400,294.85; 21258000,295.25; 21261600,295.75;
        21265200,296.05; 21268800,295.45; 21272400,295.75; 21276000,296.35;
        21279600,296.25; 21283200,296.35; 21286800,296.45; 21290400,295.35;
        21294000,295.45; 21297600,295.65; 21301200,295.35; 21304800,295.15;
        21308400,295.65; 21312000,295.25; 21315600,294.95; 21319200,294.95;
        21322800,294.95; 21326400,294.95; 21330000,294.95; 21333600,294.95;
        21337200,295.15; 21340800,295.45; 21344400,295.55; 21348000,295.75;
        21351600,295.75; 21355200,295.65; 21358800,295.55; 21362400,295.85;
        21366000,295.85; 21369600,295.85; 21373200,296.25; 21376800,295.55;
        21380400,295.35; 21384000,295.35; 21387600,295.25; 21391200,295.45;
        21394800,295.45; 21398400,295.35; 21402000,295.15; 21405600,295.05;
        21409200,295.05; 21412800,295.05; 21416400,295.05; 21420000,295.05;
        21423600,295.05; 21427200,294.95; 21430800,295.15; 21434400,295.75;
        21438000,295.65; 21441600,295.65; 21445200,295.65; 21448800,295.75;
        21452400,294.85; 21456000,294.95; 21459600,295.15; 21463200,295.25;
        21466800,295.25; 21470400,294.95; 21474000,295.15; 21477600,295.25;
        21481200,295.35; 21484800,295.55; 21488400,295.45; 21492000,295.25;
        21495600,295.35; 21499200,295.25; 21502800,295.25; 21506400,295.25;
        21510000,295.15; 21513600,295.05; 21517200,295.05; 21520800,295.25;
        21524400,295.25; 21528000,295.15; 21531600,295.05; 21535200,295.25;
        21538800,295.05; 21542400,294.95; 21546000,294.95; 21549600,294.95;
        21553200,295.15; 21556800,294.95; 21560400,295.05; 21564000,295.05;
        21567600,294.75; 21571200,295.05; 21574800,295.35; 21578400,294.85;
        21582000,294.75; 21585600,294.75; 21589200,294.75; 21592800,294.75;
        21596400,294.75; 21600000,294.65; 21603600,294.95; 21607200,295.05;
        21610800,295.65; 21614400,295.55; 21618000,294.95; 21621600,294.85;
        21625200,294.65; 21628800,294.95; 21632400,295.45; 21636000,295.65;
        21639600,295.15; 21643200,295.15; 21646800,295.45; 21650400,294.85;
        21654000,294.95; 21657600,295.35; 21661200,295.05; 21664800,294.85;
        21668400,294.75; 21672000,294.65; 21675600,294.75; 21679200,294.95;
        21682800,294.95; 21686400,294.65; 21690000,294.65; 21693600,295.15;
        21697200,295.35; 21700800,295.45; 21704400,295.15; 21708000,295.05;
        21711600,294.95; 21715200,294.85; 21718800,295.55; 21722400,295.75;
        21726000,295.35; 21729600,295.35; 21733200,295.45; 21736800,295.35;
        21740400,295.05; 21744000,295.05; 21747600,295.05; 21751200,295.15;
        21754800,294.85; 21758400,294.85; 21762000,294.85; 21765600,294.85;
        21769200,294.85; 21772800,294.95; 21776400,294.85; 21780000,295.35;
        21783600,295.55; 21787200,295.35; 21790800,295.55; 21794400,295.75;
        21798000,294.75; 21801600,295.15; 21805200,295.95; 21808800,295.85;
        21812400,295.05; 21816000,295.25; 21819600,295.25; 21823200,294.85;
        21826800,295.05; 21830400,295.15; 21834000,294.95; 21837600,295.25;
        21841200,295.05; 21844800,294.85; 21848400,294.85; 21852000,294.85;
        21855600,294.85; 21859200,294.75; 21862800,295.05; 21866400,295.35;
        21870000,295.55; 21873600,295.65; 21877200,295.65; 21880800,295.45;
        21884400,295.35; 21888000,295.85; 21891600,295.75; 21895200,295.15;
        21898800,295.35; 21902400,295.45; 21906000,295.35; 21909600,294.95;
        21913200,294.95; 21916800,294.95; 21920400,295.05; 21924000,295.05;
        21927600,295.05; 21931200,295.05; 21934800,295.05; 21938400,295.05;
        21942000,295.05; 21945600,294.95; 21949200,295.65; 21952800,296.05;
        21956400,296.05; 21960000,295.95; 21963600,295.85; 21967200,295.75;
        21970800,295.65; 21974400,295.65; 21978000,295.45; 21981600,295.45;
        21985200,295.45; 21988800,295.45; 21992400,295.45; 21996000,295.35;
        21999600,295.35; 22003200,295.35; 22006800,295.35; 22010400,295.35;
        22014000,295.35; 22017600,295.35; 22021200,295.35; 22024800,295.35;
        22028400,295.35; 22032000,295.05; 22035600,295.55; 22039200,295.85;
        22042800,296.05; 22046400,295.95; 22050000,295.75; 22053600,295.85;
        22057200,295.65; 22060800,296.25; 22064400,296.65; 22068000,295.85;
        22071600,295.25; 22075200,295.35; 22078800,295.65; 22082400,294.95;
        22086000,295.15; 22089600,295.35; 22093200,295.25; 22096800,295.35;
        22100400,295.15; 22104000,295.15; 22107600,295.25; 22111200,295.35;
        22114800,295.35; 22118400,295.35; 22122000,295.35; 22125600,295.65;
        22129200,295.55; 22132800,295.55; 22136400,295.55; 22140000,295.45;
        22143600,295.25; 22147200,295.35; 22150800,295.95; 22154400,295.75;
        22158000,295.35; 22161600,295.15; 22165200,295.25; 22168800,295.25;
        22172400,295.05; 22176000,294.85; 22179600,295.35; 22183200,295.45;
        22186800,295.05; 22190400,295.25; 22194000,295.55; 22197600,295.85;
        22201200,296.15; 22204800,295.95; 22208400,295.85; 22212000,295.95;
        22215600,296.05; 22219200,296.05; 22222800,295.95; 22226400,296.55;
        22230000,295.85; 22233600,296.35; 22237200,296.55; 22240800,295.55;
        22244400,295.35; 22248000,295.45; 22251600,295.35; 22255200,295.25;
        22258800,295.25; 22262400,295.55; 22266000,295.45; 22269600,295.35;
        22273200,295.55; 22276800,295.35; 22280400,295.15; 22284000,295.25;
        22287600,295.45; 22291200,295.55; 22294800,295.35; 22298400,295.65;
        22302000,295.55; 22305600,295.55; 22309200,295.65; 22312800,295.95;
        22316400,295.35; 22320000,295.45; 22323600,296.05; 22327200,295.65;
        22330800,295.35; 22334400,295.35; 22338000,295.35; 22341600,295.25;
        22345200,295.05; 22348800,295.35; 22352400,295.35; 22356000,295.15;
        22359600,295.25; 22363200,295.15; 22366800,295.05; 22370400,295.15;
        22374000,295.25; 22377600,295.45; 22381200,295.45; 22384800,295.55;
        22388400,295.65; 22392000,295.65; 22395600,295.55; 22399200,295.55;
        22402800,295.25; 22406400,295.55; 22410000,295.75; 22413600,295.45;
        22417200,295.35; 22420800,295.45; 22424400,295.45; 22428000,295.25;
        22431600,295.15; 22435200,295.35; 22438800,295.25; 22442400,295.25;
        22446000,295.45; 22449600,295.15; 22453200,295.45; 22456800,295.65;
        22460400,295.75; 22464000,295.65; 22467600,295.25; 22471200,295.25;
        22474800,295.55; 22478400,295.45; 22482000,295.55; 22485600,295.55;
        22489200,295.45; 22492800,295.65; 22496400,296.05; 22500000,295.35;
        22503600,295.35; 22507200,295.55; 22510800,295.35; 22514400,295.35;
        22518000,295.15; 22521600,295.25; 22525200,295.15; 22528800,294.95;
        22532400,295.15; 22536000,294.95; 22539600,294.75; 22543200,294.85;
        22546800,295.15; 22550400,295.45; 22554000,295.55; 22557600,295.75;
        22561200,295.95; 22564800,295.85; 22568400,295.65; 22572000,295.55;
        22575600,295.45; 22579200,295.85; 22582800,295.85; 22586400,295.35;
        22590000,295.55; 22593600,295.85; 22597200,295.35; 22600800,295.45;
        22604400,295.25; 22608000,295.05; 22611600,295.35; 22615200,295.45;
        22618800,295.25; 22622400,295.25; 22626000,295.15; 22629600,295.15;
        22633200,295.05; 22636800,295.15; 22640400,295.65; 22644000,295.95;
        22647600,295.75; 22651200,295.75; 22654800,295.55; 22658400,295.85;
        22662000,295.45; 22665600,295.85; 22669200,296.65; 22672800,295.65;
        22676400,295.65; 22680000,295.65; 22683600,295.05; 22687200,295.25;
        22690800,294.85; 22694400,294.65; 22698000,294.75; 22701600,294.75;
        22705200,294.75; 22708800,294.85; 22712400,294.85; 22716000,294.85;
        22719600,294.85; 22723200,295.05; 22726800,295.55; 22730400,295.85;
        22734000,296.05; 22737600,296.15; 22741200,296.15; 22744800,295.95;
        22748400,295.65; 22752000,296.05; 22755600,297.05; 22759200,296.05;
        22762800,295.55; 22766400,295.35; 22770000,295.35; 22773600,295.25;
        22777200,295.05; 22780800,295.15; 22784400,294.95; 22788000,295.15;
        22791600,295.15; 22795200,295.15; 22798800,295.15; 22802400,295.15;
        22806000,295.15; 22809600,294.95; 22813200,295.45; 22816800,295.85;
        22820400,295.85; 22824000,295.75; 22827600,295.65; 22831200,295.45;
        22834800,295.15; 22838400,295.35; 22842000,296.05; 22845600,295.65;
        22849200,295.55; 22852800,295.15; 22856400,295.35; 22860000,295.25;
        22863600,295.05; 22867200,295.25; 22870800,295.35; 22874400,295.35;
        22878000,295.35; 22881600,295.35; 22885200,295.35; 22888800,295.35;
        22892400,295.35; 22896000,295.25; 22899600,295.05; 22903200,295.15;
        22906800,295.35; 22910400,295.05; 22914000,294.95; 22917600,294.85;
        22921200,294.85; 22924800,294.85; 22928400,294.85; 22932000,295.05;
        22935600,295.35; 22939200,295.05; 22942800,295.05; 22946400,295.15;
        22950000,295.05; 22953600,295.15; 22957200,295.15; 22960800,294.95;
        22964400,294.85; 22968000,294.85; 22971600,294.85; 22975200,294.95;
        22978800,294.95; 22982400,294.65; 22986000,294.95; 22989600,295.75;
        22993200,296.15; 22996800,296.05; 23000400,295.95; 23004000,296.05;
        23007600,295.55; 23011200,295.65; 23014800,296.25; 23018400,295.55;
        23022000,295.55; 23025600,295.25; 23029200,295.25; 23032800,295.25;
        23036400,295.05; 23040000,295.15; 23043600,295.15; 23047200,295.15;
        23050800,295.15; 23054400,295.15; 23058000,295.15; 23061600,295.15;
        23065200,295.15; 23068800,294.95; 23072400,295.35; 23076000,295.75;
        23079600,295.65; 23083200,295.95; 23086800,296.15; 23090400,296.35;
        23094000,296.05; 23097600,295.55; 23101200,295.45; 23104800,295.55;
        23108400,295.55; 23112000,295.15; 23115600,295.45; 23119200,295.45;
        23122800,295.25; 23126400,295.25; 23130000,295.25; 23133600,295.25;
        23137200,295.25; 23140800,295.35; 23144400,295.35; 23148000,295.35;
        23151600,295.35; 23155200,295.35; 23158800,295.05; 23162400,295.45;
        23166000,295.85; 23169600,295.55; 23173200,295.45; 23176800,295.85;
        23180400,296.05; 23184000,295.45; 23187600,295.15; 23191200,295.25;
        23194800,295.35; 23198400,295.05; 23202000,295.05; 23205600,295.25;
        23209200,295.15; 23212800,295.15; 23216400,295.15; 23220000,295.05;
        23223600,294.85; 23227200,294.95; 23230800,294.95; 23234400,294.95;
        23238000,295.05; 23241600,294.95; 23245200,295.15; 23248800,295.85;
        23252400,295.85; 23256000,295.75; 23259600,295.75; 23263200,295.95;
        23266800,295.85; 23270400,296.55; 23274000,296.65; 23277600,295.95;
        23281200,295.75; 23284800,295.25; 23288400,295.25; 23292000,295.25;
        23295600,295.25; 23299200,295.55; 23302800,295.55; 23306400,295.15;
        23310000,294.95; 23313600,295.05; 23317200,295.05; 23320800,295.05;
        23324400,295.05; 23328000,295.05; 23331600,295.05; 23335200,295.05;
        23338800,295.55; 23342400,295.15; 23346000,294.95; 23349600,294.85;
        23353200,294.85; 23356800,294.85; 23360400,294.75; 23364000,294.85;
        23367600,295.35; 23371200,295.05; 23374800,295.05; 23378400,295.15;
        23382000,295.05; 23385600,295.15; 23389200,295.35; 23392800,294.85;
        23396400,294.75; 23400000,294.85; 23403600,294.85; 23407200,294.85;
        23410800,294.85; 23414400,294.85; 23418000,294.85; 23421600,294.85;
        23425200,295.05; 23428800,295.05; 23432400,294.75; 23436000,294.75;
        23439600,294.75; 23443200,294.75; 23446800,294.85; 23450400,294.85;
        23454000,294.85; 23457600,295.15; 23461200,294.85; 23464800,294.95;
        23468400,294.85; 23472000,294.95; 23475600,295.05; 23479200,294.75;
        23482800,294.75; 23486400,294.75; 23490000,294.85; 23493600,294.85;
        23497200,294.85; 23500800,294.85; 23504400,294.85; 23508000,294.85;
        23511600,294.85; 23515200,294.75; 23518800,294.75; 23522400,294.75;
        23526000,294.75; 23529600,294.75; 23533200,294.75; 23536800,294.85;
        23540400,294.85; 23544000,294.65; 23547600,294.75; 23551200,294.65;
        23554800,294.55; 23558400,294.65; 23562000,294.65; 23565600,294.65;
        23569200,294.65; 23572800,294.75; 23576400,294.75; 23580000,294.75;
        23583600,294.75; 23587200,294.75; 23590800,295.55; 23594400,295.65;
        23598000,295.45; 23601600,295.45; 23605200,295.75; 23608800,295.75;
        23612400,295.45; 23616000,296.15; 23619600,296.35; 23623200,295.85;
        23626800,295.55; 23630400,295.05; 23634000,295.35; 23637600,295.25;
        23641200,295.25; 23644800,295.35; 23648400,295.15; 23652000,294.65;
        23655600,294.65; 23659200,294.65; 23662800,294.75; 23666400,294.85;
        23670000,295.15; 23673600,295.45; 23677200,295.55; 23680800,295.85;
        23684400,295.95; 23688000,295.85; 23691600,295.85; 23695200,296.05;
        23698800,295.75; 23702400,295.55; 23706000,295.45; 23709600,295.55;
        23713200,295.65; 23716800,295.25; 23720400,295.65; 23724000,295.75;
        23727600,295.05; 23731200,295.25; 23734800,295.45; 23738400,294.95;
        23742000,294.85; 23745600,294.85; 23749200,294.85; 23752800,294.85;
        23756400,294.85; 23760000,294.85; 23763600,294.85; 23767200,295.15;
        23770800,295.55; 23774400,295.45; 23778000,295.25; 23781600,294.85;
        23785200,294.85; 23788800,294.85; 23792400,294.85; 23796000,295.35;
        23799600,295.65; 23803200,295.15; 23806800,295.05; 23810400,295.45;
        23814000,295.05; 23817600,295.15; 23821200,295.15; 23824800,294.95;
        23828400,294.85; 23832000,294.85; 23835600,294.65; 23839200,294.65;
        23842800,294.85; 23846400,294.85; 23850000,294.95; 23853600,295.15;
        23857200,295.25; 23860800,295.25; 23864400,295.35; 23868000,295.15;
        23871600,295.15; 23875200,295.15; 23878800,294.95; 23882400,295.25;
        23886000,295.15; 23889600,295.35; 23893200,295.35; 23896800,295.25;
        23900400,295.25; 23904000,295.45; 23907600,295.45; 23911200,294.95;
        23914800,294.65; 23918400,294.65; 23922000,294.65; 23925600,294.75;
        23929200,295.65; 23932800,296.45; 23936400,295.05; 23940000,295.35;
        23943600,295.85; 23947200,296.25; 23950800,295.65; 23954400,294.55;
        23958000,294.45; 23961600,294.75; 23965200,295.55; 23968800,295.65;
        23972400,295.95; 23976000,296.35; 23979600,295.55; 23983200,295.45;
        23986800,295.85; 23990400,295.55; 23994000,295.45; 23997600,295.65;
        24001200,295.65; 24004800,295.35; 24008400,295.25; 24012000,294.95;
        24015600,295.05; 24019200,295.25; 24022800,295.25; 24026400,295.45;
        24030000,295.75; 24033600,295.65; 24037200,295.75; 24040800,295.95;
        24044400,295.95; 24048000,295.25; 24051600,295.95; 24055200,295.85;
        24058800,295.95; 24062400,295.25; 24066000,295.35; 24069600,295.35;
        24073200,294.95; 24076800,295.15; 24080400,295.35; 24084000,295.25;
        24087600,294.85; 24091200,294.85; 24094800,294.85; 24098400,295.05;
        24102000,295.35; 24105600,295.45; 24109200,295.75; 24112800,295.75;
        24116400,295.65; 24120000,295.75; 24123600,295.85; 24127200,295.85;
        24130800,295.75; 24134400,296.95; 24138000,297.65; 24141600,297.45;
        24145200,296.45; 24148800,296.35; 24152400,296.35; 24156000,295.75;
        24159600,296.15; 24163200,295.95; 24166800,295.35; 24170400,295.25;
        24174000,294.95; 24177600,294.95; 24181200,294.95; 24184800,295.05;
        24188400,295.35; 24192000,295.55; 24195600,295.85; 24199200,295.65;
        24202800,295.95; 24206400,296.35; 24210000,296.55; 24213600,296.75;
        24217200,295.95; 24220800,296.15; 24224400,296.65; 24228000,296.25;
        24231600,295.65; 24235200,295.05; 24238800,295.75; 24242400,295.95;
        24246000,295.45; 24249600,295.55; 24253200,295.45; 24256800,295.45;
        24260400,295.35; 24264000,295.35; 24267600,295.35; 24271200,295.35;
        24274800,295.35; 24278400,295.35; 24282000,295.25; 24285600,295.95;
        24289200,295.75; 24292800,295.85; 24296400,295.95; 24300000,295.85;
        24303600,295.65; 24307200,294.95; 24310800,294.85; 24314400,295.65;
        24318000,295.95; 24321600,295.65; 24325200,296.25; 24328800,296.15;
        24332400,295.35; 24336000,295.35; 24339600,295.65; 24343200,295.45;
        24346800,294.65; 24350400,294.65; 24354000,294.65; 24357600,294.65;
        24361200,294.75; 24364800,294.75; 24368400,295.05; 24372000,295.65;
        24375600,295.85; 24379200,295.95; 24382800,296.25; 24386400,295.35;
        24390000,294.75; 24393600,295.25; 24397200,295.45; 24400800,295.75;
        24404400,295.75; 24408000,295.85; 24411600,296.45; 24415200,295.75;
        24418800,295.65; 24422400,295.65; 24426000,295.55; 24429600,295.05;
        24433200,294.85; 24436800,294.85; 24440400,294.85; 24444000,294.85;
        24447600,294.75; 24451200,295.05; 24454800,295.65; 24458400,295.75;
        24462000,295.65; 24465600,295.45; 24469200,296.05; 24472800,296.45;
        24476400,295.75; 24480000,296.65; 24483600,296.95; 24487200,296.15;
        24490800,295.55; 24494400,295.65; 24498000,295.85; 24501600,295.95;
        24505200,295.65; 24508800,295.45; 24512400,295.55; 24516000,295.25;
        24519600,294.95; 24523200,295.15; 24526800,295.65; 24530400,296.15;
        24534000,296.35; 24537600,295.95; 24541200,295.75; 24544800,296.45;
        24548400,296.65; 24552000,296.25; 24555600,295.65; 24559200,295.45;
        24562800,296.15; 24566400,297.25; 24570000,297.35; 24573600,296.25;
        24577200,295.55; 24580800,295.65; 24584400,295.95; 24588000,295.65;
        24591600,295.55; 24595200,295.85; 24598800,295.35; 24602400,295.35;
        24606000,295.55; 24609600,295.45; 24613200,295.45; 24616800,295.35;
        24620400,295.25; 24624000,295.15; 24627600,295.15; 24631200,295.55;
        24634800,295.55; 24638400,295.35; 24642000,295.55; 24645600,294.55;
        24649200,294.55; 24652800,294.95; 24656400,295.95; 24660000,295.75;
        24663600,295.75; 24667200,295.25; 24670800,295.45; 24674400,295.45;
        24678000,295.45; 24681600,295.45; 24685200,295.85; 24688800,295.25;
        24692400,295.05; 24696000,294.85; 24699600,294.85; 24703200,294.85;
        24706800,294.85; 24710400,294.85; 24714000,294.75; 24717600,295.25;
        24721200,295.55; 24724800,295.35; 24728400,295.15; 24732000,295.25;
        24735600,295.25; 24739200,295.35; 24742800,295.15; 24746400,295.55;
        24750000,295.55; 24753600,295.15; 24757200,295.35; 24760800,295.45;
        24764400,295.25; 24768000,295.65; 24771600,295.85; 24775200,295.05;
        24778800,294.85; 24782400,294.85; 24786000,294.85; 24789600,294.85;
        24793200,294.85; 24796800,294.85; 24800400,294.85; 24804000,295.35;
        24807600,295.45; 24811200,295.25; 24814800,294.85; 24818400,294.75;
        24822000,294.75; 24825600,294.75; 24829200,295.55; 24832800,295.45;
        24836400,295.45; 24840000,295.35; 24843600,295.25; 24847200,295.35;
        24850800,295.45; 24854400,295.25; 24858000,295.35; 24861600,295.15;
        24865200,295.05; 24868800,294.95; 24872400,294.95; 24876000,295.05;
        24879600,294.95; 24883200,294.65; 24886800,295.15; 24890400,295.35;
        24894000,295.25; 24897600,295.15; 24901200,295.35; 24904800,295.25;
        24908400,295.25; 24912000,295.25; 24915600,295.05; 24919200,295.35;
        24922800,295.55; 24926400,295.15; 24930000,295.05; 24933600,295.25;
        24937200,294.75; 24940800,294.75; 24944400,294.95; 24948000,295.15;
        24951600,294.65; 24955200,294.75; 24958800,294.75; 24962400,294.75;
        24966000,294.75; 24969600,294.85; 24973200,294.85; 24976800,294.95;
        24980400,295.55; 24984000,295.85; 24987600,294.75; 24991200,294.55;
        24994800,294.55; 24998400,294.65; 25002000,294.95; 25005600,295.25;
        25009200,295.35; 25012800,295.25; 25016400,295.45; 25020000,295.15;
        25023600,295.05; 25027200,294.95; 25030800,295.35; 25034400,295.15;
        25038000,294.85; 25041600,294.85; 25045200,294.65; 25048800,295.15;
        25052400,295.75; 25056000,295.75; 25059600,295.75; 25063200,295.85;
        25066800,295.95; 25070400,296.15; 25074000,296.05; 25077600,296.15;
        25081200,295.85; 25084800,297.05; 25088400,297.15; 25092000,296.35;
        25095600,295.45; 25099200,295.65; 25102800,295.85; 25106400,295.55;
        25110000,295.75; 25113600,295.65; 25117200,295.55; 25120800,295.55;
        25124400,295.55; 25128000,295.55; 25131600,295.45; 25135200,295.35;
        25138800,295.35; 25142400,295.05; 25146000,295.05; 25149600,295.15;
        25153200,295.45; 25156800,295.35; 25160400,295.25; 25164000,295.25;
        25167600,295.25; 25171200,295.05; 25174800,295.95; 25178400,296.25;
        25182000,295.55; 25185600,295.85; 25189200,296.05; 25192800,295.65;
        25196400,295.75; 25200000,295.95; 25203600,295.85; 25207200,295.15;
        25210800,295.45; 25214400,295.45; 25218000,295.25; 25221600,295.25;
        25225200,294.95; 25228800,295.15; 25232400,295.75; 25236000,295.75;
        25239600,295.65; 25243200,295.75; 25246800,295.75; 25250400,295.65;
        25254000,295.55; 25257600,295.25; 25261200,295.45; 25264800,295.65;
        25268400,295.85; 25272000,296.65; 25275600,296.65; 25279200,295.85;
        25282800,295.25; 25286400,294.95; 25290000,295.05; 25293600,295.45;
        25297200,295.05; 25300800,294.85; 25304400,295.15; 25308000,295.55;
        25311600,295.65; 25315200,295.55; 25318800,295.75; 25322400,295.95;
        25326000,295.85; 25329600,295.95; 25333200,296.15; 25336800,296.55;
        25340400,296.35; 25344000,297.05; 25347600,297.55; 25351200,296.55;
        25354800,295.75; 25358400,295.55; 25362000,295.75; 25365600,295.95;
        25369200,295.35; 25372800,295.35; 25376400,295.85; 25380000,295.85;
        25383600,295.25; 25387200,295.35; 25390800,295.95; 25394400,296.35;
        25398000,296.45; 25401600,296.15; 25405200,296.65; 25408800,296.75;
        25412400,297.25; 25416000,297.15; 25419600,296.95; 25423200,296.65;
        25426800,297.35; 25430400,298.45; 25434000,297.25; 25437600,297.25;
        25441200,296.85; 25444800,295.95; 25448400,296.05; 25452000,296.45;
        25455600,296.25; 25459200,296.25; 25462800,296.35; 25466400,296.45;
        25470000,296.65; 25473600,296.45; 25477200,296.45; 25480800,296.55;
        25484400,296.75; 25488000,296.15; 25491600,296.75; 25495200,297.35;
        25498800,296.95; 25502400,296.95; 25506000,296.95; 25509600,296.55;
        25513200,296.35; 25516800,296.75; 25520400,296.75; 25524000,297.45;
        25527600,296.95; 25531200,296.45; 25534800,296.55; 25538400,296.35;
        25542000,296.35; 25545600,296.15; 25549200,296.45; 25552800,296.25;
        25556400,296.55; 25560000,296.55; 25563600,296.55; 25567200,296.55;
        25570800,296.15; 25574400,296.55; 25578000,296.55; 25581600,296.65;
        25585200,296.75; 25588800,296.55; 25592400,296.65; 25596000,296.85;
        25599600,296.05; 25603200,296.45; 25606800,296.65; 25610400,296.95;
        25614000,296.75; 25617600,296.25; 25621200,296.85; 25624800,296.55;
        25628400,296.15; 25632000,296.55; 25635600,296.65; 25639200,296.45;
        25642800,296.65; 25646400,296.65; 25650000,296.75; 25653600,297.05;
        25657200,297.15; 25660800,296.45; 25664400,296.45; 25668000,296.65;
        25671600,296.45; 25675200,296.65; 25678800,296.65; 25682400,297.15;
        25686000,296.45; 25689600,297.75; 25693200,297.55; 25696800,297.45;
        25700400,297.05; 25704000,297.05; 25707600,297.35; 25711200,296.75;
        25714800,296.95; 25718400,296.75; 25722000,296.65; 25725600,296.75;
        25729200,296.85; 25732800,296.75; 25736400,296.85; 25740000,297.05;
        25743600,296.55; 25747200,296.55; 25750800,296.95; 25754400,296.55;
        25758000,296.65; 25761600,296.65; 25765200,296.55; 25768800,297.15;
        25772400,296.45; 25776000,297.55; 25779600,297.45; 25783200,297.15;
        25786800,297.35; 25790400,296.55; 25794000,296.35; 25797600,296.75;
        25801200,296.25; 25804800,296.25; 25808400,296.45; 25812000,296.55;
        25815600,297.15; 25819200,297.15; 25822800,297.05; 25826400,296.95;
        25830000,296.45; 25833600,296.65; 25837200,296.95; 25840800,296.75;
        25844400,296.55; 25848000,296.65; 25851600,296.45; 25855200,297.05;
        25858800,296.45; 25862400,297.35; 25866000,297.85; 25869600,296.95;
        25873200,296.55; 25876800,296.65; 25880400,296.95; 25884000,297.05;
        25887600,296.95; 25891200,296.55; 25894800,296.45; 25898400,296.75;
        25902000,296.75; 25905600,295.85; 25909200,295.35; 25912800,295.95;
        25916400,296.15; 25920000,296.35; 25923600,296.85; 25927200,296.45;
        25930800,295.85; 25934400,296.15; 25938000,296.05; 25941600,296.65;
        25945200,296.45; 25948800,297.45; 25952400,296.85; 25956000,296.55;
        25959600,296.95; 25963200,295.85; 25966800,296.05; 25970400,296.25;
        25974000,296.25; 25977600,296.55; 25981200,296.95; 25984800,297.05;
        25988400,296.85; 25992000,296.45; 25995600,296.35; 25999200,296.35;
        26002800,296.45; 26006400,295.95; 26010000,296.15; 26013600,296.25;
        26017200,296.55; 26020800,296.65; 26024400,296.85; 26028000,297.25;
        26031600,296.35; 26035200,297.25; 26038800,297.25; 26042400,296.85;
        26046000,296.75; 26049600,296.55; 26053200,296.85; 26056800,296.45;
        26060400,295.95; 26064000,296.05; 26067600,295.95; 26071200,296.35;
        26074800,297.05; 26078400,297.65; 26082000,297.15; 26085600,296.05;
        26089200,296.05; 26092800,296.15; 26096400,296.55; 26100000,296.65;
        26103600,296.45; 26107200,296.45; 26110800,295.95; 26114400,295.65;
        26118000,295.95; 26121600,295.75; 26125200,295.65; 26128800,295.75;
        26132400,295.75; 26136000,295.65; 26139600,295.95; 26143200,295.55;
        26146800,295.35; 26150400,295.65; 26154000,295.65; 26157600,295.75;
        26161200,295.55; 26164800,294.85; 26168400,295.45; 26172000,296.05;
        26175600,296.15; 26179200,296.15; 26182800,296.15; 26186400,296.45;
        26190000,296.25; 26193600,296.25; 26197200,296.15; 26200800,296.05;
        26204400,296.05; 26208000,296.15; 26211600,296.15; 26215200,295.95;
        26218800,296.25; 26222400,295.95; 26226000,295.65; 26229600,295.85;
        26233200,295.75; 26236800,295.65; 26240400,295.95; 26244000,295.85;
        26247600,295.85; 26251200,295.95; 26254800,295.75; 26258400,296.35;
        26262000,296.75; 26265600,296.55; 26269200,295.95; 26272800,295.95;
        26276400,296.15; 26280000,296.05; 26283600,295.95; 26287200,296.35;
        26290800,296.95; 26294400,296.15; 26298000,296.45; 26301600,296.85;
        26305200,296.85; 26308800,296.35; 26312400,296.25; 26316000,296.25;
        26319600,296.45; 26323200,296.95; 26326800,296.75; 26330400,296.35;
        26334000,296.45; 26337600,296.75; 26341200,296.95; 26344800,296.45;
        26348400,296.45; 26352000,297.15; 26355600,296.15; 26359200,295.55;
        26362800,296.25; 26366400,296.55; 26370000,296.35; 26373600,296.85;
        26377200,296.75; 26380800,295.95; 26384400,295.65; 26388000,296.75;
        26391600,296.25; 26395200,296.05; 26398800,295.65; 26402400,295.85;
        26406000,296.05; 26409600,295.45; 26413200,295.75; 26416800,295.85;
        26420400,296.25; 26424000,296.45; 26427600,295.35; 26431200,294.95;
        26434800,295.75; 26438400,296.35; 26442000,296.05; 26445600,295.85;
        26449200,295.55; 26452800,295.95; 26456400,296.45; 26460000,296.65;
        26463600,296.25; 26467200,296.15; 26470800,295.25; 26474400,296.15;
        26478000,295.85; 26481600,296.05; 26485200,296.05; 26488800,296.05;
        26492400,296.15; 26496000,295.95; 26499600,295.85; 26503200,295.95;
        26506800,295.45; 26510400,294.85; 26514000,294.85; 26517600,295.05;
        26521200,295.15; 26524800,295.85; 26528400,295.45; 26532000,295.85;
        26535600,295.95; 26539200,296.05; 26542800,296.15; 26546400,296.15;
        26550000,295.15; 26553600,295.65; 26557200,295.45; 26560800,296.15;
        26564400,296.25; 26568000,295.85; 26571600,295.95; 26575200,295.85;
        26578800,295.95; 26582400,296.05; 26586000,297.05; 26589600,295.85;
        26593200,295.25; 26596800,295.05; 26600400,295.05; 26604000,294.95;
        26607600,295.35; 26611200,295.25; 26614800,296.05; 26618400,296.35;
        26622000,295.95; 26625600,296.05; 26629200,296.15; 26632800,295.85;
        26636400,295.95; 26640000,295.85; 26643600,295.65; 26647200,296.45;
        26650800,296.55; 26654400,296.35; 26658000,296.35; 26661600,296.35;
        26665200,296.25; 26668800,296.55; 26672400,296.05; 26676000,296.25;
        26679600,296.35; 26683200,294.75; 26686800,295.65; 26690400,295.85;
        26694000,295.95; 26697600,295.55; 26701200,295.95; 26704800,296.65;
        26708400,296.45; 26712000,296.45; 26715600,296.65; 26719200,296.15;
        26722800,296.15; 26726400,296.45; 26730000,296.35; 26733600,296.35;
        26737200,296.15; 26740800,295.75; 26744400,295.45; 26748000,295.75;
        26751600,295.35; 26755200,295.65; 26758800,296.15; 26762400,296.15;
        26766000,296.05; 26769600,296.35; 26773200,296.05; 26776800,295.85;
        26780400,296.05; 26784000,296.35; 26787600,296.45; 26791200,296.45;
        26794800,296.85; 26798400,296.05; 26802000,296.25; 26805600,296.55;
        26809200,295.85; 26812800,295.15; 26816400,295.95; 26820000,296.25;
        26823600,296.15; 26827200,295.95; 26830800,295.75; 26834400,295.95;
        26838000,295.85; 26841600,295.85; 26845200,296.15; 26848800,296.35;
        26852400,296.05; 26856000,296.15; 26859600,295.95; 26863200,295.85;
        26866800,296.15; 26870400,296.95; 26874000,296.35; 26877600,296.05;
        26881200,296.35; 26884800,296.15; 26888400,296.25; 26892000,296.55;
        26895600,296.85; 26899200,296.65; 26902800,297.65; 26906400,297.15;
        26910000,296.85; 26913600,295.75; 26917200,296.35; 26920800,295.85;
        26924400,296.15; 26928000,296.35; 26931600,296.05; 26935200,295.95;
        26938800,295.55; 26942400,295.45; 26946000,295.75; 26949600,296.25;
        26953200,296.45; 26956800,296.15; 26960400,296.35; 26964000,296.65;
        26967600,296.65; 26971200,296.35; 26974800,296.35; 26978400,296.45;
        26982000,296.65; 26985600,296.95; 26989200,297.85; 26992800,297.45;
        26996400,296.65; 27000000,295.65; 27003600,296.35; 27007200,296.15;
        27010800,295.85; 27014400,296.55; 27018000,296.45; 27021600,296.45;
        27025200,296.25; 27028800,295.95; 27032400,296.05; 27036000,296.35;
        27039600,296.45; 27043200,296.15; 27046800,295.75; 27050400,296.65;
        27054000,296.65; 27057600,296.75; 27061200,296.25; 27064800,295.95;
        27068400,296.45; 27072000,296.45; 27075600,297.45; 27079200,297.65;
        27082800,297.05; 27086400,295.75; 27090000,296.35; 27093600,296.15;
        27097200,295.95; 27100800,296.45; 27104400,296.55; 27108000,297.25;
        27111600,297.45; 27115200,297.15; 27118800,296.35; 27122400,296.85;
        27126000,297.25; 27129600,296.45; 27133200,296.55; 27136800,296.85;
        27140400,296.75; 27144000,297.05; 27147600,296.95; 27151200,297.15;
        27154800,297.85; 27158400,296.65; 27162000,297.55; 27165600,297.35;
        27169200,297.05; 27172800,296.35; 27176400,296.45; 27180000,296.15;
        27183600,296.15; 27187200,296.35; 27190800,297.05; 27194400,296.75;
        27198000,295.95; 27201600,295.55; 27205200,295.35; 27208800,296.25;
        27212400,296.45; 27216000,295.95; 27219600,296.45; 27223200,297.05;
        27226800,296.35; 27230400,296.55; 27234000,297.85; 27237600,296.15;
        27241200,296.15; 27244800,295.95; 27248400,296.45; 27252000,296.65;
        27255600,296.25; 27259200,296.25; 27262800,296.15; 27266400,296.05;
        27270000,296.45; 27273600,296.45; 27277200,296.35; 27280800,295.95;
        27284400,295.85; 27288000,295.45; 27291600,295.85; 27295200,295.75;
        27298800,296.15; 27302400,296.15; 27306000,297.05; 27309600,297.45;
        27313200,296.45; 27316800,296.85; 27320400,297.15; 27324000,297.15;
        27327600,297.35; 27331200,296.65; 27334800,296.25; 27338400,296.35;
        27342000,296.65; 27345600,295.85; 27349200,295.75; 27352800,295.65;
        27356400,295.65; 27360000,295.75; 27363600,296.05; 27367200,296.05;
        27370800,296.35; 27374400,296.75; 27378000,296.25; 27381600,296.25;
        27385200,297.05; 27388800,296.65; 27392400,296.45; 27396000,296.45;
        27399600,296.35; 27403200,297.15; 27406800,297.35; 27410400,295.95;
        27414000,296.35; 27417600,296.45; 27421200,296.35; 27424800,296.15;
        27428400,296.35; 27432000,296.35; 27435600,295.95; 27439200,296.55;
        27442800,296.45; 27446400,296.15; 27450000,296.25; 27453600,296.45;
        27457200,296.25; 27460800,296.25; 27464400,296.55; 27468000,296.55;
        27471600,296.15; 27475200,296.65; 27478800,296.25; 27482400,296.05;
        27486000,296.25; 27489600,296.25; 27493200,296.35; 27496800,296.35;
        27500400,296.85; 27504000,296.05; 27507600,297.15; 27511200,297.35;
        27514800,296.75; 27518400,296.55; 27522000,296.55; 27525600,296.75;
        27529200,296.55; 27532800,296.45; 27536400,296.45; 27540000,296.35;
        27543600,297.05; 27547200,296.95; 27550800,296.45; 27554400,296.45;
        27558000,296.55; 27561600,296.45; 27565200,296.85; 27568800,297.35;
        27572400,297.15; 27576000,297.05; 27579600,297.25; 27583200,297.25;
        27586800,297.05; 27590400,297.75; 27594000,299.05; 27597600,298.55;
        27601200,298.25; 27604800,297.55; 27608400,297.25; 27612000,296.85;
        27615600,296.95; 27619200,297.75; 27622800,297.75; 27626400,297.55;
        27630000,297.65; 27633600,297.45; 27637200,297.45; 27640800,298.15;
        27644400,298.35; 27648000,297.35; 27651600,297.45; 27655200,298.65;
        27658800,298.25; 27662400,297.95; 27666000,298.05; 27669600,297.95;
        27673200,297.35; 27676800,297.15; 27680400,298.75; 27684000,298.65;
        27687600,298.15; 27691200,298.15; 27694800,297.75; 27698400,297.85;
        27702000,297.95; 27705600,297.85; 27709200,297.75; 27712800,298.05;
        27716400,297.85; 27720000,297.35; 27723600,297.35; 27727200,297.55;
        27730800,297.35; 27734400,297.05; 27738000,297.15; 27741600,297.65;
        27745200,297.15; 27748800,297.25; 27752400,297.45; 27756000,297.55;
        27759600,297.75; 27763200,297.15; 27766800,298.35; 27770400,298.65;
        27774000,298.55; 27777600,297.95; 27781200,298.05; 27784800,297.15;
        27788400,297.65; 27792000,297.85; 27795600,297.65; 27799200,297.65;
        27802800,297.55; 27806400,297.15; 27810000,297.45; 27813600,297.45;
        27817200,297.65; 27820800,297.45; 27824400,297.75; 27828000,298.35;
        27831600,297.65; 27835200,297.95; 27838800,297.85; 27842400,297.75;
        27846000,297.25; 27849600,297.75; 27853200,298.85; 27856800,298.55;
        27860400,298.35; 27864000,298.35; 27867600,298.55; 27871200,297.35;
        27874800,297.35; 27878400,297.35; 27882000,297.15; 27885600,297.35;
        27889200,297.15; 27892800,296.45; 27896400,296.55; 27900000,297.35;
        27903600,297.95; 27907200,297.15; 27910800,297.15; 27914400,297.85;
        27918000,297.65; 27921600,298.25; 27925200,298.25; 27928800,297.75;
        27932400,298.05; 27936000,298.55; 27939600,298.75; 27943200,298.55;
        27946800,299.35; 27950400,298.35; 27954000,297.15; 27957600,298.25;
        27961200,297.45; 27964800,297.75; 27968400,298.85; 27972000,299.15;
        27975600,299.55; 27979200,299.35; 27982800,298.65; 27986400,298.75;
        27990000,299.65; 27993600,299.55; 27997200,299.25; 28000800,299.25;
        28004400,299.45; 28008000,299.45; 28011600,299.15; 28015200,299.15;
        28018800,298.95; 28022400,299.55; 28026000,299.55; 28029600,298.85;
        28033200,299.05; 28036800,298.85; 28040400,298.65; 28044000,298.45;
        28047600,297.65; 28051200,296.55; 28054800,297.75; 28058400,297.35;
        28062000,296.75; 28065600,295.95; 28069200,295.95; 28072800,295.95;
        28076400,297.35; 28080000,298.05; 28083600,297.55; 28087200,296.65;
        28090800,297.05; 28094400,297.35; 28098000,296.95; 28101600,296.55;
        28105200,295.75; 28108800,295.45; 28112400,296.85; 28116000,297.35;
        28119600,297.25; 28123200,296.55; 28126800,296.85; 28130400,296.65;
        28134000,296.65; 28137600,296.75; 28141200,296.55; 28144800,296.55;
        28148400,296.45; 28152000,296.65; 28155600,296.35; 28159200,295.65;
        28162800,296.35; 28166400,296.45; 28170000,296.35; 28173600,297.15;
        28177200,296.45; 28180800,296.05; 28184400,296.65; 28188000,296.05;
        28191600,295.95; 28195200,295.35; 28198800,296.85; 28202400,296.65;
        28206000,296.35; 28209600,296.55; 28213200,295.65; 28216800,296.35;
        28220400,296.05; 28224000,296.15; 28227600,296.25; 28231200,296.05;
        28234800,296.35; 28238400,296.55; 28242000,296.25; 28245600,296.25;
        28249200,296.45; 28252800,296.25; 28256400,296.65; 28260000,297.05;
        28263600,295.85; 28267200,295.95; 28270800,296.35; 28274400,296.25;
        28278000,296.85; 28281600,296.15; 28285200,296.75; 28288800,296.85;
        28292400,296.25; 28296000,295.95; 28299600,296.45; 28303200,296.35;
        28306800,296.05; 28310400,296.45; 28314000,296.65; 28317600,295.75;
        28321200,295.85; 28324800,296.05; 28328400,295.95; 28332000,295.95;
        28335600,295.55; 28339200,295.95; 28342800,297.05; 28346400,296.15;
        28350000,296.05; 28353600,296.15; 28357200,296.05; 28360800,296.05;
        28364400,295.85; 28368000,295.25; 28371600,295.95; 28375200,296.45;
        28378800,296.25; 28382400,296.05; 28386000,296.05; 28389600,295.95;
        28393200,296.05; 28396800,296.55; 28400400,296.05; 28404000,295.85;
        28407600,296.35; 28411200,296.65; 28414800,296.25; 28418400,295.55;
        28422000,296.55; 28425600,296.75; 28429200,295.65; 28432800,296.05;
        28436400,296.65; 28440000,296.15; 28443600,296.25; 28447200,296.25;
        28450800,296.05; 28454400,295.65; 28458000,296.05; 28461600,297.05;
        28465200,296.45; 28468800,296.25; 28472400,296.05; 28476000,296.15;
        28479600,296.35; 28483200,296.25; 28486800,296.15; 28490400,296.45;
        28494000,295.95; 28497600,296.65; 28501200,296.55; 28504800,295.75;
        28508400,295.35; 28512000,296.55; 28515600,296.45; 28519200,296.65;
        28522800,296.45; 28526400,295.95; 28530000,296.15; 28533600,296.55;
        28537200,296.15; 28540800,296.05; 28544400,295.95; 28548000,296.05;
        28551600,295.85; 28555200,296.25; 28558800,296.85; 28562400,296.05;
        28566000,295.65; 28569600,295.45; 28573200,295.75; 28576800,295.75;
        28580400,295.55; 28584000,295.65; 28587600,295.55; 28591200,295.85;
        28594800,296.05; 28598400,296.15; 28602000,296.25; 28605600,295.95;
        28609200,296.05; 28612800,295.85; 28616400,296.05; 28620000,296.55;
        28623600,296.65; 28627200,297.35; 28630800,296.25; 28634400,296.05;
        28638000,295.95; 28641600,295.95; 28645200,295.35; 28648800,295.75;
        28652400,295.65; 28656000,295.25; 28659600,296.05; 28663200,296.15;
        28666800,295.35; 28670400,294.95; 28674000,295.25; 28677600,295.05;
        28681200,295.65; 28684800,296.25; 28688400,295.95; 28692000,295.55;
        28695600,295.85; 28699200,296.25; 28702800,296.15; 28706400,296.25;
        28710000,295.95; 28713600,295.25; 28717200,296.45; 28720800,297.15;
        28724400,297.05; 28728000,296.75; 28731600,296.55; 28735200,296.15;
        28738800,296.45; 28742400,296.65; 28746000,296.55; 28749600,296.65;
        28753200,297.05; 28756800,297.05; 28760400,296.55; 28764000,296.15;
        28767600,296.45; 28771200,296.05; 28774800,296.15; 28778400,296.55;
        28782000,296.35; 28785600,296.25; 28789200,296.45; 28792800,296.45;
        28796400,296.85; 28800000,296.05; 28803600,297.15; 28807200,297.15;
        28810800,296.65; 28814400,296.25; 28818000,296.45; 28821600,296.15;
        28825200,295.95; 28828800,296.15; 28832400,296.25; 28836000,295.95;
        28839600,295.55; 28843200,295.35; 28846800,295.25; 28850400,295.25;
        28854000,296.05; 28857600,296.45; 28861200,295.65; 28864800,296.35;
        28868400,296.55; 28872000,296.45; 28875600,296.35; 28879200,296.45;
        28882800,296.65; 28886400,296.05; 28890000,296.85; 28893600,296.85;
        28897200,296.45; 28900800,296.55; 28904400,296.45; 28908000,296.55;
        28911600,296.35; 28915200,296.35; 28918800,296.45; 28922400,296.35;
        28926000,296.15; 28929600,296.25; 28933200,296.25; 28936800,296.05;
        28940400,296.15; 28944000,296.05; 28947600,296.25; 28951200,296.35;
        28954800,296.15; 28958400,296.15; 28962000,296.55; 28965600,296.35;
        28969200,296.25; 28972800,296.15; 28976400,296.85; 28980000,297.05;
        28983600,296.65; 28987200,296.65; 28990800,296.85; 28994400,296.45;
        28998000,296.55; 29001600,296.65; 29005200,296.75; 29008800,296.65;
        29012400,296.95; 29016000,297.25; 29019600,296.85; 29023200,295.95;
        29026800,296.25; 29030400,296.55; 29034000,296.25; 29037600,296.45;
        29041200,296.25; 29044800,296.05; 29048400,296.35; 29052000,296.45;
        29055600,296.65; 29059200,295.45; 29062800,296.85; 29066400,297.25;
        29070000,296.75; 29073600,296.45; 29077200,296.25; 29080800,296.45;
        29084400,296.45; 29088000,296.45; 29091600,296.25; 29095200,296.25;
        29098800,296.35; 29102400,296.35; 29106000,296.75; 29109600,296.15;
        29113200,296.45; 29116800,295.95; 29120400,296.35; 29124000,297.25;
        29127600,297.15; 29131200,296.95; 29134800,297.05; 29138400,296.95;
        29142000,296.45; 29145600,296.35; 29149200,296.85; 29152800,296.95;
        29156400,297.35; 29160000,297.95; 29163600,296.55; 29167200,297.55;
        29170800,297.25; 29174400,297.15; 29178000,297.85; 29181600,297.95;
        29185200,297.55; 29188800,297.25; 29192400,297.75; 29196000,297.55;
        29199600,297.45; 29203200,297.35; 29206800,297.05; 29210400,297.25;
        29214000,297.15; 29217600,297.25; 29221200,297.15; 29224800,297.35;
        29228400,297.35; 29232000,297.05; 29235600,295.85; 29239200,296.35;
        29242800,296.35; 29246400,296.75; 29250000,295.85; 29253600,295.65;
        29257200,295.85; 29260800,295.75; 29264400,295.95; 29268000,296.05;
        29271600,295.75; 29275200,295.45; 29278800,295.05; 29282400,295.45;
        29286000,295.95; 29289600,297.05; 29293200,296.65; 29296800,296.15;
        29300400,296.65; 29304000,296.85; 29307600,297.35; 29311200,296.05;
        29314800,296.05; 29318400,295.25; 29322000,296.55; 29325600,296.75;
        29329200,296.05; 29332800,296.25; 29336400,296.35; 29340000,296.15;
        29343600,296.35; 29347200,297.05; 29350800,297.85; 29354400,296.65;
        29358000,296.85; 29361600,296.65; 29365200,295.75; 29368800,295.65;
        29372400,295.45; 29376000,296.05; 29379600,296.25; 29383200,295.75;
        29386800,296.15; 29390400,296.45; 29394000,296.15; 29397600,296.15;
        29401200,296.45; 29404800,295.95; 29408400,296.65; 29412000,296.95;
        29415600,296.25; 29419200,296.25; 29422800,296.35; 29426400,296.25;
        29430000,296.35; 29433600,296.35; 29437200,296.05; 29440800,296.05;
        29444400,296.35; 29448000,296.45; 29451600,296.25; 29455200,295.75;
        29458800,296.15; 29462400,295.85; 29466000,296.05; 29469600,296.45;
        29473200,296.15; 29476800,296.15; 29480400,296.45; 29484000,295.65;
        29487600,296.05; 29491200,296.05; 29494800,296.45; 29498400,297.25;
        29502000,298.15; 29505600,296.25; 29509200,296.75; 29512800,296.35;
        29516400,296.25; 29520000,296.55; 29523600,296.65; 29527200,296.65;
        29530800,296.75; 29534400,296.95; 29538000,296.55; 29541600,296.35;
        29545200,296.45; 29548800,296.35; 29552400,296.55; 29556000,296.85;
        29559600,296.85; 29563200,296.55; 29566800,296.55; 29570400,296.25;
        29574000,296.95; 29577600,296.35; 29581200,297.15; 29584800,297.25;
        29588400,297.05; 29592000,296.75; 29595600,296.75; 29599200,296.75;
        29602800,296.55; 29606400,296.75; 29610000,296.55; 29613600,296.55;
        29617200,296.55; 29620800,296.85; 29624400,296.25; 29628000,296.05;
        29631600,296.65; 29635200,296.55; 29638800,296.05; 29642400,296.55;
        29646000,296.15; 29649600,295.95; 29653200,296.55; 29656800,296.75;
        29660400,296.85; 29664000,295.95; 29667600,297.05; 29671200,297.65;
        29674800,296.95; 29678400,296.25; 29682000,296.25; 29685600,296.55;
        29689200,296.35; 29692800,296.35; 29696400,296.65; 29700000,296.65;
        29703600,296.55; 29707200,296.75; 29710800,296.35; 29714400,296.25;
        29718000,296.45; 29721600,296.05; 29725200,296.45; 29728800,297.15;
        29732400,296.35; 29736000,296.25; 29739600,296.75; 29743200,296.45;
        29746800,296.75; 29750400,296.65; 29754000,296.45; 29757600,296.45;
        29761200,296.85; 29764800,296.95; 29768400,296.65; 29772000,297.35;
        29775600,296.95; 29779200,296.65; 29782800,296.65; 29786400,297.35;
        29790000,296.75; 29793600,296.55; 29797200,296.75; 29800800,296.35;
        29804400,297.25; 29808000,297.05; 29811600,296.75; 29815200,297.55;
        29818800,297.65; 29822400,297.35; 29826000,297.45; 29829600,297.85;
        29833200,297.45; 29836800,297.65; 29840400,298.45; 29844000,298.35;
        29847600,298.25; 29851200,297.45; 29854800,297.35; 29858400,297.75;
        29862000,297.25; 29865600,297.65; 29869200,298.45; 29872800,298.55;
        29876400,298.15; 29880000,297.85; 29883600,298.15; 29887200,298.25;
        29890800,297.75; 29894400,298.05; 29898000,298.05; 29901600,297.75;
        29905200,298.15; 29908800,298.35; 29912400,298.15; 29916000,297.45;
        29919600,297.75; 29923200,297.45; 29926800,299.15; 29930400,299.35;
        29934000,299.05; 29937600,298.65; 29941200,298.45; 29944800,298.35;
        29948400,298.45; 29952000,298.45; 29955600,298.25; 29959200,297.95;
        29962800,298.05; 29966400,298.05; 29970000,297.65; 29973600,298.15;
        29977200,298.05; 29980800,297.65; 29984400,298.15; 29988000,298.45;
        29991600,298.05; 29995200,298.25; 29998800,298.25; 30002400,298.05;
        30006000,298.05; 30009600,298.25; 30013200,299.55; 30016800,299.85;
        30020400,299.25; 30024000,298.65; 30027600,299.05; 30031200,298.45;
        30034800,298.25; 30038400,298.75; 30042000,298.35; 30045600,297.85;
        30049200,297.75; 30052800,297.95; 30056400,298.15; 30060000,298.75;
        30063600,298.55; 30067200,297.85; 30070800,298.65; 30074400,299.15;
        30078000,298.85; 30081600,298.35; 30085200,298.35; 30088800,298.05;
        30092400,297.55; 30096000,298.05; 30099600,299.25; 30103200,299.15;
        30106800,298.45; 30110400,298.35; 30114000,298.75; 30117600,298.35;
        30121200,298.15; 30124800,298.65; 30128400,298.75; 30132000,298.35;
        30135600,298.15; 30139200,298.15; 30142800,297.85; 30146400,298.35;
        30150000,298.65; 30153600,298.05; 30157200,298.05; 30160800,298.75;
        30164400,298.55; 30168000,298.15; 30171600,298.45; 30175200,298.45;
        30178800,297.75; 30182400,298.95; 30186000,300.05; 30189600,300.15;
        30193200,299.35; 30196800,298.85; 30200400,299.05; 30204000,298.85;
        30207600,298.75; 30211200,299.15; 30214800,298.75; 30218400,298.35;
        30222000,298.25; 30225600,298.45; 30229200,298.15; 30232800,298.45;
        30236400,298.05; 30240000,297.55; 30243600,297.95; 30247200,298.35;
        30250800,298.65; 30254400,298.75; 30258000,298.75; 30261600,298.45;
        30265200,297.95; 30268800,297.45; 30272400,299.05; 30276000,299.25;
        30279600,298.45; 30283200,298.15; 30286800,298.65; 30290400,297.85;
        30294000,297.95; 30297600,298.75; 30301200,298.65; 30304800,298.25;
        30308400,298.15; 30312000,298.15; 30315600,297.65; 30319200,298.35;
        30322800,297.65; 30326400,297.35; 30330000,298.15; 30333600,298.45;
        30337200,298.15; 30340800,298.55; 30344400,298.35; 30348000,298.25;
        30351600,298.45; 30355200,299.35; 30358800,298.95; 30362400,298.85;
        30366000,298.85; 30369600,298.15; 30373200,298.35; 30376800,298.75;
        30380400,298.35; 30384000,298.65; 30387600,298.65; 30391200,298.65;
        30394800,298.75; 30398400,298.85; 30402000,298.45; 30405600,298.65;
        30409200,298.45; 30412800,298.65; 30416400,298.85; 30420000,298.65;
        30423600,298.55; 30427200,298.95; 30430800,298.65; 30434400,298.45;
        30438000,298.75; 30441600,299.45; 30445200,299.35; 30448800,299.45;
        30452400,299.45; 30456000,298.55; 30459600,299.05; 30463200,299.15;
        30466800,298.35; 30470400,298.65; 30474000,299.45; 30477600,299.75;
        30481200,299.05; 30484800,298.65; 30488400,298.95; 30492000,299.35;
        30495600,299.45; 30499200,299.25; 30502800,299.05; 30506400,299.25;
        30510000,299.55; 30513600,299.45; 30517200,299.25; 30520800,299.15;
        30524400,298.65; 30528000,299.75; 30531600,300.75; 30535200,300.65;
        30538800,299.95; 30542400,299.35; 30546000,299.65; 30549600,298.95;
        30553200,298.75; 30556800,299.35; 30560400,299.35; 30564000,299.15;
        30567600,298.95; 30571200,299.05; 30574800,298.15; 30578400,298.65;
        30582000,299.05; 30585600,298.05; 30589200,298.35; 30592800,299.25;
        30596400,299.15; 30600000,298.85; 30603600,299.15; 30607200,299.25;
        30610800,298.55; 30614400,298.65; 30618000,299.85; 30621600,299.95;
        30625200,299.65; 30628800,299.25; 30632400,299.25; 30636000,299.35;
        30639600,299.05; 30643200,299.65; 30646800,300.25; 30650400,299.85;
        30654000,299.05; 30657600,299.05; 30661200,298.65; 30664800,299.35;
        30668400,299.65; 30672000,298.45; 30675600,298.75; 30679200,298.95;
        30682800,298.85; 30686400,298.95; 30690000,298.95; 30693600,298.55;
        30697200,298.25; 30700800,298.65; 30704400,299.65; 30708000,299.75;
        30711600,299.55; 30715200,298.95; 30718800,298.95; 30722400,298.85;
        30726000,298.75; 30729600,298.55; 30733200,298.25; 30736800,298.35;
        30740400,298.65; 30744000,298.25; 30747600,297.75; 30751200,298.35;
        30754800,297.85; 30758400,297.35; 30762000,297.45; 30765600,298.05;
        30769200,297.55; 30772800,297.45; 30776400,297.75; 30780000,297.95;
        30783600,298.55; 30787200,297.35; 30790800,298.55; 30794400,298.75;
        30798000,298.35; 30801600,298.15; 30805200,298.25; 30808800,298.15;
        30812400,298.15; 30816000,298.15; 30819600,297.95; 30823200,297.95;
        30826800,297.85; 30830400,297.95; 30834000,297.65; 30837600,297.85;
        30841200,297.95; 30844800,297.45; 30848400,297.85; 30852000,298.25;
        30855600,297.85; 30859200,297.95; 30862800,298.05; 30866400,297.85;
        30870000,298.25; 30873600,296.95; 30877200,297.45; 30880800,297.15;
        30884400,297.15; 30888000,298.15; 30891600,296.75; 30895200,296.65;
        30898800,297.35; 30902400,297.55; 30906000,297.15; 30909600,296.75;
        30913200,296.85; 30916800,296.75; 30920400,295.95; 30924000,295.65;
        30927600,296.55; 30931200,296.45; 30934800,296.35; 30938400,297.65;
        30942000,296.65; 30945600,296.45; 30949200,297.05; 30952800,296.95;
        30956400,296.85; 30960000,297.05; 30963600,296.85; 30967200,296.65;
        30970800,297.15; 30974400,297.05; 30978000,296.95; 30981600,297.55;
        30985200,297.15; 30988800,296.95; 30992400,297.05; 30996000,296.95;
        30999600,297.05; 31003200,297.45; 31006800,297.05; 31010400,296.55;
        31014000,296.65; 31017600,296.75; 31021200,296.55; 31024800,296.85;
        31028400,296.85; 31032000,296.45; 31035600,296.75; 31039200,296.85;
        31042800,297.05; 31046400,298.15; 31050000,296.95; 31053600,295.55;
        31057200,296.65; 31060800,296.65; 31064400,296.45; 31068000,296.95;
        31071600,296.05; 31075200,296.25; 31078800,296.95; 31082400,296.15;
        31086000,296.45; 31089600,296.95; 31093200,295.95; 31096800,295.95;
        31100400,297.25; 31104000,296.55; 31107600,296.25; 31111200,297.25;
        31114800,296.85; 31118400,296.75; 31122000,296.95; 31125600,297.15;
        31129200,295.95; 31132800,295.15; 31136400,296.85; 31140000,297.95;
        31143600,297.65; 31147200,296.65; 31150800,296.35; 31154400,296.65;
        31158000,297.05; 31161600,296.35; 31165200,296.35; 31168800,296.15;
        31172400,295.85; 31176000,295.95; 31179600,295.85; 31183200,295.65;
        31186800,295.55; 31190400,296.35; 31194000,296.15; 31197600,296.05;
        31201200,296.65; 31204800,296.95; 31208400,296.25; 31212000,297.05;
        31215600,296.35; 31219200,295.75; 31222800,296.75; 31226400,297.05;
        31230000,296.65; 31233600,296.95; 31237200,296.85; 31240800,296.75;
        31244400,296.55; 31248000,296.65; 31251600,296.55; 31255200,296.75;
        31258800,296.85; 31262400,297.05; 31266000,296.45; 31269600,296.45;
        31273200,296.25; 31276800,296.15; 31280400,296.15; 31284000,296.35;
        31287600,296.15; 31291200,296.25; 31294800,296.55; 31298400,296.65;
        31302000,296.85; 31305600,295.55; 31309200,296.45; 31312800,297.15;
        31316400,296.55; 31320000,296.45; 31323600,296.85; 31327200,296.45;
        31330800,296.25; 31334400,296.35; 31338000,296.15; 31341600,296.45;
        31345200,296.85; 31348800,296.05; 31352400,296.35; 31356000,296.15;
        31359600,296.25; 31363200,296.15; 31366800,296.25; 31370400,296.65;
        31374000,296.35; 31377600,296.25; 31381200,296.45; 31384800,296.55;
        31388400,296.95; 31392000,296.45; 31395600,297.05; 31399200,297.15;
        31402800,297.05; 31406400,296.85; 31410000,296.25; 31413600,296.65;
        31417200,296.25; 31420800,296.35; 31424400,296.65; 31428000,296.35;
        31431600,296.65; 31435200,296.65; 31438800,296.75; 31442400,296.15;
        31446000,296.55; 31449600,296.15; 31453200,295.95; 31456800,296.65;
        31460400,296.25; 31464000,296.25; 31467600,296.55; 31471200,296.05;
        31474800,296.45; 31478400,296.25; 31482000,297.05; 31485600,297.95;
        31489200,297.85; 31492800,297.15; 31496400,296.75; 31500000,296.45;
        31503600,296.45; 31507200,297.35; 31510800,297.65; 31514400,297.15;
        31518000,297.45; 31521600,297.05; 31525200,296.65; 31528800,297.35;
        31532400,297.35; 31536000,297.05])
    annotation (Placement(transformation(extent={{-110,158},{-90,178}})));
  Modelica.Blocks.Sources.CombiTimeTable combiTimeTable_SH_Mass_Flow(table=[0,
        0.0816601; 3600,0.0914858; 7200,0.0033161; 10800,0.0003213; 14400,
        0.0089837; 18000,0.015426; 21600,0.0005352; 25200,0.000447; 28800,
        0.005831; 32400,0.0337377; 36000,0.1096861; 39600,0.0683303; 43200,
        0.0105971; 46800,0.0107338; 50400,0.0169882; 54000,0.0253008; 57600,
        0.0650908; 61200,0.0818237; 64800,0.0424426; 68400,0.032836; 72000,
        0.0268251; 75600,0.0377832; 79200,0.0570501; 82800,0.0851827; 86400,
        0.0785884; 90000,0.3490787; 93600,0.5287416; 97200,0.3280289; 100800,
        0.1919067; 104400,0.2101336; 108000,0.1466559; 111600,0.1034459; 115200,
        0.2003261; 118800,0.2817241; 122400,0.2445762; 126000,0.1585408; 129600,
        0.0744313; 133200,0.1013521; 136800,0.1115835; 140400,0.0563571; 144000,
        0.1186927; 147600,0.2092389; 151200,0.1609578; 154800,0.0944697; 158400,
        0.0694794; 162000,0.0655306; 165600,0.0935731; 169200,0.1473636; 172800,
        0.150609; 176400,0.1185883; 180000,0.1355839; 183600,0.1615617; 187200,
        0.1365932; 190800,0.1007067; 194400,0.0956851; 198000,0.1154141; 201600,
        0.1148552; 205200,0.0862713; 208800,0.1094025; 212400,0.0741053; 216000,
        0.0225014; 219600,0.0837062; 223200,0.1256904; 226800,0.0641998; 230400,
        0.1090608; 234000,0.2068796; 237600,0.2006326; 241200,0.1337857; 244800,
        0.0766283; 248400,0.0516332; 252000,0.0939406; 255600,0.1432368; 259200,
        0.1320041; 262800,0.1165183; 266400,0.1451164; 270000,0.1399598; 273600,
        0.1268378; 277200,0.1193874; 280800,0.075359; 284400,0.0442415; 288000,
        0.1436716; 291600,0.2482419; 295200,0.3575054; 298800,0.301504; 302400,
        0.1380463; 306000,0.1094004; 309600,0.1208301; 313200,0.1448065; 316800,
        0.1583214; 320400,0.1186221; 324000,0.0631185; 327600,0.0357927; 331200,
        0.0204573; 334800,0.0214273; 338400,0.0198013; 342000,0.0302736; 345600,
        0.0211934; 349200,0.0410066; 352800,0.0768108; 356400,0.081549; 360000,
        0.0600681; 363600,0.0490214; 367200,0.0335069; 370800,0.012144; 374400,
        0.0644671; 378000,0.1198303; 381600,0.1680457; 385200,0.097648; 388800,
        0.0298769; 392400,0.0550358; 396000,0.0655382; 399600,0.0546956; 403200,
        0.0989674; 406800,0.0703044; 410400,0.0152465; 414000,0.0108776; 417600,
        0.0074963; 421200,0.0042513; 424800,0.0057675; 428400,0.0056604; 432000,
        0.0023236; 435600,0.0168516; 439200,0.0271557; 442800,0.0191372; 446400,
        0.028046; 450000,0.0395921; 453600,0.0141923; 457200,0.0039863; 460800,
        0.0112791; 464400,0.0441192; 468000,0.1001225; 471600,0.1009039; 475200,
        0.0685407; 478800,0.0425296; 482400,0.0379554; 486000,0.0517483; 489600,
        0.0584097; 493200,0.0523993; 496800,0.0120865; 500400,0.0080123; 504000,
        0.0044865; 507600,0.0030408; 511200,0.0063621; 514800,0.0102723; 518400,
        0.0091382; 522000,0.0249471; 525600,0.0405035; 529200,0.0346651; 532800,
        0.0336087; 536400,0.0426888; 540000,0.0180559; 543600,0.0030147; 547200,
        0.0074393; 550800,0.0331441; 554400,0.0965549; 558000,0.1023514; 561600,
        0.0421028; 565200,0.027626; 568800,0.0326173; 572400,0.0410062; 576000,
        0.0686771; 579600,0.0541374; 583200,0.0204323; 586800,0.0089396; 590400,
        0.0021325; 594000,0.0025927; 597600,0.0097308; 601200,0.0182956; 604800,
        0.0230509; 608400,0.0308186; 612000,0.0437317; 615600,0.0599245; 619200,
        0.0995677; 622800,0.1431172; 626400,0.1608458; 630000,0.0382706; 633600,
        0.0684883; 637200,0.1431744; 640800,0.312885; 644400,0.3218068; 648000,
        0.1263125; 651600,0.0758216; 655200,0.0736582; 658800,0.0760582; 662400,
        0.1955492; 666000,0.3054512; 669600,0.1644284; 673200,0.038177; 676800,
        0.0352281; 680400,0.0408206; 684000,0.0429876; 687600,0.0991578; 691200,
        0.2421014; 694800,0.358567; 698400,0.351462; 702000,0.404416; 705600,
        0.3549291; 709200,0.2351491; 712800,0.3119244; 716400,0.3222085; 720000,
        0.275036; 723600,0.271849; 727200,0.2268019; 730800,0.1876879; 734400,
        0.1204733; 738000,0.1274862; 741600,0.1437129; 745200,0.0634483; 748800,
        0.1159584; 752400,0.2599634; 756000,0.2181914; 759600,0.1242486; 763200,
        0.0999824; 766800,0.0577116; 770400,0.0749686; 774000,0.0892425; 777600,
        0.0969586; 781200,0.0908737; 784800,0.0934696; 788400,0.1183452; 792000,
        0.1148294; 795600,0.0983998; 799200,0.0769508; 802800,0.0396076; 806400,
        0.0808512; 810000,0.0931101; 813600,0.0691; 817200,0.067696; 820800,
        0.0477124; 824400,0.0659866; 828000,0.0988192; 831600,0.0796192; 835200,
        0.1117745; 838800,0.1399624; 842400,0.1039855; 846000,0.0688948; 849600,
        0.0268783; 853200,0.0151122; 856800,0.0170614; 860400,0.0515279; 864000,
        0.0519401; 867600,0.0339493; 871200,0.0964841; 874800,0.1064423; 878400,
        0.061444; 882000,0.07248; 885600,0.0503401; 889200,0.0092033; 892800,
        0.0524302; 896400,0.1362593; 900000,0.1976725; 903600,0.1858105; 907200,
        0.100654; 910800,0.0685193; 914400,0.0965826; 918000,0.1285779; 921600,
        0.1147849; 925200,0.0929955; 928800,0.0443419; 932400,0.018884; 936000,
        0.0195004; 939600,0.0221731; 943200,0.0454967; 946800,0.0683368; 950400,
        0.0502818; 954000,0.0990203; 957600,0.1293183; 961200,0.0677762; 964800,
        0.0919981; 968400,0.0978913; 972000,0.03866; 975600,0.0122681; 979200,
        0.0580713; 982800,0.152028; 986400,0.2432267; 990000,0.1679562; 993600,
        0.0419299; 997200,0.0561075; 1000800,0.0546367; 1004400,0.033076;
        1008000,0.0635483; 1011600,0.0582371; 1015200,0.0270754; 1018800,
        0.0173315; 1022400,0.0086571; 1026000,0.0050959; 1029600,0.0125844;
        1033200,0.0128724; 1036800,0.002264; 1040400,0.0070276; 1044000,
        0.0191723; 1047600,0.0199473; 1051200,0.0158591; 1054800,0.0269118;
        1058400,0.0122704; 1062000,0.0023908; 1065600,0.0074217; 1069200,
        0.0208932; 1072800,0.0475448; 1076400,0.0584278; 1080000,0.029222;
        1083600,0.0234261; 1087200,0.0287714; 1090800,0.0400931; 1094400,
        0.0696658; 1098000,0.0345423; 1101600,0.0089887; 1105200,0.0084133;
        1108800,0.0042201; 1112400,0.0078509; 1116000,0.0252475; 1119600,
        0.0341607; 1123200,0.0161501; 1126800,0.0058664; 1130400,0.0275887;
        1134000,0.0379903; 1137600,0.0315328; 1141200,0.0253824; 1144800,
        0.0157918; 1148400,0.0032196; 1152000,0.0080722; 1155600,0.0261196;
        1159200,0.054487; 1162800,0.0325581; 1166400,0.0228898; 1170000,
        0.0302013; 1173600,0.0304798; 1177200,0.0297169; 1180800,0.0416105;
        1184400,0.0223263; 1188000,0.01374; 1191600,0.0095882; 1195200,
        0.0047743; 1198800,0.0069351; 1202400,0.0135212; 1206000,0.0319197;
        1209600,0.0527105; 1213200,0.1139026; 1216800,0.1176021; 1220400,
        0.0982912; 1224000,0.1345409; 1227600,0.1024122; 1231200,0.0423346;
        1234800,0.0225333; 1238400,0.0854321; 1242000,0.2051991; 1245600,
        0.2661606; 1249200,0.1057521; 1252800,0.0224706; 1256400,0.0275891;
        1260000,0.0186622; 1263600,0.024586; 1267200,0.0711701; 1270800,
        0.0513901; 1274400,0.0348554; 1278000,0.0560513; 1281600,0.0392033;
        1285200,0.017829; 1288800,0.040363; 1292400,0.0902306; 1296000,
        0.1091296; 1299600,0.1595109; 1303200,0.2779739; 1306800,0.2540564;
        1310400,0.2597504; 1314000,0.2579473; 1317600,0.1670131; 1321200,
        0.1239691; 1324800,0.2087873; 1328400,0.3329582; 1332000,0.2645258;
        1335600,0.0831045; 1339200,0.0145909; 1342800,0.0289786; 1346400,
        0.0779106; 1350000,0.0868719; 1353600,0.1061296; 1357200,0.2146548;
        1360800,0.4148791; 1364400,0.3620004; 1368000,0.213999; 1371600,
        0.1877868; 1375200,0.2465623; 1378800,0.3428377; 1382400,0.3719366;
        1386000,0.4003807; 1389600,0.3630615; 1393200,0.3202843; 1396800,
        0.3958296; 1400400,0.4469141; 1404000,0.3503254; 1407600,0.2557773;
        1411200,0.3063829; 1414800,0.4423685; 1418400,0.4124554; 1422000,
        0.2251754; 1425600,0.0790261; 1429200,0.1555228; 1432800,0.1810593;
        1436400,0.0685986; 1440000,0.1318669; 1443600,0.3786323; 1447200,
        0.5124393; 1450800,0.3861337; 1454400,0.2353642; 1458000,0.1720214;
        1461600,0.2465785; 1465200,0.3527778; 1468800,0.353911; 1472400,
        0.3340511; 1476000,0.3697044; 1479600,0.4441406; 1483200,0.4644754;
        1486800,0.3340697; 1490400,0.1211531; 1494000,0.1020174; 1497600,
        0.2136049; 1501200,0.2357535; 1504800,0.2936545; 1508400,0.3124643;
        1512000,0.106968; 1515600,0.0576301; 1519200,0.090906; 1522800,
        0.1075996; 1526400,0.1145351; 1530000,0.1326901; 1533600,0.0530424;
        1537200,0.0267145; 1540800,0.0266414; 1544400,0.0303514; 1548000,
        0.0539887; 1551600,0.0745617; 1555200,0.0747606; 1558800,0.108342;
        1562400,0.1150645; 1566000,0.0764731; 1569600,0.1046014; 1573200,
        0.0987353; 1576800,0.0448572; 1580400,0.0165302; 1584000,0.0635944;
        1587600,0.1547498; 1591200,0.2257292; 1594800,0.1318565; 1598400,
        0.0457504; 1602000,0.0542376; 1605600,0.0503642; 1609200,0.0570469;
        1612800,0.0828811; 1616400,0.0818841; 1620000,0.0445665; 1623600,
        0.021155; 1627200,0.0215307; 1630800,0.0197461; 1634400,0.0559748;
        1638000,0.0935104; 1641600,0.0893421; 1645200,0.139482; 1648800,
        0.191433; 1652400,0.1173548; 1656000,0.0819727; 1659600,0.1329874;
        1663200,0.0642931; 1666800,0.0109107; 1670400,0.0607605; 1674000,
        0.1482572; 1677600,0.0892463; 1681200,0.0149769; 1684800,0.0114007;
        1688400,0.0183541; 1692000,0.0253391; 1695600,0.0078838; 1699200,
        0.0239832; 1702800,0.0282934; 1706400,0.0061198; 1710000,0.0015614;
        1713600,0.0002388; 1717200,0.0016925; 1720800,0.0046685; 1724400,
        0.0080197; 1728000,0.0031139; 1731600,0.0220617; 1735200,0.0278974;
        1738800,0.0157418; 1742400,0.019643; 1746000,0.0195438; 1749600,
        0.0051149; 1753200,0.0009553; 1756800,0.0086234; 1760400,0.0371991;
        1764000,0.0488379; 1767600,0.0321095; 1771200,0.0250683; 1774800,
        0.0212472; 1778400,0.0275096; 1782000,0.0199968; 1785600,0.0337962;
        1789200,0.0803464; 1792800,0.0558713; 1796400,0.0062575; 1800000,
        0.0014803; 1803600,0.0045312; 1807200,0.0063124; 1810800,0.0183114;
        1814400,0.0134414; 1818000,0.0253767; 1821600,0.0348813; 1825200,
        0.040495; 1828800,0.0291512; 1832400,0.070331; 1836000,0.0933436;
        1839600,0.0171309; 1843200,0.0349022; 1846800,0.1106032; 1850400,
        0.1545025; 1854000,0.0515168; 1857600,0.0146246; 1861200,0.0093329;
        1864800,0.0104408; 1868400,0.0206231; 1872000,0.022475; 1875600,
        0.0124548; 1879200,0.0190201; 1882800,0.0066998; 1886400,0.0033586;
        1890000,0.0117005; 1893600,0.028601; 1897200,0.053157; 1900800,
        0.0310207; 1904400,0.055749; 1908000,0.0854383; 1911600,0.0518874;
        1915200,0.0405784; 1918800,0.0897628; 1922400,0.1235596; 1926000,
        0.051548; 1929600,0.0389354; 1933200,0.0623712; 1936800,0.0204285;
        1940400,0.0055648; 1944000,0.0114342; 1947600,0.0222379; 1951200,
        0.0289171; 1954800,0.0561579; 1958400,0.0489176; 1962000,0.0896316;
        1965600,0.0536993; 1969200,0.0173729; 1972800,0.0159589; 1976400,
        0.0122593; 1980000,0.0203937; 1983600,0.0392824; 1987200,0.1047252;
        1990800,0.0716598; 1994400,0.0538489; 1998000,0.1390838; 2001600,
        0.1250197; 2005200,0.0470652; 2008800,0.0929854; 2012400,0.1135388;
        2016000,0.1136644; 2019600,0.1386942; 2023200,0.0229205; 2026800,
        0.0057996; 2030400,0.0046882; 2034000,0.0102548; 2037600,0.0054645;
        2041200,0.006313; 2044800,0.010743; 2048400,0.0104255; 2052000,
        0.0148295; 2055600,0.0449354; 2059200,0.0055155; 2062800,0.0024607;
        2066400,0.0030128; 2070000,0.0066323; 2073600,0.0112754; 2077200,
        0.017996; 2080800,0.0385109; 2084400,0.0854022; 2088000,0.0608091;
        2091600,0.0523759; 2095200,0.0745066; 2098800,0.0552528; 2102400,
        0.1339271; 2106000,0.3392424; 2109600,0.5146001; 2113200,0.4268183;
        2116800,0.1763793; 2120400,0.1182775; 2124000,0.1085881; 2127600,
        0.0764405; 2131200,0.1781733; 2134800,0.2065372; 2138400,0.0684788;
        2142000,0.031702; 2145600,0.0295282; 2149200,0.0244189; 2152800,
        0.0550527; 2156400,0.076993; 2160000,0.0314375; 2163600,0.0778799;
        2167200,0.0880624; 2170800,0.0510683; 2174400,0.0911683; 2178000,
        0.084212; 2181600,0.0230882; 2185200,0.0125067; 2188800,0.0502186;
        2192400,0.1496705; 2196000,0.213518; 2199600,0.1270865; 2203200,
        0.0451211; 2206800,0.0651136; 2210400,0.0800542; 2214000,0.0783404;
        2217600,0.0871305; 2221200,0.1768422; 2224800,0.2677932; 2228400,
        0.0811831; 2232000,0.0493927; 2235600,0.0193655; 2239200,0.0517982;
        2242800,0.1152912; 2246400,0.062163; 2250000,0.1050548; 2253600,
        0.157477; 2257200,0.0649391; 2260800,0.1160861; 2264400,0.1110899;
        2268000,0.0208432; 2271600,0.0059709; 2275200,0.0328646; 2278800,
        0.1132157; 2282400,0.2062753; 2286000,0.2137152; 2289600,0.1237434;
        2293200,0.0733847; 2296800,0.0363458; 2300400,0.0371529; 2304000,
        0.078649; 2307600,0.1151182; 2311200,0.1277106; 2314800,0.1057872;
        2318400,0.0515041; 2322000,0.0198261; 2325600,0.073145; 2329200,
        0.0917098; 2332800,0.0228233; 2336400,0.0915499; 2340000,0.1192368;
        2343600,0.040363; 2347200,0.0679484; 2350800,0.0679874; 2354400,
        0.0164822; 2358000,0.0066539; 2361600,0.0469038; 2365200,0.1496753;
        2368800,0.2324685; 2372400,0.199375; 2376000,0.1084858; 2379600,
        0.0974033; 2383200,0.073459; 2386800,0.1131816; 2390400,0.1533264;
        2394000,0.156976; 2397600,0.0934904; 2401200,0.0691098; 2404800,
        0.0591103; 2408400,0.1377783; 2412000,0.3096929; 2415600,0.228015;
        2419200,0.2476109; 2422800,0.3355495; 2426400,0.2855451; 2430000,
        0.2365204; 2433600,0.4248; 2437200,0.4902502; 2440800,0.3132516;
        2444400,0.1850299; 2448000,0.3100743; 2451600,0.4893719; 2455200,
        0.64297; 2458800,0.5412163; 2462400,0.1774078; 2466000,0.0604915;
        2469600,0.0826236; 2473200,0.1256689; 2476800,0.2042166; 2480400,
        0.2999864; 2484000,0.2506111; 2487600,0.1559152; 2491200,0.0931951;
        2494800,0.0767723; 2498400,0.1294326; 2502000,0.1264545; 2505600,
        0.0876407; 2509200,0.1546337; 2512800,0.1935398; 2516400,0.0993422;
        2520000,0.0794139; 2523600,0.0899831; 2527200,0.0351915; 2530800,
        0.0248107; 2534400,0.0544987; 2538000,0.0658106; 2541600,0.0594057;
        2545200,0.0517934; 2548800,0.0268336; 2552400,0.0612807; 2556000,
        0.1059842; 2559600,0.0882024; 2563200,0.0895889; 2566800,0.1364443;
        2570400,0.1031261; 2574000,0.081671; 2577600,0.0340746; 2581200,
        0.0161648; 2584800,0.0159059; 2588400,0.0398232; 2592000,0.0605278;
        2595600,0.0696482; 2599200,0.1198015; 2602800,0.1919285; 2606400,
        0.1378514; 2610000,0.1526695; 2613600,0.2842312; 2617200,0.1724355;
        2620800,0.1326218; 2624400,0.1043361; 2628000,0.1185619; 2631600,
        0.0637368; 2635200,0.0150799; 2638800,0.0317675; 2642400,0.0592913;
        2646000,0.0342247; 2649600,0.0769904; 2653200,0.1268794; 2656800,
        0.1221749; 2660400,0.0791285; 2664000,0.0298123; 2667600,0.0086458;
        2671200,0.0233698; 2674800,0.055516; 2678400,0.0544876; 2682000,
        0.0276159; 2685600,0.0908268; 2689200,0.1264406; 2692800,0.0789104;
        2696400,0.1043039; 2700000,0.0505568; 2703600,0.0286353; 2707200,
        0.1385607; 2710800,0.2474074; 2714400,0.2274869; 2718000,0.0664099;
        2721600,0.0238627; 2725200,0.0214926; 2728800,0.0062479; 2732400,
        0.0048797; 2736000,0.0182286; 2739600,0.021015; 2743200,0.01589;
        2746800,0.0096884; 2750400,0.0089827; 2754000,0.0078434; 2757600,
        0.0143892; 2761200,0.0191633; 2764800,0.0201791; 2768400,0.0491928;
        2772000,0.0807901; 2775600,0.122329; 2779200,0.1312357; 2782800,
        0.0972006; 2786400,0.049449; 2790000,0.0313022; 2793600,0.0892098;
        2797200,0.1395889; 2800800,0.2023733; 2804400,0.0907974; 2808000,
        0.0233169; 2811600,0.0282422; 2815200,0.016353; 2818800,0.0234242;
        2822400,0.0525484; 2826000,0.0732656; 2829600,0.0470634; 2833200,
        0.0171805; 2836800,0.0082778; 2840400,0.0011474; 2844000,0.0030918;
        2847600,0.0204121; 2851200,0.0365908; 2854800,0.0724337; 2858400,
        0.1225805; 2862000,0.0749606; 2865600,0.0093557; 2869200,0.0036852;
        2872800,0.0042829; 2876400,0.0014135; 2880000,0.0027927; 2883600,
        0.0202573; 2887200,0.0509717; 2890800,0.031868; 2894400,0.0257501;
        2898000,0.0128334; 2901600,0.0201883; 2905200,0.0258321; 2908800,
        0.0386532; 2912400,0.0371939; 2916000,0.0179792; 2919600,0.0064769;
        2923200,0.004632; 2926800,0.0045958; 2930400,0.0090348; 2934000,
        0.0136298; 2937600,0.019177; 2941200,0.0245115; 2944800,0.0460998;
        2948400,0.0344938; 2952000,0.0186442; 2955600,0.0332844; 2959200,
        0.0285183; 2962800,0.0040969; 2966400,0.0097347; 2970000,0.0340041;
        2973600,0.0396651; 2977200,0.0142721; 2980800,0.0119023; 2984400,
        0.0451264; 2988000,0.0544129; 2991600,0.0276419; 2995200,0.0309345;
        2998800,0.019843; 3002400,0.0367301; 3006000,0.0315456; 3009600,
        0.0059289; 3013200,0.0016397; 3016800,0.0060622; 3020400,0.0185561;
        3024000,0.0235754; 3027600,0.0326124; 3031200,0.025144; 3034800,
        0.0326009; 3038400,0.0225271; 3042000,0.0214585; 3045600,0.0182561;
        3049200,0.0102866; 3052800,0.0415085; 3056400,0.051411; 3060000,
        0.114245; 3063600,0.0748392; 3067200,0.0208355; 3070800,0.0195522;
        3074400,0.0614272; 3078000,0.0928542; 3081600,0.0578289; 3085200,
        0.0456913; 3088800,0.0228812; 3092400,0.0025532; 3096000,0.0018702;
        3099600,0.0051191; 3103200,0.0110498; 3106800,0.0118549; 3110400,
        0.0102436; 3114000,0.0315328; 3117600,0.0767551; 3121200,0.0846214;
        3124800,0.0377154; 3128400,0.0492927; 3132000,0.0639432; 3135600,
        0.0144082; 3139200,0.031158; 3142800,0.0377738; 3146400,0.0252863;
        3150000,0.0245711; 3153600,0.0009084; 3157200,0.0062312; 3160800,
        0.0151505; 3164400,0.0112537; 3168000,0.0176062; 3171600,0.0238402;
        3175200,0.0335324; 3178800,0.0569798; 3182400,0.0390136; 3186000,
        0.0156518; 3189600,0.038789; 3193200,0.1016179; 3196800,0.1151059;
        3200400,0.1015544; 3204000,0.110966; 3207600,0.1432177; 3211200,
        0.142836; 3214800,0.1377971; 3218400,0.1478884; 3222000,0.1284425;
        3225600,0.1837915; 3229200,0.2144762; 3232800,0.1347919; 3236400,
        0.0469915; 3240000,0.0063958; 3243600,0.0062953; 3247200,0.0295914;
        3250800,0.0335456; 3254400,0.062036; 3258000,0.0875132; 3261600,
        0.117783; 3265200,0.1571911; 3268800,0.1274376; 3272400,0.0787107;
        3276000,0.0690803; 3279600,0.1704702; 3283200,0.1598358; 3286800,
        0.1657484; 3290400,0.2289588; 3294000,0.2538688; 3297600,0.2519643;
        3301200,0.145807; 3304800,0.0950342; 3308400,0.1253552; 3312000,
        0.2104163; 3315600,0.3025029; 3319200,0.3601893; 3322800,0.1568259;
        3326400,0.0508777; 3330000,0.0391414; 3333600,0.0355391; 3337200,
        0.0261056; 3340800,0.0613548; 3344400,0.1037347; 3348000,0.1191082;
        3351600,0.1462634; 3355200,0.1691696; 3358800,0.1608778; 3362400,
        0.2336322; 3366000,0.2299911; 3369600,0.2528912; 3373200,0.34768;
        3376800,0.3678229; 3380400,0.2514254; 3384000,0.297362; 3387600,
        0.325131; 3391200,0.1235775; 3394800,0.056316; 3398400,0.1999306;
        3402000,0.3083055; 3405600,0.3978689; 3409200,0.2472244; 3412800,
        0.0652898; 3416400,0.0560175; 3420000,0.0611591; 3423600,0.0639195;
        3427200,0.0742292; 3430800,0.0919484; 3434400,0.0596387; 3438000,
        0.0359834; 3441600,0.0268499; 3445200,0.0232007; 3448800,0.0521659;
        3452400,0.0770802; 3456000,0.0615679; 3459600,0.1430778; 3463200,
        0.2628374; 3466800,0.2296332; 3470400,0.2772775; 3474000,0.2842032;
        3477600,0.110926; 3481200,0.0502171; 3484800,0.1794045; 3488400,
        0.3461146; 3492000,0.386395; 3495600,0.1924838; 3499200,0.094381;
        3502800,0.10073; 3506400,0.0638643; 3510000,0.0410539; 3513600,
        0.0697397; 3517200,0.0998755; 3520800,0.1223984; 3524400,0.1362838;
        3528000,0.1483646; 3531600,0.150323; 3535200,0.1736079; 3538800,
        0.1769764; 3542400,0.2602893; 3546000,0.3467439; 3549600,0.3119905;
        3553200,0.2419066; 3556800,0.2819752; 3560400,0.3628502; 3564000,
        0.21704; 3567600,0.098161; 3571200,0.2277849; 3574800,0.3496306;
        3578400,0.464013; 3582000,0.3841368; 3585600,0.1195201; 3589200,
        0.0810541; 3592800,0.0865666; 3596400,0.0532689; 3600000,0.0843683;
        3603600,0.1105745; 3607200,0.0944357; 3610800,0.1075286; 3614400,
        0.1092388; 3618000,0.1170886; 3621600,0.2056836; 3625200,0.2387638;
        3628800,0.2286639; 3632400,0.2855283; 3636000,0.2701806; 3639600,
        0.1064074; 3643200,0.1648902; 3646800,0.2830843; 3650400,0.1764761;
        3654000,0.1064943; 3657600,0.2385022; 3661200,0.3038771; 3664800,
        0.3981371; 3668400,0.1733552; 3672000,0.0154048; 3675600,0.0195219;
        3679200,0.0186516; 3682800,0.0095166; 3686400,0.0152698; 3690000,
        0.0248282; 3693600,0.0320483; 3697200,0.0542379; 3700800,0.054757;
        3704400,0.0401764; 3708000,0.0690721; 3711600,0.1776989; 3715200,
        0.2086116; 3718800,0.2306614; 3722400,0.2802303; 3726000,0.2380002;
        3729600,0.1739352; 3733200,0.2530839; 3736800,0.2217578; 3740400,
        0.1415327; 3744000,0.2011583; 3747600,0.1716446; 3751200,0.086997;
        3754800,0.0425428; 3758400,0.0064456; 3762000,0.007719; 3765600,
        0.0296263; 3769200,0.0205845; 3772800,0.0188606; 3776400,0.0563803;
        3780000,0.0855055; 3783600,0.1144214; 3787200,0.1008959; 3790800,
        0.0634779; 3794400,0.0781423; 3798000,0.1776037; 3801600,0.1789975;
        3805200,0.1163619; 3808800,0.1136122; 3812400,0.1468607; 3816000,
        0.1051384; 3819600,0.1266976; 3823200,0.0953691; 3826800,0.0612377;
        3830400,0.1035945; 3834000,0.0497694; 3837600,0.0134782; 3841200,
        0.0133986; 3844800,0.0018343; 3848400,0.0003095; 3852000,0.0003695;
        3855600,0.003026; 3859200,0.0095511; 3862800,0.009694; 3866400,
        0.0139087; 3870000,0.0206202; 3873600,0.0030727; 3877200,0.0020577;
        3880800,0.0089698; 3884400,0.0089576; 3888000,0.0004705; 3891600,
        0.0028725; 3895200,0.0154961; 3898800,0.031316; 3902400,0.0136779;
        3906000,0.0199856; 3909600,0.0248833; 3913200,0.0065591; 3916800,
        0.009173; 3920400,0.0227065; 3924000,0.027648; 3927600,0.0406096;
        3931200,0.0189247; 3934800,0.0112906; 3938400,0.0211858; 3942000,
        0.0368136; 3945600,0.0311598; 3949200,0.0107788; 3952800,0.0163464;
        3956400,0.0137605; 3960000,0.0011215; 3963600,0.0039784; 3967200,
        0.0213771; 3970800,0.0201856; 3974400,0.0081564; 3978000,0.0262902;
        3981600,0.0121038; 3985200,0.0546742; 3988800,0.0782564; 3992400,
        0.0516999; 3996000,0.0115475; 3999600,0.0106671; 4003200,0.0235205;
        4006800,0.0428976; 4010400,0.021512; 4014000,0.0207763; 4017600,
        0.0204847; 4021200,0.0214348; 4024800,0.0333174; 4028400,0.0237291;
        4032000,0.0394455; 4035600,0.0206412; 4039200,0.0176597; 4042800,
        0.0348748; 4046400,0.0313957; 4050000,0.033616; 4053600,0.0322403;
        4057200,0.0365918; 4060800,0.0314863; 4064400,0.0906262; 4068000,
        0.1204957; 4071600,0.0630933; 4075200,0.0691887; 4078800,0.0546883;
        4082400,0.0229468; 4086000,0.0144321; 4089600,0.0425906; 4093200,
        0.1282148; 4096800,0.1150045; 4100400,0.0366666; 4104000,0.0164747;
        4107600,0.0952242; 4111200,0.0537205; 4114800,0.0020245; 4118400,
        0.0204594; 4122000,0.009488; 4125600,0.0066027; 4129200,0.0109413;
        4132800,0.0034802; 4136400,0.0004481; 4140000,0.0016783; 4143600,
        0.0082376; 4147200,0.0206395; 4150800,0.042181; 4154400,0.0846822;
        4158000,0.0795868; 4161600,0.0603853; 4165200,0.0841161; 4168800,
        0.0589172; 4172400,0.0248944; 4176000,0.0681764; 4179600,0.0711519;
        4183200,0.0410172; 4186800,0.0255627; 4190400,0.0018972; 4194000,
        0.0012091; 4197600,0.01055; 4201200,0.0099872; 4204800,0.0111607;
        4208400,0.0117609; 4212000,0.0106543; 4215600,0.0118361; 4219200,
        0.0109547; 4222800,0.0225054; 4226400,0.036064; 4230000,0.0544777;
        4233600,0.1005789; 4237200,0.1104942; 4240800,0.1352921; 4244400,
        0.0827021; 4248000,0.0517052; 4251600,0.0605168; 4255200,0.0256503;
        4258800,0.0053672; 4262400,0.0171295; 4266000,0.0691575; 4269600,
        0.0907828; 4273200,0.0294498; 4276800,0.0091389; 4280400,0.0161867;
        4284000,0.0165114; 4287600,0.0103815; 4291200,0.0245017; 4294800,
        0.0150577; 4298400,0.0111206; 4302000,0.0059938; 4305600,0.001984;
        4309200,0.0011987; 4312800,0.0002772; 4316400,0.0032355; 4320000,
        0.0198945; 4323600,0.1094384; 4327200,0.2320401; 4330800,0.1528948;
        4334400,0.0597761; 4338000,0.1888252; 4341600,0.1641809; 4345200,
        0.0380183; 4348800,0.0589115; 4352400,0.0453928; 4356000,0.0318216;
        4359600,0.0183238; 4363200,0.0004531; 4366800,2.2e-06; 4370400,
        0.0005822; 4374000,0.0044717; 4377600,0.0049098; 4381200,0.0056254;
        4384800,0.0154026; 4388400,0.0364279; 4392000,0.0161096; 4395600,
        0.011366; 4399200,0.0112684; 4402800,0.0428591; 4406400,0.1151182;
        4410000,0.1581162; 4413600,0.0655665; 4417200,0.0472666; 4420800,
        0.125102; 4424400,0.1446412; 4428000,0.0555544; 4431600,0.0282227;
        4435200,0.0590776; 4438800,0.0398031; 4442400,0.0139971; 4446000,
        0.0156534; 4449600,0.0029742; 4453200,0.0041589; 4456800,0.0164097;
        4460400,0.0109068; 4464000,0.0075467; 4467600,0.026232; 4471200,
        0.0302338; 4474800,0.0186809; 4478400,0.0063681; 4482000,0.002386;
        4485600,0.0064643; 4489200,0.0116407; 4492800,0.0078647; 4496400,
        0.0087796; 4500000,0.0258692; 4503600,0.0386085; 4507200,0.026799;
        4510800,0.0251495; 4514400,0.0177717; 4518000,0.0060445; 4521600,
        0.0168663; 4525200,0.045007; 4528800,0.0543277; 4532400,0.0511473;
        4536000,0.0272613; 4539600,0.0265612; 4543200,0.0338066; 4546800,
        0.0380247; 4550400,0.0335495; 4554000,0.0199292; 4557600,0.0150736;
        4561200,0.0152274; 4564800,0.0085225; 4568400,0.0049546; 4572000,
        0.0134907; 4575600,0.0438449; 4579200,0.0818729; 4582800,0.109198;
        4586400,0.1454628; 4590000,0.176426; 4593600,0.1344202; 4597200,
        0.1551138; 4600800,0.122963; 4604400,0.0684161; 4608000,0.1543475;
        4611600,0.1349939; 4615200,0.0789746; 4618800,0.0375386; 4622400,
        0.0287722; 4626000,0.0223109; 4629600,0.0254072; 4633200,0.0301071;
        4636800,0.0421856; 4640400,0.0396371; 4644000,0.033774; 4647600,
        0.0449931; 4651200,0.028598; 4654800,0.0265129; 4658400,0.0646831;
        4662000,0.0917715; 4665600,0.0176993; 4669200,0.1206824; 4672800,
        0.1476205; 4676400,0.0623536; 4680000,0.0700622; 4683600,0.0874587;
        4687200,0.0337536; 4690800,0.0119222; 4694400,0.061957; 4698000,
        0.1456017; 4701600,0.1078269; 4705200,0.0458777; 4708800,0.0161018;
        4712400,0.0270005; 4716000,0.011053; 4719600,0.008607; 4723200,
        0.0392805; 4726800,0.0077531; 4730400,0.0089287; 4734000,0.0137091;
        4737600,0.0010387; 4741200,0.0033664; 4744800,0.0040157; 4748400,
        0.0049534; 4752000,0.014908; 4755600,0.0885312; 4759200,0.2058455;
        4762800,0.147648; 4766400,0.178133; 4770000,0.0986984; 4773600,
        0.0290068; 4777200,0.0457679; 4780800,0.130233; 4784400,0.1551245;
        4788000,0.098644; 4791600,0.0288453; 4795200,0.0023628; 4798800,
        0.0043148; 4802400,0.0048267; 4806000,0.0142869; 4809600,0.0242042;
        4813200,0.020464; 4816800,0.0195507; 4820400,0.020685; 4824000,
        0.0180774; 4827600,0.007627; 4831200,0.0084562; 4834800,0.0156178;
        4838400,0.018094; 4842000,0.0404881; 4845600,0.0512467; 4849200,
        0.0311633; 4852800,0.0508172; 4856400,0.0630878; 4860000,0.0227303;
        4863600,0.0066821; 4867200,0.0147869; 4870800,0.0204472; 4874400,
        0.0126961; 4878000,0.0055139; 4881600,0.0018663; 4885200,0.0080558;
        4888800,0.0103078; 4892400,0.0018965; 4896000,0.0066831; 4899600,
        0.0035974; 4903200,0.0040473; 4906800,0.0031752; 4910400,0.0011834;
        4914000,0.0052111; 4917600,0.0048024; 4921200,0.0028405; 4924800,
        0.0040857; 4928400,0.0234259; 4932000,0.0845693; 4935600,0.1881883;
        4939200,0.162373; 4942800,0.0817906; 4946400,0.1185458; 4950000,
        0.1544964; 4953600,0.1420818; 4957200,0.0670272; 4960800,0.0397447;
        4964400,0.0220469; 4968000,0.0022713; 4971600,0.0031693; 4975200,
        0.0128122; 4978800,0.0136114; 4982400,0.0162407; 4986000,0.0370653;
        4989600,0.022505; 4993200,0.0148077; 4996800,0.0056126; 5000400,
        0.0028798; 5004000,0.0068739; 5007600,0.0105672; 5011200,0.0055959;
        5014800,0.00667; 5018400,0.0232909; 5022000,0.0263164; 5025600,
        0.0200422; 5029200,0.028005; 5032800,0.0208232; 5036400,0.007755;
        5040000,0.0076451; 5043600,0.0029977; 5047200,0.003299; 5050800,
        0.0071099; 5054400,0.0037872; 5058000,0.0076491; 5061600,0.0138502;
        5065200,0.0047369; 5068800,0.0051505; 5072400,0.0127103; 5076000,
        0.016258; 5079600,0.0152682; 5083200,0.0121455; 5086800,0.0118576;
        5090400,0.0317744; 5094000,0.105219; 5097600,0.2124178; 5101200,
        0.2543189; 5104800,0.3254508; 5108400,0.4882444; 5112000,0.5068656;
        5115600,0.4260663; 5119200,0.3071238; 5122800,0.1676587; 5126400,
        0.2303306; 5130000,0.3120548; 5133600,0.2389993; 5137200,0.0870707;
        5140800,0.0382283; 5144400,0.0624419; 5148000,0.0442181; 5151600,
        0.0331595; 5155200,0.07067; 5158800,0.056501; 5162400,0.0519132;
        5166000,0.0905842; 5169600,0.1420835; 5173200,0.2048006; 5176800,
        0.2447433; 5180400,0.2879806; 5184000,0.2587191; 5187600,0.22908;
        5191200,0.2550914; 5194800,0.1915013; 5198400,0.1894744; 5202000,
        0.1925611; 5205600,0.0967683; 5209200,0.0782016; 5212800,0.1965796;
        5216400,0.2617938; 5220000,0.296576; 5223600,0.1772617; 5227200,
        0.069663; 5230800,0.0625235; 5234400,0.0906238; 5238000,0.0985768;
        5241600,0.082903; 5245200,0.0705146; 5248800,0.0468646; 5252400,
        0.0452537; 5256000,0.0387618; 5259600,0.0349703; 5263200,0.0482581;
        5266800,0.0654108; 5270400,0.0608386; 5274000,0.1245063; 5277600,
        0.1477992; 5281200,0.0941142; 5284800,0.1357331; 5288400,0.1866065;
        5292000,0.1403238; 5295600,0.083737; 5299200,0.1442826; 5302800,
        0.1723517; 5306400,0.2118079; 5310000,0.1073856; 5313600,0.0225088;
        5317200,0.0401345; 5320800,0.0488147; 5324400,0.0193382; 5328000,
        0.0878834; 5331600,0.1037193; 5335200,0.0383218; 5338800,0.0151606;
        5342400,0.0150571; 5346000,0.0103755; 5349600,0.0258394; 5353200,
        0.0408664; 5356800,0.0238786; 5360400,0.0564819; 5364000,0.087983;
        5367600,0.050825; 5371200,0.0681716; 5374800,0.0937053; 5378400,
        0.0770933; 5382000,0.0891823; 5385600,0.1705139; 5389200,0.2222512;
        5392800,0.1806222; 5396400,0.0332302; 5400000,0.0093862; 5403600,
        0.0157114; 5407200,0.0236588; 5410800,0.0300104; 5414400,0.0169811;
        5418000,0.0152687; 5421600,0.0187119; 5425200,0.0141287; 5428800,
        0.0077304; 5432400,0.0049336; 5436000,0.0091685; 5439600,0.0119734;
        5443200,0.0099554; 5446800,0.0182287; 5450400,0.0259756; 5454000,
        0.021053; 5457600,0.0244183; 5461200,0.0199508; 5464800,0.0137355;
        5468400,0.0011919; 5472000,0.0050716; 5475600,0.0305661; 5479200,
        0.0441428; 5482800,0.0256747; 5486400,0.0242838; 5490000,0.0285883;
        5493600,0.0191022; 5497200,0.0336297; 5500800,0.0902177; 5504400,
        0.0617271; 5508000,0.0106655; 5511600,0.0066391; 5515200,0.0065436;
        5518800,0.0060621; 5522400,0.0123895; 5526000,0.0173857; 5529600,
        0.0062447; 5533200,0.0210869; 5536800,0.0413348; 5540400,0.0384386;
        5544000,0.0453762; 5547600,0.0493217; 5551200,0.0267995; 5554800,
        0.0242104; 5558400,0.0207515; 5562000,0.0103881; 5565600,0.0068961;
        5569200,0.0110026; 5572800,0.0035656; 5576400,0.0047175; 5580000,
        0.0058972; 5583600,0.0030196; 5587200,0.0051782; 5590800,0.0050342;
        5594400,0.008464; 5598000,0.0144118; 5601600,0.0079748; 5605200,
        0.000908; 5608800,1e-06; 5612400,7.6e-05; 5616000,0.002215; 5619600,
        0.0131276; 5623200,0.0290962; 5626800,0.0297079; 5630400,0.0249154;
        5634000,0.0242304; 5637600,0.014926; 5641200,0.0074169; 5644800,
        0.0055177; 5648400,0.0067342; 5652000,0.0093145; 5655600,0.0144734;
        5659200,0.0076604; 5662800,0.0063001; 5666400,0.0176931; 5670000,
        0.011592; 5673600,0.0114184; 5677200,0.020367; 5680800,0.0188765;
        5684400,0.0165009; 5688000,0.0059374; 5691600,0.0045172; 5695200,
        0.0064283; 5698800,0.0179081; 5702400,0.0262902; 5706000,0.0126257;
        5709600,0.0175877; 5713200,0.0337303; 5716800,0.0397537; 5720400,
        0.0292948; 5724000,0.0161642; 5727600,0.0088667; 5731200,0.0083061;
        5734800,0.0170877; 5738400,0.0152738; 5742000,0.016777; 5745600,
        0.0241628; 5749200,0.0237585; 5752800,0.0197777; 5756400,0.0193478;
        5760000,0.0289315; 5763600,0.0159825; 5767200,0.0065462; 5770800,
        0.0061322; 5774400,0.0064866; 5778000,0.0012605; 5781600,0.0030446;
        5785200,0.0094139; 5788800,0.0105594; 5792400,0.0168165; 5796000,
        0.0353678; 5799600,0.0301955; 5803200,0.0217778; 5806800,0.0346398;
        5810400,0.0205702; 5814000,0.0030169; 5817600,0.0029329; 5821200,
        0.0048045; 5824800,0.0105485; 5828400,0.0080053; 5832000,0.0059623;
        5835600,0.0070166; 5839200,0.0088411; 5842800,0.0025171; 5846400,
        0.0061183; 5850000,0.0051643; 5853600,0.0025963; 5857200,0.0022264;
        5860800,3.95e-05; 5864400,0.0015718; 5868000,0.0035381; 5871600,
        0.0022171; 5875200,0.004679; 5878800,0.0081588; 5882400,0.0198079;
        5886000,0.0312918; 5889600,0.035004; 5893200,0.0267758; 5896800,
        0.0093986; 5900400,0.0037222; 5904000,0.0005704; 5907600,0.0077922;
        5911200,0.0236374; 5914800,0.0181673; 5918400,0.0032799; 5922000,
        0.0171353; 5925600,0.0160488; 5929200,0.0199535; 5932800,0.0242003;
        5936400,0.0044042; 5940000,0.0023186; 5943600,0.0014208; 5947200,
        0.0048458; 5950800,0.0065215; 5954400,0.0007316; 5958000,1e-06; 5961600,
        1e-06; 5965200,0.0020605; 5968800,0.0121515; 5972400,0.0246494; 5976000,
        0.0264831; 5979600,0.0233143; 5983200,0.0179876; 5986800,0.0014971;
        5990400,0.0034477; 5994000,0.0240706; 5997600,0.0370099; 6001200,
        0.0249169; 6004800,0.0161728; 6008400,0.0210889; 6012000,0.0201468;
        6015600,0.0155008; 6019200,0.0223332; 6022800,0.0135576; 6026400,
        0.0040303; 6030000,0.0005489; 6033600,4.49e-05; 6037200,0.0004144;
        6040800,0.002978; 6044400,0.0103244; 6048000,0.016519; 6051600,
        0.0169811; 6055200,0.0171294; 6058800,0.0237457; 6062400,0.0289258;
        6066000,0.0241723; 6069600,0.0073198; 6073200,0.0054369; 6076800,
        0.0089806; 6080400,0.0224263; 6084000,0.0274457; 6087600,0.0171983;
        6091200,0.0131188; 6094800,0.011374; 6098400,0.0141568; 6102000,
        0.014726; 6105600,0.0148521; 6109200,0.007341; 6112800,0.004054;
        6116400,0.0052606; 6120000,0.0012888; 6123600,0.003704; 6127200,
        0.0010769; 6130800,0.0009677; 6134400,0.0097813; 6138000,0.0257532;
        6141600,0.0428436; 6145200,0.0389251; 6148800,0.0289265; 6152400,
        0.0424715; 6156000,0.0274216; 6159600,0.0060071; 6163200,0.0114004;
        6166800,0.0211417; 6170400,0.0178633; 6174000,0.0169105; 6177600,
        0.0211114; 6181200,0.0467512; 6184800,0.039119; 6188400,0.0163376;
        6192000,0.0163688; 6195600,0.0201278; 6199200,0.0305866; 6202800,
        0.0221781; 6206400,0.0038404; 6210000,1.01e-05; 6213600,5.8e-06;
        6217200,0.0023698; 6220800,0.0165713; 6224400,0.0315307; 6228000,
        0.0471269; 6231600,0.0604877; 6235200,0.0577707; 6238800,0.0853162;
        6242400,0.1943728; 6246000,0.1344983; 6249600,0.0650001; 6253200,
        0.0379469; 6256800,0.0106449; 6260400,0.0064963; 6264000,2.3e-05;
        6267600,7.68e-05; 6271200,0.0012343; 6274800,0.0010918; 6278400,
        0.0001391; 6282000,0.0032407; 6285600,0.010048; 6289200,0.0094193;
        6292800,0.0028127; 6296400,0.0041986; 6300000,0.004779; 6303600,
        0.0022723; 6307200,0.0044868; 6310800,0.0393807; 6314400,0.0644171;
        6318000,0.0523573; 6321600,0.0375521; 6325200,0.0268632; 6328800,
        0.0475982; 6332400,0.0181946; 6336000,0.0184552; 6339600,0.0062401;
        6343200,0.0028767; 6346800,0.0121244; 6350400,0.0016445; 6354000,
        0.0009696; 6357600,0.0085561; 6361200,0.0222579; 6364800,0.0128603;
        6368400,0.0044716; 6372000,0.0002026; 6375600,0.0001123; 6379200,1e-06;
        6382800,5.87e-05; 6386400,0.0012465; 6390000,0.0021559; 6393600,
        0.0012517; 6397200,0.000846; 6400800,0.0074479; 6404400,0.0282042;
        6408000,0.0419285; 6411600,0.0282651; 6415200,0.0167229; 6418800,
        0.0134536; 6422400,0.0107833; 6426000,0.0203759; 6429600,0.0262651;
        6433200,0.0133292; 6436800,0.0017535; 6440400,0.015389; 6444000,
        0.0172764; 6447600,0.0049366; 6451200,0.0132435; 6454800,0.0083634;
        6458400,0.0096387; 6462000,0.0084504; 6465600,0.0054301; 6469200,
        0.0049177; 6472800,0.0055529; 6476400,0.0062636; 6480000,0.0055228;
        6483600,0.03529; 6487200,0.086224; 6490800,0.0816696; 6494400,0.0663482;
        6498000,0.1269755; 6501600,0.1682051; 6505200,0.0594825; 6508800,
        0.0382572; 6512400,0.0207469; 6516000,0.0127583; 6519600,0.0075426;
        6523200,8.5e-06; 6526800,0.0001308; 6530400,0.0020322; 6534000,
        0.0062731; 6537600,0.0050239; 6541200,0.0019704; 6544800,0.001657;
        6548400,0.002829; 6552000,0.0003356; 6555600,1e-06; 6559200,0.0003344;
        6562800,0.0040037; 6566400,0.006328; 6570000,0.0243991; 6573600,
        0.0608829; 6577200,0.0404466; 6580800,0.0464418; 6584400,0.0205237;
        6588000,0.015679; 6591600,0.0184034; 6595200,0.0436567; 6598800,
        0.0740336; 6602400,0.0461706; 6606000,0.0098919; 6609600,0.0018691;
        6613200,0.0076319; 6616800,0.0088412; 6620400,0.0045146; 6624000,
        0.0138373; 6627600,0.0103022; 6631200,0.0079836; 6634800,0.0131738;
        6638400,0.0171823; 6642000,0.0315911; 6645600,0.043066; 6649200,
        0.0666714; 6652800,0.0896184; 6656400,0.1696157; 6660000,0.2179154;
        6663600,0.132537; 6667200,0.1813842; 6670800,0.2029475; 6674400,
        0.2008373; 6678000,0.1220285; 6681600,0.1040008; 6685200,0.0828606;
        6688800,0.0687662; 6692400,0.0143929; 6696000,0.0004487; 6699600,
        0.0001172; 6703200,0.0013626; 6706800,0.0018957; 6710400,0.0044488;
        6714000,0.0009511; 6717600,0.001058; 6721200,0.0048813; 6724800,
        0.0060247; 6728400,0.0169383; 6732000,0.022535; 6735600,0.0257449;
        6739200,0.0518129; 6742800,0.152109; 6746400,0.2479422; 6750000,
        0.2485461; 6753600,0.1784439; 6757200,0.1768949; 6760800,0.2372879;
        6764400,0.2006926; 6768000,0.119304; 6771600,0.0586032; 6775200,
        0.0264319; 6778800,0.0095762; 6782400,1e-06; 6786000,1e-06; 6789600,
        1e-06; 6793200,1e-06; 6796800,0.0002761; 6800400,0.0090596; 6804000,
        0.0060936; 6807600,0.0025527; 6811200,0.0013799; 6814800,0.0023974;
        6818400,0.0174651; 6822000,0.0393954; 6825600,0.0945254; 6829200,
        0.0803678; 6832800,0.0869278; 6836400,0.1625879; 6840000,0.1799;
        6843600,0.1896602; 6847200,0.1440337; 6850800,0.1164251; 6854400,
        0.1014414; 6858000,0.0321501; 6861600,0.0180333; 6865200,0.0097394;
        6868800,1e-06; 6872400,1e-06; 6876000,1e-06; 6879600,1e-06; 6883200,
        1e-06; 6886800,1e-06; 6890400,1e-06; 6894000,0.000771; 6897600,
        0.0020747; 6901200,1e-06; 6904800,0.0002579; 6908400,0.0125465; 6912000,
        0.0484457; 6915600,0.0911021; 6919200,0.1340103; 6922800,0.2034561;
        6926400,0.1627185; 6930000,0.1973; 6933600,0.1402689; 6937200,0.0319015;
        6940800,0.0519253; 6944400,0.0690681; 6948000,0.021669; 6951600,
        0.0113635; 6955200,0.0028915; 6958800,0.0104874; 6962400,0.0156062;
        6966000,0.0064621; 6969600,1e-06; 6973200,0.0003821; 6976800,0.0015424;
        6980400,0.000298; 6984000,1e-06; 6987600,1e-06; 6991200,1e-06; 6994800,
        0.0001101; 6998400,0.0006725; 7002000,0.0003027; 7005600,0.001653;
        7009200,0.004738; 7012800,0.007215; 7016400,0.0089004; 7020000,
        0.0042136; 7023600,0.0025033; 7027200,0.0014768; 7030800,0.0001487;
        7034400,0.0046479; 7038000,0.0092814; 7041600,0.0031134; 7045200,
        0.0094169; 7048800,0.0095208; 7052400,0.0033881; 7056000,0.0080967;
        7059600,0.0037202; 7063200,0.0026817; 7066800,0.0053738; 7070400,
        0.0040602; 7074000,0.0030761; 7077600,0.0025067; 7081200,0.0026688;
        7084800,0.0013071; 7088400,0.002351; 7092000,0.0082817; 7095600,
        0.010081; 7099200,0.0144893; 7102800,0.0174744; 7106400,0.0078302;
        7110000,0.0037986; 7113600,0.0023816; 7117200,0.0010089; 7120800,
        0.0074103; 7124400,0.010595; 7128000,0.0159861; 7131600,0.0094057;
        7135200,0.0087931; 7138800,0.009627; 7142400,0.0058197; 7146000,
        0.0016955; 7149600,6.3e-06; 7153200,1e-06; 7156800,1e-06; 7160400,1e-06;
        7164000,1e-06; 7167600,0.0005424; 7171200,0.003325; 7174800,0.0090398;
        7178400,0.0272003; 7182000,0.0326928; 7185600,0.0676427; 7189200,
        0.1111586; 7192800,0.05886; 7196400,0.0102108; 7200000,0.0001145;
        7203600,4.17e-05; 7207200,0.0035662; 7210800,0.0033541; 7214400,
        0.0015387; 7218000,0.0006854; 7221600,0.0010675; 7225200,0.0026725;
        7228800,0.0046603; 7232400,0.0033437; 7236000,0.002131; 7239600,
        0.0004195; 7243200,3.61e-05; 7246800,0.0012024; 7250400,0.004809;
        7254000,0.0080055; 7257600,0.0086215; 7261200,0.0222927; 7264800,
        0.0269952; 7268400,0.0251373; 7272000,0.0678548; 7275600,0.0630069;
        7279200,0.0422621; 7282800,0.0086876; 7286400,0.0038082; 7290000,
        0.0126019; 7293600,0.0350483; 7297200,0.0246989; 7300800,0.0075963;
        7304400,0.0124722; 7308000,0.0154355; 7311600,0.0035572; 7315200,
        0.0101765; 7318800,0.0011982; 7322400,1e-06; 7326000,1.39e-05; 7329600,
        1e-06; 7333200,1e-06; 7336800,1e-06; 7340400,1e-06; 7344000,0.0005849;
        7347600,0.0048681; 7351200,0.0130035; 7354800,0.0261321; 7358400,
        0.049625; 7362000,0.0436154; 7365600,0.0233535; 7369200,0.0076599;
        7372800,0.0010474; 7376400,1e-06; 7380000,0.0001308; 7383600,0.0019501;
        7387200,0.0014161; 7390800,0.0002164; 7394400,0.0012087; 7398000,
        0.0005593; 7401600,6e-06; 7405200,0.0001891; 7408800,4.78e-05; 7412400,
        1e-06; 7416000,1e-06; 7419600,4.82e-05; 7423200,0.0024851; 7426800,
        0.0131728; 7430400,0.0364768; 7434000,0.0677108; 7437600,0.0775794;
        7441200,0.1187574; 7444800,0.130318; 7448400,0.0825249; 7452000,
        0.0264629; 7455600,0.0204406; 7459200,0.0112935; 7462800,0.0030065;
        7466400,0.0039642; 7470000,0.0065281; 7473600,0.0003457; 7477200,
        0.0001121; 7480800,0.001209; 7484400,0.0017782; 7488000,0.0006383;
        7491600,0.0018895; 7495200,0.0054324; 7498800,0.0040979; 7502400,
        0.0013125; 7506000,0.001745; 7509600,0.0006014; 7513200,0.0002804;
        7516800,0.0057092; 7520400,0.0080524; 7524000,0.0074216; 7527600,
        0.0088478; 7531200,0.0108748; 7534800,0.0064621; 7538400,0.003421;
        7542000,0.0034484; 7545600,0.0047411; 7549200,0.0106214; 7552800,
        0.0117659; 7556400,0.0051231; 7560000,0.0027497; 7563600,0.0096267;
        7567200,0.0048279; 7570800,0.0033544; 7574400,0.001497; 7578000,
        3.06e-05; 7581600,0.0005065; 7585200,4.98e-05; 7588800,1e-06; 7592400,
        1e-06; 7596000,1e-06; 7599600,1e-06; 7603200,1e-06; 7606800,0.0008678;
        7610400,0.00454; 7614000,0.0056653; 7617600,0.0065658; 7621200,
        0.0034837; 7624800,8.43e-05; 7628400,0.00034; 7632000,0.0012605;
        7635600,0.0054843; 7639200,0.0096383; 7642800,0.002028; 7646400,
        0.0008137; 7650000,0.0006598; 7653600,0.0011711; 7657200,0.0006718;
        7660800,0.001433; 7664400,0.0012005; 7668000,1e-06; 7671600,1e-06;
        7675200,1e-06; 7678800,1e-06; 7682400,0.0005286; 7686000,0.0027978;
        7689600,0.0065482; 7693200,0.0112871; 7696800,0.010328; 7700400,
        0.0060211; 7704000,0.0077663; 7707600,0.0048908; 7711200,0.0040344;
        7714800,0.006143; 7718400,0.0100652; 7722000,0.0206753; 7725600,
        0.0121464; 7729200,0.0084661; 7732800,0.0157402; 7736400,0.0208767;
        7740000,0.0153721; 7743600,0.010571; 7747200,0.0073083; 7750800,
        0.0048099; 7754400,0.0003833; 7758000,1e-06; 7761600,1e-06; 7765200,
        0.0022005; 7768800,0.010916; 7772400,0.0057413; 7776000,0.0054932;
        7779600,0.0189567; 7783200,0.0285407; 7786800,0.0224846; 7790400,
        0.0328803; 7794000,0.0251758; 7797600,0.0080995; 7801200,0.0210799;
        7804800,0.0525662; 7808400,0.0544975; 7812000,0.0179103; 7815600,
        0.0111576; 7819200,0.0289403; 7822800,0.032874; 7826400,0.0225733;
        7830000,0.0270585; 7833600,0.0087772; 7837200,0.0043455; 7840800,
        0.0069664; 7844400,0.0014439; 7848000,0.0013744; 7851600,0.0030588;
        7855200,0.0061408; 7858800,0.0090734; 7862400,0.0275743; 7866000,
        0.0519755; 7869600,0.0490102; 7873200,0.0460794; 7876800,0.0287226;
        7880400,0.0170873; 7884000,0.0294183; 7887600,0.0721492; 7891200,
        0.0818781; 7894800,0.0917314; 7898400,0.0725748; 7902000,0.0225474;
        7905600,0.0304597; 7909200,0.0653501; 7912800,0.0548856; 7916400,
        0.0216273; 7920000,0.0273603; 7923600,0.0208079; 7927200,0.0073557;
        7930800,0.0045163; 7934400,0.0039473; 7938000,0.0191004; 7941600,
        0.0377449; 7945200,0.0348278; 7948800,0.0722381; 7952400,0.103781;
        7956000,0.0554447; 7959600,0.0561054; 7963200,0.0841032; 7966800,
        0.0455416; 7970400,0.0242964; 7974000,0.0314698; 7977600,0.0254864;
        7981200,0.0107847; 7984800,0.0154663; 7988400,0.0067505; 7992000,
        0.0072811; 7995600,0.0277093; 7999200,0.0091137; 8002800,0.0053954;
        8006400,0.0099876; 8010000,0.0178127; 8013600,0.0126819; 8017200,
        0.0032783; 8020800,0.0037381; 8024400,0.0073075; 8028000,0.0129286;
        8031600,0.0170001; 8035200,0.0158189; 8038800,0.0245188; 8042400,
        0.0322131; 8046000,0.0277793; 8049600,0.0317267; 8053200,0.0272088;
        8056800,0.0094937; 8060400,0.0059573; 8064000,0.0098054; 8067600,
        0.008943; 8071200,0.0100913; 8074800,0.0075879; 8078400,0.005313;
        8082000,0.0090155; 8085600,0.0099415; 8089200,0.0103143; 8092800,
        0.0136349; 8096400,0.0141398; 8100000,0.0099719; 8103600,0.003324;
        8107200,0.0028262; 8110800,0.0064679; 8114400,0.0149227; 8118000,
        0.0194184; 8121600,0.0110718; 8125200,0.018934; 8128800,0.0308855;
        8132400,0.0225359; 8136000,0.0258943; 8139600,0.0155067; 8143200,
        0.0022291; 8146800,0.010942; 8150400,0.0363918; 8154000,0.0494921;
        8157600,0.0356302; 8161200,0.010522; 8164800,0.0039491; 8168400,
        0.0108691; 8172000,0.0131063; 8175600,0.0113789; 8179200,0.0095043;
        8182800,0.00804; 8186400,0.0040406; 8190000,0.000558; 8193600,0.0004265;
        8197200,0.0024034; 8200800,0.0039331; 8204400,0.0072418; 8208000,
        0.0216316; 8211600,0.0350749; 8215200,0.0280128; 8218800,0.0278286;
        8222400,0.0357279; 8226000,0.0160638; 8229600,0.00373; 8233200,
        0.0026341; 8236800,0.0062816; 8240400,0.0183721; 8244000,0.014993;
        8247600,0.0041492; 8251200,0.0027095; 8254800,0.0205163; 8258400,
        0.0154134; 8262000,0.0048796; 8265600,0.0073955; 8269200,0.0056538;
        8272800,0.002994; 8276400,0.0017515; 8280000,0.001788; 8283600,
        0.0021495; 8287200,0.0024898; 8290800,0.0037601; 8294400,0.0156897;
        8298000,0.0384568; 8301600,0.0430505; 8305200,0.0354745; 8308800,
        0.0326524; 8312400,0.0179041; 8316000,0.0044721; 8319600,0.0033707;
        8323200,0.0120803; 8326800,0.038372; 8330400,0.0464533; 8334000,
        0.0132206; 8337600,0.004623; 8341200,0.0082007; 8344800,0.0071399;
        8348400,0.0019528; 8352000,0.0005083; 8355600,0.0015576; 8359200,
        0.0016345; 8362800,0.00054; 8366400,5.76e-05; 8370000,0.001571; 8373600,
        0.0042689; 8377200,0.0056294; 8380800,0.0077588; 8384400,0.0120177;
        8388000,0.0175447; 8391600,0.0328688; 8395200,0.0432423; 8398800,
        0.0153256; 8402400,0.0056729; 8406000,0.0046005; 8409600,0.0075574;
        8413200,0.0120801; 8416800,0.0067261; 8420400,0.0035825; 8424000,
        0.0009308; 8427600,0.0033624; 8431200,0.0024496; 8434800,0.0023326;
        8438400,0.0002786; 8442000,1e-06; 8445600,1e-06; 8449200,1e-06; 8452800,
        1e-06; 8456400,1e-06; 8460000,1e-06; 8463600,0.0005981; 8467200,
        0.0091519; 8470800,0.0240352; 8474400,0.0227704; 8478000,0.0224615;
        8481600,0.025919; 8485200,0.0170398; 8488800,0.0105087; 8492400,
        0.0093421; 8496000,0.0136321; 8499600,0.0088544; 8503200,0.0041743;
        8506800,0.0014351; 8510400,0.0004757; 8514000,0.0034886; 8517600,
        0.0023681; 8521200,0.0001586; 8524800,0.0009594; 8528400,0.0008806;
        8532000,8.3e-05; 8535600,1e-06; 8539200,1e-06; 8542800,1e-06; 8546400,
        1e-06; 8550000,1e-06; 8553600,0.000211; 8557200,0.0052319; 8560800,
        0.0112125; 8564400,0.0143194; 8568000,0.0192737; 8571600,0.0177157;
        8575200,0.0087102; 8578800,0.0007563; 8582400,0.0006198; 8586000,
        0.0028835; 8589600,0.0060819; 8593200,0.0028011; 8596800,0.0004295;
        8600400,0.0047829; 8604000,0.0050281; 8607600,0.0004008; 8611200,
        0.0008676; 8614800,0.0006503; 8618400,7.8e-06; 8622000,1e-06; 8625600,
        5.9e-06; 8629200,0.0008488; 8632800,0.0030559; 8636400,0.004392;
        8640000,0.004299; 8643600,0.0088473; 8647200,0.0148965; 8650800,
        0.0185086; 8654400,0.0249689; 8658000,0.0181895; 8661600,0.0043694;
        8665200,0.0016292; 8668800,0.0002469; 8672400,0.0010247; 8676000,
        0.0032306; 8679600,0.0014372; 8683200,2e-06; 8686800,0.0005135; 8690400,
        0.0005254; 8694000,1e-06; 8697600,1e-06; 8701200,1e-06; 8704800,1e-06;
        8708400,1e-06; 8712000,1e-06; 8715600,1e-06; 8719200,1e-06; 8722800,
        1e-06; 8726400,1e-06; 8730000,0.0002349; 8733600,0.0035785; 8737200,
        0.0049275; 8740800,0.0035119; 8744400,0.0009897; 8748000,0.0001312;
        8751600,0.0011296; 8755200,0.0047526; 8758800,0.0089451; 8762400,
        0.0071181; 8766000,0.0025766; 8769600,0.0024047; 8773200,0.0040373;
        8776800,0.0037505; 8780400,0.0015936; 8784000,1.97e-05; 8787600,
        0.0002073; 8791200,1e-06; 8794800,1e-06; 8798400,1e-06; 8802000,1e-06;
        8805600,1e-06; 8809200,1e-06; 8812800,2.37e-05; 8816400,0.0027623;
        8820000,0.0097325; 8823600,0.0126265; 8827200,0.0115344; 8830800,
        0.0059085; 8834400,0.0032712; 8838000,0.0018939; 8841600,0.0023101;
        8845200,0.0080244; 8848800,0.0175401; 8852400,0.0190183; 8856000,
        0.021829; 8859600,0.0253772; 8863200,0.0214864; 8866800,0.0305549;
        8870400,0.023559; 8874000,0.0179595; 8877600,0.009107; 8881200,
        0.0015826; 8884800,0.0003263; 8888400,0.0005468; 8892000,0.0012989;
        8895600,0.0029358; 8899200,0.0081101; 8902800,0.0193246; 8906400,
        0.0288361; 8910000,0.0338732; 8913600,0.035124; 8917200,0.0207479;
        8920800,0.0048781; 8924400,0.015453; 8928000,0.0399445; 8931600,
        0.0327179; 8935200,0.0154535; 8938800,0.0150943; 8942400,0.0182664;
        8946000,0.0161235; 8949600,0.0127895; 8953200,0.0180064; 8956800,
        0.0129573; 8960400,0.0071042; 8964000,0.0064664; 8967600,0.0057389;
        8971200,0.0018904; 8974800,0.001862; 8978400,0.0072067; 8982000,
        0.0231218; 8985600,0.0550681; 8989200,0.0788294; 8992800,0.0727399;
        8996400,0.0888882; 9000000,0.0960588; 9003600,0.024334; 9007200,
        0.0070093; 9010800,0.0144311; 9014400,0.0549319; 9018000,0.0446596;
        9021600,0.0207189; 9025200,0.0170956; 9028800,0.0549124; 9032400,
        0.0388044; 9036000,0.0115801; 9039600,0.0101107; 9043200,0.0314817;
        9046800,0.01278; 9050400,0.0095659; 9054000,0.0064943; 9057600,
        0.0027125; 9061200,0.0003362; 9064800,0.0005643; 9068400,0.0075885;
        9072000,0.0467443; 9075600,0.10128; 9079200,0.1016425; 9082800,
        0.0968607; 9086400,0.1126068; 9090000,0.0585933; 9093600,0.0206201;
        9097200,0.0323192; 9100800,0.0496354; 9104400,0.0255739; 9108000,
        0.0070862; 9111600,0.0016399; 9115200,0.005858; 9118800,0.0110751;
        9122400,0.0106471; 9126000,0.0036686; 9129600,7.35e-05; 9133200,1e-06;
        9136800,1e-06; 9140400,1e-06; 9144000,1e-06; 9147600,1e-06; 9151200,
        0.0001812; 9154800,0.0018562; 9158400,0.0110016; 9162000,0.0385554;
        9165600,0.051897; 9169200,0.1168291; 9172800,0.1568442; 9176400,
        0.0786726; 9180000,0.0323621; 9183600,0.0265886; 9187200,0.0074594;
        9190800,1e-06; 9194400,3.56e-05; 9198000,0.00091; 9201600,0.0013283;
        9205200,0.0006334; 9208800,0.0004468; 9212400,1.61e-05; 9216000,1e-06;
        9219600,1e-06; 9223200,1e-06; 9226800,1e-06; 9230400,1e-06; 9234000,
        1e-06; 9237600,1e-06; 9241200,1e-06; 9244800,0.0001674; 9248400,
        0.0035078; 9252000,0.0074473; 9255600,0.0068714; 9259200,0.0057057;
        9262800,0.0034918; 9266400,4.78e-05; 9270000,0.0002029; 9273600,
        0.0006034; 9277200,0.0016949; 9280800,0.0030055; 9284400,0.0020865;
        9288000,0.0008056; 9291600,0.0045696; 9295200,0.004402; 9298800,
        0.0011507; 9302400,0.0005809; 9306000,0.0010852; 9309600,0.0001061;
        9313200,1e-06; 9316800,4.1e-06; 9320400,0.0008349; 9324000,0.0021781;
        9327600,0.0012983; 9331200,0.0038629; 9334800,0.0089912; 9338400,
        0.0126668; 9342000,0.0128648; 9345600,0.0173065; 9349200,0.0153132;
        9352800,0.0059491; 9356400,0.0005171; 9360000,0.0126331; 9363600,
        0.0479333; 9367200,0.0222335; 9370800,0.0015472; 9374400,0.0129847;
        9378000,0.0406894; 9381600,0.0316527; 9385200,0.0038448; 9388800,
        0.0016872; 9392400,0.0041188; 9396000,0.007694; 9399600,0.0002245;
        9403200,1e-06; 9406800,0.0001124; 9410400,0.0020625; 9414000,0.0035616;
        9417600,0.0028346; 9421200,0.0066806; 9424800,0.0085868; 9428400,
        0.0091884; 9432000,0.0125433; 9435600,0.0055913; 9439200,0.0029569;
        9442800,0.0007839; 9446400,0.0092993; 9450000,0.0130638; 9453600,
        0.0111479; 9457200,0.0071048; 9460800,0.0020334; 9464400,0.0094105;
        9468000,0.0034853; 9471600,0.0004538; 9475200,0.0005539; 9478800,
        0.0010145; 9482400,0.0002018; 9486000,1e-06; 9489600,1e-06; 9493200,
        0.0007086; 9496800,0.003878; 9500400,0.0063431; 9504000,0.0062915;
        9507600,0.0081708; 9511200,0.0144365; 9514800,0.0172618; 9518400,
        0.0209489; 9522000,0.024182; 9525600,0.0064949; 9529200,0.0005102;
        9532800,0.0035637; 9536400,0.0049492; 9540000,0.0011205; 9543600,
        0.0027424; 9547200,0.0014836; 9550800,0.0013177; 9554400,0.001919;
        9558000,0.000295; 9561600,0.00067; 9565200,0.0010654; 9568800,0.0001255;
        9572400,0.0009212; 9576000,0.0020229; 9579600,0.003572; 9583200,
        0.0056474; 9586800,0.0067617; 9590400,0.0112075; 9594000,0.025197;
        9597600,0.0376899; 9601200,0.0427694; 9604800,0.0559864; 9608400,
        0.0406875; 9612000,0.0199013; 9615600,0.0069995; 9619200,0.0040786;
        9622800,0.005864; 9626400,0.0010329; 9630000,0.0021495; 9633600,
        0.0005532; 9637200,0.0010778; 9640800,0.0026889; 9644400,0.0026733;
        9648000,0.0011942; 9651600,0.0015168; 9655200,0.0006707; 9658800,2e-06;
        9662400,0.0003021; 9666000,0.0014392; 9669600,0.0034747; 9673200,
        0.0046211; 9676800,0.0073756; 9680400,0.0130877; 9684000,0.0177423;
        9687600,0.0221804; 9691200,0.0330299; 9694800,0.023649; 9698400,
        0.006493; 9702000,0.0024044; 9705600,0.0048078; 9709200,0.0087793;
        9712800,0.0039219; 9716400,0.0027244; 9720000,0.0013648; 9723600,
        0.0028743; 9727200,0.0022035; 9730800,0.0012751; 9734400,0.0010637;
        9738000,0.000986; 9741600,1.82e-05; 9745200,1e-06; 9748800,1e-06;
        9752400,1e-06; 9756000,7.89e-05; 9759600,0.001925; 9763200,0.00718;
        9766800,0.0174637; 9770400,0.0243427; 9774000,0.022379; 9777600,
        0.0418984; 9781200,0.1008233; 9784800,0.05491; 9788400,0.0049248;
        9792000,0.0005171; 9795600,0.0005687; 9799200,0.0009302; 9802800,
        0.0014392; 9806400,0.0006527; 9810000,0.0003793; 9813600,0.0010329;
        9817200,0.0001084; 9820800,0.0002886; 9824400,0.0009166; 9828000,
        0.0002348; 9831600,1e-06; 9835200,1e-06; 9838800,1e-06; 9842400,1e-06;
        9846000,1e-06; 9849600,0.0006194; 9853200,0.0052358; 9856800,0.0109132;
        9860400,0.0106862; 9864000,0.0099456; 9867600,0.0048682; 9871200,
        0.0030357; 9874800,0.0032685; 9878400,0.0033348; 9882000,0.0026951;
        9885600,0.0031195; 9889200,0.0034309; 9892800,0.0033188; 9896400,
        0.0046085; 9900000,0.0042194; 9903600,0.0005687; 9907200,0.0006477;
        9910800,0.0016799; 9914400,0.0013106; 9918000,0.0011615; 9921600,
        0.0008471; 9925200,0.0010962; 9928800,0.0026023; 9932400,0.00454;
        9936000,0.0106507; 9939600,0.0216698; 9943200,0.0225687; 9946800,
        0.0233203; 9950400,0.028148; 9954000,0.0236989; 9957600,0.0083963;
        9961200,0.0033484; 9964800,0.0010885; 9968400,0.002565; 9972000,
        0.0013424; 9975600,0.0017808; 9979200,0.0001245; 9982800,0.000621;
        9986400,0.0014515; 9990000,0.0003111; 9993600,0.0010717; 9997200,
        0.0013848; 10000800,1.03e-05; 10004400,1e-06; 10008000,1e-06; 10011600,
        1.22e-05; 10015200,0.0002228; 10018800,3.61e-05; 10022400,1e-06;
        10026000,0.0003652; 10029600,0.0033171; 10033200,0.006893; 10036800,
        0.0085457; 10040400,0.0051188; 10044000,0.0022528; 10047600,0.0022114;
        10051200,0.0087333; 10054800,0.0202434; 10058400,0.0123838; 10062000,
        0.0102804; 10065600,0.0023458; 10069200,0.0072865; 10072800,0.0094793;
        10076400,0.0041848; 10080000,0.0024382; 10083600,0.0015059; 10087200,
        2e-06; 10090800,1e-06; 10094400,1e-06; 10098000,0.0001658; 10101600,
        0.001437; 10105200,0.0023554; 10108800,0.0013946; 10112400,0.0073115;
        10116000,0.010432; 10119600,0.0092275; 10123200,0.0090982; 10126800,
        0.0059201; 10130400,0.0014711; 10134000,5.82e-05; 10137600,0.0012337;
        10141200,0.0033753; 10144800,0.0092751; 10148400,0.0084289; 10152000,
        0.0053934; 10155600,0.0068625; 10159200,0.0077938; 10162800,0.0038683;
        10166400,0.0026653; 10170000,0.002056; 10173600,0.0001845; 10177200,
        1e-06; 10180800,1e-06; 10184400,0.0005902; 10188000,0.0021131; 10191600,
        0.0031942; 10195200,0.004485; 10198800,0.0107746; 10202400,0.0196795;
        10206000,0.0189691; 10209600,0.0168093; 10213200,0.0123093; 10216800,
        0.0057619; 10220400,0.0038171; 10224000,0.0193563; 10227600,0.0349145;
        10231200,0.0246365; 10234800,0.0118789; 10238400,0.017194; 10242000,
        0.0249987; 10245600,0.0088722; 10249200,0.0075542; 10252800,0.0071333;
        10256400,0.0070541; 10260000,0.0017763; 10263600,2.1e-06; 10267200,
        6.23e-05; 10270800,0.0011166; 10274400,0.0018754; 10278000,0.0003593;
        10281600,0.0077528; 10285200,0.0250016; 10288800,0.035091; 10292400,
        0.0299157; 10296000,0.0333025; 10299600,0.0275865; 10303200,0.0068898;
        10306800,0.0008539; 10310400,2.2e-06; 10314000,0.000275; 10317600,
        0.0011713; 10321200,0.0020238; 10324800,0.0019966; 10328400,0.0052433;
        10332000,0.0019693; 10335600,1e-06; 10339200,1e-06; 10342800,1e-06;
        10346400,1e-06; 10350000,1e-06; 10353600,1e-06; 10357200,1e-06;
        10360800,1e-06; 10364400,1e-06; 10368000,4.42e-05; 10371600,0.0036668;
        10375200,0.0089478; 10378800,0.0090296; 10382400,0.0139592; 10386000,
        0.0101453; 10389600,0.0029854; 10393200,0.0021664; 10396800,0.0027981;
        10400400,0.0030839; 10404000,0.0036181; 10407600,0.0038608; 10411200,
        0.0012336; 10414800,0.0049775; 10418400,0.0068422; 10422000,0.000761;
        10425600,2e-06; 10429200,2.59e-05; 10432800,1e-06; 10436400,1e-06;
        10440000,1e-06; 10443600,1e-06; 10447200,1e-06; 10450800,1.99e-05;
        10454400,0.0011863; 10458000,0.0054507; 10461600,0.0131169; 10465200,
        0.0275789; 10468800,0.0309389; 10472400,0.0183533; 10476000,0.0040098;
        10479600,1e-06; 10483200,1e-06; 10486800,1e-06; 10490400,0.0003671;
        10494000,0.0025716; 10497600,0.0013054; 10501200,1e-06; 10504800,
        7.9e-06; 10508400,9.98e-05; 10512000,0.0004229; 10515600,0.0008811;
        10519200,6e-06; 10522800,1e-06; 10526400,1e-06; 10530000,1e-06;
        10533600,1e-06; 10537200,1e-06; 10540800,1e-06; 10544400,0.0002507;
        10548000,0.0034631; 10551600,0.0057071; 10555200,0.005979; 10558800,
        0.0022073; 10562400,5.6e-06; 10566000,0.000134; 10569600,0.0007331;
        10573200,0.0016558; 10576800,0.0023949; 10580400,0.0020231; 10584000,
        0.0009415; 10587600,0.0012698; 10591200,4e-06; 10594800,1e-06; 10598400,
        1e-06; 10602000,1e-06; 10605600,1e-06; 10609200,1e-06; 10612800,1e-06;
        10616400,1e-06; 10620000,1e-06; 10623600,1e-06; 10627200,0.0004855;
        10630800,0.0039214; 10634400,0.0085937; 10638000,0.0109693; 10641600,
        0.0204986; 10645200,0.0167099; 10648800,0.0079771; 10652400,0.0097126;
        10656000,0.0302598; 10659600,0.0357866; 10663200,0.0104414; 10666800,
        0.0058864; 10670400,0.0109526; 10674000,0.0114871; 10677600,0.0016437;
        10681200,0.001812; 10684800,0.0003903; 10688400,0.0003759; 10692000,
        0.001228; 10695600,0.0017528; 10699200,0.0013581; 10702800,0.0019188;
        10706400,0.0036344; 10710000,0.0046296; 10713600,0.0055599; 10717200,
        0.0102656; 10720800,0.0195041; 10724400,0.0196061; 10728000,0.0163698;
        10731600,0.0108909; 10735200,0.0050538; 10738800,0.0006479; 10742400,
        0.001039; 10746000,0.006775; 10749600,0.0067221; 10753200,0.0062202;
        10756800,0.0037499; 10760400,0.0028468; 10764000,0.0004473; 10767600,
        0.006324; 10771200,0.0072094; 10774800,0.0007529; 10778400,1e-06;
        10782000,1e-06; 10785600,1e-06; 10789200,1e-06; 10792800,1e-06;
        10796400,1e-06; 10800000,0.0004816; 10803600,0.0080819; 10807200,
        0.0239253; 10810800,0.0182367; 10814400,0.0174925; 10818000,0.0170788;
        10821600,0.0036772; 10825200,1.9e-06; 10828800,0.0034206; 10832400,
        0.0160474; 10836000,0.0077766; 10839600,0.0046007; 10843200,0.0042222;
        10846800,0.005265; 10850400,0.0049352; 10854000,0.0003928; 10857600,
        1e-06; 10861200,1e-06; 10864800,1e-06; 10868400,1e-06; 10872000,1e-06;
        10875600,1e-06; 10879200,1e-06; 10882800,1e-06; 10886400,0.000207;
        10890000,0.0032416; 10893600,0.0051627; 10897200,0.0051157; 10900800,
        0.0071471; 10904400,0.0097432; 10908000,0.0044312; 10911600,5.19e-05;
        10915200,1e-06; 10918800,1e-06; 10922400,0.0004996; 10926000,0.0010472;
        10929600,8.16e-05; 10933200,0.0002777; 10936800,0.0007529; 10940400,
        1e-06; 10944000,0.0004125; 10947600,0.0010227; 10951200,8e-06; 10954800,
        1e-06; 10958400,1e-06; 10962000,1e-06; 10965600,1e-06; 10969200,1e-06;
        10972800,1e-06; 10976400,0.001056; 10980000,0.0042006; 10983600,
        0.0067833; 10987200,0.0079221; 10990800,0.0076146; 10994400,0.0038275;
        10998000,0.0001388; 11001600,1e-06; 11005200,1e-06; 11008800,1e-06;
        11012400,1e-06; 11016000,1e-06; 11019600,1e-06; 11023200,1e-06;
        11026800,1e-06; 11030400,1e-06; 11034000,1e-06; 11037600,1e-06;
        11041200,1e-06; 11044800,1e-06; 11048400,1e-06; 11052000,1e-06;
        11055600,1e-06; 11059200,1e-06; 11062800,5.22e-05; 11066400,0.0017296;
        11070000,0.0039169; 11073600,0.0047788; 11077200,0.0010839; 11080800,
        1e-06; 11084400,1e-06; 11088000,1e-06; 11091600,1e-06; 11095200,1e-06;
        11098800,1e-06; 11102400,1e-06; 11106000,1e-06; 11109600,1e-06;
        11113200,1e-06; 11116800,1e-06; 11120400,1e-06; 11124000,1e-06;
        11127600,1e-06; 11131200,1e-06; 11134800,1e-06; 11138400,1e-06;
        11142000,1e-06; 11145600,1e-06; 11149200,1e-06; 11152800,0.000229;
        11156400,0.0021415; 11160000,0.0029216; 11163600,0.0005339; 11167200,
        1e-06; 11170800,1e-06; 11174400,1e-06; 11178000,1e-06; 11181600,1e-06;
        11185200,1e-06; 11188800,1e-06; 11192400,0.000134; 11196000,0.0003294;
        11199600,1.34e-05; 11203200,1e-06; 11206800,1e-06; 11210400,1e-06;
        11214000,1e-06; 11217600,1e-06; 11221200,1e-06; 11224800,1e-06;
        11228400,1e-06; 11232000,1e-06; 11235600,8.35e-05; 11239200,0.0014448;
        11242800,0.0020472; 11246400,0.0023964; 11250000,0.0017164; 11253600,
        1e-06; 11257200,1e-06; 11260800,1.52e-05; 11264400,1e-06; 11268000,
        1e-06; 11271600,1e-06; 11275200,1e-06; 11278800,1e-06; 11282400,1e-06;
        11286000,1e-06; 11289600,1e-06; 11293200,1e-06; 11296800,1e-06;
        11300400,1e-06; 11304000,1e-06; 11307600,1e-06; 11311200,1e-06;
        11314800,1e-06; 11318400,1e-06; 11322000,0.0002157; 11325600,0.0021021;
        11329200,0.0035744; 11332800,0.0035971; 11336400,0.0011359; 11340000,
        1e-06; 11343600,1e-06; 11347200,1e-06; 11350800,1e-06; 11354400,1e-06;
        11358000,1e-06; 11361600,1e-06; 11365200,1e-06; 11368800,1e-06;
        11372400,1e-06; 11376000,1e-06; 11379600,1e-06; 11383200,1e-06;
        11386800,1e-06; 11390400,1e-06; 11394000,1e-06; 11397600,1e-06;
        11401200,1e-06; 11404800,1e-06; 11408400,1e-06; 11412000,0.0001907;
        11415600,0.0017639; 11419200,0.0032222; 11422800,0.0011279; 11426400,
        1e-06; 11430000,1e-06; 11433600,1e-06; 11437200,1e-06; 11440800,1e-06;
        11444400,1e-06; 11448000,1e-06; 11451600,1e-06; 11455200,1e-06;
        11458800,1e-06; 11462400,1e-06; 11466000,1e-06; 11469600,1e-06;
        11473200,1e-06; 11476800,1e-06; 11480400,1e-06; 11484000,1e-06;
        11487600,1e-06; 11491200,1e-06; 11494800,0.0004291; 11498400,0.002858;
        11502000,0.0038779; 11505600,0.0030487; 11509200,0.0028891; 11512800,
        0.0020731; 11516400,0.0003987; 11520000,8.84e-05; 11523600,0.0005239;
        11527200,0.0018; 11530800,0.0021245; 11534400,0.0015113; 11538000,
        0.0015703; 11541600,0.0001242; 11545200,9.1e-05; 11548800,1e-06;
        11552400,1e-06; 11556000,1e-06; 11559600,1e-06; 11563200,1e-06;
        11566800,1e-06; 11570400,1e-06; 11574000,1e-06; 11577600,1e-06;
        11581200,0.0005027; 11584800,0.0028782; 11588400,0.0037229; 11592000,
        0.0060471; 11595600,0.008529; 11599200,0.0024214; 11602800,1.93e-05;
        11606400,0.0005274; 11610000,0.0009072; 11613600,0.0001836; 11617200,
        1e-06; 11620800,1e-06; 11624400,1e-06; 11628000,1e-06; 11631600,1e-06;
        11635200,1e-06; 11638800,1e-06; 11642400,1e-06; 11646000,1e-06;
        11649600,1e-06; 11653200,1e-06; 11656800,1e-06; 11660400,1e-06;
        11664000,1e-06; 11667600,0.0003759; 11671200,0.003034; 11674800,
        0.0035413; 11678400,0.0021171; 11682000,0.0011158; 11685600,0.0016245;
        11689200,0.0036207; 11692800,0.0075361; 11696400,0.0061097; 11700000,
        0.0035022; 11703600,0.0028969; 11707200,0.0007691; 11710800,0.0011922;
        11714400,0.0026954; 11718000,0.0009955; 11721600,0.0010284; 11725200,
        0.0023744; 11728800,0.0022317; 11732400,0.0015262; 11736000,1e-06;
        11739600,8.67e-05; 11743200,0.0006171; 11746800,0.0004931; 11750400,
        1e-06; 11754000,1e-06; 11757600,1e-06; 11761200,1e-06; 11764800,1e-06;
        11768400,1e-06; 11772000,1e-06; 11775600,1e-06; 11779200,1e-06;
        11782800,1e-06; 11786400,1e-06; 11790000,1e-06; 11793600,1e-06;
        11797200,1e-06; 11800800,1e-06; 11804400,1e-06; 11808000,1e-06;
        11811600,1e-06; 11815200,1e-06; 11818800,1e-06; 11822400,1e-06;
        11826000,1e-06; 11829600,1e-06; 11833200,1e-06; 11836800,1e-06;
        11840400,1e-06; 11844000,1e-06; 11847600,1e-06; 11851200,1e-06;
        11854800,1e-06; 11858400,1e-06; 11862000,1e-06; 11865600,1e-06;
        11869200,1e-06; 11872800,1e-06; 11876400,1e-06; 11880000,1e-06;
        11883600,1e-06; 11887200,1e-06; 11890800,1e-06; 11894400,1e-06;
        11898000,1e-06; 11901600,1e-06; 11905200,1e-06; 11908800,1e-06;
        11912400,1e-06; 11916000,1e-06; 11919600,1e-06; 11923200,1e-06;
        11926800,1e-06; 11930400,1e-06; 11934000,1e-06; 11937600,1e-06;
        11941200,1e-06; 11944800,1e-06; 11948400,1e-06; 11952000,1e-06;
        11955600,1e-06; 11959200,1e-06; 11962800,1e-06; 11966400,1e-06;
        11970000,1e-06; 11973600,1e-06; 11977200,1e-06; 11980800,1e-06;
        11984400,1e-06; 11988000,1e-06; 11991600,1e-06; 11995200,1e-06;
        11998800,1e-06; 12002400,1e-06; 12006000,1e-06; 12009600,1e-06;
        12013200,1e-06; 12016800,1e-06; 12020400,1e-06; 12024000,1e-06;
        12027600,1e-06; 12031200,1e-06; 12034800,1e-06; 12038400,1e-06;
        12042000,1e-06; 12045600,1e-06; 12049200,1e-06; 12052800,1e-06;
        12056400,1e-06; 12060000,1e-06; 12063600,1e-06; 12067200,1e-06;
        12070800,1e-06; 12074400,1e-06; 12078000,1e-06; 12081600,1e-06;
        12085200,1e-06; 12088800,1e-06; 12092400,1e-06; 12096000,1e-06;
        12099600,1e-06; 12103200,1e-06; 12106800,1e-06; 12110400,1e-06;
        12114000,1e-06; 12117600,1e-06; 12121200,1e-06; 12124800,1e-06;
        12128400,1e-06; 12132000,1e-06; 12135600,1e-06; 12139200,1e-06;
        12142800,1e-06; 12146400,1e-06; 12150000,1e-06; 12153600,1e-06;
        12157200,1e-06; 12160800,1e-06; 12164400,1e-06; 12168000,1e-06;
        12171600,1e-06; 12175200,1e-06; 12178800,1e-06; 12182400,1e-06;
        12186000,1e-06; 12189600,1e-06; 12193200,1e-06; 12196800,1e-06;
        12200400,1e-06; 12204000,1e-06; 12207600,1e-06; 12211200,1e-06;
        12214800,1e-06; 12218400,1e-06; 12222000,1e-06; 12225600,1e-06;
        12229200,1e-06; 12232800,1e-06; 12236400,1e-06; 12240000,1e-06;
        12243600,1e-06; 12247200,1e-06; 12250800,1e-06; 12254400,1e-06;
        12258000,1e-06; 12261600,1e-06; 12265200,1e-06; 12268800,1e-06;
        12272400,1e-06; 12276000,1e-06; 12279600,1e-06; 12283200,1e-06;
        12286800,1e-06; 12290400,1e-06; 12294000,1e-06; 12297600,1e-06;
        12301200,1e-06; 12304800,1e-06; 12308400,1e-06; 12312000,1e-06;
        12315600,1e-06; 12319200,1e-06; 12322800,1e-06; 12326400,1e-06;
        12330000,1e-06; 12333600,1e-06; 12337200,1e-06; 12340800,1e-06;
        12344400,1e-06; 12348000,1e-06; 12351600,1e-06; 12355200,1e-06;
        12358800,1e-06; 12362400,1e-06; 12366000,1e-06; 12369600,1e-06;
        12373200,1e-06; 12376800,1e-06; 12380400,1e-06; 12384000,1e-06;
        12387600,1e-06; 12391200,1e-06; 12394800,1e-06; 12398400,1e-06;
        12402000,1e-06; 12405600,1e-06; 12409200,1e-06; 12412800,1e-06;
        12416400,1e-06; 12420000,1e-06; 12423600,1e-06; 12427200,1e-06;
        12430800,1e-06; 12434400,1e-06; 12438000,1e-06; 12441600,1e-06;
        12445200,1e-06; 12448800,1e-06; 12452400,1e-06; 12456000,1e-06;
        12459600,1e-06; 12463200,1e-06; 12466800,1e-06; 12470400,1e-06;
        12474000,1e-06; 12477600,1e-06; 12481200,1e-06; 12484800,1e-06;
        12488400,1e-06; 12492000,1e-06; 12495600,1e-06; 12499200,1e-06;
        12502800,1e-06; 12506400,1e-06; 12510000,1e-06; 12513600,1e-06;
        12517200,1e-06; 12520800,1e-06; 12524400,1e-06; 12528000,1e-06;
        12531600,1e-06; 12535200,1e-06; 12538800,1e-06; 12542400,1e-06;
        12546000,1e-06; 12549600,1e-06; 12553200,1e-06; 12556800,1e-06;
        12560400,1e-06; 12564000,1e-06; 12567600,1e-06; 12571200,1e-06;
        12574800,1e-06; 12578400,1e-06; 12582000,1e-06; 12585600,1e-06;
        12589200,1e-06; 12592800,1e-06; 12596400,1e-06; 12600000,1e-06;
        12603600,1e-06; 12607200,1e-06; 12610800,1e-06; 12614400,1e-06;
        12618000,1e-06; 12621600,1e-06; 12625200,1e-06; 12628800,1e-06;
        12632400,1e-06; 12636000,1e-06; 12639600,1e-06; 12643200,1e-06;
        12646800,1e-06; 12650400,1e-06; 12654000,1e-06; 12657600,1e-06;
        12661200,1e-06; 12664800,1e-06; 12668400,1e-06; 12672000,1e-06;
        12675600,1e-06; 12679200,1e-06; 12682800,1e-06; 12686400,1e-06;
        12690000,1e-06; 12693600,1e-06; 12697200,1e-06; 12700800,1e-06;
        12704400,1e-06; 12708000,1e-06; 12711600,1e-06; 12715200,1e-06;
        12718800,1e-06; 12722400,1e-06; 12726000,1e-06; 12729600,1e-06;
        12733200,1e-06; 12736800,1e-06; 12740400,1e-06; 12744000,1e-06;
        12747600,1e-06; 12751200,1e-06; 12754800,1e-06; 12758400,1e-06;
        12762000,1e-06; 12765600,1e-06; 12769200,1e-06; 12772800,1e-06;
        12776400,1e-06; 12780000,1e-06; 12783600,1e-06; 12787200,1e-06;
        12790800,1e-06; 12794400,1e-06; 12798000,1e-06; 12801600,1e-06;
        12805200,1e-06; 12808800,1e-06; 12812400,1e-06; 12816000,1e-06;
        12819600,1e-06; 12823200,1e-06; 12826800,1e-06; 12830400,1e-06;
        12834000,1e-06; 12837600,1e-06; 12841200,1e-06; 12844800,1e-06;
        12848400,1e-06; 12852000,1e-06; 12855600,1e-06; 12859200,1e-06;
        12862800,1e-06; 12866400,1e-06; 12870000,1e-06; 12873600,1e-06;
        12877200,1e-06; 12880800,1e-06; 12884400,1e-06; 12888000,1e-06;
        12891600,1e-06; 12895200,1e-06; 12898800,1e-06; 12902400,1e-06;
        12906000,1e-06; 12909600,1e-06; 12913200,1e-06; 12916800,1e-06;
        12920400,1e-06; 12924000,1e-06; 12927600,1e-06; 12931200,1e-06;
        12934800,1e-06; 12938400,1e-06; 12942000,1e-06; 12945600,1e-06;
        12949200,1e-06; 12952800,1e-06; 12956400,1e-06; 12960000,1e-06;
        12963600,1e-06; 12967200,1e-06; 12970800,1e-06; 12974400,1e-06;
        12978000,1e-06; 12981600,1e-06; 12985200,1e-06; 12988800,1e-06;
        12992400,1e-06; 12996000,1e-06; 12999600,1e-06; 13003200,1e-06;
        13006800,1e-06; 13010400,1e-06; 13014000,1e-06; 13017600,1e-06;
        13021200,1e-06; 13024800,1e-06; 13028400,1e-06; 13032000,1e-06;
        13035600,1e-06; 13039200,1e-06; 13042800,1e-06; 13046400,1e-06;
        13050000,1e-06; 13053600,1e-06; 13057200,1e-06; 13060800,1e-06;
        13064400,1e-06; 13068000,1e-06; 13071600,1e-06; 13075200,1e-06;
        13078800,1e-06; 13082400,1e-06; 13086000,1e-06; 13089600,1e-06;
        13093200,1e-06; 13096800,1e-06; 13100400,1e-06; 13104000,1e-06;
        13107600,1e-06; 13111200,1e-06; 13114800,1e-06; 13118400,1e-06;
        13122000,1e-06; 13125600,1e-06; 13129200,1e-06; 13132800,1e-06;
        13136400,1e-06; 13140000,1e-06; 13143600,1e-06; 13147200,1e-06;
        13150800,1e-06; 13154400,1e-06; 13158000,1e-06; 13161600,1e-06;
        13165200,1e-06; 13168800,1e-06; 13172400,1e-06; 13176000,1e-06;
        13179600,1e-06; 13183200,1e-06; 13186800,1e-06; 13190400,1e-06;
        13194000,1e-06; 13197600,1e-06; 13201200,1e-06; 13204800,1e-06;
        13208400,1e-06; 13212000,1e-06; 13215600,1e-06; 13219200,1e-06;
        13222800,1e-06; 13226400,1e-06; 13230000,1e-06; 13233600,1e-06;
        13237200,1e-06; 13240800,1e-06; 13244400,1e-06; 13248000,1e-06;
        13251600,1e-06; 13255200,1e-06; 13258800,1e-06; 13262400,1e-06;
        13266000,1e-06; 13269600,1e-06; 13273200,1e-06; 13276800,1e-06;
        13280400,1e-06; 13284000,1e-06; 13287600,1e-06; 13291200,1e-06;
        13294800,1e-06; 13298400,1e-06; 13302000,1e-06; 13305600,1e-06;
        13309200,1e-06; 13312800,1e-06; 13316400,1e-06; 13320000,1e-06;
        13323600,1e-06; 13327200,1e-06; 13330800,1e-06; 13334400,1e-06;
        13338000,1e-06; 13341600,1e-06; 13345200,1e-06; 13348800,1e-06;
        13352400,1e-06; 13356000,1e-06; 13359600,1e-06; 13363200,1e-06;
        13366800,1e-06; 13370400,1e-06; 13374000,1e-06; 13377600,1e-06;
        13381200,1e-06; 13384800,1e-06; 13388400,1e-06; 13392000,1e-06;
        13395600,1e-06; 13399200,1e-06; 13402800,1e-06; 13406400,1e-06;
        13410000,1e-06; 13413600,1e-06; 13417200,1e-06; 13420800,1e-06;
        13424400,1e-06; 13428000,1e-06; 13431600,1e-06; 13435200,1e-06;
        13438800,1e-06; 13442400,1e-06; 13446000,1e-06; 13449600,1e-06;
        13453200,1e-06; 13456800,1e-06; 13460400,1e-06; 13464000,1e-06;
        13467600,1e-06; 13471200,1e-06; 13474800,1e-06; 13478400,1e-06;
        13482000,1e-06; 13485600,1e-06; 13489200,1e-06; 13492800,1e-06;
        13496400,1e-06; 13500000,1e-06; 13503600,1e-06; 13507200,1e-06;
        13510800,1e-06; 13514400,1e-06; 13518000,1e-06; 13521600,1e-06;
        13525200,1e-06; 13528800,1e-06; 13532400,1e-06; 13536000,1e-06;
        13539600,1e-06; 13543200,1e-06; 13546800,1e-06; 13550400,1e-06;
        13554000,1e-06; 13557600,1e-06; 13561200,1e-06; 13564800,1e-06;
        13568400,1e-06; 13572000,1e-06; 13575600,1e-06; 13579200,1e-06;
        13582800,1e-06; 13586400,1e-06; 13590000,1e-06; 13593600,1e-06;
        13597200,1e-06; 13600800,1e-06; 13604400,1e-06; 13608000,1e-06;
        13611600,1e-06; 13615200,1e-06; 13618800,1e-06; 13622400,1e-06;
        13626000,1e-06; 13629600,1e-06; 13633200,1e-06; 13636800,1e-06;
        13640400,1e-06; 13644000,1e-06; 13647600,1e-06; 13651200,1e-06;
        13654800,1e-06; 13658400,1e-06; 13662000,1e-06; 13665600,1e-06;
        13669200,1e-06; 13672800,1e-06; 13676400,1e-06; 13680000,1e-06;
        13683600,1e-06; 13687200,1e-06; 13690800,1e-06; 13694400,1e-06;
        13698000,1e-06; 13701600,1e-06; 13705200,1e-06; 13708800,1e-06;
        13712400,1e-06; 13716000,1e-06; 13719600,1e-06; 13723200,1e-06;
        13726800,1e-06; 13730400,1e-06; 13734000,1e-06; 13737600,1e-06;
        13741200,1e-06; 13744800,1e-06; 13748400,1e-06; 13752000,1e-06;
        13755600,1e-06; 13759200,1e-06; 13762800,1e-06; 13766400,1e-06;
        13770000,1e-06; 13773600,1e-06; 13777200,1e-06; 13780800,1e-06;
        13784400,1e-06; 13788000,1e-06; 13791600,1e-06; 13795200,1e-06;
        13798800,1e-06; 13802400,1e-06; 13806000,1e-06; 13809600,1e-06;
        13813200,1e-06; 13816800,1e-06; 13820400,1e-06; 13824000,1e-06;
        13827600,1e-06; 13831200,1e-06; 13834800,1e-06; 13838400,1e-06;
        13842000,1e-06; 13845600,1e-06; 13849200,1e-06; 13852800,1e-06;
        13856400,1e-06; 13860000,1e-06; 13863600,1e-06; 13867200,1e-06;
        13870800,1e-06; 13874400,1e-06; 13878000,1e-06; 13881600,1e-06;
        13885200,1e-06; 13888800,1e-06; 13892400,1e-06; 13896000,1e-06;
        13899600,1e-06; 13903200,1e-06; 13906800,1e-06; 13910400,1e-06;
        13914000,1e-06; 13917600,1e-06; 13921200,1e-06; 13924800,1e-06;
        13928400,1e-06; 13932000,1e-06; 13935600,1e-06; 13939200,1e-06;
        13942800,1e-06; 13946400,1e-06; 13950000,1e-06; 13953600,1e-06;
        13957200,1e-06; 13960800,1e-06; 13964400,1e-06; 13968000,1e-06;
        13971600,1e-06; 13975200,1e-06; 13978800,1e-06; 13982400,1e-06;
        13986000,1e-06; 13989600,1e-06; 13993200,1e-06; 13996800,1e-06;
        14000400,1e-06; 14004000,1e-06; 14007600,1e-06; 14011200,1e-06;
        14014800,1e-06; 14018400,1e-06; 14022000,1e-06; 14025600,1e-06;
        14029200,1e-06; 14032800,1e-06; 14036400,1e-06; 14040000,1e-06;
        14043600,1e-06; 14047200,1e-06; 14050800,1e-06; 14054400,1e-06;
        14058000,1e-06; 14061600,1e-06; 14065200,1e-06; 14068800,1e-06;
        14072400,1e-06; 14076000,1e-06; 14079600,1e-06; 14083200,1e-06;
        14086800,1e-06; 14090400,1e-06; 14094000,1e-06; 14097600,1e-06;
        14101200,1e-06; 14104800,1e-06; 14108400,1e-06; 14112000,1e-06;
        14115600,1e-06; 14119200,1e-06; 14122800,1e-06; 14126400,1e-06;
        14130000,1e-06; 14133600,1e-06; 14137200,1e-06; 14140800,1e-06;
        14144400,1e-06; 14148000,1e-06; 14151600,1e-06; 14155200,1e-06;
        14158800,1e-06; 14162400,1e-06; 14166000,1e-06; 14169600,1e-06;
        14173200,1e-06; 14176800,1e-06; 14180400,1e-06; 14184000,1e-06;
        14187600,1e-06; 14191200,1e-06; 14194800,1e-06; 14198400,1e-06;
        14202000,1e-06; 14205600,1e-06; 14209200,1e-06; 14212800,1e-06;
        14216400,1e-06; 14220000,1e-06; 14223600,1e-06; 14227200,1e-06;
        14230800,1e-06; 14234400,1e-06; 14238000,1e-06; 14241600,1e-06;
        14245200,1e-06; 14248800,1e-06; 14252400,1e-06; 14256000,1e-06;
        14259600,1e-06; 14263200,1e-06; 14266800,1e-06; 14270400,1e-06;
        14274000,1e-06; 14277600,1e-06; 14281200,1e-06; 14284800,1e-06;
        14288400,1e-06; 14292000,1e-06; 14295600,1e-06; 14299200,1e-06;
        14302800,1e-06; 14306400,1e-06; 14310000,1e-06; 14313600,1e-06;
        14317200,1e-06; 14320800,1e-06; 14324400,1e-06; 14328000,1e-06;
        14331600,1e-06; 14335200,1e-06; 14338800,1e-06; 14342400,1e-06;
        14346000,1e-06; 14349600,1e-06; 14353200,1e-06; 14356800,1e-06;
        14360400,1e-06; 14364000,1e-06; 14367600,1e-06; 14371200,1e-06;
        14374800,1e-06; 14378400,1e-06; 14382000,1e-06; 14385600,1e-06;
        14389200,1e-06; 14392800,1e-06; 14396400,1e-06; 14400000,1e-06;
        14403600,1e-06; 14407200,1e-06; 14410800,1e-06; 14414400,1e-06;
        14418000,1e-06; 14421600,1e-06; 14425200,1e-06; 14428800,1e-06;
        14432400,1e-06; 14436000,1e-06; 14439600,1e-06; 14443200,1e-06;
        14446800,1e-06; 14450400,1e-06; 14454000,1e-06; 14457600,1e-06;
        14461200,1e-06; 14464800,1e-06; 14468400,1e-06; 14472000,1e-06;
        14475600,1e-06; 14479200,1e-06; 14482800,1e-06; 14486400,1e-06;
        14490000,1e-06; 14493600,1e-06; 14497200,1e-06; 14500800,1e-06;
        14504400,1e-06; 14508000,1e-06; 14511600,1e-06; 14515200,1e-06;
        14518800,1e-06; 14522400,1e-06; 14526000,1e-06; 14529600,1e-06;
        14533200,1e-06; 14536800,1e-06; 14540400,1e-06; 14544000,1e-06;
        14547600,1e-06; 14551200,1e-06; 14554800,1e-06; 14558400,1e-06;
        14562000,1e-06; 14565600,1e-06; 14569200,1e-06; 14572800,1e-06;
        14576400,1e-06; 14580000,1e-06; 14583600,1e-06; 14587200,1e-06;
        14590800,1e-06; 14594400,1e-06; 14598000,1e-06; 14601600,1e-06;
        14605200,1e-06; 14608800,1e-06; 14612400,1e-06; 14616000,1e-06;
        14619600,1e-06; 14623200,1e-06; 14626800,1e-06; 14630400,1e-06;
        14634000,1e-06; 14637600,1e-06; 14641200,1e-06; 14644800,1e-06;
        14648400,1e-06; 14652000,1e-06; 14655600,1e-06; 14659200,1e-06;
        14662800,1e-06; 14666400,1e-06; 14670000,1e-06; 14673600,1e-06;
        14677200,1e-06; 14680800,1e-06; 14684400,1e-06; 14688000,1e-06;
        14691600,1e-06; 14695200,1e-06; 14698800,1e-06; 14702400,1e-06;
        14706000,1e-06; 14709600,1e-06; 14713200,1e-06; 14716800,1e-06;
        14720400,1e-06; 14724000,1e-06; 14727600,1e-06; 14731200,1e-06;
        14734800,1e-06; 14738400,1e-06; 14742000,1e-06; 14745600,1e-06;
        14749200,1e-06; 14752800,1e-06; 14756400,1e-06; 14760000,1e-06;
        14763600,1e-06; 14767200,1e-06; 14770800,1e-06; 14774400,1e-06;
        14778000,1e-06; 14781600,1e-06; 14785200,1e-06; 14788800,1e-06;
        14792400,1e-06; 14796000,1e-06; 14799600,1e-06; 14803200,1e-06;
        14806800,1e-06; 14810400,1e-06; 14814000,1e-06; 14817600,1e-06;
        14821200,1e-06; 14824800,1e-06; 14828400,1e-06; 14832000,1e-06;
        14835600,1e-06; 14839200,1e-06; 14842800,1e-06; 14846400,1e-06;
        14850000,1e-06; 14853600,1e-06; 14857200,1e-06; 14860800,1e-06;
        14864400,1e-06; 14868000,1e-06; 14871600,1e-06; 14875200,1e-06;
        14878800,1e-06; 14882400,1e-06; 14886000,1e-06; 14889600,1e-06;
        14893200,1e-06; 14896800,1e-06; 14900400,1e-06; 14904000,1e-06;
        14907600,1e-06; 14911200,1e-06; 14914800,1e-06; 14918400,1e-06;
        14922000,1e-06; 14925600,1e-06; 14929200,1e-06; 14932800,1e-06;
        14936400,1e-06; 14940000,1e-06; 14943600,1e-06; 14947200,1e-06;
        14950800,1e-06; 14954400,1e-06; 14958000,1e-06; 14961600,1e-06;
        14965200,1e-06; 14968800,1e-06; 14972400,1e-06; 14976000,1e-06;
        14979600,1e-06; 14983200,1e-06; 14986800,1e-06; 14990400,1e-06;
        14994000,1e-06; 14997600,1e-06; 15001200,1e-06; 15004800,1e-06;
        15008400,1e-06; 15012000,1e-06; 15015600,1e-06; 15019200,1e-06;
        15022800,1e-06; 15026400,1e-06; 15030000,1e-06; 15033600,1e-06;
        15037200,1e-06; 15040800,1e-06; 15044400,1e-06; 15048000,1e-06;
        15051600,1e-06; 15055200,1e-06; 15058800,1e-06; 15062400,1e-06;
        15066000,1e-06; 15069600,1e-06; 15073200,1e-06; 15076800,1e-06;
        15080400,1e-06; 15084000,1e-06; 15087600,1e-06; 15091200,1e-06;
        15094800,1e-06; 15098400,1e-06; 15102000,1e-06; 15105600,1e-06;
        15109200,1e-06; 15112800,1e-06; 15116400,1e-06; 15120000,1e-06;
        15123600,1e-06; 15127200,1e-06; 15130800,1e-06; 15134400,1e-06;
        15138000,1e-06; 15141600,1e-06; 15145200,1e-06; 15148800,1e-06;
        15152400,1e-06; 15156000,1e-06; 15159600,1e-06; 15163200,1e-06;
        15166800,1e-06; 15170400,1e-06; 15174000,1e-06; 15177600,1e-06;
        15181200,1e-06; 15184800,1e-06; 15188400,1e-06; 15192000,1e-06;
        15195600,1e-06; 15199200,1e-06; 15202800,1e-06; 15206400,1e-06;
        15210000,1e-06; 15213600,1e-06; 15217200,1e-06; 15220800,1e-06;
        15224400,1e-06; 15228000,1e-06; 15231600,1e-06; 15235200,1e-06;
        15238800,1e-06; 15242400,1e-06; 15246000,1e-06; 15249600,1e-06;
        15253200,1e-06; 15256800,1e-06; 15260400,1e-06; 15264000,1e-06;
        15267600,1e-06; 15271200,1e-06; 15274800,1e-06; 15278400,1e-06;
        15282000,1e-06; 15285600,1e-06; 15289200,1e-06; 15292800,1e-06;
        15296400,1e-06; 15300000,1e-06; 15303600,1e-06; 15307200,1e-06;
        15310800,1e-06; 15314400,1e-06; 15318000,1e-06; 15321600,1e-06;
        15325200,1e-06; 15328800,1e-06; 15332400,1e-06; 15336000,1e-06;
        15339600,1e-06; 15343200,1e-06; 15346800,1e-06; 15350400,1e-06;
        15354000,1e-06; 15357600,1e-06; 15361200,1e-06; 15364800,1e-06;
        15368400,1e-06; 15372000,1e-06; 15375600,1e-06; 15379200,1e-06;
        15382800,1e-06; 15386400,1e-06; 15390000,1e-06; 15393600,1e-06;
        15397200,1e-06; 15400800,1e-06; 15404400,1e-06; 15408000,1e-06;
        15411600,1e-06; 15415200,1e-06; 15418800,1e-06; 15422400,1e-06;
        15426000,1e-06; 15429600,1e-06; 15433200,1e-06; 15436800,1e-06;
        15440400,1e-06; 15444000,1e-06; 15447600,1e-06; 15451200,1e-06;
        15454800,1e-06; 15458400,1e-06; 15462000,1e-06; 15465600,1e-06;
        15469200,1e-06; 15472800,1e-06; 15476400,1e-06; 15480000,1e-06;
        15483600,1e-06; 15487200,1e-06; 15490800,1e-06; 15494400,1e-06;
        15498000,1e-06; 15501600,1e-06; 15505200,1e-06; 15508800,1e-06;
        15512400,1e-06; 15516000,1e-06; 15519600,1e-06; 15523200,1e-06;
        15526800,1e-06; 15530400,1e-06; 15534000,1e-06; 15537600,1e-06;
        15541200,1e-06; 15544800,1e-06; 15548400,1e-06; 15552000,1e-06;
        15555600,1e-06; 15559200,1e-06; 15562800,1e-06; 15566400,1e-06;
        15570000,1e-06; 15573600,1e-06; 15577200,1e-06; 15580800,1e-06;
        15584400,1e-06; 15588000,1e-06; 15591600,1e-06; 15595200,1e-06;
        15598800,1e-06; 15602400,1e-06; 15606000,1e-06; 15609600,1e-06;
        15613200,1e-06; 15616800,1e-06; 15620400,1e-06; 15624000,1e-06;
        15627600,1e-06; 15631200,1e-06; 15634800,1e-06; 15638400,1e-06;
        15642000,1e-06; 15645600,1e-06; 15649200,1e-06; 15652800,1e-06;
        15656400,1e-06; 15660000,1e-06; 15663600,1e-06; 15667200,1e-06;
        15670800,1e-06; 15674400,1e-06; 15678000,1e-06; 15681600,1e-06;
        15685200,1e-06; 15688800,1e-06; 15692400,1e-06; 15696000,1e-06;
        15699600,1e-06; 15703200,1e-06; 15706800,1e-06; 15710400,1e-06;
        15714000,1e-06; 15717600,1e-06; 15721200,1e-06; 15724800,1e-06;
        15728400,1e-06; 15732000,1e-06; 15735600,1e-06; 15739200,1e-06;
        15742800,1e-06; 15746400,1e-06; 15750000,1e-06; 15753600,1e-06;
        15757200,1e-06; 15760800,1e-06; 15764400,1e-06; 15768000,1e-06;
        15771600,1e-06; 15775200,1e-06; 15778800,1e-06; 15782400,1e-06;
        15786000,1e-06; 15789600,1e-06; 15793200,1e-06; 15796800,1e-06;
        15800400,1e-06; 15804000,1e-06; 15807600,1e-06; 15811200,1e-06;
        15814800,1e-06; 15818400,1e-06; 15822000,1e-06; 15825600,1e-06;
        15829200,1e-06; 15832800,1e-06; 15836400,1e-06; 15840000,1e-06;
        15843600,1e-06; 15847200,1e-06; 15850800,1e-06; 15854400,1e-06;
        15858000,1e-06; 15861600,1e-06; 15865200,1e-06; 15868800,1e-06;
        15872400,1e-06; 15876000,1e-06; 15879600,1e-06; 15883200,1e-06;
        15886800,1e-06; 15890400,1e-06; 15894000,1e-06; 15897600,1e-06;
        15901200,1e-06; 15904800,1e-06; 15908400,1e-06; 15912000,1e-06;
        15915600,1e-06; 15919200,1e-06; 15922800,1e-06; 15926400,1e-06;
        15930000,1e-06; 15933600,1e-06; 15937200,1e-06; 15940800,1e-06;
        15944400,1e-06; 15948000,1e-06; 15951600,1e-06; 15955200,1e-06;
        15958800,1e-06; 15962400,1e-06; 15966000,1e-06; 15969600,1e-06;
        15973200,1e-06; 15976800,1e-06; 15980400,1e-06; 15984000,1e-06;
        15987600,1e-06; 15991200,1e-06; 15994800,1e-06; 15998400,1e-06;
        16002000,1e-06; 16005600,1e-06; 16009200,1e-06; 16012800,1e-06;
        16016400,1e-06; 16020000,1e-06; 16023600,1e-06; 16027200,1e-06;
        16030800,1e-06; 16034400,1e-06; 16038000,1e-06; 16041600,1e-06;
        16045200,1e-06; 16048800,1e-06; 16052400,1e-06; 16056000,1e-06;
        16059600,1e-06; 16063200,1e-06; 16066800,1e-06; 16070400,1e-06;
        16074000,1e-06; 16077600,1e-06; 16081200,1e-06; 16084800,1e-06;
        16088400,1e-06; 16092000,1e-06; 16095600,1e-06; 16099200,1e-06;
        16102800,1e-06; 16106400,1e-06; 16110000,1e-06; 16113600,1e-06;
        16117200,1e-06; 16120800,1e-06; 16124400,1e-06; 16128000,1e-06;
        16131600,1e-06; 16135200,1e-06; 16138800,1e-06; 16142400,1e-06;
        16146000,1e-06; 16149600,1e-06; 16153200,1e-06; 16156800,1e-06;
        16160400,1e-06; 16164000,1e-06; 16167600,1e-06; 16171200,1e-06;
        16174800,1e-06; 16178400,1e-06; 16182000,1e-06; 16185600,1e-06;
        16189200,1e-06; 16192800,1e-06; 16196400,1e-06; 16200000,1e-06;
        16203600,1e-06; 16207200,1e-06; 16210800,1e-06; 16214400,1e-06;
        16218000,1e-06; 16221600,1e-06; 16225200,1e-06; 16228800,1e-06;
        16232400,1e-06; 16236000,1e-06; 16239600,1e-06; 16243200,1e-06;
        16246800,1e-06; 16250400,1e-06; 16254000,1e-06; 16257600,1e-06;
        16261200,1e-06; 16264800,1e-06; 16268400,1e-06; 16272000,1e-06;
        16275600,1e-06; 16279200,1e-06; 16282800,1e-06; 16286400,1e-06;
        16290000,1e-06; 16293600,1e-06; 16297200,1e-06; 16300800,1e-06;
        16304400,1e-06; 16308000,1e-06; 16311600,1e-06; 16315200,1e-06;
        16318800,1e-06; 16322400,1e-06; 16326000,1e-06; 16329600,1e-06;
        16333200,1e-06; 16336800,1e-06; 16340400,1e-06; 16344000,1e-06;
        16347600,1e-06; 16351200,1e-06; 16354800,1e-06; 16358400,1e-06;
        16362000,1e-06; 16365600,1e-06; 16369200,1e-06; 16372800,1e-06;
        16376400,1e-06; 16380000,1e-06; 16383600,1e-06; 16387200,1e-06;
        16390800,1e-06; 16394400,1e-06; 16398000,1e-06; 16401600,1e-06;
        16405200,1e-06; 16408800,1e-06; 16412400,1e-06; 16416000,1e-06;
        16419600,1e-06; 16423200,1e-06; 16426800,1e-06; 16430400,1e-06;
        16434000,1e-06; 16437600,1e-06; 16441200,1e-06; 16444800,1e-06;
        16448400,1e-06; 16452000,1e-06; 16455600,1e-06; 16459200,1e-06;
        16462800,1e-06; 16466400,1e-06; 16470000,1e-06; 16473600,1e-06;
        16477200,1e-06; 16480800,1e-06; 16484400,1e-06; 16488000,1e-06;
        16491600,1e-06; 16495200,1e-06; 16498800,1e-06; 16502400,1e-06;
        16506000,1e-06; 16509600,1e-06; 16513200,1e-06; 16516800,1e-06;
        16520400,1e-06; 16524000,1e-06; 16527600,1e-06; 16531200,1e-06;
        16534800,1e-06; 16538400,1e-06; 16542000,1e-06; 16545600,1e-06;
        16549200,1e-06; 16552800,1e-06; 16556400,1e-06; 16560000,1e-06;
        16563600,1e-06; 16567200,1e-06; 16570800,1e-06; 16574400,1e-06;
        16578000,1e-06; 16581600,1e-06; 16585200,1e-06; 16588800,1e-06;
        16592400,1e-06; 16596000,1e-06; 16599600,1e-06; 16603200,1e-06;
        16606800,1e-06; 16610400,1e-06; 16614000,1e-06; 16617600,1e-06;
        16621200,1e-06; 16624800,1e-06; 16628400,1e-06; 16632000,1e-06;
        16635600,1e-06; 16639200,1e-06; 16642800,1e-06; 16646400,1e-06;
        16650000,1e-06; 16653600,1e-06; 16657200,1e-06; 16660800,1e-06;
        16664400,1e-06; 16668000,1e-06; 16671600,1e-06; 16675200,1e-06;
        16678800,1e-06; 16682400,1e-06; 16686000,1e-06; 16689600,1e-06;
        16693200,1e-06; 16696800,1e-06; 16700400,1e-06; 16704000,1e-06;
        16707600,1e-06; 16711200,1e-06; 16714800,1e-06; 16718400,1e-06;
        16722000,1e-06; 16725600,1e-06; 16729200,1e-06; 16732800,1e-06;
        16736400,1e-06; 16740000,1e-06; 16743600,1e-06; 16747200,1e-06;
        16750800,1e-06; 16754400,1e-06; 16758000,1e-06; 16761600,1e-06;
        16765200,1e-06; 16768800,1e-06; 16772400,1e-06; 16776000,1e-06;
        16779600,1e-06; 16783200,1e-06; 16786800,1e-06; 16790400,1e-06;
        16794000,1e-06; 16797600,1e-06; 16801200,1e-06; 16804800,1e-06;
        16808400,1e-06; 16812000,1e-06; 16815600,1e-06; 16819200,1e-06;
        16822800,1e-06; 16826400,1e-06; 16830000,1e-06; 16833600,1e-06;
        16837200,1e-06; 16840800,1e-06; 16844400,1e-06; 16848000,1e-06;
        16851600,1e-06; 16855200,1e-06; 16858800,1e-06; 16862400,1e-06;
        16866000,1e-06; 16869600,1e-06; 16873200,1e-06; 16876800,1e-06;
        16880400,1e-06; 16884000,1e-06; 16887600,1e-06; 16891200,1e-06;
        16894800,1e-06; 16898400,1e-06; 16902000,1e-06; 16905600,1e-06;
        16909200,1e-06; 16912800,1e-06; 16916400,1e-06; 16920000,1e-06;
        16923600,1e-06; 16927200,1e-06; 16930800,1e-06; 16934400,1e-06;
        16938000,1e-06; 16941600,1e-06; 16945200,1e-06; 16948800,1e-06;
        16952400,1e-06; 16956000,1e-06; 16959600,1e-06; 16963200,1e-06;
        16966800,1e-06; 16970400,1e-06; 16974000,1e-06; 16977600,1e-06;
        16981200,1e-06; 16984800,1e-06; 16988400,1e-06; 16992000,1e-06;
        16995600,1e-06; 16999200,1e-06; 17002800,1e-06; 17006400,1e-06;
        17010000,1e-06; 17013600,1e-06; 17017200,1e-06; 17020800,1e-06;
        17024400,1e-06; 17028000,1e-06; 17031600,1e-06; 17035200,1e-06;
        17038800,1e-06; 17042400,1e-06; 17046000,1e-06; 17049600,1e-06;
        17053200,1e-06; 17056800,1e-06; 17060400,1e-06; 17064000,1e-06;
        17067600,1e-06; 17071200,1e-06; 17074800,1e-06; 17078400,1e-06;
        17082000,1e-06; 17085600,1e-06; 17089200,1e-06; 17092800,1e-06;
        17096400,1e-06; 17100000,1e-06; 17103600,1e-06; 17107200,1e-06;
        17110800,1e-06; 17114400,1e-06; 17118000,1e-06; 17121600,1e-06;
        17125200,1e-06; 17128800,1e-06; 17132400,1e-06; 17136000,1e-06;
        17139600,1e-06; 17143200,1e-06; 17146800,1e-06; 17150400,1e-06;
        17154000,1e-06; 17157600,1e-06; 17161200,1e-06; 17164800,1e-06;
        17168400,1e-06; 17172000,1e-06; 17175600,1e-06; 17179200,1e-06;
        17182800,1e-06; 17186400,1e-06; 17190000,1e-06; 17193600,1e-06;
        17197200,1e-06; 17200800,1e-06; 17204400,1e-06; 17208000,1e-06;
        17211600,1e-06; 17215200,1e-06; 17218800,1e-06; 17222400,1e-06;
        17226000,1e-06; 17229600,1e-06; 17233200,1e-06; 17236800,1e-06;
        17240400,1e-06; 17244000,1e-06; 17247600,1e-06; 17251200,1e-06;
        17254800,1e-06; 17258400,1e-06; 17262000,1e-06; 17265600,1e-06;
        17269200,1e-06; 17272800,1e-06; 17276400,1e-06; 17280000,1e-06;
        17283600,1e-06; 17287200,1e-06; 17290800,1e-06; 17294400,1e-06;
        17298000,1e-06; 17301600,1e-06; 17305200,1e-06; 17308800,1e-06;
        17312400,1e-06; 17316000,1e-06; 17319600,1e-06; 17323200,1e-06;
        17326800,1e-06; 17330400,1e-06; 17334000,1e-06; 17337600,1e-06;
        17341200,1e-06; 17344800,1e-06; 17348400,1e-06; 17352000,1e-06;
        17355600,1e-06; 17359200,1e-06; 17362800,1e-06; 17366400,1e-06;
        17370000,1e-06; 17373600,1e-06; 17377200,1e-06; 17380800,1e-06;
        17384400,1e-06; 17388000,1e-06; 17391600,1e-06; 17395200,1e-06;
        17398800,1e-06; 17402400,1e-06; 17406000,1e-06; 17409600,1e-06;
        17413200,1e-06; 17416800,1e-06; 17420400,1e-06; 17424000,1e-06;
        17427600,1e-06; 17431200,1e-06; 17434800,1e-06; 17438400,1e-06;
        17442000,1e-06; 17445600,1e-06; 17449200,1e-06; 17452800,1e-06;
        17456400,1e-06; 17460000,1e-06; 17463600,1e-06; 17467200,1e-06;
        17470800,1e-06; 17474400,1e-06; 17478000,1e-06; 17481600,1e-06;
        17485200,1e-06; 17488800,1e-06; 17492400,1e-06; 17496000,1e-06;
        17499600,1e-06; 17503200,1e-06; 17506800,1e-06; 17510400,1e-06;
        17514000,1e-06; 17517600,1e-06; 17521200,1e-06; 17524800,1e-06;
        17528400,1e-06; 17532000,1e-06; 17535600,1e-06; 17539200,1e-06;
        17542800,1e-06; 17546400,1e-06; 17550000,1e-06; 17553600,1e-06;
        17557200,1e-06; 17560800,1e-06; 17564400,1e-06; 17568000,1e-06;
        17571600,1e-06; 17575200,1e-06; 17578800,1e-06; 17582400,1e-06;
        17586000,1e-06; 17589600,1e-06; 17593200,1e-06; 17596800,1e-06;
        17600400,1e-06; 17604000,1e-06; 17607600,1e-06; 17611200,1e-06;
        17614800,1e-06; 17618400,1e-06; 17622000,1e-06; 17625600,1e-06;
        17629200,1e-06; 17632800,1e-06; 17636400,1e-06; 17640000,1e-06;
        17643600,1e-06; 17647200,1e-06; 17650800,1e-06; 17654400,1e-06;
        17658000,1e-06; 17661600,1e-06; 17665200,1e-06; 17668800,1e-06;
        17672400,1e-06; 17676000,1e-06; 17679600,1e-06; 17683200,1e-06;
        17686800,1e-06; 17690400,1e-06; 17694000,1e-06; 17697600,1e-06;
        17701200,1e-06; 17704800,1e-06; 17708400,1e-06; 17712000,1e-06;
        17715600,1e-06; 17719200,1e-06; 17722800,1e-06; 17726400,1e-06;
        17730000,1e-06; 17733600,1e-06; 17737200,1e-06; 17740800,1e-06;
        17744400,1e-06; 17748000,1e-06; 17751600,1e-06; 17755200,1e-06;
        17758800,1e-06; 17762400,1e-06; 17766000,1e-06; 17769600,1e-06;
        17773200,1e-06; 17776800,1e-06; 17780400,1e-06; 17784000,1e-06;
        17787600,1e-06; 17791200,1e-06; 17794800,1e-06; 17798400,1e-06;
        17802000,1e-06; 17805600,1e-06; 17809200,1e-06; 17812800,1e-06;
        17816400,1e-06; 17820000,1e-06; 17823600,1e-06; 17827200,1e-06;
        17830800,1e-06; 17834400,1e-06; 17838000,1e-06; 17841600,1e-06;
        17845200,1e-06; 17848800,1e-06; 17852400,1e-06; 17856000,1e-06;
        17859600,1e-06; 17863200,1e-06; 17866800,1e-06; 17870400,1e-06;
        17874000,1e-06; 17877600,1e-06; 17881200,1e-06; 17884800,1e-06;
        17888400,1e-06; 17892000,1e-06; 17895600,1e-06; 17899200,1e-06;
        17902800,1e-06; 17906400,1e-06; 17910000,1e-06; 17913600,1e-06;
        17917200,1e-06; 17920800,1e-06; 17924400,1e-06; 17928000,1e-06;
        17931600,1e-06; 17935200,1e-06; 17938800,1e-06; 17942400,1e-06;
        17946000,1e-06; 17949600,1e-06; 17953200,1e-06; 17956800,1e-06;
        17960400,1e-06; 17964000,1e-06; 17967600,1e-06; 17971200,1e-06;
        17974800,1e-06; 17978400,1e-06; 17982000,1e-06; 17985600,1e-06;
        17989200,1e-06; 17992800,1e-06; 17996400,1e-06; 18000000,1e-06;
        18003600,1e-06; 18007200,1e-06; 18010800,1e-06; 18014400,1e-06;
        18018000,1e-06; 18021600,1e-06; 18025200,1e-06; 18028800,1e-06;
        18032400,1e-06; 18036000,1e-06; 18039600,1e-06; 18043200,1e-06;
        18046800,1e-06; 18050400,1e-06; 18054000,1e-06; 18057600,1e-06;
        18061200,1e-06; 18064800,1e-06; 18068400,1e-06; 18072000,1e-06;
        18075600,1e-06; 18079200,1e-06; 18082800,1e-06; 18086400,1e-06;
        18090000,1e-06; 18093600,1e-06; 18097200,1e-06; 18100800,1e-06;
        18104400,1e-06; 18108000,1e-06; 18111600,1e-06; 18115200,1e-06;
        18118800,1e-06; 18122400,1e-06; 18126000,1e-06; 18129600,1e-06;
        18133200,1e-06; 18136800,1e-06; 18140400,1e-06; 18144000,1e-06;
        18147600,1e-06; 18151200,1e-06; 18154800,1e-06; 18158400,1e-06;
        18162000,1e-06; 18165600,1e-06; 18169200,1e-06; 18172800,1e-06;
        18176400,1e-06; 18180000,1e-06; 18183600,1e-06; 18187200,1e-06;
        18190800,1e-06; 18194400,1e-06; 18198000,1e-06; 18201600,1e-06;
        18205200,1e-06; 18208800,1e-06; 18212400,1e-06; 18216000,1e-06;
        18219600,1e-06; 18223200,1e-06; 18226800,1e-06; 18230400,1e-06;
        18234000,1e-06; 18237600,1e-06; 18241200,1e-06; 18244800,1e-06;
        18248400,1e-06; 18252000,1e-06; 18255600,1e-06; 18259200,1e-06;
        18262800,1e-06; 18266400,1e-06; 18270000,1e-06; 18273600,1e-06;
        18277200,1e-06; 18280800,1e-06; 18284400,1e-06; 18288000,1e-06;
        18291600,1e-06; 18295200,1e-06; 18298800,1e-06; 18302400,1e-06;
        18306000,1e-06; 18309600,1e-06; 18313200,1e-06; 18316800,1e-06;
        18320400,1e-06; 18324000,1e-06; 18327600,1e-06; 18331200,1e-06;
        18334800,1e-06; 18338400,1e-06; 18342000,1e-06; 18345600,1e-06;
        18349200,1e-06; 18352800,1e-06; 18356400,1e-06; 18360000,1e-06;
        18363600,1e-06; 18367200,1e-06; 18370800,1e-06; 18374400,1e-06;
        18378000,1e-06; 18381600,1e-06; 18385200,1e-06; 18388800,1e-06;
        18392400,1e-06; 18396000,1e-06; 18399600,1e-06; 18403200,1e-06;
        18406800,1e-06; 18410400,1e-06; 18414000,1e-06; 18417600,1e-06;
        18421200,1e-06; 18424800,1e-06; 18428400,1e-06; 18432000,1e-06;
        18435600,1e-06; 18439200,1e-06; 18442800,1e-06; 18446400,1e-06;
        18450000,1e-06; 18453600,1e-06; 18457200,1e-06; 18460800,1e-06;
        18464400,1e-06; 18468000,1e-06; 18471600,1e-06; 18475200,1e-06;
        18478800,1e-06; 18482400,1e-06; 18486000,1e-06; 18489600,1e-06;
        18493200,1e-06; 18496800,1e-06; 18500400,1e-06; 18504000,1e-06;
        18507600,1e-06; 18511200,1e-06; 18514800,1e-06; 18518400,1e-06;
        18522000,1e-06; 18525600,1e-06; 18529200,1e-06; 18532800,1e-06;
        18536400,1e-06; 18540000,1e-06; 18543600,1e-06; 18547200,1e-06;
        18550800,1e-06; 18554400,1e-06; 18558000,1e-06; 18561600,1e-06;
        18565200,1e-06; 18568800,1e-06; 18572400,1e-06; 18576000,1e-06;
        18579600,1e-06; 18583200,1e-06; 18586800,1e-06; 18590400,1e-06;
        18594000,1e-06; 18597600,1e-06; 18601200,1e-06; 18604800,1e-06;
        18608400,1e-06; 18612000,1e-06; 18615600,1e-06; 18619200,1e-06;
        18622800,1e-06; 18626400,1e-06; 18630000,1e-06; 18633600,1e-06;
        18637200,1e-06; 18640800,1e-06; 18644400,1e-06; 18648000,1e-06;
        18651600,1e-06; 18655200,1e-06; 18658800,1e-06; 18662400,1e-06;
        18666000,1e-06; 18669600,1e-06; 18673200,1e-06; 18676800,1e-06;
        18680400,1e-06; 18684000,1e-06; 18687600,1e-06; 18691200,1e-06;
        18694800,1e-06; 18698400,1e-06; 18702000,1e-06; 18705600,1e-06;
        18709200,1e-06; 18712800,1e-06; 18716400,1e-06; 18720000,1e-06;
        18723600,1e-06; 18727200,1e-06; 18730800,1e-06; 18734400,1e-06;
        18738000,1e-06; 18741600,1e-06; 18745200,1e-06; 18748800,1e-06;
        18752400,1e-06; 18756000,1e-06; 18759600,1e-06; 18763200,1e-06;
        18766800,1e-06; 18770400,1e-06; 18774000,1e-06; 18777600,1e-06;
        18781200,1e-06; 18784800,1e-06; 18788400,1e-06; 18792000,1e-06;
        18795600,1e-06; 18799200,1e-06; 18802800,1e-06; 18806400,1e-06;
        18810000,1e-06; 18813600,1e-06; 18817200,1e-06; 18820800,1e-06;
        18824400,1e-06; 18828000,1e-06; 18831600,1e-06; 18835200,1e-06;
        18838800,1e-06; 18842400,1e-06; 18846000,1e-06; 18849600,1e-06;
        18853200,1e-06; 18856800,1e-06; 18860400,1e-06; 18864000,1e-06;
        18867600,1e-06; 18871200,1e-06; 18874800,1e-06; 18878400,1e-06;
        18882000,1e-06; 18885600,1e-06; 18889200,1e-06; 18892800,1e-06;
        18896400,1e-06; 18900000,1e-06; 18903600,1e-06; 18907200,1e-06;
        18910800,1e-06; 18914400,1e-06; 18918000,1e-06; 18921600,1e-06;
        18925200,1e-06; 18928800,1e-06; 18932400,1e-06; 18936000,1e-06;
        18939600,1e-06; 18943200,1e-06; 18946800,1e-06; 18950400,1e-06;
        18954000,1e-06; 18957600,1e-06; 18961200,1e-06; 18964800,1e-06;
        18968400,1e-06; 18972000,1e-06; 18975600,1e-06; 18979200,1e-06;
        18982800,1e-06; 18986400,1e-06; 18990000,1e-06; 18993600,1e-06;
        18997200,1e-06; 19000800,1e-06; 19004400,1e-06; 19008000,1e-06;
        19011600,1e-06; 19015200,1e-06; 19018800,1e-06; 19022400,1e-06;
        19026000,1e-06; 19029600,1e-06; 19033200,1e-06; 19036800,1e-06;
        19040400,1e-06; 19044000,1e-06; 19047600,1e-06; 19051200,1e-06;
        19054800,1e-06; 19058400,1e-06; 19062000,1e-06; 19065600,1e-06;
        19069200,1e-06; 19072800,1e-06; 19076400,1e-06; 19080000,1e-06;
        19083600,1e-06; 19087200,1e-06; 19090800,1e-06; 19094400,1e-06;
        19098000,1e-06; 19101600,1e-06; 19105200,1e-06; 19108800,1e-06;
        19112400,1e-06; 19116000,1e-06; 19119600,1e-06; 19123200,1e-06;
        19126800,1e-06; 19130400,1e-06; 19134000,1e-06; 19137600,1e-06;
        19141200,1e-06; 19144800,1e-06; 19148400,1e-06; 19152000,1e-06;
        19155600,1e-06; 19159200,1e-06; 19162800,1e-06; 19166400,1e-06;
        19170000,1e-06; 19173600,1e-06; 19177200,1e-06; 19180800,1e-06;
        19184400,1e-06; 19188000,1e-06; 19191600,1e-06; 19195200,1e-06;
        19198800,1e-06; 19202400,1e-06; 19206000,1e-06; 19209600,1e-06;
        19213200,1e-06; 19216800,1e-06; 19220400,1e-06; 19224000,1e-06;
        19227600,1e-06; 19231200,1e-06; 19234800,1e-06; 19238400,1e-06;
        19242000,1e-06; 19245600,1e-06; 19249200,1e-06; 19252800,1e-06;
        19256400,1e-06; 19260000,1e-06; 19263600,1e-06; 19267200,1e-06;
        19270800,1e-06; 19274400,1e-06; 19278000,1e-06; 19281600,1e-06;
        19285200,1e-06; 19288800,1e-06; 19292400,1e-06; 19296000,1e-06;
        19299600,1e-06; 19303200,1e-06; 19306800,1e-06; 19310400,1e-06;
        19314000,1e-06; 19317600,1e-06; 19321200,1e-06; 19324800,1e-06;
        19328400,1e-06; 19332000,1e-06; 19335600,1e-06; 19339200,1e-06;
        19342800,1e-06; 19346400,1e-06; 19350000,1e-06; 19353600,1e-06;
        19357200,1e-06; 19360800,1e-06; 19364400,1e-06; 19368000,1e-06;
        19371600,1e-06; 19375200,1e-06; 19378800,1e-06; 19382400,1e-06;
        19386000,1e-06; 19389600,1e-06; 19393200,1e-06; 19396800,1e-06;
        19400400,1e-06; 19404000,1e-06; 19407600,1e-06; 19411200,1e-06;
        19414800,1e-06; 19418400,1e-06; 19422000,1e-06; 19425600,1e-06;
        19429200,1e-06; 19432800,1e-06; 19436400,1e-06; 19440000,1e-06;
        19443600,1e-06; 19447200,1e-06; 19450800,1e-06; 19454400,1e-06;
        19458000,1e-06; 19461600,1e-06; 19465200,1e-06; 19468800,1e-06;
        19472400,1e-06; 19476000,1e-06; 19479600,1e-06; 19483200,1e-06;
        19486800,1e-06; 19490400,1e-06; 19494000,1e-06; 19497600,1e-06;
        19501200,1e-06; 19504800,1e-06; 19508400,1e-06; 19512000,1e-06;
        19515600,1e-06; 19519200,1e-06; 19522800,1e-06; 19526400,1e-06;
        19530000,1e-06; 19533600,1e-06; 19537200,1e-06; 19540800,1e-06;
        19544400,1e-06; 19548000,1e-06; 19551600,1e-06; 19555200,1e-06;
        19558800,1e-06; 19562400,1e-06; 19566000,1e-06; 19569600,1e-06;
        19573200,1e-06; 19576800,1e-06; 19580400,1e-06; 19584000,1e-06;
        19587600,1e-06; 19591200,1e-06; 19594800,1e-06; 19598400,1e-06;
        19602000,1e-06; 19605600,1e-06; 19609200,1e-06; 19612800,1e-06;
        19616400,1e-06; 19620000,1e-06; 19623600,1e-06; 19627200,1e-06;
        19630800,1e-06; 19634400,1e-06; 19638000,1e-06; 19641600,1e-06;
        19645200,1e-06; 19648800,1e-06; 19652400,1e-06; 19656000,1e-06;
        19659600,1e-06; 19663200,1e-06; 19666800,1e-06; 19670400,1e-06;
        19674000,1e-06; 19677600,1e-06; 19681200,1e-06; 19684800,1e-06;
        19688400,1e-06; 19692000,1e-06; 19695600,1e-06; 19699200,1e-06;
        19702800,1e-06; 19706400,1e-06; 19710000,1e-06; 19713600,1e-06;
        19717200,1e-06; 19720800,1e-06; 19724400,1e-06; 19728000,1e-06;
        19731600,1e-06; 19735200,1e-06; 19738800,1e-06; 19742400,1e-06;
        19746000,1e-06; 19749600,1e-06; 19753200,1e-06; 19756800,1e-06;
        19760400,1e-06; 19764000,1e-06; 19767600,1e-06; 19771200,1e-06;
        19774800,1e-06; 19778400,1e-06; 19782000,1e-06; 19785600,1e-06;
        19789200,1e-06; 19792800,1e-06; 19796400,1e-06; 19800000,1e-06;
        19803600,1e-06; 19807200,1e-06; 19810800,1e-06; 19814400,1e-06;
        19818000,1e-06; 19821600,1e-06; 19825200,1e-06; 19828800,1e-06;
        19832400,1e-06; 19836000,1e-06; 19839600,1e-06; 19843200,1e-06;
        19846800,1e-06; 19850400,1e-06; 19854000,1e-06; 19857600,1e-06;
        19861200,1e-06; 19864800,1e-06; 19868400,1e-06; 19872000,1e-06;
        19875600,1e-06; 19879200,1e-06; 19882800,1e-06; 19886400,1e-06;
        19890000,1e-06; 19893600,1e-06; 19897200,1e-06; 19900800,1e-06;
        19904400,1e-06; 19908000,1e-06; 19911600,1e-06; 19915200,1e-06;
        19918800,1e-06; 19922400,1e-06; 19926000,1e-06; 19929600,1e-06;
        19933200,1e-06; 19936800,1e-06; 19940400,1e-06; 19944000,1e-06;
        19947600,1e-06; 19951200,1e-06; 19954800,1e-06; 19958400,1e-06;
        19962000,1e-06; 19965600,1e-06; 19969200,1e-06; 19972800,1e-06;
        19976400,1e-06; 19980000,1e-06; 19983600,1e-06; 19987200,1e-06;
        19990800,1e-06; 19994400,1e-06; 19998000,1e-06; 20001600,1e-06;
        20005200,1e-06; 20008800,1e-06; 20012400,1e-06; 20016000,1e-06;
        20019600,1e-06; 20023200,1e-06; 20026800,1e-06; 20030400,1e-06;
        20034000,1e-06; 20037600,1e-06; 20041200,1e-06; 20044800,1e-06;
        20048400,1e-06; 20052000,1e-06; 20055600,1e-06; 20059200,1e-06;
        20062800,1e-06; 20066400,1e-06; 20070000,1e-06; 20073600,1e-06;
        20077200,1e-06; 20080800,1e-06; 20084400,1e-06; 20088000,1e-06;
        20091600,1e-06; 20095200,1e-06; 20098800,1e-06; 20102400,1e-06;
        20106000,1e-06; 20109600,1e-06; 20113200,1e-06; 20116800,1e-06;
        20120400,1e-06; 20124000,1e-06; 20127600,1e-06; 20131200,1e-06;
        20134800,1e-06; 20138400,1e-06; 20142000,1e-06; 20145600,1e-06;
        20149200,1e-06; 20152800,1e-06; 20156400,1e-06; 20160000,1e-06;
        20163600,1e-06; 20167200,1e-06; 20170800,1e-06; 20174400,1e-06;
        20178000,1e-06; 20181600,1e-06; 20185200,1e-06; 20188800,1e-06;
        20192400,1e-06; 20196000,1e-06; 20199600,1e-06; 20203200,1e-06;
        20206800,1e-06; 20210400,1e-06; 20214000,1e-06; 20217600,1e-06;
        20221200,1e-06; 20224800,1e-06; 20228400,1e-06; 20232000,1e-06;
        20235600,1e-06; 20239200,1e-06; 20242800,1e-06; 20246400,1e-06;
        20250000,1e-06; 20253600,1e-06; 20257200,1e-06; 20260800,1e-06;
        20264400,1e-06; 20268000,1e-06; 20271600,1e-06; 20275200,1e-06;
        20278800,1e-06; 20282400,1e-06; 20286000,1e-06; 20289600,1e-06;
        20293200,1e-06; 20296800,1e-06; 20300400,1e-06; 20304000,1e-06;
        20307600,1e-06; 20311200,1e-06; 20314800,1e-06; 20318400,1e-06;
        20322000,1e-06; 20325600,1e-06; 20329200,1e-06; 20332800,1e-06;
        20336400,1e-06; 20340000,1e-06; 20343600,1e-06; 20347200,1e-06;
        20350800,1e-06; 20354400,1e-06; 20358000,1e-06; 20361600,1e-06;
        20365200,1e-06; 20368800,1e-06; 20372400,1e-06; 20376000,1e-06;
        20379600,1e-06; 20383200,1e-06; 20386800,1e-06; 20390400,1e-06;
        20394000,1e-06; 20397600,1e-06; 20401200,1e-06; 20404800,1e-06;
        20408400,1e-06; 20412000,1e-06; 20415600,1e-06; 20419200,1e-06;
        20422800,1e-06; 20426400,1e-06; 20430000,1e-06; 20433600,1e-06;
        20437200,1e-06; 20440800,1e-06; 20444400,1e-06; 20448000,1e-06;
        20451600,1e-06; 20455200,1e-06; 20458800,1e-06; 20462400,1e-06;
        20466000,1e-06; 20469600,1e-06; 20473200,1e-06; 20476800,1e-06;
        20480400,1e-06; 20484000,1e-06; 20487600,1e-06; 20491200,1e-06;
        20494800,1e-06; 20498400,1e-06; 20502000,1e-06; 20505600,1e-06;
        20509200,1e-06; 20512800,1e-06; 20516400,1e-06; 20520000,1e-06;
        20523600,1e-06; 20527200,1e-06; 20530800,1e-06; 20534400,1e-06;
        20538000,1e-06; 20541600,1e-06; 20545200,1e-06; 20548800,1e-06;
        20552400,1e-06; 20556000,1e-06; 20559600,1e-06; 20563200,1e-06;
        20566800,1e-06; 20570400,1e-06; 20574000,1e-06; 20577600,1e-06;
        20581200,1e-06; 20584800,1e-06; 20588400,1e-06; 20592000,1e-06;
        20595600,1e-06; 20599200,1e-06; 20602800,1e-06; 20606400,1e-06;
        20610000,1e-06; 20613600,1e-06; 20617200,1e-06; 20620800,1e-06;
        20624400,1e-06; 20628000,1e-06; 20631600,1e-06; 20635200,1e-06;
        20638800,1e-06; 20642400,1e-06; 20646000,1e-06; 20649600,1e-06;
        20653200,1e-06; 20656800,1e-06; 20660400,1e-06; 20664000,1e-06;
        20667600,1e-06; 20671200,1e-06; 20674800,1e-06; 20678400,1e-06;
        20682000,1e-06; 20685600,1e-06; 20689200,1e-06; 20692800,1e-06;
        20696400,1e-06; 20700000,1e-06; 20703600,1e-06; 20707200,1e-06;
        20710800,1e-06; 20714400,1e-06; 20718000,1e-06; 20721600,1e-06;
        20725200,1e-06; 20728800,1e-06; 20732400,1e-06; 20736000,1e-06;
        20739600,1e-06; 20743200,1e-06; 20746800,1e-06; 20750400,1e-06;
        20754000,1e-06; 20757600,1e-06; 20761200,1e-06; 20764800,1e-06;
        20768400,1e-06; 20772000,1e-06; 20775600,1e-06; 20779200,1e-06;
        20782800,1e-06; 20786400,1e-06; 20790000,1e-06; 20793600,1e-06;
        20797200,1e-06; 20800800,1e-06; 20804400,1e-06; 20808000,1e-06;
        20811600,1e-06; 20815200,1e-06; 20818800,1e-06; 20822400,1e-06;
        20826000,1e-06; 20829600,1e-06; 20833200,1e-06; 20836800,1e-06;
        20840400,1e-06; 20844000,1e-06; 20847600,1e-06; 20851200,1e-06;
        20854800,1e-06; 20858400,1e-06; 20862000,1e-06; 20865600,1e-06;
        20869200,1e-06; 20872800,1e-06; 20876400,1e-06; 20880000,1e-06;
        20883600,1e-06; 20887200,1e-06; 20890800,1e-06; 20894400,1e-06;
        20898000,1e-06; 20901600,1e-06; 20905200,1e-06; 20908800,1e-06;
        20912400,1e-06; 20916000,1e-06; 20919600,1e-06; 20923200,1e-06;
        20926800,1e-06; 20930400,1e-06; 20934000,1e-06; 20937600,1e-06;
        20941200,1e-06; 20944800,1e-06; 20948400,1e-06; 20952000,1e-06;
        20955600,1e-06; 20959200,1e-06; 20962800,1e-06; 20966400,1e-06;
        20970000,1e-06; 20973600,1e-06; 20977200,1e-06; 20980800,1e-06;
        20984400,1e-06; 20988000,1e-06; 20991600,1e-06; 20995200,0.0996072;
        20998800,0.0451988; 21002400,0.0171292; 21006000,0.0079009; 21009600,
        0.0097814; 21013200,0.0118753; 21016800,0.0084158; 21020400,0.0080491;
        21024000,0.0125821; 21027600,0.0140536; 21031200,0.010059; 21034800,
        0.0063832; 21038400,0.0033575; 21042000,0.0012642; 21045600,0.0021876;
        21049200,0.0037108; 21052800,0.0037303; 21056400,0.0032222; 21060000,
        0.0023061; 21063600,0.0006491; 21067200,0.0001816; 21070800,1e-06;
        21074400,1e-06; 21078000,1e-06; 21081600,0.0001282; 21085200,0.0035786;
        21088800,0.0124766; 21092400,0.0142013; 21096000,0.0117257; 21099600,
        0.0078366; 21103200,0.003706; 21106800,0.0051728; 21110400,0.008875;
        21114000,0.0098069; 21117600,0.0055197; 21121200,0.005137; 21124800,
        0.0146183; 21128400,0.0108896; 21132000,0.0051876; 21135600,0.0342919;
        21139200,0.0210522; 21142800,0.0004235; 21146400,0.0006944; 21150000,
        0.0001252; 21153600,0.0012392; 21157200,0.0018948; 21160800,0.0019629;
        21164400,0.0015655; 21168000,0.0033184; 21171600,0.006591; 21175200,
        0.0079021; 21178800,0.0217868; 21182400,0.0161276; 21186000,0.0042827;
        21189600,0.0038612; 21193200,0.0046958; 21196800,0.0048313; 21200400,
        0.0188202; 21204000,0.0160309; 21207600,0.0015233; 21211200,0.0032222;
        21214800,0.0028639; 21218400,0.0001938; 21222000,0.0014009; 21225600,
        0.0003157; 21229200,1e-06; 21232800,1e-06; 21236400,1e-06; 21240000,
        1e-06; 21243600,1e-06; 21247200,1e-06; 21250800,0.0001806; 21254400,
        0.0007068; 21258000,0.0049794; 21261600,0.0103956; 21265200,0.0118729;
        21268800,0.0081428; 21272400,0.0127295; 21276000,0.0104822; 21279600,
        0.0068736; 21283200,0.0038368; 21286800,0.0021897; 21290400,0.0014229;
        21294000,0.0023251; 21297600,0.0025296; 21301200,0.0002105; 21304800,
        0.0001771; 21308400,0.0016158; 21312000,0.000867; 21315600,1e-06;
        21319200,1e-06; 21322800,1e-06; 21326400,1e-06; 21330000,1e-06;
        21333600,0.0003543; 21337200,0.0021794; 21340800,0.0039663; 21344400,
        0.0061026; 21348000,0.0082063; 21351600,0.0071881; 21355200,0.0097278;
        21358800,0.0122732; 21362400,0.0084881; 21366000,0.0075518; 21369600,
        0.0078794; 21373200,0.0025527; 21376800,0.0026766; 21380400,0.0006214;
        21384000,0.0003542; 21387600,0.0006784; 21391200,0.0009635; 21394800,
        0.0012085; 21398400,0.0006619; 21402000,6.97e-05; 21405600,0.0001954;
        21409200,1e-06; 21412800,1e-06; 21416400,1e-06; 21420000,1e-06;
        21423600,1e-06; 21427200,8.81e-05; 21430800,0.0032083; 21434400,
        0.0089856; 21438000,0.008299; 21441600,0.0121245; 21445200,0.0078442;
        21448800,0.0015273; 21452400,0.000967; 21456000,0.0031616; 21459600,
        0.009631; 21463200,0.0104304; 21466800,0.0066733; 21470400,0.0039721;
        21474000,0.0086717; 21477600,0.0094691; 21481200,0.0089199; 21484800,
        0.0079948; 21488400,0.0045236; 21492000,0.0017521; 21495600,0.0012448;
        21499200,0.0004716; 21502800,0.0008911; 21506400,0.0006041; 21510000,
        4e-06; 21513600,0.0002191; 21517200,0.0009988; 21520800,0.0041766;
        21524400,0.0062739; 21528000,0.0071471; 21531600,0.003622; 21535200,
        0.0012785; 21538800,0.0023508; 21542400,0.0024099; 21546000,0.0040112;
        21549600,0.0075213; 21553200,0.0059987; 21556800,0.0049137; 21560400,
        0.0080651; 21564000,0.0056728; 21567600,0.0025887; 21571200,0.003922;
        21574800,0.0033417; 21578400,0.0034913; 21582000,0.0008013; 21585600,
        8.09e-05; 21589200,1e-06; 21592800,1e-06; 21596400,1e-06; 21600000,
        0.0006439; 21603600,0.0036726; 21607200,0.0038016; 21610800,0.0143861;
        21614400,0.0119438; 21618000,0.0020281; 21621600,0.000332; 21625200,
        0.0006821; 21628800,0.0019009; 21632400,0.0015861; 21636000,0.0050446;
        21639600,0.0041219; 21643200,0.0029596; 21646800,0.0037172; 21650400,
        0.0015456; 21654000,0.003606; 21657600,0.0035198; 21661200,7.9e-06;
        21664800,4.08e-05; 21668400,0.0001117; 21672000,0.000621; 21675600,
        0.001094; 21679200,0.0018108; 21682800,0.001065; 21686400,0.0002981;
        21690000,0.0030724; 21693600,0.0084328; 21697200,0.0133464; 21700800,
        0.0130134; 21704400,0.0049518; 21708000,0.0029094; 21711600,0.0034885;
        21715200,0.0016699; 21718800,0.0013527; 21722400,0.002843; 21726000,
        0.0019309; 21729600,0.002866; 21733200,0.003656; 21736800,0.0022973;
        21740400,0.001658; 21744000,0.0011073; 21747600,0.00121; 21751200,
        0.0017256; 21754800,1.55e-05; 21758400,1e-06; 21762000,1e-06; 21765600,
        1e-06; 21769200,1e-06; 21772800,1e-06; 21776400,0.0007107; 21780000,
        0.0045034; 21783600,0.0088431; 21787200,0.0113892; 21790800,0.0075027;
        21794400,0.0040455; 21798000,0.0010016; 21801600,0.0011086; 21805200,
        0.0020365; 21808800,0.0028491; 21812400,0.0004717; 21816000,0.0030366;
        21819600,0.0019709; 21823200,5.83e-05; 21826800,0.0012396; 21830400,
        0.0019684; 21834000,0.0014663; 21837600,0.0027516; 21841200,0.0003217;
        21844800,1.94e-05; 21848400,1e-06; 21852000,1e-06; 21855600,1e-06;
        21859200,0.0002658; 21862800,0.0033437; 21866400,0.0093267; 21870000,
        0.0150939; 21873600,0.0142678; 21877200,0.0077445; 21880800,0.0081979;
        21884400,0.0100533; 21888000,0.0030837; 21891600,0.0011292; 21895200,
        0.0016898; 21898800,0.0015787; 21902400,0.0026211; 21906000,0.0020078;
        21909600,1e-06; 21913200,1e-06; 21916800,1e-06; 21920400,1e-06;
        21924000,1e-06; 21927600,1e-06; 21931200,1e-06; 21934800,1e-06;
        21938400,1e-06; 21942000,5.9e-06; 21945600,0.0021887; 21949200,
        0.0098753; 21952800,0.0145173; 21956400,0.0168045; 21960000,0.0218278;
        21963600,0.0135438; 21967200,0.007253; 21970800,0.0073; 21974400,
        0.0036843; 21978000,0.0010737; 21981600,0.0016596; 21985200,0.0013534;
        21988800,0.0007594; 21992400,0.0009819; 21996000,0.0001154; 21999600,
        1e-06; 22003200,1e-06; 22006800,1e-06; 22010400,1e-06; 22014000,1e-06;
        22017600,1e-06; 22021200,1e-06; 22024800,1e-06; 22028400,1e-06;
        22032000,0.0014291; 22035600,0.0073606; 22039200,0.0101853; 22042800,
        0.0108315; 22046400,0.0140443; 22050000,0.0093187; 22053600,0.0047386;
        22057200,0.0053374; 22060800,0.0130154; 22064400,0.0193001; 22068000,
        0.006886; 22071600,0.0010497; 22075200,0.002443; 22078800,0.0044797;
        22082400,0.0008927; 22086000,0.0075611; 22089600,0.0042181; 22093200,
        0.0017601; 22096800,0.0020766; 22100400,0.000621; 22104000,0.0014609;
        22107600,0.0017983; 22111200,0.0016334; 22114800,0.0011841; 22118400,
        0.0013703; 22122000,0.0046431; 22125600,0.0095098; 22129200,0.0120961;
        22132800,0.012022; 22136400,0.0055879; 22140000,0.0031151; 22143600,
        0.0042729; 22147200,0.0142046; 22150800,0.0263805; 22154400,0.0132176;
        22158000,0.0043375; 22161600,0.0018788; 22165200,0.003147; 22168800,
        0.0040562; 22172400,0.0025107; 22176000,0.0001398; 22179600,0.0019633;
        22183200,0.0032539; 22186800,0.000827; 22190400,0.0020993; 22194000,
        0.0031316; 22197600,0.0044068; 22201200,0.0048375; 22204800,0.0072589;
        22208400,0.0167966; 22212000,0.0256043; 22215600,0.0234015; 22219200,
        0.0253251; 22222800,0.0220495; 22226400,0.0082691; 22230000,0.0141398;
        22233600,0.0355067; 22237200,0.0156639; 22240800,0.0065103; 22244400,
        0.0058089; 22248000,0.0031865; 22251600,0.0031089; 22255200,0.002017;
        22258800,0.0036708; 22262400,0.0028598; 22266000,0.0018984; 22269600,
        0.0007873; 22273200,0.0003171; 22276800,0.0002226; 22280400,0.0002727;
        22284000,0.000871; 22287600,0.0017229; 22291200,0.0024089; 22294800,
        0.0051977; 22298400,0.0098338; 22302000,0.0098355; 22305600,0.0143074;
        22309200,0.0086811; 22312800,0.003269; 22316400,0.0056855; 22320000,
        0.0177901; 22323600,0.0252218; 22327200,0.0126395; 22330800,0.0040298;
        22334400,0.0019754; 22338000,0.0041513; 22341600,0.0019629; 22345200,
        0.0009928; 22348800,0.0026069; 22352400,0.0023944; 22356000,0.001429;
        22359600,0.000275; 22363200,0.0002607; 22366800,0.0004125; 22370400,
        0.0006468; 22374000,0.0013427; 22377600,0.0024598; 22381200,0.0054524;
        22384800,0.0142786; 22388400,0.016951; 22392000,0.0139396; 22395600,
        0.0097222; 22399200,0.0041817; 22402800,0.0072975; 22406400,0.0186394;
        22410000,0.0165508; 22413600,0.008645; 22417200,0.0037485; 22420800,
        0.0018433; 22424400,0.0025619; 22428000,0.0052985; 22431600,0.0051509;
        22435200,0.0028863; 22438800,0.0025449; 22442400,0.0015173; 22446000,
        0.0004777; 22449600,0.0015624; 22453200,0.0025374; 22456800,0.0030529;
        22460400,0.0030567; 22464000,0.0013229; 22467600,0.000275; 22471200,
        0.0039277; 22474800,0.0066935; 22478400,0.0102433; 22482000,0.0083551;
        22485600,0.0033746; 22489200,0.0054075; 22492800,0.0060041; 22496400,
        0.0039698; 22500000,0.0028782; 22503600,0.0010383; 22507200,0.000488;
        22510800,0.0010525; 22514400,0.0007084; 22518000,0.0003463; 22521600,
        0.0012203; 22525200,0.0016937; 22528800,0.0008731; 22532400,0.0002707;
        22536000,0.0003015; 22539600,1e-06; 22543200,0.0001883; 22546800,
        0.0019764; 22550400,0.0047706; 22554000,0.0115938; 22557600,0.0258633;
        22561200,0.0310506; 22564800,0.0249952; 22568400,0.0148763; 22572000,
        0.0093907; 22575600,0.0127827; 22579200,0.0078519; 22582800,0.0014246;
        22586400,0.002779; 22590000,0.0022422; 22593600,0.0007144; 22597200,
        0.0014654; 22600800,0.0005818; 22604400,0.0001184; 22608000,0.0002724;
        22611600,0.0011577; 22615200,0.0010533; 22618800,0.0002609; 22622400,
        9.63e-05; 22626000,1e-06; 22629600,2e-06; 22633200,0.0004698; 22636800,
        0.0030372; 22640400,0.0102242; 22644000,0.0173155; 22647600,0.0233094;
        22651200,0.0204979; 22654800,0.0100722; 22658400,0.0023101; 22662000,
        0.0048849; 22665600,0.0178069; 22669200,0.0143141; 22672800,0.0042326;
        22676400,0.003786; 22680000,0.0010259; 22683600,0.0034029; 22687200,
        0.0050135; 22690800,0.0011204; 22694400,7.6e-06; 22698000,1e-06;
        22701600,1e-06; 22705200,1e-06; 22708800,1e-06; 22712400,1e-06;
        22716000,1e-06; 22719600,6.6e-05; 22723200,0.0023508; 22726800,
        0.0088719; 22730400,0.0137784; 22734000,0.0157588; 22737600,0.0162625;
        22741200,0.0076427; 22744800,0.0071629; 22748400,0.0091526; 22752000,
        0.022586; 22755600,0.0213225; 22759200,0.0075932; 22762800,0.0027734;
        22766400,0.0008238; 22770000,0.0011233; 22773600,0.0007466; 22777200,
        0.0018988; 22780800,0.0003742; 22784400,0.0001175; 22788000,0.0006369;
        22791600,1e-06; 22795200,1e-06; 22798800,1e-06; 22802400,1e-06;
        22806000,1e-06; 22809600,0.0004581; 22813200,0.0060056; 22816800,
        0.0106017; 22820400,0.0067508; 22824000,0.0071168; 22827600,0.0027165;
        22831200,8.57e-05; 22834800,0.0001672; 22838400,0.0077237; 22842000,
        0.0182719; 22845600,0.0111878; 22849200,0.0044081; 22852800,0.0017057;
        22856400,0.004465; 22860000,0.0024706; 22863600,0.0034542; 22867200,
        0.0020712; 22870800,0.0014249; 22874400,2.83e-05; 22878000,1e-06;
        22881600,1e-06; 22885200,1e-06; 22888800,1e-06; 22892400,1e-06;
        22896000,1e-06; 22899600,0.0002882; 22903200,0.0028222; 22906800,
        0.0029207; 22910400,0.0023212; 22914000,0.0013723; 22917600,0.000235;
        22921200,1e-06; 22924800,1.55e-05; 22928400,0.0023942; 22932000,
        0.0034246; 22935600,0.0028458; 22939200,0.0029371; 22942800,0.0054892;
        22946400,0.0036303; 22950000,0.0024949; 22953600,0.0017276; 22957200,
        0.0022809; 22960800,0.0008575; 22964400,1e-06; 22968000,1e-06; 22971600,
        1e-06; 22975200,1e-06; 22978800,1e-06; 22982400,0.000342; 22986000,
        0.0040426; 22989600,0.013534; 22993200,0.0143735; 22996800,0.0129487;
        23000400,0.0071309; 23004000,0.0029198; 23007600,0.0053861; 23011200,
        0.0078234; 23014800,0.0122616; 23018400,0.0058; 23022000,0.0017563;
        23025600,7.83e-05; 23029200,0.0009272; 23032800,0.0005158; 23036400,
        1e-06; 23040000,1e-06; 23043600,1e-06; 23047200,1e-06; 23050800,1e-06;
        23054400,1e-06; 23058000,1e-06; 23061600,1e-06; 23065200,1e-06;
        23068800,0.0003034; 23072400,0.0039752; 23076000,0.0084514; 23079600,
        0.0114204; 23083200,0.0153856; 23086800,0.0152702; 23090400,0.0054622;
        23094000,0.0021151; 23097600,0.0008174; 23101200,0.0013901; 23104800,
        0.0041611; 23108400,0.0031213; 23112000,0.0007424; 23115600,0.0016045;
        23119200,0.0007002; 23122800,1e-06; 23126400,1e-06; 23130000,1e-06;
        23133600,1e-06; 23137200,1e-06; 23140800,1e-06; 23144400,1e-06;
        23148000,1e-06; 23151600,1e-06; 23155200,1e-06; 23158800,0.0003454;
        23162400,0.0039806; 23166000,0.0052776; 23169600,0.0061068; 23173200,
        0.0083388; 23176800,0.0076152; 23180400,0.0037417; 23184000,0.0009635;
        23187600,0.000418; 23191200,0.0016016; 23194800,0.0013703; 23198400,
        4.54e-05; 23202000,0.0004658; 23205600,0.0004777; 23209200,1e-06;
        23212800,1e-06; 23216400,1e-06; 23220000,5.9e-06; 23223600,1e-06;
        23227200,1e-06; 23230800,1e-06; 23234400,1e-06; 23238000,1e-06;
        23241600,0.0001527; 23245200,0.0031307; 23248800,0.0064781; 23252400,
        0.0059117; 23256000,0.0083948; 23259600,0.0067356; 23263200,0.0046594;
        23266800,0.0090673; 23270400,0.0253908; 23274000,0.0213677; 23277600,
        0.0096515; 23281200,0.0055686; 23284800,0.0024726; 23288400,0.003147;
        23292000,0.0029844; 23295600,0.0045479; 23299200,0.002308; 23302800,
        0.0024192; 23306400,0.0009175; 23310000,1e-06; 23313600,1e-06; 23317200,
        1e-06; 23320800,1e-06; 23324400,1e-06; 23328000,1e-06; 23331600,
        1.78e-05; 23335200,0.0007501; 23338800,0.0014351; 23342400,0.0015703;
        23346000,0.0003798; 23349600,1e-06; 23353200,1e-06; 23356800,1e-06;
        23360400,0.0003024; 23364000,0.0012816; 23367600,0.0019471; 23371200,
        0.0022798; 23374800,0.0038016; 23378400,0.0039607; 23382000,0.0044905;
        23385600,0.0020818; 23389200,0.0024673; 23392800,0.0001068; 23396400,
        1e-06; 23400000,1e-06; 23403600,1e-06; 23407200,1e-06; 23410800,1e-06;
        23414400,1e-06; 23418000,1e-06; 23421600,8.74e-05; 23425200,0.0010382;
        23428800,0.0015633; 23432400,0.0003024; 23436000,1e-06; 23439600,1e-06;
        23443200,1e-06; 23446800,1e-06; 23450400,3.9e-06; 23454000,0.0005204;
        23457600,0.0010131; 23461200,0.0021515; 23464800,0.0030637; 23468400,
        0.0019068; 23472000,0.0009886; 23475600,0.0020508; 23479200,0.0001695;
        23482800,1e-06; 23486400,1e-06; 23490000,1e-06; 23493600,1e-06;
        23497200,1e-06; 23500800,1e-06; 23504400,1e-06; 23508000,1e-06;
        23511600,1.9e-06; 23515200,0.0005104; 23518800,0.0001791; 23522400,
        1e-06; 23526000,1e-06; 23529600,1e-06; 23533200,1e-06; 23536800,1e-06;
        23540400,1e-06; 23544000,0.0002847; 23547600,0.0011364; 23551200,
        0.0006248; 23554800,7.6e-06; 23558400,1e-06; 23562000,5.35e-05;
        23565600,0.0001815; 23569200,1e-06; 23572800,1e-06; 23576400,1e-06;
        23580000,1e-06; 23583600,1e-06; 23587200,0.0008552; 23590800,0.0038543;
        23594400,0.0067891; 23598000,0.0085878; 23601600,0.0085307; 23605200,
        0.0061049; 23608800,0.0032452; 23612400,0.0051645; 23616000,0.0125236;
        23619600,0.0139187; 23623200,0.0105658; 23626800,0.004472; 23630400,
        0.003316; 23634000,0.0088065; 23637600,0.0058504; 23641200,0.006003;
        23644800,0.0037363; 23648400,0.0012539; 23652000,3.25e-05; 23655600,
        1e-06; 23659200,0.000172; 23662800,0.0008648; 23666400,0.0016369;
        23670000,0.0028322; 23673600,0.0042725; 23677200,0.0072247; 23680800,
        0.0107285; 23684400,0.0160893; 23688000,0.0227907; 23691600,0.0167142;
        23695200,0.0037676; 23698800,0.0010077; 23702400,0.0008174; 23706000,
        0.0021638; 23709600,0.0044802; 23713200,0.0028702; 23716800,0.0014872;
        23720400,0.003759; 23724000,0.003065; 23727600,0.0009238; 23731200,
        0.0038555; 23734800,0.0020638; 23738400,0.0007576; 23742000,7.96e-05;
        23745600,1e-06; 23749200,1e-06; 23752800,1e-06; 23756400,1e-06;
        23760000,1e-06; 23763600,0.000266; 23767200,0.0035845; 23770800,
        0.0045955; 23774400,0.0030742; 23778000,0.0032714; 23781600,0.0005398;
        23785200,7.8e-06; 23788800,1e-06; 23792400,0.000132; 23796000,0.001263;
        23799600,0.0018858; 23803200,0.0003025; 23806800,0.0014705; 23810400,
        0.0026333; 23814000,0.0012415; 23817600,0.0014012; 23821200,0.0030352;
        23824800,0.00185; 23828400,1e-06; 23832000,7.8e-06; 23835600,8.98e-05;
        23839200,0.0004509; 23842800,0.0014757; 23846400,0.0010194; 23850000,
        0.0014154; 23853600,0.0039308; 23857200,0.0078534; 23860800,0.0057481;
        23864400,0.0011456; 23868000,1e-06; 23871600,1e-06; 23875200,1e-06;
        23878800,0.002635; 23882400,0.0138805; 23886000,0.0102878; 23889600,
        0.0077318; 23893200,0.0102618; 23896800,0.0047165; 23900400,0.0067335;
        23904000,0.0053442; 23907600,0.0014963; 23911200,6.85e-05; 23914800,
        0.0002178; 23918400,1e-06; 23922000,1e-06; 23925600,0.0001483; 23929200,
        0.0030924; 23932800,0.0052901; 23936400,0.0050649; 23940000,0.0173661;
        23943600,0.0307209; 23947200,0.0317803; 23950800,0.011273; 23954400,
        0.0005497; 23958000,0.0006262; 23961600,0.0024596; 23965200,0.0075274;
        23968800,0.0066251; 23972400,0.007197; 23976000,0.0070677; 23979600,
        0.003181; 23983200,0.0116641; 23986800,0.0174497; 23990400,0.0117914;
        23994000,0.0091696; 23997600,0.0054828; 24001200,0.002324; 24004800,
        0.0001963; 24008400,1e-06; 24012000,0.0003211; 24015600,0.0013008;
        24019200,0.0019468; 24022800,0.0037391; 24026400,0.0114089; 24030000,
        0.0185809; 24033600,0.0168659; 24037200,0.0097734; 24040800,0.0044632;
        24044400,0.0030729; 24048000,0.0031851; 24051600,0.0105108; 24055200,
        0.0101093; 24058800,0.0050475; 24062400,0.0002669; 24066000,0.0028498;
        24069600,0.0018985; 24073200,0.0021554; 24076800,0.0009016; 24080400,
        0.0008602; 24084000,0.0007627; 24087600,1.36e-05; 24091200,1e-06;
        24094800,0.0001903; 24098400,0.001512; 24102000,0.002945; 24105600,
        0.0047052; 24109200,0.008443; 24112800,0.011022; 24116400,0.0099729;
        24120000,0.0087258; 24123600,0.0058419; 24127200,0.0019804; 24130800,
        0.0100017; 24134400,0.0435709; 24138000,0.0537503; 24141600,0.045871;
        24145200,0.0252986; 24148800,0.0262718; 24152400,0.020396; 24156000,
        0.0073683; 24159600,0.0226632; 24163200,0.0042414; 24166800,0.0003481;
        24170400,0.0005579; 24174000,1e-06; 24177600,1e-06; 24181200,2.74e-05;
        24184800,0.0015258; 24188400,0.0020362; 24192000,0.002969; 24195600,
        0.0048464; 24199200,0.0138026; 24202800,0.0322917; 24206400,0.0455002;
        24210000,0.0283965; 24213600,0.0069354; 24217200,0.0126497; 24220800,
        0.0193043; 24224400,0.0258942; 24228000,0.0148253; 24231600,0.0011173;
        24235200,0.0016324; 24238800,0.008994; 24242400,0.0053183; 24246000,
        0.0019168; 24249600,0.0022339; 24253200,0.0004838; 24256800,0.0007145;
        24260400,6.1e-06; 24264000,1e-06; 24267600,1e-06; 24271200,1e-06;
        24274800,1e-06; 24278400,2e-06; 24282000,0.0009493; 24285600,0.0026123;
        24289200,0.0063249; 24292800,0.0088094; 24296400,0.0080031; 24300000,
        0.0024074; 24303600,0.0004797; 24307200,0.0003524; 24310800,0.0027728;
        24314400,0.0025586; 24318000,0.0027445; 24321600,0.0022804; 24325200,
        0.0085498; 24328800,0.0029919; 24332400,1e-06; 24336000,0.0005323;
        24339600,0.0018982; 24343200,0.0047093; 24346800,4.78e-05; 24350400,
        1e-06; 24354000,1e-06; 24357600,1e-06; 24361200,1e-06; 24364800,
        2.89e-05; 24368400,0.0039003; 24372000,0.0182823; 24375600,0.0182803;
        24379200,0.0182069; 24382800,0.0217975; 24386400,0.0028174; 24390000,
        0.0007242; 24393600,0.0051681; 24397200,0.0024863; 24400800,0.0019107;
        24404400,0.0019589; 24408000,0.0049627; 24411600,0.0056048; 24415200,
        0.0005342; 24418800,0.0009865; 24422400,0.0013562; 24426000,0.000315;
        24429600,0.0007678; 24433200,1.9e-06; 24436800,1e-06; 24440400,1e-06;
        24444000,2.33e-05; 24447600,0.0009438; 24451200,0.0038806; 24454800,
        0.0082927; 24458400,0.0104626; 24462000,0.0066064; 24465600,0.0098228;
        24469200,0.0106938; 24472800,0.0064887; 24476400,0.0109633; 24480000,
        0.0303775; 24483600,0.0307769; 24487200,0.0132857; 24490800,0.0047314;
        24494400,0.0067164; 24498000,0.0095111; 24501600,0.0071053; 24505200,
        0.0073789; 24508800,0.0033621; 24512400,0.0032078; 24516000,0.0018585;
        24519600,0.000601; 24523200,0.0019863; 24526800,0.0048764; 24530400,
        0.005897; 24534000,0.0054711; 24537600,0.0093444; 24541200,0.0228883;
        24544800,0.061059; 24548400,0.0443209; 24552000,0.0114619; 24555600,
        0.006976; 24559200,0.0058076; 24562800,0.0322231; 24566400,0.0557908;
        24570000,0.0277145; 24573600,0.0083526; 24577200,0.002759; 24580800,
        0.004893; 24584400,0.0080628; 24588000,0.0069407; 24591600,0.0098313;
        24595200,0.0062837; 24598800,0.0026231; 24602400,0.0015079; 24606000,
        1e-06; 24609600,1e-06; 24613200,1e-06; 24616800,2.43e-05; 24620400,
        9.23e-05; 24624000,1e-06; 24627600,0.0014131; 24631200,0.0068047;
        24634800,0.0070518; 24638400,0.0048232; 24642000,0.0028516; 24645600,
        0.0001744; 24649200,1e-06; 24652800,0.0020536; 24656400,0.0096493;
        24660000,0.0085121; 24663600,0.0037355; 24667200,0.0060431; 24670800,
        0.0122051; 24674400,0.0117947; 24678000,0.0104026; 24681600,0.0079795;
        24685200,0.0057151; 24688800,0.0011239; 24692400,1e-06; 24696000,
        0.0001107; 24699600,0.0005126; 24703200,2.72e-05; 24706800,1e-06;
        24710400,3.9e-06; 24714000,0.0012654; 24717600,0.0084535; 24721200,
        0.0123967; 24724800,0.0106848; 24728400,0.0049976; 24732000,0.0011942;
        24735600,0.0014912; 24739200,0.0017589; 24742800,0.0027605; 24746400,
        0.007758; 24750000,0.0054067; 24753600,0.0030989; 24757200,0.0092963;
        24760800,0.0115498; 24764400,0.0084696; 24768000,0.0069802; 24771600,
        0.0039989; 24775200,0.0004283; 24778800,1e-06; 24782400,1e-06; 24786000,
        1e-06; 24789600,1e-06; 24793200,1e-06; 24796800,1e-06; 24800400,
        0.0001573; 24804000,0.0027567; 24807600,0.0058647; 24811200,0.0069744;
        24814800,0.0022; 24818400,0.0001059; 24822000,1.93e-05; 24825600,
        0.0014253; 24829200,0.0104161; 24832800,0.0141566; 24836400,0.0140769;
        24840000,0.0107314; 24843600,0.010316; 24847200,0.0135083; 24850800,
        0.0141504; 24854400,0.0065629; 24858000,0.0060255; 24861600,0.0015962;
        24865200,0.0005112; 24868800,0.0005677; 24872400,0.0006695; 24876000,
        0.0011073; 24879600,0.000693; 24883200,0.0006898; 24886800,0.0063291;
        24890400,0.0127837; 24894000,0.0114038; 24897600,0.0073322; 24901200,
        0.0044913; 24904800,0.0001465; 24908400,1e-06; 24912000,1e-06; 24915600,
        0.000148; 24919200,0.001095; 24922800,0.0019477; 24926400,0.0005712;
        24930000,0.0010659; 24933600,0.001431; 24937200,0.0001156; 24940800,
        3.9e-06; 24944400,0.0005442; 24948000,0.0013932; 24951600,1e-06;
        24955200,1e-06; 24958800,1e-06; 24962400,1e-06; 24966000,1e-06;
        24969600,1e-06; 24973200,9.7e-06; 24976800,0.0014702; 24980400,
        0.0055529; 24984000,0.0047175; 24987600,0.0005566; 24991200,2.65e-05;
        24994800,7.6e-06; 24998400,0.0004395; 25002000,0.0007752; 25005600,
        0.0022599; 25009200,0.0030806; 25012800,0.0018745; 25016400,0.003658;
        25020000,0.0007066; 25023600,2e-06; 25027200,0.0007106; 25030800,
        0.0029207; 25034400,0.001443; 25038000,5.8e-06; 25041600,1.75e-05;
        25045200,0.0011407; 25048800,0.0040363; 25052400,0.0063584; 25056000,
        0.0076113; 25059600,0.0135298; 25063200,0.0242132; 25066800,0.0310805;
        25070400,0.0317889; 25074000,0.0111865; 25077600,0.0037084; 25081200,
        0.0165303; 25084800,0.0448181; 25088400,0.043155; 25092000,0.0169373;
        25095600,0.0047787; 25099200,0.0101577; 25102800,0.0140447; 25106400,
        0.0117255; 25110000,0.0163036; 25113600,0.0090674; 25117200,0.0050896;
        25120800,0.0048405; 25124400,0.0012106; 25128000,0.0008709; 25131600,
        0.0004511; 25135200,1e-06; 25138800,1e-06; 25142400,1e-06; 25146000,
        2.96e-05; 25149600,0.0015106; 25153200,0.0033968; 25156800,0.0025098;
        25160400,0.000277; 25164000,1e-06; 25167600,1e-06; 25171200,0.0016363;
        25174800,0.0121187; 25178400,0.0122441; 25182000,0.008211; 25185600,
        0.0169615; 25189200,0.0158147; 25192800,0.0094578; 25196400,0.0132679;
        25200000,0.0055252; 25203600,0.0057933; 25207200,0.0034989; 25210800,
        0.0038009; 25214400,0.002123; 25218000,2.61e-05; 25221600,1e-06;
        25225200,0.0006969; 25228800,0.0054813; 25232400,0.0107811; 25236000,
        0.0100583; 25239600,0.0084464; 25243200,0.0090841; 25246800,0.00507;
        25250400,0.0028224; 25254000,0.001921; 25257600,0.0016437; 25261200,
        0.0029742; 25264800,0.0066687; 25268400,0.0090546; 25272000,0.0218613;
        25275600,0.0285123; 25279200,0.0045886; 25282800,8e-06; 25286400,1e-06;
        25290000,0.0002921; 25293600,0.0026598; 25297200,7.11e-05; 25300800,
        0.0006485; 25304400,0.0023864; 25308000,0.003879; 25311600,0.0032191;
        25315200,0.0041796; 25318800,0.0098174; 25322400,0.0124706; 25326000,
        0.0145478; 25329600,0.0261673; 25333200,0.0193043; 25336800,0.006604;
        25340400,0.0185915; 25344000,0.0355934; 25347600,0.029919; 25351200,
        0.0125298; 25354800,0.0019568; 25358400,0.000945; 25362000,0.0064716;
        25365600,0.0061223; 25369200,0.0024187; 25372800,0.0021009; 25376400,
        0.0020882; 25380000,0.0031218; 25383600,0.0005098; 25387200,0.0021192;
        25390800,0.0049857; 25394400,0.0060947; 25398000,0.0055602; 25401600,
        0.0159194; 25405200,0.0368487; 25408800,0.0502701; 25412400,0.0689001;
        25416000,0.0674851; 25419600,0.016126; 25423200,0.0208719; 25426800,
        0.0684066; 25430400,0.078313; 25434000,0.0345466; 25437600,0.018231;
        25441200,0.0079534; 25444800,0.0013776; 25448400,0.0142526; 25452000,
        0.0194617; 25455600,0.0171523; 25459200,0.0152569; 25462800,0.0097259;
        25466400,0.0080757; 25470000,0.003164; 25473600,0.0022232; 25477200,
        0.002491; 25480800,0.0036749; 25484400,0.0044047; 25488000,0.0151616;
        25491600,0.0463178; 25495200,0.0651921; 25498800,0.0589429; 25502400,
        0.0530821; 25506000,0.0384898; 25509600,0.0264092; 25513200,0.0245226;
        25516800,0.0222828; 25520400,0.0257803; 25524000,0.0221673; 25527600,
        0.0094878; 25531200,0.0074731; 25534800,0.0252849; 25538400,0.0177224;
        25542000,0.0038766; 25545600,0.0156502; 25549200,0.0262562; 25552800,
        0.0162451; 25556400,0.0025641; 25560000,0.0020346; 25563600,0.0028728;
        25567200,0.0035104; 25570800,0.0091126; 25574400,0.0170181; 25578000,
        0.0261636; 25581600,0.0382499; 25585200,0.041672; 25588800,0.0307443;
        25592400,0.0260125; 25596000,0.0161689; 25599600,0.0122967; 25603200,
        0.01129; 25606800,0.0150488; 25610400,0.020322; 25614000,0.0091951;
        25617600,0.0117533; 25621200,0.0433659; 25624800,0.02234; 25628400,
        0.0140456; 25632000,0.0324229; 25635600,0.0313123; 25639200,0.0269213;
        25642800,0.0136659; 25646400,0.006469; 25650000,0.0113148; 25653600,
        0.0208661; 25657200,0.0249415; 25660800,0.0229549; 25664400,0.0345261;
        25668000,0.0440888; 25671600,0.0387648; 25675200,0.0352338; 25678800,
        0.0193683; 25682400,0.0051994; 25686000,0.0267115; 25689600,0.0804466;
        25693200,0.0916975; 25696800,0.0481215; 25700400,0.0189129; 25704000,
        0.0343922; 25707600,0.0429488; 25711200,0.0185166; 25714800,0.0278406;
        25718400,0.0187141; 25722000,0.0108067; 25725600,0.0054748; 25729200,
        0.0017298; 25732800,0.0020163; 25736400,0.0035524; 25740000,0.0045308;
        25743600,0.0066108; 25747200,0.0200306; 25750800,0.0398713; 25754400,
        0.0394798; 25758000,0.0385797; 25761600,0.0401788; 25765200,0.0183565;
        25768800,0.0052735; 25772400,0.0212563; 25776000,0.0684634; 25779600,
        0.0958563; 25783200,0.0959613; 25786800,0.0327544; 25790400,0.0038597;
        25794000,0.0162363; 25797600,0.0211621; 25801200,0.0132498; 25804800,
        0.0130307; 25808400,0.0088235; 25812000,0.0088301; 25815600,0.0051158;
        25819200,0.0041772; 25822800,0.0034974; 25826400,0.0034748; 25830000,
        0.0063793; 25833600,0.0253142; 25837200,0.0518599; 25840800,0.0339214;
        25844400,0.0288291; 25848000,0.0276889; 25851600,0.0070802; 25855200,
        0.0041146; 25858800,0.0157608; 25862400,0.0568548; 25866000,0.0662522;
        25869600,0.0331184; 25873200,0.02177; 25876800,0.026688; 25880400,
        0.035015; 25884000,0.0376034; 25887600,0.0341557; 25891200,0.0219119;
        25894800,0.0134908; 25898400,0.0053921; 25902000,0.0017522; 25905600,
        0.000167; 25909200,0.0023661; 25912800,0.004589; 25916400,0.0042426;
        25920000,0.0094008; 25923600,0.0154315; 25927200,0.012089; 25930800,
        0.0132881; 25934400,0.0187941; 25938000,0.0078277; 25941600,0.004572;
        25945200,0.010473; 25948800,0.0264171; 25952400,0.03586; 25956000,
        0.0262245; 25959600,0.0112861; 25963200,0.0051783; 25966800,0.0162773;
        25970400,0.0144681; 25974000,0.0275755; 25977600,0.0304537; 25981200,
        0.0127964; 25984800,0.0056043; 25988400,2.09e-05; 25992000,0.0004353;
        25995600,0.0053738; 25999200,0.0139121; 26002800,0.0067655; 26006400,
        0.0023222; 26010000,0.0098639; 26013600,0.0181931; 26017200,0.0191338;
        26020800,0.0220001; 26024400,0.0129017; 26028000,0.0035222; 26031600,
        0.0093942; 26035200,0.0263056; 26038800,0.0441844; 26042400,0.0344107;
        26046000,0.0166403; 26049600,0.0247622; 26053200,0.0316769; 26056800,
        0.0192697; 26060400,0.0196228; 26064000,0.0120579; 26067600,0.0077109;
        26071200,0.0064419; 26074800,0.0089929; 26078400,0.0076854; 26082000,
        0.0060401; 26085600,0.0051037; 26089200,0.004596; 26092800,0.0140326;
        26096400,0.0296335; 26100000,0.0261581; 26103600,0.0233946; 26107200,
        0.0254816; 26110800,0.0104362; 26114400,0.0030924; 26118000,0.002318;
        26121600,0.0022941; 26125200,0.0044527; 26128800,0.0057257; 26132400,
        0.0047914; 26136000,0.0014849; 26139600,0.0039557; 26143200,0.0037905;
        26146800,0.0057381; 26150400,0.0130154; 26154000,0.0183176; 26157600,
        0.0156541; 26161200,0.0033149; 26164800,0.0028796; 26168400,0.0076264;
        26172000,0.0136265; 26175600,0.0147187; 26179200,0.014393; 26182800,
        0.0253512; 26186400,0.0380796; 26190000,0.0322405; 26193600,0.0324004;
        26197200,0.0353323; 26200800,0.0174478; 26204400,0.0126776; 26208000,
        0.0107063; 26211600,0.0049113; 26215200,0.0081225; 26218800,0.0110105;
        26222400,0.0040794; 26226000,0.0045088; 26229600,0.015277; 26233200,
        0.0112923; 26236800,0.0159375; 26240400,0.0241991; 26244000,0.0230274;
        26247600,0.0185868; 26251200,0.0063782; 26254800,0.0144453; 26258400,
        0.02094; 26262000,0.0222575; 26265600,0.0224527; 26269200,0.0155669;
        26272800,0.0324005; 26276400,0.0362724; 26280000,0.0274638; 26283600,
        0.0285045; 26287200,0.0155773; 26290800,0.0039431; 26294400,0.0095165;
        26298000,0.0287918; 26301600,0.0616216; 26305200,0.0545795; 26308800,
        0.0186822; 26312400,0.0270628; 26316000,0.0275711; 26319600,0.0320373;
        26323200,0.0463995; 26326800,0.0265244; 26330400,0.0139121; 26334000,
        0.0081494; 26337600,0.0049581; 26341200,0.0037183; 26344800,0.005241;
        26348400,0.0142586; 26352000,0.0169787; 26355600,0.0078989; 26359200,
        0.0078836; 26362800,0.0196765; 26366400,0.02323; 26370000,0.0180983;
        26373600,0.0061633; 26377200,0.0002687; 26380800,0.0002921; 26384400,
        0.0077382; 26388000,0.0272754; 26391600,0.0182654; 26395200,0.0108788;
        26398800,0.003813; 26402400,0.0112886; 26406000,0.0126238; 26409600,
        0.006075; 26413200,0.0083383; 26416800,0.0068395; 26420400,0.0050199;
        26424000,0.001087; 26427600,1e-06; 26431200,0.0014036; 26434800,
        0.0065617; 26438400,0.0095976; 26442000,0.0129659; 26445600,0.0107116;
        26449200,0.0065803; 26452800,0.0235529; 26456400,0.0308766; 26460000,
        0.0071173; 26463600,0.0003002; 26467200,1e-06; 26470800,0.0025128;
        26474400,0.0120568; 26478000,0.0120876; 26481600,0.0176071; 26485200,
        0.0150659; 26488800,0.0158728; 26492400,0.019439; 26496000,0.0230752;
        26499600,0.0121193; 26503200,0.0100183; 26506800,0.0040663; 26510400,
        1e-06; 26514000,1e-06; 26517600,0.0002941; 26521200,0.0038452; 26524800,
        0.0074567; 26528400,0.0063893; 26532000,0.0173314; 26535600,0.024698;
        26539200,0.0187517; 26542800,0.0189526; 26546400,0.0177302; 26550000,
        0.0009673; 26553600,0.0011817; 26557200,0.0093942; 26560800,0.0313025;
        26564400,0.0218742; 26568000,0.0089341; 26571600,0.0113382; 26575200,
        0.0197852; 26578800,0.0240434; 26582400,0.0256865; 26586000,0.0312802;
        26589600,0.0057658; 26593200,0.0016397; 26596800,1e-06; 26600400,
        3.9e-06; 26604000,0.0021358; 26607600,0.007754; 26611200,0.0069463;
        26614800,0.0156576; 26618400,0.0199781; 26622000,0.0194352; 26625600,
        0.0191885; 26629200,0.0198602; 26632800,0.0083085; 26636400,0.0021154;
        26640000,0.0021051; 26643600,0.0122636; 26647200,0.0378742; 26650800,
        0.0406492; 26654400,0.0370216; 26658000,0.0284191; 26661600,0.0310529;
        26665200,0.0439455; 26668800,0.0482423; 26672400,0.0210949; 26676000,
        0.0148472; 26679600,0.008388; 26683200,0.0002658; 26686800,0.0026272;
        26690400,0.0086297; 26694000,0.0137799; 26697600,0.0066812; 26701200,
        0.0109459; 26704800,0.028253; 26708400,0.0292784; 26712000,0.0359502;
        26715600,0.0369739; 26719200,0.0169572; 26722800,0.0122674; 26726400,
        0.0131091; 26730000,0.005606; 26733600,0.0050863; 26737200,0.0059926;
        26740800,0.0027717; 26744400,0.001135; 26748000,0.0021034; 26751600,
        0.0041634; 26755200,0.0108472; 26758800,0.0229194; 26762400,0.0237163;
        26766000,0.0132026; 26769600,0.0024127; 26773200,0.0008391; 26776800,
        0.0021897; 26780400,0.0085443; 26784000,0.0162474; 26787600,0.019071;
        26791200,0.0216737; 26794800,0.0177758; 26798400,0.007832; 26802000,
        0.0173013; 26805600,0.0247013; 26809200,0.0048464; 26812800,0.001427;
        26816400,0.0037318; 26820000,0.0058745; 26823600,0.0104848; 26827200,
        0.0054463; 26830800,0.0044582; 26834400,0.0152534; 26838000,0.0124997;
        26841600,0.0161393; 26845200,0.0267104; 26848800,0.0310728; 26852400,
        0.0148357; 26856000,0.0087935; 26859600,0.0074017; 26863200,0.0092215;
        26866800,0.0127624; 26870400,0.0218744; 26874000,0.0124526; 26877600,
        0.0239545; 26881200,0.0356394; 26884800,0.0385001; 26888400,0.0428653;
        26892000,0.0315532; 26895600,0.0134257; 26899200,0.0431062; 26902800,
        0.0656041; 26906400,0.0531765; 26910000,0.0144275; 26913600,0.0048123;
        26917200,0.0146817; 26920800,0.0095957; 26924400,0.0157262; 26928000,
        0.02299; 26931600,0.0117223; 26935200,0.0020919; 26938800,0.0006033;
        26942400,0.0002531; 26946000,0.0023297; 26949600,0.0044217; 26953200,
        0.0046629; 26956800,0.0078012; 26960400,0.0212342; 26964000,0.0377358;
        26967600,0.034697; 26971200,0.023806; 26974800,0.0540894; 26978400,
        0.0541953; 26982000,0.0191523; 26985600,0.0460459; 26989200,0.0951024;
        26992800,0.0586573; 26996400,0.0105224; 27000000,0.0027912; 27003600,
        0.0150023; 27007200,0.0136027; 27010800,0.0127259; 27014400,0.0386304;
        27018000,0.0206715; 27021600,0.0099507; 27025200,0.0067159; 27028800,
        7.68e-05; 27032400,0.0015578; 27036000,0.0058448; 27039600,0.0102386;
        27043200,0.0044814; 27046800,0.0094046; 27050400,0.0323086; 27054000,
        0.0359685; 27057600,0.0341556; 27061200,0.0181317; 27064800,0.0093231;
        27068400,0.0086427; 27072000,0.0353676; 27075600,0.0855348; 27079200,
        0.0856863; 27082800,0.0146304; 27086400,0.0014581; 27090000,0.0102632;
        27093600,0.0120025; 27097200,0.0117989; 27100800,0.0319659; 27104400,
        0.0295186; 27108000,0.0360133; 27111600,0.0279781; 27115200,0.0220134;
        27118800,0.0363006; 27122400,0.0467976; 27126000,0.0388118; 27129600,
        0.0181737; 27133200,0.0567052; 27136800,0.0468742; 27140400,0.0134046;
        27144000,0.0137886; 27147600,0.0190248; 27151200,0.0161213; 27154800,
        0.0055523; 27158400,0.0124967; 27162000,0.0525361; 27165600,0.0512495;
        27169200,0.0357188; 27172800,0.0126693; 27176400,0.0282784; 27180000,
        0.020264; 27183600,0.0150791; 27187200,0.0254403; 27190800,0.0316586;
        27194400,0.0135079; 27198000,0.0032626; 27201600,0.0001688; 27205200,
        0.0009796; 27208800,0.0087383; 27212400,0.0155265; 27216000,0.0097389;
        27219600,0.0271378; 27223200,0.0419876; 27226800,0.0237662; 27230400,
        0.0308592; 27234000,0.0511286; 27237600,0.0108344; 27241200,0.0039799;
        27244800,0.0066362; 27248400,0.0194639; 27252000,0.0281393; 27255600,
        0.0158091; 27259200,0.0192579; 27262800,0.0207873; 27266400,0.0134586;
        27270000,0.0218813; 27273600,0.0251602; 27277200,0.0160218; 27280800,
        0.0098114; 27284400,0.0083655; 27288000,0.0026333; 27291600,0.0013569;
        27295200,0.0050637; 27298800,0.0094361; 27302400,0.0069653; 27306000,
        0.0168532; 27309600,0.0337077; 27313200,0.0294034; 27316800,0.0392593;
        27320400,0.0378242; 27324000,0.0268235; 27327600,0.0111375; 27331200,
        0.012317; 27334800,0.0110916; 27338400,0.0079766; 27342000,0.0120259;
        27345600,0.006197; 27349200,0.0060987; 27352800,0.0106001; 27356400,
        0.0053416; 27360000,0.0114326; 27363600,0.0256371; 27367200,0.0257812;
        27370800,0.0290604; 27374400,0.0163303; 27378000,0.0095928; 27381600,
        0.0121849; 27385200,0.0229328; 27388800,0.0243475; 27392400,0.0194884;
        27396000,0.0317025; 27399600,0.0331073; 27403200,0.0359255; 27406800,
        0.0359422; 27410400,0.0160723; 27414000,0.0062075; 27417600,0.0081985;
        27421200,0.0102787; 27424800,0.0140044; 27428400,0.0201085; 27432000,
        0.0097237; 27435600,0.0163154; 27439200,0.0392319; 27442800,0.0301512;
        27446400,0.0276592; 27450000,0.0481328; 27453600,0.0525793; 27457200,
        0.033851; 27460800,0.0069941; 27464400,0.0065454; 27468000,0.0063404;
        27471600,0.0165491; 27475200,0.0264469; 27478800,0.0148318; 27482400,
        0.0217167; 27486000,0.0454048; 27489600,0.0312391; 27493200,0.0189984;
        27496800,0.0152146; 27500400,0.0037866; 27504000,0.0132004; 27507600,
        0.0463697; 27511200,0.0743068; 27514800,0.0654682; 27518400,0.0331935;
        27522000,0.0407168; 27525600,0.0473949; 27529200,0.0339866; 27532800,
        0.0537221; 27536400,0.0560926; 27540000,0.0270104; 27543600,0.0083781;
        27547200,0.0052754; 27550800,0.0049798; 27554400,0.0162497; 27558000,
        0.0465682; 27561600,0.0529074; 27565200,0.0904626; 27568800,0.1003641;
        27572400,0.096279; 27576000,0.0860514; 27579600,0.1104742; 27583200,
        0.073836; 27586800,0.0260944; 27590400,0.1212339; 27594000,0.2332882;
        27597600,0.1734799; 27601200,0.052243; 27604800,0.0202313; 27608400,
        0.0233189; 27612000,0.0159857; 27615600,0.0211064; 27619200,0.0729207;
        27622800,0.0722424; 27626400,0.0689585; 27630000,0.0639473; 27633600,
        0.0520167; 27637200,0.0762941; 27640800,0.1198525; 27644400,0.0969831;
        27648000,0.0189678; 27651600,0.1313048; 27655200,0.236626; 27658800,
        0.1039279; 27662400,0.0739323; 27666000,0.0899592; 27669600,0.0247453;
        27673200,0.0097142; 27676800,0.0646023; 27680400,0.1549012; 27684000,
        0.2098175; 27687600,0.149375; 27691200,0.0542765; 27694800,0.078353;
        27698400,0.114489; 27702000,0.1051157; 27705600,0.1236212; 27709200,
        0.1210383; 27712800,0.0307808; 27716400,0.0160199; 27720000,0.015166;
        27723600,0.0083056; 27727200,0.0201019; 27730800,0.0407603; 27734400,
        0.0328386; 27738000,0.0558013; 27741600,0.0771486; 27745200,0.0666659;
        27748800,0.0978667; 27752400,0.0578497; 27756000,0.0198258; 27759600,
        0.0108517; 27763200,0.0408741; 27766800,0.1290113; 27770400,0.165813;
        27774000,0.0784905; 27777600,0.0336627; 27781200,0.0472787; 27784800,
        0.0333437; 27788400,0.087338; 27792000,0.0861037; 27795600,0.1010647;
        27799200,0.0723819; 27802800,0.0216966; 27806400,0.0186625; 27810000,
        0.0250284; 27813600,0.0460384; 27817200,0.0831949; 27820800,0.0898165;
        27824400,0.1480037; 27828000,0.1388931; 27831600,0.0729652; 27835200,
        0.0796487; 27838800,0.1014173; 27842400,0.0885288; 27846000,0.0360399;
        27849600,0.0905284; 27853200,0.1796035; 27856800,0.1552424; 27860400,
        0.0317161; 27864000,0.0265432; 27867600,0.0351698; 27871200,0.0163943;
        27874800,0.0212173; 27878400,0.0297032; 27882000,0.0263888; 27885600,
        0.0156242; 27889200,0.0162216; 27892800,0.0077655; 27896400,0.011935;
        27900000,0.0291573; 27903600,0.0374866; 27907200,0.0297086; 27910800,
        0.0738906; 27914400,0.0912887; 27918000,0.1264918; 27921600,0.1903967;
        27925200,0.0803879; 27928800,0.0829416; 27932400,0.1418309; 27936000,
        0.166912; 27939600,0.1598172; 27943200,0.1145211; 27946800,0.0440619;
        27950400,0.0083836; 27954000,0.0315691; 27957600,0.0719509; 27961200,
        0.0322057; 27964800,0.0734467; 27968400,0.1718774; 27972000,0.304293;
        27975600,0.3129706; 27979200,0.1673434; 27982800,0.0702511; 27986400,
        0.1477333; 27990000,0.2613868; 27993600,0.2371501; 27997200,0.1679944;
        28000800,0.1975857; 28004400,0.2516912; 28008000,0.1936203; 28011600,
        0.1746806; 28015200,0.180335; 28018800,0.0974241; 28022400,0.1676775;
        28026000,0.1467795; 28029600,0.0856927; 28033200,0.0257823; 28036800,
        0.0001237; 28040400,1e-06; 28044000,1e-06; 28047600,0.0002187; 28051200,
        0.0080933; 28054800,0.0147671; 28058400,0.0090513; 28062000,0.010968;
        28065600,0.0002282; 28069200,1e-06; 28072800,0.0015268; 28076400,
        0.008347; 28080000,0.009577; 28083600,0.0044309; 28087200,0.0054523;
        28090800,0.0090426; 28094400,0.0091781; 28098000,0.0042592; 28101600,
        0.0006827; 28105200,4.82e-05; 28108800,0.0041561; 28112400,0.0175161;
        28116000,0.0174105; 28119600,0.0066415; 28123200,0.0085823; 28126800,
        0.0187358; 28130400,0.0091053; 28134000,0.0117643; 28137600,0.0281526;
        28141200,0.0146545; 28144800,0.0076067; 28148400,0.0059753; 28152000,
        0.0020472; 28155600,0.000973; 28159200,0.0036677; 28162800,0.0081911;
        28166400,0.0045066; 28170000,0.0100797; 28173600,0.0193289; 28177200,
        0.0104574; 28180800,0.0060914; 28184400,0.0154697; 28188000,0.005349;
        28191600,1.49e-05; 28195200,0.0039934; 28198800,0.013857; 28202400,
        0.023731; 28206000,0.0247946; 28209600,0.0080212; 28213200,0.0066354;
        28216800,0.0149249; 28220400,0.011094; 28224000,0.0328397; 28227600,
        0.0195691; 28231200,0.0107045; 28234800,0.0083813; 28238400,0.0036501;
        28242000,0.0052303; 28245600,0.0090034; 28249200,0.0088681; 28252800,
        0.0034445; 28256400,0.0109113; 28260000,0.0208732; 28263600,0.018999;
        28267200,0.0235273; 28270800,0.0343501; 28274400,0.0164664; 28278000,
        0.0048671; 28281600,0.0105217; 28285200,0.0261019; 28288800,0.0208783;
        28292400,0.0131775; 28296000,0.0120398; 28299600,0.0287338; 28303200,
        0.0209422; 28306800,0.0169379; 28310400,0.0322717; 28314000,0.0223686;
        28317600,0.0055225; 28321200,0.0049944; 28324800,0.0023173; 28328400,
        0.001723; 28332000,0.0019128; 28335600,0.0023925; 28339200,0.0055337;
        28342800,0.0130177; 28346400,0.013264; 28350000,0.0217447; 28353600,
        0.020746; 28357200,0.0205118; 28360800,0.0086561; 28364400,0.0007736;
        28368000,0.0005118; 28371600,0.0095214; 28375200,0.026091; 28378800,
        0.0240785; 28382400,0.0209378; 28386000,0.0217877; 28389600,0.0237278;
        28393200,0.0291378; 28396800,0.0415144; 28400400,0.0215683; 28404000,
        0.0105785; 28407600,0.0079877; 28411200,0.0057047; 28414800,0.0016236;
        28418400,0.0008689; 28422000,0.0107566; 28425600,0.010302; 28429200,
        0.0099168; 28432800,0.0240341; 28436400,0.0280483; 28440000,0.0127017;
        28443600,0.0153139; 28447200,0.0099938; 28450800,0.000482; 28454400,
        0.0017092; 28458000,0.0196533; 28461600,0.0617352; 28465200,0.0508762;
        28468800,0.0252858; 28472400,0.0231756; 28476000,0.0266083; 28479600,
        0.0356372; 28483200,0.0444254; 28486800,0.0303168; 28490400,0.010973;
        28494000,0.0060711; 28497600,0.0071741; 28501200,0.0022644; 28504800,
        2.51e-05; 28508400,0.0023195; 28512000,0.0104682; 28515600,0.0200197;
        28519200,0.0304002; 28522800,0.0231937; 28526400,0.0103978; 28530000,
        0.0180646; 28533600,0.0206547; 28537200,0.006442; 28540800,0.001646;
        28544400,0.0017486; 28548000,0.0059752; 28551600,0.0054277; 28555200,
        0.0054187; 28558800,0.0072184; 28562400,0.0086411; 28566000,0.0066292;
        28569600,0.0066282; 28573200,0.0154027; 28576800,0.0191298; 28580400,
        0.0097202; 28584000,0.003757; 28587600,0.0089789; 28591200,0.0126582;
        28594800,0.0127981; 28598400,0.013175; 28602000,0.0148581; 28605600,
        0.0156202; 28609200,0.0212864; 28612800,0.0149007; 28616400,0.0214349;
        28620000,0.0202423; 28623600,0.0100015; 28627200,0.0147444; 28630800,
        0.005778; 28634400,0.0025002; 28638000,0.0115152; 28641600,0.0049899;
        28645200,0.0024045; 28648800,0.0123063; 28652400,0.0046417; 28656000,
        0.0083773; 28659600,0.0273928; 28663200,0.0202597; 28666800,0.0036675;
        28670400,0.0002075; 28674000,0.0004676; 28677600,0.0015297; 28681200,
        0.0098421; 28684800,0.0138436; 28688400,0.0074998; 28692000,0.0090181;
        28695600,0.0252678; 28699200,0.0313005; 28702800,0.0200599; 28706400,
        0.0060147; 28710000,8.32e-05; 28713600,0.0032213; 28717200,0.0317382;
        28720800,0.068204; 28724400,0.0518318; 28728000,0.0365417; 28731600,
        0.0236626; 28735200,0.0170897; 28738800,0.0317047; 28742400,0.0504782;
        28746000,0.0554411; 28749600,0.042806; 28753200,0.0174302; 28756800,
        0.0080896; 28760400,0.0059145; 28764000,0.0145472; 28767600,0.0221089;
        28771200,0.0150573; 28774800,0.0300801; 28778400,0.0431277; 28782000,
        0.0291887; 28785600,0.0270475; 28789200,0.0367984; 28792800,0.0130488;
        28796400,0.0031767; 28800000,0.0112338; 28803600,0.0411751; 28807200,
        0.0590232; 28810800,0.0218909; 28814400,0.0112997; 28818000,0.020071;
        28821600,0.0098248; 28825200,0.0186632; 28828800,0.0459105; 28832400,
        0.022262; 28836000,0.0050027; 28839600,0.0027734; 28843200,0.001014;
        28846800,1e-06; 28850400,0.0018083; 28854000,0.0098525; 28857600,
        0.0142207; 28861200,0.0098711; 28864800,0.0284346; 28868400,0.0307646;
        28872000,0.0257696; 28875600,0.0347747; 28879200,0.0108614; 28882800,
        0.0022996; 28886400,0.0083076; 28890000,0.0332189; 28893600,0.0600773;
        28897200,0.0504343; 28900800,0.027128; 28904400,0.0482446; 28908000,
        0.048524; 28911600,0.0262917; 28915200,0.0465241; 28918800,0.0437893;
        28922400,0.0123155; 28926000,0.0042534; 28929600,0.0003922; 28933200,
        0.0020575; 28936800,0.0054286; 28940400,0.0104544; 28944000,0.0116663;
        28947600,0.0223124; 28951200,0.0324771; 28954800,0.0277048; 28958400,
        0.0244371; 28962000,0.0423233; 28965600,0.0132443; 28969200,0.0028594;
        28972800,0.0096663; 28976400,0.0391387; 28980000,0.0745613; 28983600,
        0.0393895; 28987200,0.0320721; 28990800,0.0359411; 28994400,0.0251959;
        28998000,0.0334526; 29001600,0.0638279; 29005200,0.0490346; 29008800,
        0.011116; 29012400,0.0081016; 29016000,0.004135; 29019600,0.0013518;
        29023200,0.0022028; 29026800,0.0075288; 29030400,0.0066671; 29034000,
        0.0147354; 29037600,0.0271111; 29041200,0.0192229; 29044800,0.0170863;
        29048400,0.0329658; 29052000,0.0162608; 29055600,0.0011669; 29059200,
        0.0042949; 29062800,0.0300259; 29066400,0.0548861; 29070000,0.0478358;
        29073600,0.0341199; 29077200,0.0213549; 29080800,0.0452491; 29084400,
        0.0535704; 29088000,0.0651371; 29091600,0.0373612; 29095200,0.012862;
        29098800,0.0109643; 29102400,0.0138082; 29106000,0.0088254; 29109600,
        0.0140304; 29113200,0.0236669; 29116800,0.0209023; 29120400,0.0422604;
        29124000,0.0937269; 29127600,0.0964175; 29131200,0.0524523; 29134800,
        0.0687843; 29138400,0.0613898; 29142000,0.0058146; 29145600,0.0147701;
        29149200,0.0383712; 29152800,0.0635932; 29156400,0.056984; 29160000,
        0.0154178; 29163600,0.0191698; 29167200,0.0595942; 29170800,0.0496366;
        29174400,0.0845211; 29178000,0.165086; 29181600,0.1540119; 29185200,
        0.0954442; 29188800,0.0623841; 29192400,0.0221786; 29196000,0.0340314;
        29199600,0.0614075; 29203200,0.0595015; 29206800,0.0521227; 29210400,
        0.0675419; 29214000,0.0617435; 29217600,0.0511106; 29221200,0.0328493;
        29224800,0.0129531; 29228400,0.003156; 29232000,9.46e-05; 29235600,
        0.0009744; 29239200,0.0028063; 29242800,0.0029722; 29246400,0.0029923;
        29250000,0.000391; 29253600,0.005381; 29257200,0.0057151; 29260800,
        0.0040267; 29264400,0.0089136; 29268000,0.0058289; 29271600,0.0021788;
        29275200,0.0003797; 29278800,0.0006849; 29282400,0.0021699; 29286000,
        0.0037936; 29289600,0.0075126; 29293200,0.0045993; 29296800,0.0051219;
        29300400,0.0094396; 29304000,0.0068566; 29307600,0.0120855; 29311200,
        0.0037116; 29314800,0.0031457; 29318400,0.0027717; 29322000,0.0145959;
        29325600,0.0209279; 29329200,0.0197544; 29332800,0.0235044; 29336400,
        0.0286513; 29340000,0.0218208; 29343600,0.0240095; 29347200,0.0513494;
        29350800,0.0417626; 29354400,0.013468; 29358000,0.0109215; 29361600,
        0.0010668; 29365200,1e-06; 29368800,3.32e-05; 29372400,0.0028946;
        29376000,0.0095663; 29379600,0.0148844; 29383200,0.0156039; 29386800,
        0.0248127; 29390400,0.0284793; 29394000,0.0213779; 29397600,0.007925;
        29401200,0.0027477; 29404800,0.0060775; 29408400,0.0270042; 29412000,
        0.0399111; 29415600,0.0315612; 29419200,0.0310638; 29422800,0.0292727;
        29426400,0.0318176; 29430000,0.0523092; 29433600,0.0545162; 29437200,
        0.0234445; 29440800,0.0125184; 29444400,0.0063158; 29448000,0.0022678;
        29451600,0.0015009; 29455200,0.0041503; 29458800,0.0085524; 29462400,
        0.0097647; 29466000,0.0178222; 29469600,0.0319971; 29473200,0.0243481;
        29476800,0.0165881; 29480400,0.0301668; 29484000,0.01049; 29487600,
        0.0033329; 29491200,0.0068057; 29494800,0.0271512; 29498400,0.0587485;
        29502000,0.0565666; 29505600,0.0156952; 29509200,0.0253279; 29512800,
        0.022048; 29516400,0.0282416; 29520000,0.0660355; 29523600,0.0504942;
        29527200,0.0191386; 29530800,0.0092985; 29534400,0.0053363; 29538000,
        0.007147; 29541600,0.015438; 29545200,0.0256401; 29548800,0.0296221;
        29552400,0.0538617; 29556000,0.070273; 29559600,0.0219728; 29563200,
        0.0241561; 29566800,0.0384569; 29570400,0.011142; 29574000,0.0036879;
        29577600,0.0129546; 29581200,0.0441318; 29584800,0.0890708; 29588400,
        0.0909628; 29592000,0.0506857; 29595600,0.0505801; 29599200,0.0436769;
        29602800,0.0329997; 29606400,0.0656336; 29610000,0.0412958; 29613600,
        0.0106056; 29617200,0.0051394; 29620800,0.0015443; 29624400,0.0009093;
        29628000,0.0051554; 29631600,0.0087868; 29635200,0.0045762; 29638800,
        0.014343; 29642400,0.0311386; 29646000,0.0231952; 29649600,0.0211944;
        29653200,0.0283898; 29656800,0.0109359; 29660400,0.0024162; 29664000,
        0.0074742; 29667600,0.0370737; 29671200,0.0734303; 29674800,0.0683558;
        29678400,0.0279677; 29682000,0.0376526; 29685600,0.0573496; 29689200,
        0.0385497; 29692800,0.0547926; 29696400,0.0455537; 29700000,0.0139184;
        29703600,0.0051507; 29707200,0.002324; 29710800,0.0028837; 29714400,
        0.0068473; 29718000,0.0099663; 29721600,0.0103732; 29725200,0.033256;
        29728800,0.0443826; 29732400,0.0242483; 29736000,0.0366008; 29739600,
        0.0616537; 29743200,0.0373988; 29746800,0.0290482; 29750400,0.0467228;
        29754000,0.0314793; 29757600,0.0110623; 29761200,0.0246718; 29764800,
        0.0118434; 29768400,0.0192751; 29772000,0.0522804; 29775600,0.0317673;
        29779200,0.0323245; 29782800,0.0468252; 29786400,0.0705488; 29790000,
        0.0410152; 29793600,0.063717; 29797200,0.0155196; 29800800,0.0164951;
        29804400,0.0649919; 29808000,0.0656606; 29811600,0.0715057; 29815200,
        0.131869; 29818800,0.098699; 29822400,0.0771143; 29826000,0.1184545;
        29829600,0.1405246; 29833200,0.0572957; 29836800,0.0921926; 29840400,
        0.146013; 29844000,0.1240745; 29847600,0.0557289; 29851200,0.0250284;
        29854800,0.0476012; 29858400,0.0603946; 29862000,0.0604878; 29865600,
        0.1355599; 29869200,0.2275297; 29872800,0.2389789; 29876400,0.1022132;
        29880000,0.0403194; 29883600,0.0595945; 29887200,0.0682664; 29890800,
        0.0876548; 29894400,0.1466732; 29898000,0.084466; 29901600,0.0433281;
        29905200,0.1803015; 29908800,0.1284848; 29912400,0.0226389; 29916000,
        0.048673; 29919600,0.0274761; 29923200,0.0605507; 29926800,0.1995432;
        29930400,0.3224602; 29934000,0.2147358; 29937600,0.1148681; 29941200,
        0.1035004; 29944800,0.1175174; 29948400,0.1496449; 29952000,0.1742998;
        29955600,0.1316246; 29959200,0.0637039; 29962800,0.036581; 29966400,
        0.0197786; 29970000,0.0384674; 29973600,0.0624632; 29977200,0.084739;
        29980800,0.0970347; 29984400,0.1448186; 29988000,0.1238837; 29991600,
        0.1218371; 29995200,0.1444439; 29998800,0.1018696; 30002400,0.0872533;
        30006000,0.0334368; 30009600,0.1012256; 30013200,0.2495883; 30016800,
        0.3742078; 30020400,0.1431133; 30024000,0.0532854; 30027600,0.0915149;
        30031200,0.0733304; 30034800,0.1092386; 30038400,0.1801096; 30042000,
        0.1086371; 30045600,0.0396773; 30049200,0.0415267; 30052800,0.057611;
        30056400,0.086198; 30060000,0.1128465; 30063600,0.0798346; 30067200,
        0.1065972; 30070800,0.2072437; 30074400,0.209634; 30078000,0.0835173;
        30081600,0.0720493; 30085200,0.0788235; 30088800,0.0507248; 30092400,
        0.0279461; 30096000,0.0797628; 30099600,0.1894592; 30103200,0.2146585;
        30106800,0.0821261; 30110400,0.0647621; 30114000,0.0750253; 30117600,
        0.0577138; 30121200,0.0845235; 30124800,0.1686256; 30128400,0.1749008;
        30132000,0.0961282; 30135600,0.0505825; 30139200,0.030876; 30142800,
        0.0521378; 30146400,0.1074674; 30150000,0.1423538; 30153600,0.0558007;
        30157200,0.12332; 30160800,0.1909965; 30164400,0.1065646; 30168000,
        0.1155481; 30171600,0.1431058; 30175200,0.0707609; 30178800,0.0673081;
        30182400,0.1805938; 30186000,0.3055803; 30189600,0.3829711; 30193200,
        0.1671841; 30196800,0.1359285; 30200400,0.157448; 30204000,0.1211294;
        30207600,0.1842494; 30211200,0.215772; 30214800,0.1007796; 30218400,
        0.0458209; 30222000,0.0384872; 30225600,0.0150932; 30229200,0.0272006;
        30232800,0.0476708; 30236400,0.0567849; 30240000,0.0546234; 30243600,
        0.0975873; 30247200,0.1412977; 30250800,0.1980781; 30254400,0.1594106;
        30258000,0.0599787; 30261600,0.0285586; 30265200,0.0196441; 30268800,
        0.0397229; 30272400,0.1630001; 30276000,0.2192712; 30279600,0.065512;
        30283200,0.0738131; 30286800,0.0688293; 30290400,0.0228177; 30294000,
        0.0640777; 30297600,0.1524731; 30301200,0.1667037; 30304800,0.0880628;
        30308400,0.0412149; 30312000,0.0221373; 30315600,0.0564253; 30319200,
        0.0646834; 30322800,0.0415371; 30326400,0.0512495; 30330000,0.136478;
        30333600,0.1229723; 30337200,0.145827; 30340800,0.1625463; 30344400,
        0.0778818; 30348000,0.1614467; 30351600,0.107783; 30355200,0.0735212;
        30358800,0.1468453; 30362400,0.1787575; 30366000,0.0820641; 30369600,
        0.0393334; 30373200,0.0927736; 30376800,0.1183567; 30380400,0.1432953;
        30384000,0.1785527; 30387600,0.1856812; 30391200,0.2214136; 30394800,
        0.1239579; 30398400,0.0242633; 30402000,0.0483846; 30405600,0.0883069;
        30409200,0.1265246; 30412800,0.1820902; 30416400,0.1473781; 30420000,
        0.0915186; 30423600,0.1648402; 30427200,0.1791987; 30430800,0.0985431;
        30434400,0.1489696; 30438000,0.1294056; 30441600,0.1481797; 30445200,
        0.210404; 30448800,0.2222215; 30452400,0.119715; 30456000,0.0758133;
        30459600,0.1051108; 30463200,0.0924349; 30466800,0.0609489; 30470400,
        0.1644558; 30474000,0.2910276; 30477600,0.2974877; 30481200,0.1400484;
        30484800,0.0820579; 30488400,0.0562018; 30492000,0.1357498; 30495600,
        0.2263251; 30499200,0.1734452; 30502800,0.1495045; 30506400,0.2303241;
        30510000,0.2421185; 30513600,0.1908443; 30517200,0.2069667; 30520800,
        0.1061201; 30524400,0.0699532; 30528000,0.2271122; 30531600,0.3416303;
        30535200,0.4123606; 30538800,0.2033642; 30542400,0.049944; 30546000,
        0.0674373; 30549600,0.0620183; 30553200,0.0800977; 30556800,0.1573766;
        30560400,0.1462096; 30564000,0.1348848; 30567600,0.0531873; 30571200,
        0.0237154; 30574800,0.0323515; 30578400,0.0833841; 30582000,0.116103;
        30585600,0.0827785; 30589200,0.1558748; 30592800,0.2212938; 30596400,
        0.1737193; 30600000,0.1651382; 30603600,0.1674648; 30607200,0.0501583;
        30610800,0.0279325; 30614400,0.1196336; 30618000,0.2323271; 30621600,
        0.3397951; 30625200,0.2547982; 30628800,0.0809014; 30632400,0.1083039;
        30636000,0.1202103; 30639600,0.1242559; 30643200,0.2902189; 30646800,
        0.3704046; 30650400,0.1495071; 30654000,0.0511224; 30657600,0.0552887;
        30661200,0.1050254; 30664800,0.1528969; 30668400,0.1277382; 30672000,
        0.1089799; 30675600,0.1315011; 30679200,0.1152406; 30682800,0.1758484;
        30686400,0.1569172; 30690000,0.0626242; 30693600,0.0650491; 30697200,
        0.0483412; 30700800,0.0936765; 30704400,0.2009617; 30708000,0.3114337;
        30711600,0.2479259; 30715200,0.1233755; 30718800,0.137892; 30722400,
        0.1030125; 30726000,0.1129005; 30729600,0.1174233; 30733200,0.0957968;
        30736800,0.0447109; 30740400,0.0132595; 30744000,0.0102404; 30747600,
        0.0109025; 30751200,0.0144033; 30754800,0.0240658; 30758400,0.0272223;
        30762000,0.0484489; 30765600,0.0640208; 30769200,0.0560763; 30772800,
        0.0565742; 30776400,0.0564056; 30780000,0.0330137; 30783600,0.0073789;
        30787200,0.039415; 30790800,0.1224999; 30794400,0.2014398; 30798000,
        0.1542789; 30801600,0.1002813; 30805200,0.1129258; 30808800,0.1166468;
        30812400,0.1313271; 30816000,0.139482; 30819600,0.1022809; 30823200,
        0.0376112; 30826800,0.0331081; 30830400,0.0206514; 30834000,0.0309454;
        30837600,0.066753; 30841200,0.0708793; 30844800,0.0716257; 30848400,
        0.1217362; 30852000,0.1100222; 30855600,0.1053748; 30859200,0.1030493;
        30862800,0.0382398; 30866400,0.0393615; 30870000,0.0109649; 30873600,
        0.012204; 30877200,0.0405403; 30880800,0.032632; 30884400,0.0194793;
        30888000,0.0284319; 30891600,0.0150581; 30895200,0.0255803; 30898800,
        0.0406262; 30902400,0.05072; 30906000,0.021999; 30909600,0.0045264;
        30913200,0.0058387; 30916800,0.0006545; 30920400,0.0001002; 30924000,
        0.0009429; 30927600,0.0064215; 30931200,0.0012611; 30934800,0.0121231;
        30938400,0.0282956; 30942000,0.0218795; 30945600,0.0354323; 30949200,
        0.0435223; 30952800,0.0315941; 30956400,0.0099754; 30960000,0.0134717;
        30963600,0.0247878; 30967200,0.0275547; 30970800,0.0296967; 30974400,
        0.0244652; 30978000,0.0395271; 30981600,0.0621069; 30985200,0.0488321;
        30988800,0.0441399; 30992400,0.0784607; 30996000,0.0719594; 30999600,
        0.0290267; 31003200,0.0111735; 31006800,0.0042352; 31010400,0.0043666;
        31014000,0.0190999; 31017600,0.0261776; 31021200,0.0175904; 31024800,
        0.0320224; 31028400,0.0434516; 31032000,0.0325083; 31035600,0.0350306;
        31039200,0.0225455; 31042800,0.022746; 31046400,0.0556564; 31050000,
        0.0201698; 31053600,0.0051411; 31057200,0.0134862; 31060800,0.0139707;
        31064400,0.0182519; 31068000,0.0228251; 31071600,0.015109; 31075200,
        0.029622; 31078800,0.0463901; 31082400,0.0374145; 31086000,0.0347962;
        31089600,0.0233894; 31093200,0.0003988; 31096800,0.0066596; 31100400,
        0.0288218; 31104000,0.0178518; 31107600,0.0119702; 31111200,0.0257604;
        31114800,0.0321058; 31118400,0.0207166; 31122000,0.0180414; 31125600,
        0.0250872; 31129200,0.003783; 31132800,0.0065242; 31136400,0.0422876;
        31140000,0.0914736; 31143600,0.09396; 31147200,0.0363779; 31150800,
        0.0300334; 31154400,0.0470663; 31158000,0.05016; 31161600,0.0291113;
        31165200,0.0231669; 31168800,0.008674; 31172400,0.0045294; 31176000,
        0.0024182; 31179600,0.0013886; 31183200,6.2e-06; 31186800,0.0022051;
        31190400,0.0104004; 31194000,0.0170745; 31197600,0.0200255; 31201200,
        0.0337098; 31204800,0.0454441; 31208400,0.019052; 31212000,0.0226467;
        31215600,0.0086467; 31219200,0.0067335; 31222800,0.0351707; 31226400,
        0.097435; 31230000,0.0607208; 31233600,0.0419084; 31237200,0.0399619;
        31240800,0.0391229; 31244400,0.0376683; 31248000,0.0654384; 31251600,
        0.0425531; 31255200,0.0146355; 31258800,0.0119997; 31262400,0.0048618;
        31266000,0.0054932; 31269600,0.0081003; 31273200,0.0118037; 31276800,
        0.0099312; 31280400,0.0159368; 31284000,0.0241599; 31287600,0.0314393;
        31291200,0.0322755; 31294800,0.035343; 31298400,0.0150397; 31302000,
        0.0017878; 31305600,0.0020116; 31309200,0.0164104; 31312800,0.0443659;
        31316400,0.0357891; 31320000,0.0474589; 31323600,0.0526618; 31327200,
        0.033256; 31330800,0.0302421; 31334400,0.0415019; 31338000,0.0236794;
        31341600,0.0127788; 31345200,0.0047697; 31348800,0.0033501; 31352400,
        0.0049757; 31356000,0.0082637; 31359600,0.0189556; 31363200,0.014228;
        31366800,0.0286777; 31370400,0.0378155; 31374000,0.0286623; 31377600,
        0.0354395; 31381200,0.039084; 31384800,0.0153575; 31388400,0.0064696;
        31392000,0.0184349; 31395600,0.0412167; 31399200,0.0922188; 31402800,
        0.1010199; 31406400,0.0112948; 31410000,0.0160216; 31413600,0.0333163;
        31417200,0.0215236; 31420800,0.0405886; 31424400,0.0412615; 31428000,
        0.015511; 31431600,0.0071309; 31435200,0.0059549; 31438800,0.0044345;
        31442400,0.0120981; 31446000,0.0248388; 31449600,0.0099746; 31453200,
        0.0186291; 31456800,0.0461565; 31460400,0.0265303; 31464000,0.0245737;
        31467600,0.0337207; 31471200,0.009179; 31474800,0.0037343; 31478400,
        0.0137407; 31482000,0.0491053; 31485600,0.143228; 31489200,0.084681;
        31492800,0.0111154; 31496400,0.0138524; 31500000,0.0187675; 31503600,
        0.0281959; 31507200,0.0684773; 31510800,0.0906616; 31514400,0.0504801;
        31518000,0.0320211; 31521600,0.027868; 31525200,0.0444118; 31528800,
        0.0646096; 31532400,0.0867749; 31536000,0.0816365], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
    annotation (Placement(transformation(extent={{50,178},{70,198}})));
  Modelica.Blocks.Sources.CombiTimeTable combiTimeTable_DHW_Mass_Flow(table=[0,
        0.005872979; 3600,0.001053612; 7200,1e-06; 10800,0.006134523; 14400,
        0.002927484; 18000,0.002581762; 21600,0.002380906; 25200,0.006999025;
        28800,0.010303555; 32400,0.00411226; 36000,0.003300223; 39600,
        0.005977518; 43200,0.00344509; 46800,0.002924352; 50400,0.00844691;
        54000,0.00676254; 57600,0.00353201; 61200,0.004489305; 64800,
        0.003131864; 68400,0.002763432; 72000,0.008065167; 75600,0.014710638;
        79200,0.007893284; 82800,0.003972092; 86400,0.006085973; 90000,
        0.001088459; 93600,1e-06; 97200,0.006136872; 100800,0.002926701; 104400,
        0.002571973; 108000,0.002373858; 111600,0.007048358; 115200,0.010753033;
        118800,0.00417099; 122400,0.003307662; 126000,0.006015888; 129600,
        0.003448613; 133200,0.002931791; 136800,0.00838544; 140400,0.006786423;
        144000,0.003528877; 147600,0.004482258; 151200,0.003147917; 154800,
        0.002771655; 158400,0.008077696; 162000,0.01470594; 165600,0.007890152;
        169200,0.003970917; 172800,0.00608284; 176400,0.001088459; 180000,1e-06;
        183600,0.006064047; 187200,0.002917305; 190800,0.00256845; 194400,
        0.002371901; 198000,0.006960263; 201600,0.010725235; 205200,0.004168249;
        208800,0.003301789; 212400,0.006004925; 216000,0.003433344; 219600,
        0.002922394; 223200,0.008352551; 226800,0.00678564; 230400,0.003525745;
        234000,0.004476385; 237600,0.003145176; 241200,0.002769305; 244800,
        0.00806869; 248400,0.014694194; 252000,0.007887411; 255600,0.003968959;
        259200,0.006079708; 262800,0.001086893; 266400,1e-06; 270000,
        0.006063264; 273600,0.002913781; 277200,0.002565709; 280800,0.002371901;
        284400,0.007007639; 288000,0.010253047; 291600,0.004104429; 295200,
        0.003297091; 298800,0.00596264; 302400,0.003442349; 306000,0.002932966;
        309600,0.008474709; 313200,0.006767238; 316800,0.003533576; 320400,
        0.004405126; 324000,0.003146742; 327600,0.002775962; 331200,0.008141124;
        334800,0.01473413; 338400,0.0078463; 342000,0.003919626; 345600,
        0.006060523; 349200,0.001084935; 352800,1e-06; 356400,0.006142745;
        360000,0.002909082; 363600,0.002556704; 367200,0.002366028; 370800,
        0.006996284; 374400,0.011313316; 378000,0.004323687; 381600,0.003317842;
        385200,0.005842831; 388800,0.003437259; 392400,0.002939622; 396000,
        0.00861292; 399600,0.006672096; 403200,0.003535142; 406800,0.004497527;
        410400,0.003117377; 414000,0.002764216; 417600,0.008074563; 421200,
        0.014833971; 424800,0.007916384; 428400,0.003980705; 432000,0.006100068;
        435600,0.001087676; 439200,1e-06; 442800,0.006083232; 446400,
        0.002893421; 450000,0.002566492; 453600,0.002373075; 457200,0.007047967;
        460800,0.010835255; 464400,0.004189; 468000,0.003313535; 471600,
        0.005651372; 475200,0.003421598; 478800,0.00292905; 482400,0.008657946;
        486000,0.006182681; 489600,0.00352183; 493200,0.004528458; 496800,
        0.003152224; 500400,0.002775178; 504000,0.008189674; 507600,0.014762321;
        511200,0.00783103; 514800,0.003972483; 518400,0.006092237; 522000,
        0.001087676; 525600,1e-06; 529200,0.006066004; 532800,0.00289068;
        536400,0.002564534; 540000,0.002372684; 543600,0.007044443; 547200,
        0.010890461; 550800,0.004197222; 554400,0.003313143; 558000,0.006027634;
        561600,0.00340437; 565200,0.002920828; 568800,0.0083549; 572400,
        0.006796995; 576000,0.003529269; 579600,0.004481083; 583200,0.003110721;
        586800,0.002759126; 590400,0.008054595; 594000,0.014691845; 597600,
        0.007887803; 601200,0.003970134; 604800,0.006082057; 608400,0.001086501;
        612000,1e-06; 615600,0.00608519; 619200,0.002917696; 622800,0.002569233;
        626400,0.002371509; 630000,0.006975925; 633600,0.010321565; 637200,
        0.004060969; 640800,0.003282604; 644400,0.005961857; 648000,0.00340437;
        651600,0.002918088; 655200,0.008439471; 658800,0.006765672; 662400,
        0.003531227; 666000,0.004486956; 669600,0.003111896; 673200,0.0027603;
        676800,0.008062426; 680400,0.014799125; 684000,0.007909728; 687600,
        0.003939203; 691200,0.006073052; 694800,0.00108611; 698400,1e-06;
        702000,0.006138829; 705600,0.002912998; 709200,0.00257119; 712800,
        0.002374641; 716400,0.006989628; 720000,0.010293375; 723600,0.004110694;
        727200,0.003299831; 730800,0.005975561; 734400,0.003445481; 738000,
        0.002933749; 741600,0.008468053; 745200,0.006770762; 748800,0.003533967;
        752400,0.004491263; 756000,0.003151832; 759600,0.002774395; 763200,
        0.008085918; 766800,0.014719252; 770400,0.007894067; 774000,0.003972483;
        777600,0.006085973; 781200,0.001086893; 784800,1e-06; 788400,
        0.006067962; 792000,0.002891855; 795600,0.00256845; 799200,0.00237425;
        802800,0.007018993; 806400,0.011287083; 810000,0.004303328; 813600,
        0.003317059; 817200,0.006141962; 820800,0.003459968; 824400,0.002938839;
        828000,0.008442603; 831600,0.006781333; 835200,0.003533184; 838800,
        0.004489305; 842400,0.003151049; 846000,0.002774004; 849600,0.008085526;
        853200,0.014714554; 856800,0.007891718; 860400,0.003971309; 864000,
        0.006084406; 867600,0.001084543; 871200,1e-06; 874800,0.006138046;
        878400,0.00292631; 882000,0.002568058; 885600,0.002373467; 889200,
        0.007023692; 892800,0.010352105; 896400,0.004118916; 900000,0.003302572;
        903600,0.005988481; 907200,0.003448613; 910800,0.002934532; 914400,
        0.008461397; 918000,0.00677272; 921600,0.003533576; 925200,0.004490088;
        928800,0.003146742; 932400,0.002773612; 936000,0.008084743; 939600,
        0.014711813; 943200,0.007890935; 946800,0.003971309; 950400,0.006084015;
        954000,0.001085718; 957600,1e-06; 961200,0.006135697; 964800,
        0.002874628; 968400,0.002561402; 972000,0.002369943; 975600,0.006878433;
        979200,0.011076439; 982800,0.004162376; 986400,0.003292001; 990000,
        0.006040555; 993600,0.003408286; 997200,0.002918479; 1000800,
        0.008459831; 1004400,0.006756275; 1008000,0.003532793; 1011600,
        0.00449048; 1015200,0.003149875; 1018800,0.002773221; 1022400,
        0.008087092; 1026000,0.014713771; 1029600,0.007888194; 1033200,
        0.003923542; 1036800,0.006035856; 1040400,0.00108102; 1044000,1e-06;
        1047600,0.006076967; 1051200,0.002883241; 1054800,0.002559836; 1058400,
        0.002366419; 1062000,0.00700529; 1065600,0.010779658; 1069200,
        0.004177254; 1072800,0.003306096; 1076400,0.006012365; 1080000,
        0.003445481; 1083600,0.002927876; 1087200,0.008675565; 1090800,
        0.005932884; 1094400,0.003517915; 1098000,0.004514755; 1101600,
        0.003156531; 1105200,0.002778311; 1108800,0.008187325; 1112400,
        0.014761146; 1116000,0.007829856; 1119600,0.003947034; 1123200,
        0.00607775; 1126800,0.00108611; 1130400,1e-06; 1134000,0.006091846;
        1137600,0.002920045; 1141200,0.002570799; 1144800,0.002373858; 1148400,
        0.007008422; 1152000,0.011180978; 1155600,0.004175297; 1159200,
        0.003306096; 1162800,0.006081666; 1166400,0.003456444; 1170000,
        0.002941971; 1173600,0.008503291; 1177200,0.006778984; 1180800,
        0.003539057; 1184400,0.004499094; 1188000,0.003155747; 1191600,
        0.002777528; 1195200,0.008099621; 1198800,0.014827315; 1202400,
        0.0079203; 1206000,0.00398188; 1209600,0.006102025; 1213200,0.001085718;
        1216800,1e-06; 1220400,0.006147835; 1224000,0.002896162; 1227600,
        0.00257628; 1231200,0.002379731; 1234800,0.006999025; 1238400,
        0.01029729; 1242000,0.004059403; 1245600,0.003283387; 1249200,
        0.005956767; 1252800,0.003406719; 1256400,0.002915738; 1260000,
        0.008474709; 1263600,0.006020978; 1267200,0.003485809; 1270800,
        0.004484998; 1274400,0.003150266; 1278000,0.002761083; 1281600,
        0.008266022; 1285200,0.014945949; 1288800,0.007699867; 1292400,
        0.003976398; 1296000,0.005713626; 1299600,0.001057528; 1303200,1e-06;
        1306800,0.006079317; 1310400,0.00290086; 1314000,0.002577846; 1317600,
        0.002378165; 1321200,0.007003332; 1324800,0.010401046; 1328400,
        0.00410717; 1332000,0.003301397; 1335600,0.005992788; 1339200,
        0.003398106; 1342800,0.002916521; 1346400,0.008448085; 1350000,
        0.006765281; 1353600,0.003535533; 1357200,0.004495178; 1360800,
        0.003121684; 1364400,0.002763824; 1368000,0.008072606; 1371600,
        0.014716511; 1375200,0.007893284; 1378800,0.003973266; 1382400,
        0.00608793; 1386000,0.001083369; 1389600,1e-06; 1393200,0.006100068;
        1396800,0.002920828; 1400400,0.002580196; 1404000,0.002380906; 1407600,
        0.007001374; 1411200,0.010330179; 1414800,0.004114218; 1418400,
        0.003300614; 1422000,0.005983783; 1425600,0.003432561; 1429200,
        0.002927484; 1432800,0.008449651; 1436400,0.006766847; 1440000,
        0.003532401; 1443600,0.004488914; 1447200,0.003148308; 1450800,
        0.002773612; 1454400,0.008087092; 1458000,0.014713379; 1461600,
        0.007891326; 1465200,0.003970917; 1468800,0.006083623; 1472400,
        0.001081803; 1476000,1e-06; 1479600,0.00608519; 1483200,0.002916521;
        1486800,0.002573931; 1490400,0.002373858; 1494000,0.006856507; 1497600,
        0.011006355; 1501200,0.004223064; 1504800,0.003287302; 1508400,
        0.006115729; 1512000,0.003438825; 1515600,0.002925918; 1519200,
        0.008383091; 1522800,0.006769196; 1526400,0.003524962; 1530000,
        0.004476385; 1533600,0.003142435; 1537200,0.002768914; 1540800,
        0.008071431; 1544400,0.014694194; 1548000,0.007886628; 1551600,
        0.003968568; 1555200,0.006079317; 1558800,0.001081411; 1562400,1e-06;
        1566000,0.006093803; 1569600,0.002916913; 1573200,0.002567275; 1576800,
        0.002371901; 1580400,0.007019385; 1584000,0.010571363; 1587600,
        0.004147889; 1591200,0.003301006; 1594800,0.005998661; 1598400,
        0.003446264; 1602000,0.002930225; 1605600,0.008400709; 1609200,
        0.00677272; 1612800,0.003527703; 1616400,0.004481475; 1620000,
        0.00311033; 1623600,0.002759126; 1627200,0.008053421; 1630800,
        0.014697326; 1634400,0.007890152; 1638000,0.003970917; 1641600,
        0.006083232; 1645200,0.001081411; 1648800,1e-06; 1652400,0.0061032;
        1656000,0.002920828; 1659600,0.002568841; 1663200,0.002371509; 1666800,
        0.006988845; 1670400,0.011076439; 1674000,0.004177646; 1677600,
        0.003280646; 1681200,0.005940714; 1684800,0.003408677; 1688400,
        0.00292122; 1692000,0.008513471; 1695600,0.006735524; 1699200,
        0.00350656; 1702800,0.004474427; 1706400,0.00311033; 1710000,0.00275012;
        1713600,0.008029537; 1717200,0.014779548; 1720800,0.007910903; 1724400,
        0.003954864; 1728000,0.005878069; 1731600,0.001052046; 1735200,1e-06;
        1738800,0.006105941; 1742400,0.002920828; 1746000,0.002571582; 1749600,
        0.00237425; 1753200,0.006987671; 1756800,0.010366591; 1760400,
        0.004125964; 1764000,0.003295524; 1767600,0.00573007; 1771200,
        0.003383228; 1774800,0.002902818; 1778400,0.008562412; 1782000,
        0.006636075; 1785600,0.003531227; 1789200,0.004493612; 1792800,
        0.003151832; 1796400,0.002759909; 1800000,0.008061251; 1803600,
        0.014820267; 1807200,0.007111003; 1810800,0.003942335; 1814400,
        0.00594737; 1818000,0.001079454; 1821600,1e-06; 1825200,0.006105158;
        1828800,0.002905559; 1832400,0.002562577; 1836000,0.002368377; 1839600,
        0.006854941; 1843200,0.009960573; 1846800,0.004014377; 1850400,
        0.003247758; 1854000,0.005946196; 1857600,0.003383619; 1861200,
        0.002898511; 1864800,0.008313789; 1868400,0.00678055; 1872000,
        0.003523004; 1875600,0.004472469; 1879200,0.003142044; 1882800,
        0.002766565; 1886400,0.008230002; 1890000,0.0147725; 1893600,
        0.008065167; 1897200,0.003954081; 1900800,0.006053867; 1904400,
        0.001081803; 1908000,1e-06; 1911600,0.006103592; 1915200,0.002890289;
        1918800,0.00256336; 1922400,0.002368768; 1926000,0.006974359; 1929600,
        0.010314518; 1933200,0.004113435; 1936800,0.003295916; 1940400,
        0.005713234; 1944000,0.003339376; 1947600,0.00288794; 1951200,
        0.008578465; 1954800,0.006552679; 1958400,0.003515565; 1962000,
        0.004498311; 1965600,0.003156922; 1969200,0.002766956; 1972800,
        0.008189282; 1976400,0.014762712; 1980000,0.007982945; 1983600,
        0.003930589; 1987200,0.006057391; 1990800,0.00108102; 1994400,1e-06;
        1998000,0.006085973; 2001600,0.002907908; 2005200,0.002574714; 2008800,
        0.00237699; 2012400,0.006990803; 2016000,0.009948435; 2019600,
        0.003998716; 2023200,0.003261853; 2026800,0.005824429; 2030400,
        0.003384011; 2034000,0.002916521; 2037600,0.008614094; 2041200,
        0.006480245; 2044800,0.003532793; 2048400,0.004506924; 2052000,
        0.003113854; 2055600,0.002764216; 2059200,0.008213166; 2062800,
        0.014845325; 2066400,0.007765645; 2070000,0.003927065; 2073600,
        0.006089496; 2077200,0.001088459; 2080800,1e-06; 2084400,0.006162713;
        2088000,0.002887157; 2091600,0.002566492; 2095200,0.002372292; 2098800,
        0.006981798; 2102400,0.009986805; 2106000,0.004052356; 2109600,
        0.003291218; 2113200,0.005980259; 2116800,0.003448222; 2120400,
        0.002934532; 2124000,0.008460222; 2127600,0.006777026; 2131200,
        0.00353475; 2134800,0.004492438; 2138400,0.003152615; 2142000,
        0.002775178; 2145600,0.008089833; 2149200,0.014720035; 2152800,
        0.007893284; 2156400,0.003972092; 2160000,0.006085581; 2163600,
        0.001082586; 2167200,1e-06; 2170800,0.006086364; 2174400,0.002920437;
        2178000,0.002574323; 2181600,0.002373858; 2185200,0.006961438; 2188800,
        0.010746377; 2192400,0.004172164; 2196000,0.003302572; 2199600,
        0.006006492; 2203200,0.003434518; 2206800,0.002923961; 2210400,
        0.008349419; 2214000,0.006787989; 2217600,0.003526137; 2221200,
        0.004424703; 2224800,0.003107981; 2228400,0.002740332; 2232000,
        0.008169314; 2235600,0.014785029; 2239200,0.007392906; 2242800,
        0.003963478; 2246400,0.00595755; 2250000,0.001081803; 2253600,1e-06;
        2257200,0.006094195; 2260800,0.002918871; 2264400,0.002570799; 2268000,
        0.002371901; 2271600,0.007020951; 2275200,0.011262808; 2278800,
        0.004271614; 2282400,0.003314709; 2286000,0.006165845; 2289600,
        0.003450571; 2293200,0.002930617; 2296800,0.008425768; 2300400,
        0.006780159; 2304000,0.003532793; 2307600,0.004488914; 2311200,
        0.003151441; 2314800,0.002768131; 2318400,0.008069082; 2322000,
        0.014719252; 2325600,0.007896025; 2329200,0.003973658; 2332800,
        0.00608793; 2336400,0.00108376; 2340000,1e-06; 2343600,0.006119644;
        2347200,0.002909474; 2350800,0.002560619; 2354400,0.002368377; 2358000,
        0.006968486; 2361600,0.011059603; 2365200,0.004228937; 2368800,
        0.00330727; 2372400,0.00616976; 2376000,0.00340946; 2379600,0.002924744;
        2383200,0.008388963; 2386800,0.006780159; 2390400,0.003528877; 2394000,
        0.004482649; 2397600,0.003131081; 2401200,0.002755602; 2404800,
        0.008046765; 2408400,0.014704765; 2412000,0.007893284; 2415600,
        0.003963086; 2419200,0.006069137; 2422800,0.001080237; 2426400,1e-06;
        2430000,0.006104766; 2433600,0.002918088; 2437200,0.00257628; 2440800,
        0.00237699; 2444400,0.006989237; 2448000,0.010319216; 2451600,
        0.004113826; 2455200,0.00329944; 2458800,0.005979867; 2462400,
        0.003427079; 2466000,0.002923961; 2469600,0.008442603; 2473200,
        0.006763714; 2476800,0.003531618; 2480400,0.004487739; 2484000,
        0.003133039; 2487600,0.002764607; 2491200,0.008062034; 2494800,
        0.014699284; 2498400,0.007888977; 2502000,0.003970917; 2505600,
        0.006083232; 2509200,0.00108102; 2512800,1e-06; 2516400,0.006145094;
        2520000,0.002873453; 2523600,0.002566883; 2527200,0.002371901; 2530800,
        0.006873343; 2534400,0.010033789; 2538000,0.004080154; 2541600,
        0.003292001; 2545200,0.005899603; 2548800,0.003384794; 2552400,
        0.002918871; 2556000,0.008482148; 2559600,0.006739439; 2563200,
        0.00353201; 2566800,0.004490088; 2570400,0.003125208; 2574000,
        0.002758343; 2577600,0.00811959; 2581200,0.014793643; 2584800,
        0.00797668; 2588400,0.003976007; 2592000,0.006078533; 2595600,
        0.001081803; 2599200,1e-06; 2602800,0.006159189; 2606400,0.002928659;
        2610000,0.002571582; 2613600,0.00237425; 2617200,0.006987671; 2620800,
        0.010314909; 2624400,0.004095424; 2628000,0.003292392; 2631600,
        0.005972037; 2635200,0.003427079; 2638800,0.00291613; 2642400,
        0.008440646; 2646000,0.006759799; 2649600,0.003532793; 2653200,
        0.00449048; 2656800,0.003131864; 2660400,0.002763824; 2664000,
        0.00806869; 2667600,0.014708289; 2671200,0.007891326; 2674800,0.0039717;
        2678400,0.00608519; 2682000,0.001082194; 2685600,1e-06; 2689200,
        0.006227707; 2692800,0.002919654; 2696400,0.00257628; 2700000,
        0.002376599; 2703600,0.006911713; 2707200,0.010948799; 2710800,
        0.004133011; 2714400,0.003288868; 2718000,0.006075793; 2721600,
        0.003448613; 2725200,0.002932574; 2728800,0.008446519; 2732400,
        0.006769979; 2736000,0.003531227; 2739600,0.004486956; 2743200,
        0.003130298; 2746800,0.002762258; 2750400,0.00806086; 2754000,
        0.014706723; 2757600,0.007892501; 2761200,0.0039717; 2764800,
        0.006084798; 2768400,0.001082586; 2772000,1e-06; 2775600,0.006090671;
        2779200,0.002917305; 2782800,0.002577063; 2786400,0.002376207; 2790000,
        0.006986496; 2793600,0.010352888; 2797200,0.00409425; 2800800,
        0.003275556; 2804400,0.00595755; 2808000,0.003442349; 2811600,0.0029314;
        2815200,0.008456699; 2818800,0.006772328; 2822400,0.003530835; 2826000,
        0.0044803; 2829600,0.003121293; 2833200,0.002761475; 2836800,
        0.008071431; 2840400,0.014706331; 2844000,0.007890935; 2847600,
        0.003967785; 2851200,0.00607266; 2854800,0.001082977; 2858400,1e-06;
        2862000,0.006076967; 2865600,0.002871887; 2869200,0.002557487; 2872800,
        0.002362504; 2876400,0.006960655; 2880000,0.010062763; 2883600,
        0.004050006; 2887200,0.003288868; 2890800,0.005800546; 2894400,
        0.003363259; 2898000,0.002894204; 2901600,0.008476667; 2905200,
        0.006731609; 2908800,0.003535533; 2912400,0.004497919; 2916000,
        0.003155356; 2919600,0.002773221; 2923200,0.008217473; 2926800,
        0.01477485; 2930400,0.007771518; 2934000,0.003940378; 2937600,
        0.006091454; 2941200,0.001081803; 2944800,1e-06; 2948400,0.006101242;
        2952000,0.002903601; 2955600,0.002562577; 2959200,0.002368768; 2962800,
        0.006939904; 2966400,0.010836038; 2970000,0.004187043; 2973600,
        0.003298657; 2977200,0.005772747; 2980800,0.003360127; 2984400,
        0.002891072; 2988000,0.008116066; 2991600,0.006821661; 2995200,
        0.003489333; 2998800,0.004446628; 3002400,0.003113071; 3006000,
        0.002751295; 3009600,0.008036193; 3013200,0.014672268; 3016800,
        0.006905449; 3020400,0.003897701; 3024000,0.006035465; 3027600,
        0.001079845; 3031200,1e-06; 3034800,0.006091846; 3038400,0.002912606;
        3042000,0.002564143; 3045600,0.002367985; 3049200,0.006966136; 3052800,
        0.010309036; 3056400,0.004111477; 3060000,0.003298265; 3063600,
        0.005979084; 3067200,0.003441174; 3070800,0.00290595; 3074400,
        0.008412455; 3078000,0.006751968; 3081600,0.003528877; 3085200,
        0.004460723; 3088800,0.003086055; 3092400,0.002753253; 3096000,
        0.008058511; 3099600,0.014696152; 3103200,0.007888194; 3106800,
        0.003960737; 3110400,0.006053475; 3114000,0.001082586; 3117600,1e-06;
        3121200,0.006100068; 3124800,0.002893421; 3128400,0.002564926; 3132000,
        0.002370334; 3135600,0.006970052; 3139200,0.010310211; 3142800,
        0.00411226; 3146400,0.003298657; 3150000,0.005979867; 3153600,
        0.003432561; 3157200,0.002927876; 3160800,0.008471968; 3164400,
        0.006030375; 3168000,0.003513608; 3171600,0.004417263; 3175200,
        0.003131081; 3178800,0.002764216; 3182400,0.008337281; 3186000,
        0.014888785; 3189600,0.007755856; 3193200,0.003974441; 3196800,
        0.006107898; 3200400,0.001088067; 3204000,1e-06; 3207600,0.006160755;
        3211200,0.002928659; 3214800,0.00258137; 3218400,0.002380514; 3222000,
        0.007042094; 3225600,0.010323131; 3229200,0.004064493; 3232800,
        0.003285736; 3236400,0.005960682; 3240000,0.003423164; 3243600,
        0.002923961; 3247200,0.008453566; 3250800,0.006765672; 3254400,
        0.003533967; 3258000,0.004491654; 3261600,0.003152224; 3265200,
        0.002774787; 3268800,0.008088658; 3272400,0.014718077; 3276000,
        0.007892893; 3279600,0.003964261; 3283200,0.005838916; 3286800,
        0.001054396; 3290400,1e-06; 3294000,0.006125126; 3297600,0.002904384;
        3301200,0.002573148; 3304800,0.002373858; 3308400,0.006914454; 3312000,
        0.010926874; 3315600,0.004203487; 3319200,0.003293958; 3322800,
        0.006146269; 3326400,0.003439217; 3330000,0.002914955; 3333600,
        0.008350202; 3337200,0.006775069; 3340800,0.003522613; 3344400,
        0.004469729; 3348000,0.003143218; 3351600,0.002768522; 3355200,
        0.008067516; 3358800,0.014693019; 3362400,0.007887803; 3366000,
        0.003969351; 3369600,0.006080491; 3373200,0.001081411; 3376800,1e-06;
        3380400,0.006082057; 3384000,0.002899686; 3387600,0.002573539; 3391200,
        0.002375816; 3394800,0.006982581; 3398400,0.010130889; 3402000,
        0.004094641; 3405600,0.003291609; 3409200,0.005936016; 3412800,
        0.003435301; 3416400,0.002931791; 3420000,0.008488021; 3423600,
        0.006757841; 3427200,0.003531618; 3430800,0.004482649; 3434400,
        0.003147134; 3438000,0.002758343; 3441600,0.00805068; 3445200,
        0.014692236; 3448800,0.007887411; 3452400,0.003970134; 3456000,
        0.006082449; 3459600,0.001082194; 3463200,1e-06; 3466800,0.006090279;
        3470400,0.002916913; 3474000,0.002573539; 3477600,0.002374641; 3481200,
        0.006982189; 3484800,0.010336052; 3488400,0.004116958; 3492000,
        0.003301789; 3495600,0.005985349; 3499200,0.003436084; 3502800,
        0.002914955; 3506400,0.008426942; 3510000,0.00675745; 3513600,
        0.003529269; 3517200,0.004481475; 3520800,0.003147525; 3524400,
        0.002771655; 3528000,0.008101971; 3531600,0.014736088; 3535200,
        0.00792813; 3538800,0.003954473; 3542400,0.006073444; 3546000,
        0.001079845; 3549600,1e-06; 3553200,0.006091454; 3556800,0.002913781;
        3560400,0.002575889; 3564000,0.002376599; 3567600,0.006986105; 3571200,
        0.010333703; 3574800,0.004076239; 3578400,0.003291609; 3582000,
        0.006071877; 3585600,0.003443523; 3589200,0.002936098; 3592800,
        0.008501333; 3596400,0.006010407; 3600000,0.003504602; 3603600,
        0.00454921; 3607200,0.003136954; 3610800,0.002764216; 3614400,
        0.008074955; 3618000,0.014714162; 3621600,0.006810307; 3625200,
        0.00394351; 3628800,0.005910175; 3632400,0.001063009; 3636000,1e-06;
        3639600,0.006096544; 3643200,0.002920045; 3646800,0.002575106; 3650400,
        0.002373467; 3654000,0.006852984; 3657600,0.011010661; 3661200,
        0.004209751; 3664800,0.003291609; 3668400,0.006128258; 3672000,
        0.003400846; 3675600,0.002900077; 3679200,0.008388572; 3682800,0.006732;
        3686400,0.003491682; 3690000,0.004458374; 3693600,0.003142435; 3697200,
        0.002770089; 3700800,0.00816305; 3704400,0.01473139; 3708000,
        0.007787962; 3711600,0.003918843; 3715200,0.005909; 3718800,0.001053612;
        3722400,1e-06; 3726000,0.006057391; 3729600,0.002875019; 3733200,
        0.00256101; 3736800,0.002366028; 3740400,0.006833016; 3744000,
        0.010992651; 3747600,0.004221106; 3751200,0.003293567; 3754800,
        0.006121994; 3758400,0.003441566; 3762000,0.00292631; 3765600,
        0.008383091; 3769200,0.006766847; 3772800,0.003523396; 3776400,
        0.004417655; 3780000,0.003115028; 3783600,0.002753253; 3787200,
        0.008149737; 3790800,0.014771326; 3794400,0.007001374; 3798000,
        0.003956039; 3801600,0.005854577; 3805200,0.001050872; 3808800,1e-06;
        3812400,0.006144702; 3816000,0.002901252; 3819600,0.002571973; 3823200,
        0.002371901; 3826800,0.006976316; 3830400,0.010492273; 3834000,
        0.004109128; 3837600,0.00327908; 3841200,0.005973994; 3844800,
        0.003375005; 3848400,0.002890289; 3852000,0.008735078; 3855600,
        0.005979867; 3859200,0.003539057; 3862800,0.004549601; 3866400,
        0.003148308; 3870000,0.002752078; 3873600,0.008284424; 3877200,
        0.014829272; 3880800,0.007586323; 3884400,0.003921584; 3888000,
        0.006043296; 3891600,0.001042258; 3895200,1e-06; 3898800,0.00607775;
        3902400,0.002875802; 3906000,0.002550048; 3909600,0.002359763; 3913200,
        0.006952824; 3916800,0.010356803; 3920400,0.004120091; 3924000,
        0.003288085; 3927600,0.005970862; 3931200,0.003440391; 3934800,
        0.002907125; 3938400,0.008622317; 3942000,0.006324416; 3945600,
        0.003523788; 3949200,0.004464639; 3952800,0.003142044; 3956400,
        0.002777528; 3960000,0.008245663; 3963600,0.014783463; 3967200,
        0.007397605; 3970800,0.003961912; 3974400,0.005956767; 3978000,
        0.001080628; 3981600,1e-06; 3985200,0.006183464; 3988800,0.002917305;
        3992400,0.002566492; 3996000,0.002370726; 3999600,0.006966136; 4003200,
        0.010514982; 4006800,0.004107953; 4010400,0.00329435; 4014000,
        0.006063264; 4017600,0.003420815; 4021200,0.00292122; 4024800,
        0.008241747; 4028400,0.00684437; 4032000,0.00351165; 4035600,
        0.004459549; 4039200,0.003131081; 4042800,0.00275012; 4046400,
        0.008268372; 4050000,0.014817918; 4053600,0.007638397; 4057200,
        0.003923542; 4060800,0.006049169; 4064400,0.001077104; 4068000,1e-06;
        4071600,0.006091063; 4075200,0.002920045; 4078800,0.002570407; 4082400,
        0.00237425; 4086000,0.006988062; 4089600,0.010327047; 4093200,
        0.004116175; 4096800,0.003300614; 4100400,0.005977518; 4104000,
        0.003384794; 4107600,0.002916913; 4111200,0.008479799; 4114800,
        0.005771964; 4118400,0.003519089; 4122000,0.004504184; 4125600,
        0.003113462; 4129200,0.002749337; 4132800,0.008201811; 4136400,
        0.014768194; 4140000,0.007467689; 4143600,0.003954864; 4147200,
        0.005934058; 4150800,0.001082194; 4154400,1e-06; 4158000,0.006084406;
        4161600,0.002920437; 4165200,0.002578629; 4168800,0.00237934; 4172400,
        0.006991978; 4176000,0.010356412; 4179600,0.004105996; 4183200,
        0.003267726; 4186800,0.005952852; 4190400,0.003441174; 4194000,
        0.002924352; 4197600,0.008432815; 4201200,0.006762148; 4204800,
        0.00353201; 4208400,0.004489305; 4212000,0.003113071; 4215600,
        0.002740724; 4219200,0.008072997; 4222800,0.014774458; 4226400,
        0.007750375; 4230000,0.003971309; 4233600,0.006098502; 4237200,
        0.001086501; 4240800,1e-06; 4244400,0.006173284; 4248000,0.002914564;
        4251600,0.002577846; 4255200,0.002378557; 4258800,0.006991586; 4262400,
        0.00991398; 4266000,0.004066059; 4269600,0.00329435; 4273200,
        0.006140396; 4276800,0.003426688; 4280400,0.002924352; 4284000,
        0.008400318; 4287600,0.00677272; 4291200,0.003528877; 4294800,
        0.004483041; 4298400,0.003145176; 4302000,0.002770872; 4305600,
        0.008079262; 4309200,0.014711421; 4312800,0.007892501; 4316400,
        0.0039717; 4320000,0.006084015; 4323600,0.001082977; 4327200,1e-06;
        4330800,0.006111031; 4334400,0.002897336; 4338000,0.002568841; 4341600,
        0.002373858; 4345200,0.006980623; 4348800,0.010315692; 4352400,
        0.004095424; 4356000,0.003288085; 4359600,0.005963423; 4363200,
        0.003393799; 4366800,0.002894596; 4370400,0.008644242; 4374000,
        0.005746906; 4377600,0.003512825; 4381200,0.004404343; 4384800,
        0.003100541; 4388400,0.002751687; 4392000,0.008036976; 4395600,
        0.014768585; 4399200,0.007916384; 4402800,0.003977573; 4406400,
        0.006094195; 4410000,0.001084543; 4413600,1e-06; 4417200,0.006111422;
        4420800,0.002924352; 4424400,0.002577063; 4428000,0.00237699; 4431600,
        0.006994718; 4435200,0.010161429; 4438800,0.004087202; 4442400,
        0.003293567; 4446000,0.005948936; 4449600,0.003439608; 4453200,
        0.002934532; 4456800,0.008498201; 4460400,0.006762931; 4464000,
        0.003535533; 4467600,0.004494004; 4471200,0.003153007; 4474800,
        0.002775178; 4478400,0.008088267; 4482000,0.014714945; 4485600,
        0.007891718; 4489200,0.0039717; 4492800,0.006107507; 4496400,
        0.001083369; 4500000,1e-06; 4503600,0.006100459; 4507200,0.002919654;
        4510800,0.002578629; 4514400,0.00237934; 4518000,0.006991978; 4521600,
        0.010321957; 4525200,0.004065276; 4528800,0.003284953; 4532400,
        0.005968905; 4536000,0.003443523; 4539600,0.0029314; 4543200,
        0.008673999; 4546800,0.006264511; 4550400,0.003525354; 4554000,
        0.004499485; 4557600,0.003113854; 4561200,0.002753644; 4564800,
        0.00788467; 4568400,0.014649168; 4572000,0.007951231; 4575600,
        0.003971309; 4579200,0.006080491; 4582800,0.001082977; 4586400,1e-06;
        4590000,0.006099676; 4593600,0.002918479; 4597200,0.002577846; 4600800,
        0.002378165; 4604400,0.006988062; 4608000,0.010373639; 4611600,
        0.004115001; 4615200,0.003300614; 4618800,0.006025677; 4622400,
        0.003444307; 4626000,0.002937664; 4629600,0.00852091; 4633200,
        0.006757058; 4636800,0.003537883; 4640400,0.004498311; 4644000,
        0.003151832; 4647600,0.002759909; 4651200,0.008064775; 4654800,
        0.014798733; 4658400,0.007894067; 4662000,0.003922367; 4665600,
        0.00606483; 4669200,0.001082977; 4672800,1e-06; 4676400,0.006101634;
        4680000,0.002908691; 4683600,0.002568841; 4687200,0.00237425; 4690800,
        0.007017427; 4694400,0.010152423; 4698000,0.004082112; 4701600,
        0.00328417; 4705200,0.005911349; 4708800,0.003435693; 4712400,
        0.002918479; 4716000,0.008608221; 4719600,0.005746514; 4723200,
        0.003479153; 4726800,0.004354227; 4730400,0.003113854; 4734000,
        0.002754819; 4737600,0.008037368; 4741200,0.014817135; 4744800,
        0.007933612; 4748400,0.003959563; 4752000,0.006110639; 4755600,
        0.001084543; 4759200,1e-06; 4762800,0.00611338; 4766400,0.002896162;
        4770000,0.002564143; 4773600,0.002372684; 4777200,0.006996676; 4780800,
        0.011085836; 4784400,0.004221889; 4788000,0.003306879; 4791600,
        0.006170935; 4795200,0.003444698; 4798800,0.002915347; 4802400,
        0.008188108; 4806000,0.006849851; 4809600,0.003528486; 4813200,
        0.004463856; 4816800,0.003109938; 4820400,0.002758734; 4824000,
        0.00783847; 4827600,0.014615888; 4831200,0.007960236; 4834800,
        0.003968176; 4838400,0.006070703; 4842000,0.001082194; 4845600,1e-06;
        4849200,0.006097327; 4852800,0.002918871; 4856400,0.002577063; 4860000,
        0.00237699; 4863600,0.007029173; 4867200,0.011142999; 4870800,
        0.004243423; 4874400,0.003313143; 4878000,0.005997095; 4881600,
        0.003399672; 4885200,0.002915347; 4888800,0.008691618; 4892400,
        0.006520573; 4896000,0.003498338; 4899600,0.004482649; 4903200,
        0.003113462; 4906800,0.002751295; 4910400,0.008282858; 4914000,
        0.014946732; 4917600,0.007830639; 4921200,0.0039717; 4924800,
        0.006116121; 4928400,0.001090808; 4932000,1e-06; 4935600,0.006100459;
        4939200,0.00292122; 4942800,0.002578238; 4946400,0.002380906; 4950000,
        0.007008813; 4953600,0.010377163; 4957200,0.004126355; 4960800,
        0.003295916; 4964400,0.005975169; 4968000,0.003414159; 4971600,
        0.002919654; 4975200,0.008448085; 4978800,0.006768413; 4982400,
        0.003507735; 4986000,0.004471686; 4989600,0.003146742; 4993200,
        0.002772046; 4996800,0.008084743; 5000400,0.014719252; 5004000,
        0.007894459; 5007600,0.003972875; 5011200,0.006086756; 5014800,
        0.001084543; 5018400,1e-06; 5022000,0.006106332; 5025600,0.002913781;
        5029200,0.002577063; 5032800,0.002377774; 5036400,0.007011163; 5040000,
        0.009989155; 5043600,0.004014377; 5047200,0.003280255; 5050800,
        0.006137655; 5054400,0.003422772; 5058000,0.002896553; 5061600,
        0.008617618; 5065200,0.006349474; 5068800,0.003526528; 5072400,
        0.004508099; 5076000,0.003113854; 5079600,0.002763432; 5083200,
        0.00825506; 5086800,0.014878214; 5090400,0.006962613; 5094000,
        0.003961912; 5097600,0.006060915; 5101200,0.001061052; 5104800,1e-06;
        5108400,0.006158798; 5112000,0.002922394; 5115600,0.002577455; 5119200,
        0.002376599; 5122800,0.006991978; 5126400,0.010294158; 5130000,
        0.004105212; 5133600,0.003295133; 5137200,0.005961857; 5140800,
        0.003391058; 5144400,0.002921611; 5148000,0.008455524; 5151600,
        0.006765672; 5155200,0.003533184; 5158800,0.004490871; 5162400,
        0.003151832; 5166000,0.002774395; 5169600,0.008087484; 5173200,
        0.014773283; 5176800,0.007910903; 5180400,0.003975224; 5184000,
        0.006085581; 5187600,0.001081803; 5191200,1e-06; 5194800,0.006098893;
        5198400,0.00291613; 5202000,0.002567667; 5205600,0.002373467; 5209200,
        0.006858857; 5212800,0.011071349; 5216400,0.004238333; 5220000,
        0.003304138; 5223600,0.006147443; 5227200,0.003454095; 5230800,
        0.002933749; 5234400,0.008402276; 5238000,0.00573516; 5241600,
        0.003499121; 5245200,0.004521019; 5248800,0.003147917; 5252400,
        0.002772829; 5256000,0.008096489; 5259600,0.014713771; 5263200,
        0.007885845; 5266800,0.003971309; 5270400,0.006084015; 5274000,
        0.001082194; 5277600,1e-06; 5281200,0.006091063; 5284800,0.002918479;
        5288400,0.002577846; 5292000,0.002377774; 5295600,0.006988454; 5299200,
        0.010320782; 5302800,0.004113826; 5306400,0.003299831; 5310000,
        0.005981825; 5313600,0.003428645; 5317200,0.002924744; 5320800,
        0.008443386; 5324400,0.006764497; 5328000,0.003531618; 5331600,
        0.004487739; 5335200,0.003127949; 5338800,0.002742681; 5342400,
        0.008024447; 5346000,0.014679707; 5349600,0.007885062; 5353200,
        0.003960737; 5356800,0.006065221; 5360400,0.001081803; 5364000,1e-06;
        5367600,0.006082449; 5371200,0.002916913; 5374800,0.002572756; 5378400,
        0.002373858; 5382000,0.006980232; 5385600,0.010316867; 5389200,
        0.0040919; 5392800,0.003288477; 5396400,0.005966947; 5400000,
        0.003420815; 5403600,0.002920828; 5407200,0.008437513; 5410800,
        0.006763323; 5414400,0.003531227; 5418000,0.004487348; 5421600,
        0.003148308; 5425200,0.002772438; 5428800,0.008083177; 5432400,
        0.014719252; 5436000,0.007895242; 5439600,0.003972483; 5443200,
        0.006085973; 5446800,0.00108376; 5450400,1e-06; 5454000,0.006102417;
        5457600,0.00291613; 5461200,0.00256845; 5464800,0.002371901; 5468400,
        0.006953607; 5472000,0.010457035; 5475600,0.004139276; 5479200,
        0.003306487; 5482800,0.006003359; 5486400,0.003446656; 5490000,
        0.002934532; 5493600,0.008450826; 5497200,0.006778593; 5500800,
        0.003533576; 5504400,0.00449048; 5508000,0.003147134; 5511600,
        0.002774004; 5515200,0.008086701; 5518800,0.014716903; 5522400,
        0.007892893; 5526000,0.003972092; 5529600,0.006085581; 5533200,
        0.001082977; 5536800,1e-06; 5540400,0.006080491; 5544000,0.002898119;
        5547600,0.00257119; 5551200,0.002375816; 5554800,0.006988062; 5558400,
        0.010032223; 5562000,0.004080937; 5565600,0.003297874; 5569200,
        0.005943846; 5572800,0.003395757; 5576400,0.00292905; 5580000,
        0.008240573; 5583600,0.006849851; 5587200,0.003501079; 5590800,
        0.004466205; 5594400,0.003131864; 5598000,0.002747771; 5601600,
        0.008068299; 5605200,0.014770151; 5608800,0.007899549; 5612400,
        0.003949774; 5616000,0.005909392; 5619600,0.001085718; 5623200,1e-06;
        5626800,0.0061032; 5630400,0.002922003; 5634000,0.002573931; 5637600,
        0.00237425; 5641200,0.007005681; 5644800,0.011079571; 5648400,
        0.004230111; 5652000,0.00330727; 5655600,0.006170543; 5659200,
        0.003453703; 5662800,0.002929442; 5666400,0.008379567; 5670000,
        0.006776635; 5673600,0.003502253; 5677200,0.00446229; 5680800,
        0.003142435; 5684400,0.002768522; 5688000,0.008072997; 5691600,
        0.014719252; 5695200,0.00710004; 5698800,0.003955256; 5702400,
        0.005993963; 5706000,0.001073189; 5709600,1e-06; 5713200,0.006131782;
        5716800,0.002893421; 5720400,0.002568058; 5724000,0.002372292; 5727600,
        0.006978665; 5731200,0.010004424; 5734800,0.004035128; 5738400,
        0.003276731; 5742000,0.005988481; 5745600,0.003395365; 5749200,
        0.002914955; 5752800,0.008642285; 5756400,0.005929751; 5760000,
        0.003515565; 5763600,0.004499485; 5767200,0.0031487; 5770800,0.00275521;
        5774400,0.008314181; 5778000,0.014876256; 5781600,0.007780131; 5785200,
        0.003974832; 5788800,0.006104766; 5792400,0.001087676; 5796000,1e-06;
        5799600,0.006096544; 5803200,0.002923961; 5806800,0.002579412; 5810400,
        0.00237699; 5814000,0.006863947; 5817600,0.011032979; 5821200,
        0.004231286; 5824800,0.003281038; 5828400,0.005782927; 5832000,
        0.003422772; 5835600,0.002927484; 5839200,0.008645808; 5842800,
        0.005715192; 5846400,0.003507343; 5850000,0.004476776; 5853600,
        0.003116594; 5857200,0.002744247; 5860800,0.008141124; 5864400,
        0.014724733; 5868000,0.007734322; 5871600,0.003910621; 5875200,
        0.00585262; 5878800,0.001066141; 5882400,1e-06; 5886000,0.006078142;
        5889600,0.002871887; 5893200,0.002565317; 5896800,0.002370334; 5900400,
        0.006939904; 5904000,0.010071376; 5907600,0.004087985; 5911200,
        0.00328417; 5914800,0.005776662; 5918400,0.003356603; 5922000,
        0.002912606; 5925600,0.008521693; 5929200,0.006709683; 5932800,
        0.003532401; 5936400,0.004534723; 5940000,0.003111504; 5943600,
        0.002745422; 5947200,0.008112933; 5950800,0.014864119; 5954400,
        0.006930899; 5958000,0.00396152; 5961600,0.006159581; 5965200,
        0.001090808; 5968800,1e-06; 5972400,0.006182681; 5976000,0.002910257;
        5979600,0.002572365; 5983200,0.002375033; 5986800,0.006891354; 5990400,
        0.009877176; 5994000,0.004064493; 5997600,0.003289651; 6001200,
        0.005945804; 6004800,0.003388709; 6008400,0.002920045; 6012000,
        0.008511905; 6015600,0.006732392; 6019200,0.003504994; 6022800,
        0.004379676; 6026400,0.003139695; 6030000,0.002772829; 6033600,
        0.008136425; 6037200,0.014733739; 6040800,0.00786157; 6044400,
        0.003947425; 6048000,0.006071877; 6051600,0.001084152; 6055200,1e-06;
        6058800,0.006074227; 6062400,0.002920437; 6066000,0.002577063; 6069600,
        0.002375033; 6073200,0.007026824; 6076800,0.010761647; 6080400,
        0.004114609; 6084000,0.003273207; 6087600,0.00609811; 6091200,
        0.003447047; 6094800,0.002910648; 6098400,0.008242531; 6102000,
        0.007024083; 6105600,0.00354493; 6109200,0.004484607; 6112800,
        0.003103282; 6116400,0.002739158; 6120000,0.008071823; 6123600,
        0.014891135; 6127200,0.007094167; 6130800,0.003890261; 6134400,
        0.005656854; 6138000,0.001053221; 6141600,1e-06; 6145200,0.006141962;
        6148800,0.002888723; 6152400,0.002564926; 6156000,0.002370726; 6159600,
        0.007012337; 6163200,0.01011836; 6166800,0.004107953; 6170400,
        0.003311577; 6174000,0.00598574; 6177600,0.003449005; 6181200,
        0.002936881; 6184800,0.00875857; 6188400,0.006145485; 6192000,
        0.00350656; 6195600,0.004556257; 6199200,0.003162012; 6202800,
        0.002786141; 6206400,0.008167356; 6210000,0.01478268; 6213600,
        0.007883104; 6217200,0.003954081; 6220800,0.006084015; 6224400,
        0.00108611; 6228000,1e-06; 6231600,0.006144702; 6235200,0.002914564;
        6238800,0.00257119; 6242400,0.002374641; 6246000,0.006987671; 6249600,
        0.010294158; 6253200,0.004089943; 6256800,0.003290043; 6260400,
        0.005734768; 6264000,0.003384794; 6267600,0.002890289; 6271200,
        0.008354509; 6274800,0.006755492; 6278400,0.003525354; 6282000,
        0.004355401; 6285600,0.003113854; 6289200,0.00275012; 6292800,
        0.007765645; 6296400,0.014579475; 6300000,0.007958278; 6303600,
        0.003912579; 6307200,0.00607266; 6310800,0.001082194; 6314400,1e-06;
        6318000,0.006135306; 6321600,0.002875019; 6325200,0.00255827; 6328800,
        0.002366811; 6332400,0.006856116; 6336000,0.011022799; 6339600,
        0.004189392; 6343200,0.0032689; 6346800,0.006037031; 6350400,
        0.003416899; 6354000,0.002920045; 6357600,0.008714718; 6361200,
        0.005771572; 6364800,0.003522613; 6368400,0.004488131; 6372000,
        0.003105631; 6375600,0.002751687; 6379200,0.0081607; 6382800,
        0.014794426; 6386400,0.007055014; 6390000,0.003904357; 6393600,
        0.005911349; 6397200,0.001077104; 6400800,1e-06; 6404400,0.006091454;
        6408000,0.00291613; 6411600,0.00257119; 6415200,0.00237699; 6418800,
        0.007061279; 6422400,0.01113556; 6426000,0.004241466; 6429600,
        0.003313926; 6433200,0.005797414; 6436800,0.003357778; 6440400,
        0.002916521; 6444000,0.008259366; 6447600,0.006843195; 6451200,
        0.00353201; 6454800,0.00453394; 6458400,0.00314361; 6462000,0.002755602;
        6465600,0.008019357; 6469200,0.014778373; 6472800,0.007934395; 6476400,
        0.003969351; 6480000,0.00607501; 6483600,0.001085327; 6487200,1e-06;
        6490800,0.006097327; 6494400,0.002915738; 6498000,0.002569624; 6501600,
        0.002371901; 6505200,0.006972009; 6508800,0.010213111; 6512400,
        0.004024165; 6516000,0.003264593; 6519600,0.006163104; 6523200,
        0.00342982; 6526800,0.002907908; 6530400,0.008164224; 6534000,
        0.006847111; 6537600,0.00352692; 6541200,0.004474036; 6544800,
        0.003098975; 6548400,0.002745422; 6552000,0.008156785; 6555600,
        0.014881738; 6559200,0.006941861; 6562800,0.003907489; 6566400,
        0.005935624; 6570000,0.001080628; 6573600,1e-06; 6577200,0.006155665;
        6580800,0.002875802; 6584400,0.002562577; 6588000,0.002370334; 6591600,
        0.006874518; 6595200,0.010251481; 6598800,0.004093858; 6602400,
        0.003267334; 6606000,0.005977518; 6609600,0.003411809; 6613200,
        0.002922003; 6616800,0.008501725; 6620400,0.006751968; 6624000,
        0.003536317; 6627600,0.004496353; 6631200,0.003119727; 6634800,
        0.00274738; 6638400,0.008230002; 6642000,0.014816743; 6645600,
        0.007838078; 6649200,0.003976007; 6652800,0.006098502; 6656400,
        0.001085718; 6660000,1e-06; 6663600,0.00616193; 6667200,0.002905559;
        6670800,0.00256845; 6674400,0.002372684; 6678000,0.006981015; 6681600,
        0.010285936; 6685200,0.004109911; 6688800,0.00329944; 6692400,
        0.005988873; 6696000,0.003389101; 6699600,0.002915738; 6703200,
        0.008386223; 6706800,0.00676763; 6710400,0.00352692; 6714000,
        0.004366364; 6717600,0.003109155; 6721200,0.002758343; 6724800,
        0.008253493; 6728400,0.014785812; 6732000,0.007919517; 6735600,
        0.003974832; 6739200,0.006084015; 6742800,0.001083369; 6746400,1e-06;
        6750000,0.006089105; 6753600,0.002917696; 6757200,0.002564534; 6760800,
        0.002369943; 6764400,0.006851418; 6768000,0.011016143; 6771600,
        0.004209751; 6775200,0.003293567; 6778800,0.005770789; 6782400,
        0.003359736; 6786000,0.002912606; 6789600,0.008435556; 6793200,
        0.00675236; 6796800,0.003488941; 6800400,0.004445845; 6804000,
        0.003090362; 6807600,0.002732893; 6811200,0.00801505; 6814800,
        0.014777982; 6818400,0.007913252; 6822000,0.003937637; 6825600,
        0.006071094; 6829200,0.001083369; 6832800,1e-06; 6836400,0.006156448;
        6840000,0.002887157; 6843600,0.002566492; 6847200,0.002369551; 6850800,
        0.006913671; 6854400,0.011014968; 6858000,0.004215624; 6861600,
        0.003309228; 6865200,0.005748472; 6868800,0.003407503; 6872400,
        0.002930617; 6876000,0.008662253; 6879600,0.00691093; 6883200,
        0.003553152; 6886800,0.004508099; 6890400,0.003112287; 6894000,
        0.002748946; 6897600,0.007825941; 6901200,0.01475449; 6904800,
        0.006940295; 6908400,0.003936071; 6912000,0.006058957; 6915600,
        0.001081411; 6919200,1e-06; 6922800,0.006150184; 6926400,0.002903601;
        6930000,0.002572756; 6933600,0.002376207; 6937200,0.006991586; 6940800,
        0.010293766; 6944400,0.004082895; 6948000,0.003289651; 6951600,
        0.005972428; 6955200,0.003434127; 6958800,0.002913781; 6962400,
        0.008435164; 6966000,0.005743382; 6969600,0.003479153; 6973200,
        0.004516321; 6976800,0.003110721; 6980400,0.002759909; 6984000,
        0.008069865; 6987600,0.014707115; 6991200,0.007888977; 6994800,
        0.0039717; 6998400,0.006085581; 7002000,0.001087676; 7005600,1e-06;
        7009200,0.006149792; 7012800,0.002927093; 7016400,0.002574714; 7020000,
        0.002373858; 7023600,0.006872952; 7027200,0.010665722; 7030800,
        0.004147498; 7034400,0.003283778; 7038000,0.00598574; 7041600,
        0.003430211; 7045200,0.002918871; 7048800,0.008316139; 7052400,
        0.00679073; 7056000,0.003523788; 7059600,0.004472469; 7063200,
        0.003119335; 7066800,0.002755602; 7070400,0.008047939; 7074000,
        0.014679316; 7077600,0.007884279; 7081200,0.003968176; 7084800,
        0.006078142; 7088400,0.001084543; 7092000,1e-06; 7095600,0.006145877;
        7099200,0.002927876; 7102800,0.002579804; 7106400,0.002377774; 7110000,
        0.006987279; 7113600,0.010044752; 7117200,0.004023774; 7120800,
        0.003284562; 7124400,0.005829519; 7128000,0.003423947; 7131600,
        0.002914955; 7135200,0.008591386; 7138800,0.006587133; 7142400,
        0.003530052; 7146000,0.004488131; 7149600,0.003114637; 7153200,
        0.002762649; 7156800,0.008228044; 7160400,0.014774458; 7164000,
        0.007626651; 7167600,0.003952907; 7171200,0.005689351; 7174800,
        0.001057136; 7178400,1e-06; 7182000,0.006129041; 7185600,0.002909082;
        7189200,0.002569233; 7192800,0.002371509; 7196400,0.006976316; 7200000,
        0.010318824; 7203600,0.004116175; 7207200,0.003301789; 7210800,
        0.005682303; 7214400,0.003405545; 7218000,0.002929442; 7221600,
        0.008357641; 7225200,0.006804825; 7228800,0.003530444; 7232400,
        0.004483041; 7236000,0.003146742; 7239600,0.002764216; 7243200,
        0.008059685; 7246800,0.014782289; 7250400,0.007268008; 7254000,
        0.003952123; 7257600,0.005953243; 7261200,0.001082194; 7264800,1e-06;
        7268400,0.0061032; 7272000,0.00288794; 7275600,0.00256101; 7279200,
        0.00236916; 7282800,0.006903491; 7286400,0.011009095; 7290000,
        0.00415063; 7293600,0.003276339; 7297200,0.005840091; 7300800,
        0.003366392; 7304400,0.002897728; 7308000,0.008399926; 7311600,
        0.006760974; 7315200,0.003529269; 7318800,0.004497919; 7322400,
        0.003107589; 7326000,0.002754036; 7329600,0.008128203; 7333200,
        0.014870383; 7336800,0.007901115; 7340400,0.00396661; 7344000,
        0.006001793; 7347600,0.001068491; 7351200,1e-06; 7354800,0.006161538;
        7358400,0.002892246; 7362000,0.002569624; 7365600,0.00237425; 7369200,
        0.007020951; 7372800,0.010359544; 7376400,0.00411735; 7380000,
        0.003280646; 7383600,0.006004142; 7387200,0.003436084; 7390800,
        0.002914564; 7394400,0.008332583; 7398000,0.006797386; 7401600,
        0.003528877; 7405200,0.004481475; 7408800,0.003110721; 7412400,
        0.002749337; 7416000,0.008042849; 7419600,0.014765061; 7423200,
        0.007923432; 7426800,0.003979531; 7430400,0.006093412; 7434000,
        0.001085327; 7437600,1e-06; 7441200,0.005943846; 7444800,0.002983082;
        7448400,0.002593116; 7452000,0.007686164; 7455600,0.011408458; 7459200,
        0.004279053; 7462800,0.003362085; 7466400,0.006147443; 7470000,
        0.003476804; 7473600,0.002938056; 7477200,0.008369387; 7480800,
        0.006885089; 7484400,0.003555893; 7488000,0.004521019; 7491600,
        0.003129515; 7495200,0.002764607; 7498800,0.00810706; 7502400,
        0.014863336; 7506000,0.007910903; 7509600,0.00393333; 7513200,
        0.005833826; 7516800,0.001063401; 7520400,1e-06; 7524000,0.00608793;
        7527600,0.002875411; 7531200,0.002568841; 7534800,0.002373467; 7538400,
        0.00686747; 7542000,0.011042376; 7545600,0.004220714; 7549200,
        0.003280255; 7552800,0.006120036; 7556400,0.00344; 7560000,0.002922394;
        7563600,0.008642285; 7567200,0.006311495; 7570800,0.00347837; 7574400,
        0.004471295; 7578000,0.003098975; 7581600,0.0027372; 7585200,
        0.008031495; 7588800,0.014790119; 7592400,0.007000591; 7596000,
        0.003957605; 7599600,0.005935624; 7603200,0.001082194; 7606800,1e-06;
        7610400,0.006128258; 7614000,0.002891072; 7617600,0.002567275; 7621200,
        0.002372684; 7624800,0.006981406; 7628400,0.010301206; 7632000,
        0.00402534; 7635600,0.003261461; 7639200,0.006092237; 7642800,
        0.003421206; 7646400,0.002903601; 7650000,0.00838544; 7653600,
        0.005734377; 7657200,0.003497555; 7660800,0.004522194; 7664400,
        0.003138912; 7668000,0.002755602; 7671600,0.008065558; 7675200,
        0.014701633; 7678800,0.007885845; 7682400,0.0039717; 7686000,
        0.005816207; 7689600,0.001058311; 7693200,1e-06; 7696800,0.006152925;
        7700400,0.002925527; 7704000,0.002578629; 7707600,0.002378165; 7711200,
        0.006985321; 7714800,0.010282804; 7718400,0.004104429; 7722000,
        0.003264593; 7725600,0.005736335; 7729200,0.003368349; 7732800,
        0.002889114; 7736400,0.008161875; 7740000,0.005715583; 7743600,
        0.003476804; 7747200,0.004491263; 7750800,0.003100541; 7754400,
        0.00274229; 7758000,0.008053421; 7761600,0.014686363; 7765200,
        0.007872924; 7768800,0.00396661; 7772400,0.006073052; 7776000,
        0.001086893; 7779600,1e-06; 7783200,0.006089496; 7786800,0.002906342;
        7790400,0.002570407; 7794000,0.002374641; 7797600,0.006980232; 7801200,
        0.010326264; 7804800,0.004066451; 7808400,0.003265376; 7812000,
        0.005934841; 7815600,0.003386751; 7819200,0.002890289; 7822800,
        0.008406974; 7826400,0.005769615; 7830000,0.003472497; 7833600,
        0.004427835; 7837200,0.003097801; 7840800,0.002744247; 7844400,
        0.007772692; 7848000,0.014593962; 7851600,0.007969633; 7855200,
        0.003967002; 7858800,0.006067962; 7862400,0.00108611; 7866000,1e-06;
        7869600,0.006094586; 7873200,0.002912606; 7876800,0.002574323; 7880400,
        0.002376207; 7884000,0.006978274; 7887600,0.010314126; 7891200,
        0.004111869; 7894800,0.003298265; 7898400,0.005979867; 7902000,
        0.003436476; 7905600,0.0029314; 7909200,0.008456699; 7912800,
        0.006771153; 7916400,0.003532401; 7920000,0.004488522; 7923600,
        0.003150658; 7927200,0.002773221; 7930800,0.008081219; 7934400,
        0.014707115; 7938000,0.00788976; 7941600,0.003970525; 7945200,
        0.006082449; 7948800,0.00108885; 7952400,1e-06; 7956000,0.006107507;
        7959600,0.002918871; 7963200,0.002577846; 7966800,0.002378557; 7970400,
        0.007018602; 7974000,0.011177062; 7977600,0.004244598; 7981200,
        0.003295916; 7984800,0.006161147; 7988400,0.003457619; 7992000,
        0.002936881; 7995600,0.008407365; 7999200,0.006786423; 8002800,
        0.003531227; 8006400,0.004486173; 8010000,0.003113071; 8013600,
        0.002761083; 8017200,0.008062034; 8020800,0.01470085; 8024400,
        0.00788976; 8028000,0.003971309; 8031600,0.006084015; 8035200,
        0.001090808; 8038800,1e-06; 8042400,0.006086364; 8046000,0.002890289;
        8049600,0.00256101; 8053200,0.002367985; 8056800,0.007012337; 8060400,
        0.010545521; 8064000,0.004144757; 8067600,0.00328926; 8071200,0.005983;
        8074800,0.003442349; 8078400,0.002909474; 8082000,0.008179494; 8085600,
        0.005723022; 8089200,0.003492856; 8092800,0.004509273; 8096400,
        0.003147134; 8100000,0.002773221; 8103600,0.008111367; 8107200,
        0.014717686; 8110800,0.007877623; 8114400,0.003971309; 8118000,
        0.00608519; 8121600,0.0010912; 8125200,1e-06; 8128800,0.006083232;
        8132400,0.002888331; 8136000,0.002569233; 8139600,0.002375424; 8143200,
        0.007046792; 8146800,0.010829382; 8150400,0.004187043; 8154000,
        0.003308836; 8157600,0.006016671; 8161200,0.003436084; 8164800,
        0.002923178; 8168400,0.008366646; 8172000,0.006792296; 8175600,
        0.003528486; 8179200,0.004481083; 8182800,0.003109547; 8186400,
        0.002748946; 8190000,0.008037368; 8193600,0.014697718; 8197200,
        0.007891718; 8200800,0.0039717; 8204400,0.006084798; 8208000,0.0010912;
        8211600,1e-06; 8215200,0.006084406; 8218800,0.002922394; 8222400,
        0.002570016; 8226000,0.002372292; 8229600,0.007044051; 8233200,
        0.010599944; 8236800,0.004152588; 8240400,0.00330453; 8244000,
        0.006007275; 8247600,0.003400063; 8251200,0.002916521; 8254800,
        0.008394445; 8258400,0.006769587; 8262000,0.003528486; 8265600,
        0.004483041; 8269200,0.003111504; 8272800,0.002759517; 8276400,
        0.008056161; 8280000,0.014695369; 8283600,0.006975925; 8287200,
        0.003942727; 8290800,0.005918788; 8294400,0.001081803; 8298000,1e-06;
        8301600,0.00608284; 8305200,0.002917696; 8308800,0.00257628; 8312400,
        0.002376207; 8316000,0.00697475; 8319600,0.011109327; 8323200,
        0.004239508; 8326800,0.003309228; 8330400,0.006165845; 8334000,
        0.003418074; 8337600,0.002905167; 8341200,0.008174012; 8344800,
        0.006839672; 8348400,0.003526137; 8352000,0.004472469; 8355600,
        0.003120901; 8359200,0.002750512; 8362800,0.008036976; 8366400,
        0.014772109; 8370000,0.007912469; 8373600,0.003977965; 8377200,
        0.006095369; 8380800,0.001093549; 8384400,1e-06; 8388000,0.006087539;
        8391600,0.002920437; 8395200,0.002573148; 8398800,0.002373467; 8402400,
        0.006853375; 8406000,0.011020841; 8409600,0.004174905; 8413200,
        0.003272816; 8416800,0.005999836; 8420400,0.003406328; 8424000,
        0.002897336; 8427600,0.008423027; 8431200,0.006739439; 8434800,
        0.003528486; 8438400,0.004484998; 8442000,0.003129515; 8445600,
        0.002760692; 8449200,0.008060077; 8452800,0.014786204; 8456400,
        0.007914818; 8460000,0.003977965; 8463600,0.006089496; 8467200,
        0.001059094; 8470800,1e-06; 8474400,0.006129433; 8478000,0.002894204;
        8481600,0.002566883; 8485200,0.002373075; 8488800,0.006979448; 8492400,
        0.010440982; 8496000,0.004059403; 8499600,0.003264202; 8503200,
        0.006107898; 8506800,0.003434518; 8510400,0.002913389; 8514000,
        0.008417545; 8517600,0.006764497; 8521200,0.003523004; 8524800,
        0.004472469; 8528400,0.003145959; 8532000,0.002760692; 8535600,
        0.008053421; 8539200,0.014812828; 8542800,0.007921083; 8546400,
        0.003977182; 8550000,0.006052692; 8553600,0.0010912; 8557200,1e-06;
        8560800,0.006107507; 8564400,0.002914564; 8568000,0.002566883; 8571600,
        0.002372684; 8575200,0.006968877; 8578800,0.010699785; 8582400,
        0.004159635; 8586000,0.003286519; 8589600,0.005987307; 8593200,
        0.003430603; 8596800,0.002907908; 8600400,0.008338456; 8604000,
        0.005725763; 8607600,0.003495597; 8611200,0.004425094; 8614800,
        0.003103282; 8618400,0.002743856; 8622000,0.008090616; 8625600,
        0.014752924; 8629200,0.007882321; 8632800,0.003980705; 8636400,
        0.0061032; 8640000,0.001097073; 8643600,1e-06; 8647200,0.006089888;
        8650800,0.002923569; 8654400,0.002572756; 8658000,0.00237425; 8661600,
        0.007047184; 8665200,0.011034545; 8668800,0.004208968; 8672400,
        0.003303355; 8676000,0.005892556; 8679600,0.003406328; 8683200,
        0.002902818; 8686800,0.008528349; 8690400,0.006667398; 8694000,
        0.003499904; 8697600,0.004472861; 8701200,0.003122076; 8704800,
        0.002759909; 8708400,0.00807104; 8712000,0.014762321; 8715600,
        0.007918342; 8719200,0.00395643; 8722800,0.006081666; 8726400,
        0.001096289; 8730000,1e-06; 8733600,0.006076184; 8737200,0.00291613;
        8740800,0.002570016; 8744400,0.00237425; 8748000,0.007020559; 8751600,
        0.011146523; 8755200,0.004172947; 8758800,0.003303355; 8762400,
        0.006073052; 8766000,0.003404762; 8769600,0.002917696; 8773200,
        0.008516994; 8776800,0.006740614; 8780400,0.003537491; 8784000,
        0.004499877; 8787600,0.003156139; 8791200,0.002777919; 8794800,
        0.008097664; 8798400,0.014734522; 8802000,0.006986105; 8805600,
        0.003921976; 8809200,0.005912915; 8812800,0.001100205; 8816400,1e-06;
        8820000,0.006139221; 8823600,0.002922003; 8827200,0.002575889; 8830800,
        0.002376207; 8834400,0.006982972; 8838000,0.01027928; 8841600,
        0.004103646; 8845200,0.003264985; 8848800,0.005930143; 8852400,
        0.003384794; 8856000,0.002916913; 8859600,0.008440646; 8863200,
        0.006761757; 8866800,0.003531227; 8870400,0.004487739; 8874000,
        0.003145568; 8877600,0.002752078; 8881200,0.00804559; 8884800,
        0.014691062; 8888400,0.007887803; 8892000,0.003970917; 8895600,
        0.006083232; 8899200,0.00109394; 8902800,1e-06; 8906400,0.006091454;
        8910000,0.002916913; 8913600,0.002571973; 8917200,0.002371509; 8920800,
        0.006991586; 8924400,0.010426496; 8928000,0.00412753; 8931600,
        0.003292001; 8935200,0.005773139; 8938800,0.003389101; 8942400,
        0.002891072; 8946000,0.008212383; 8949600,0.006816571; 8953200,
        0.003523788; 8956800,0.004473644; 8960400,0.003102108; 8964000,
        0.00273211; 8967600,0.008157177; 8971200,0.01472904; 8974800,
        0.007701433; 8978400,0.003965436; 8982000,0.006092629; 8985600,
        0.001095506; 8989200,1e-06; 8992800,0.006155274; 8996400,0.00292631;
        9000000,0.002577455; 9003600,0.002376207; 9007200,0.00699002; 9010800,
        0.010840345; 9014400,0.004187043; 9018000,0.00328926; 9021600,
        0.005830694; 9025200,0.003382836; 9028800,0.002913781; 9032400,
        0.008249187; 9036000,0.005669383; 9039600,0.003465449; 9043200,
        0.004454067; 9046800,0.003140478; 9050400,0.002764607; 9054000,
        0.008152087; 9057600,0.014730606; 9061200,0.007825157; 9064800,
        0.003969742; 9068400,0.006087147; 9072000,0.001091983; 9075600,1e-06;
        9079200,0.006078142; 9082800,0.002914564; 9086400,0.002573539; 9090000,
        0.00237425; 9093600,0.006980623; 9097200,0.010326264; 9100800,
        0.004065668; 9104400,0.003282604; 9108000,0.00596264; 9111600,
        0.003425513; 9115200,0.002906342; 9118800,0.008190457; 9122400,
        0.006832624; 9126000,0.003523396; 9129600,0.004471686; 9133200,
        0.003142044; 9136800,0.002767739; 9140400,0.008069865; 9144000,
        0.01475449; 9147600,0.007883104; 9151200,0.003926674; 9154800,
        0.005902344; 9158400,0.001095115; 9162000,1e-06; 9165600,0.006130999;
        9169200,0.002917696; 9172800,0.002573539; 9176400,0.00237425; 9180000,
        0.006976708; 9183600,0.010297682; 9187200,0.004080154; 9190800,
        0.003264593; 9194400,0.005960682; 9198000,0.003400846; 9201600,
        0.002901252; 9205200,0.008461788; 9208800,0.006733958; 9212400,
        0.003503819; 9216000,0.00447012; 9219600,0.003116986; 9223200,
        0.002749729; 9226800,0.008042849; 9230400,0.014740395; 9234000,
        0.006988454; 9237600,0.003927065; 9241200,0.005884725; 9244800,
        0.001058702; 9248400,1e-06; 9252000,0.006100851; 9255600,0.002916913;
        9259200,0.002575889; 9262800,0.002375816; 9266400,0.007020168; 9270000,
        0.011148089; 9273600,0.004245772; 9277200,0.003297874; 9280800,
        0.006168977; 9284400,0.003446264; 9288000,0.0029314; 9291600,
        0.008410106; 9295200,0.006430129; 9298800,0.003476804; 9302400,
        0.004459157; 9306000,0.003105631; 9309600,0.002757168; 9313200,
        0.008057727; 9316800,0.014823008; 9320400,0.007007639; 9324000,
        0.003919235; 9327600,0.005906651; 9331200,0.001084543; 9334800,1e-06;
        9338400,0.006100068; 9342000,0.002894596; 9345600,0.002565709; 9349200,
        0.002370334; 9352800,0.006953999; 9356400,0.010069027; 9360000,
        0.003993234; 9363600,0.003256763; 9367200,0.005888249; 9370800,
        0.003412592; 9374400,0.002908691; 9378000,0.008479016; 9381600,
        0.006739048; 9385200,0.003531618; 9388800,0.00448539; 9392400,
        0.003150658; 9396000,0.002774004; 9399600,0.008088658; 9403200,
        0.014789728; 9406800,0.007898374; 9410400,0.003925891; 9414000,
        0.006066004; 9417600,0.00109394; 9421200,1e-06; 9424800,0.006074227;
        9428400,0.002897728; 9432000,0.002570799; 9435600,0.00237425; 9439200,
        0.00698493; 9442800,0.01038421; 9446400,0.004108345; 9450000,
        0.003297482; 9453600,0.005735943; 9457200,0.003394974; 9460800,
        0.002902818; 9464400,0.008585121; 9468000,0.006678752; 9471600,
        0.003529269; 9475200,0.004483824; 9478800,0.003113071; 9482400,
        0.00274738; 9486000,0.008052246; 9489600,0.014724342; 9493200,
        0.007899157; 9496800,0.003972092; 9500400,0.006081274; 9504000,
        0.001095898; 9507600,1e-06; 9511200,0.006083623; 9514800,0.002883241;
        9518400,0.002570016; 9522000,0.002375816; 9525600,0.006858074; 9529200,
        0.011023974; 9532800,0.004219148; 9536400,0.003265768; 9540000,
        0.00591918; 9543600,0.003416116; 9547200,0.002922003; 9550800,
        0.008488021; 9554400,0.006734741; 9558000,0.003516348; 9561600,
        0.004471686; 9565200,0.003145568; 9568800,0.00276539; 9572400,
        0.008058119; 9576000,0.014770543; 9579600,0.007908945; 9583200,
        0.0039717; 9586800,0.0060801; 9590400,0.001094332; 9594000,1e-06;
        9597600,0.006087147; 9601200,0.002919262; 9604800,0.002577846; 9608400,
        0.002378557; 9612000,0.007011946; 9615600,0.010193534; 9619200,
        0.004045308; 9622800,0.003269292; 9626400,0.006155274; 9630000,
        0.003443915; 9633600,0.002913389; 9637200,0.008380741; 9640800,
        0.00678055; 9644400,0.00352692; 9648000,0.004477168; 9651600,
        0.003146742; 9655200,0.002771655; 9658800,0.008086309; 9662400,
        0.014732956; 9666000,0.007900332; 9669600,0.00396152; 9673200,
        0.00582208; 9676800,0.001062618; 9680400,1e-06; 9684000,0.006122385;
        9687600,0.002889114; 9691200,0.002564926; 9694800,0.002369943; 9698400,
        0.006973967; 9702000,0.010288677; 9705600,0.004060578; 9709200,
        0.00326616; 9712800,0.005951677; 9716400,0.00340946; 9720000,
        0.002918479; 9723600,0.008491936; 9727200,0.006741789; 9730800,
        0.003533967; 9734400,0.004494004; 9738000,0.003113854; 9741600,
        0.00274738; 9745200,0.008042458; 9748800,0.014705548; 9752400,
        0.007894067; 9756000,0.003973266; 9759600,0.006087539; 9763200,
        0.001093549; 9766800,1e-06; 9770400,0.00609811; 9774000,0.002918871;
        9777600,0.002568841; 9781200,0.002370726; 9784800,0.006973576; 9788400,
        0.010321174; 9792000,0.004062535; 9795600,0.003257154; 9799200,
        0.005922312; 9802800,0.003381661; 9806400,0.002891463; 9810000,
        0.008610571; 9813600,0.005673298; 9817200,0.003456444; 9820800,
        0.004443888; 9824400,0.003108764; 9828000,0.002753253; 9831600,
        0.008157177; 9835200,0.014736088; 9838800,0.007763295; 9842400,
        0.003968959; 9846000,0.006069137; 9849600,0.001099813; 9853200,1e-06;
        9856800,0.006139221; 9860400,0.00289303; 9864000,0.002565709; 9867600,
        0.002371901; 9871200,0.006976316; 9874800,0.009908499; 9878400,
        0.004067625; 9882000,0.003263419; 9885600,0.005858493; 9889200,
        0.003411809; 9892800,0.002908299; 9896400,0.00848254; 9900000,
        0.006725736; 9903600,0.003527703; 9907200,0.004478342; 9910800,
        0.00312834; 9914400,0.002761475; 9918000,0.0080636; 9921600,0.014704374;
        9925200,0.007890935; 9928800,0.0039717; 9932400,0.006084798; 9936000,
        0.001094723; 9939600,1e-06; 9943200,0.006089105; 9946800,0.002920437;
        9950400,0.002568841; 9954000,0.002370726; 9957600,0.006847502; 9961200,
        0.011009095; 9964800,0.004225021; 9968400,0.003267726; 9972000,
        0.005995137; 9975600,0.003393799; 9979200,0.002898511; 9982800,
        0.008419503; 9986400,0.006739439; 9990000,0.003510867; 9993600,
        0.004466988; 9997200,0.003115028; 10000800,0.002739158; 10004400,
        0.008020532; 10008000,0.014696152; 10011600,0.00737098; 10015200,
        0.003961912; 10018800,0.005954809; 10022400,0.001095506; 10026000,1e-06;
        10029600,0.006157623; 10033200,0.002915738; 10036800,0.002569233;
        10040400,0.002373075; 10044000,0.006980623; 10047600,0.011020058;
        10051200,0.004222672; 10054800,0.003312752; 10058400,0.006199125;
        10062000,0.003454095; 10065600,0.002916521; 10069200,0.008367429;
        10072800,0.006831058; 10076400,0.003501079; 10080000,0.00446738;
        10083600,0.003108372; 10087200,0.002734851; 10090800,0.008016617;
        10094400,0.014788945; 10098000,0.00718422; 10101600,0.003957996;
        10105200,0.006027634; 10108800,0.00109394; 10112400,1e-06; 10116000,
        0.006156448; 10119600,0.002930225; 10123200,0.002583719; 10126800,
        0.002381689; 10130400,0.007003723; 10134000,0.010306295; 10137600,
        0.004108736; 10141200,0.003270466; 10144800,0.005967338; 10148400,
        0.003426688; 10152000,0.00290595; 10155600,0.008207684; 10159200,
        0.006836539; 10162800,0.003522221; 10166400,0.004468163; 10170000,
        0.003104065; 10173600,0.002744639; 10177200,0.008028363; 10180800,
        0.014795992; 10184400,0.007164252; 10188000,0.003918452; 10191600,
        0.005953635; 10195200,0.001054787; 10198800,1e-06; 10202400,0.006058957;
        10206000,0.002920828; 10209600,0.002581762; 10213200,0.002380906;
        10216800,0.006977882; 10220400,0.010007165; 10224000,0.004077022;
        10227600,0.003289651; 10231200,0.006001793; 10234800,0.003368349;
        10238400,0.002897336; 10242000,0.008530698; 10245600,0.005742208;
        10249200,0.003505386; 10252800,0.004484215; 10256400,0.003113071;
        10260000,0.002762258; 10263600,0.008083569; 10267200,0.014727474;
        10270800,0.007890543; 10274400,0.003936854; 10278000,0.00598809;
        10281600,0.001071231; 10285200,1e-06; 10288800,0.006105941; 10292400,
        0.002873844; 10296000,0.002559053; 10299600,0.002367594; 10303200,
        0.006854941; 10306800,0.011029063; 10310400,0.004211318; 10314000,
        0.003297874; 10317600,0.006146269; 10321200,0.003392233; 10324800,
        0.002903601; 10328400,0.008362339; 10332000,0.006759799; 10335600,
        0.003524571; 10339200,0.004477559; 10342800,0.003106023; 10346400,
        0.002758343; 10350000,0.008055378; 10353600,0.014695369; 10357200,
        0.007889369; 10360800,0.00395878; 10364400,0.006018238; 10368000,
        0.001072014; 10371600,1e-06; 10375200,0.006105941; 10378800,0.002913389;
        10382400,0.002564143; 10386000,0.002368768; 10389600,0.006968094;
        10393200,0.010365808; 10396800,0.004117741; 10400400,0.003281821;
        10404000,0.005999444; 10407600,0.003439217; 10411200,0.002909082;
        10414800,0.008630147; 10418400,0.005695224; 10422000,0.003469365;
        10425600,0.004470903; 10429200,0.003138129; 10432800,0.002746597;
        10436400,0.008138775; 10440000,0.014816352; 10443600,0.007882713;
        10447200,0.003981097; 10450800,0.006103592; 10454400,0.001099813;
        10458000,1e-06; 10461600,0.006087147; 10465200,0.002894596; 10468800,
        0.002572756; 10472400,0.002376599; 10476000,0.006993935; 10479600,
        0.010378337; 10483200,0.004108736; 10486800,0.003284953; 10490400,
        0.005968121; 10494000,0.003445481; 10497600,0.00292631; 10501200,
        0.008440646; 10504800,0.005749255; 10508400,0.003481111; 10512000,
        0.004453676; 10515600,0.003140086; 10519200,0.002756776; 10522800,
        0.008066733; 10526400,0.014848849; 10530000,0.007964934; 10533600,
        0.003932547; 10537200,0.005891381; 10540800,0.001065358; 10544400,1e-06;
        10548000,0.006154099; 10551600,0.002917696; 10555200,0.002569624;
        10558800,0.002372292; 10562400,0.006988845; 10566000,0.010293766;
        10569600,0.004109519; 10573200,0.003286519; 10576800,0.005958333;
        10580400,0.003414159; 10584000,0.002896553; 10587600,0.008417154;
        10591200,0.005741424; 10594800,0.003500296; 10598400,0.004515146;
        10602000,0.0031487; 10605600,0.002766956; 10609200,0.008072606;
        10612800,0.014708289; 10616400,0.007889369; 10620000,0.003947425;
        10623600,0.006068745; 10627200,0.001097073; 10630800,1e-06; 10634400,
        0.006063655; 10638000,0.002896162; 10641600,0.002572756; 10645200,
        0.002375424; 10648800,0.006982581; 10652400,0.01030747; 10656000,
        0.004062535; 10659600,0.003266551; 10663200,0.00594463; 10666800,
        0.003401238; 10670400,0.002903601; 10674000,0.008411281; 10677600,
        0.005739075; 10681200,0.00350147; 10684800,0.004525718; 10688400,
        0.00311542; 10692000,0.002748554; 10695600,0.008046765; 10699200,
        0.014698892; 10702800,0.007888194; 10706400,0.003972092; 10710000,
        0.006052692; 10713600,0.001053221; 10717200,1e-06; 10720800,0.006151358;
        10724400,0.002890289; 10728000,0.002571582; 10731600,0.002375033;
        10735200,0.006984538; 10738800,0.010283978; 10742400,0.004104821;
        10746000,0.00326616; 10749600,0.005933275; 10753200,0.003385185;
        10756800,0.002910648; 10760400,0.008421069; 10764000,0.005741033;
        10767600,0.003501862; 10771200,0.004526892; 10774800,0.003140478;
        10778400,0.002747771; 10782000,0.008045982; 10785600,0.014692628;
        10789200,0.007886236; 10792800,0.003971309; 10796400,0.006084798;
        10800000,0.001096681; 10803600,1e-06; 10807200,0.006097719; 10810800,
        0.002891072; 10814400,0.002561402; 10818000,0.002366028; 10821600,
        0.006963396; 10825200,0.010327047; 10828800,0.004044133; 10832400,
        0.003267334; 10836000,0.005934841; 10839600,0.003376963; 10843200,
        0.002907908; 10846800,0.008637586; 10850400,0.005730462; 10854000,
        0.003498338; 10857600,0.004472469; 10861200,0.003146351; 10864800,
        0.002772046; 10868400,0.00816579; 10872000,0.014750966; 10875600,
        0.006978665; 10879200,0.003942335; 10882800,0.005900386; 10886400,
        0.001087284; 10890000,1e-06; 10893600,0.006075793; 10897200,0.002896162;
        10900800,0.002570016; 10904400,0.00237425; 10908000,0.006982581;
        10911600,0.010305904; 10915200,0.00411226; 10918800,0.00329944;
        10922400,0.005979084; 10926000,0.003421989; 10929600,0.00291613;
        10933200,0.008499376; 10936800,0.006441092; 10940400,0.003463883;
        10944000,0.004483824; 10947600,0.003109547; 10951200,0.002746597;
        10954800,0.008098838; 10958400,0.01472395; 10962000,0.006778201;
        10965600,0.003930589; 10969200,0.006120427; 10972800,0.001098639;
        10976400,1e-06; 10980000,0.006080491; 10983600,0.002920828; 10987200,
        0.002580979; 10990800,0.002381689; 10994400,0.007001766; 10998000,
        0.010338793; 11001600,0.004099731; 11005200,0.003292001; 11008800,
        0.005968905; 11012400,0.003363651; 11016000,0.002900469; 11019600,
        0.008204552; 11023200,0.005883942; 11026800,0.003465841; 11030400,
        0.004457591; 11034000,0.003141261; 11037600,0.002767739; 11041200,
        0.008234308; 11044800,0.014891135; 11048400,0.007302071; 11052000,
        0.003911796; 11055600,0.006108681; 11059200,0.001102554; 11062800,1e-06;
        11066400,0.006075401; 11070000,0.002920828; 11073600,0.002581762;
        11077200,0.002382472; 11080800,0.00700529; 11084400,0.010348189;
        11088000,0.004113435; 11091600,0.003286911; 11095200,0.005685435;
        11098800,0.003357778; 11102400,0.00289303; 11106000,0.008587862;
        11109600,0.006207347; 11113200,0.003519089; 11116800,0.004508882;
        11120400,0.003149091; 11124000,0.002754427; 11127600,0.008172838;
        11131200,0.014871949; 11134800,0.007150939; 11138400,0.003924716;
        11142000,0.005926619; 11145600,0.001097464; 11149200,1e-06; 11152800,
        0.006096935; 11156400,0.002924744; 11160000,0.002582153; 11163600,
        0.002381689; 11167200,0.007008813; 11170800,0.010343099; 11174400,
        0.004104429; 11178000,0.003274382; 11181600,0.005820905; 11185200,
        0.003394974; 11188800,0.002898903; 11192400,0.008220213; 11196000,
        0.006822444; 11199600,0.003513608; 11203200,0.004427835; 11206800,
        0.003087229; 11210400,0.00275247; 11214000,0.008213166; 11217600,
        0.014827706; 11221200,0.006743746; 11224800,0.003896526; 11228400,
        0.006065613; 11232000,0.001096289; 11235600,1e-06; 11239200,0.006096544;
        11242800,0.002925527; 11246400,0.002571973; 11250000,0.002372684;
        11253600,0.006984538; 11257200,0.010328221; 11260800,0.004116567;
        11264400,0.003295133; 11268000,0.005789974; 11271600,0.003402021;
        11275200,0.002903992; 11278800,0.008538137; 11282400,0.005674081;
        11286000,0.003486592; 11289600,0.004489305; 11293200,0.003111504;
        11296800,0.002755602; 11300400,0.008179885; 11304000,0.014774458;
        11307600,0.007082421; 11311200,0.003907489; 11314800,0.00603938;
        11318400,0.001097464; 11322000,1e-06; 11325600,0.006095761; 11329200,
        0.002923569; 11332800,0.002575497; 11336400,0.002377774; 11340000,
        0.006997067; 11343600,0.01033292; 11347200,0.004116958; 11350800,
        0.003297091; 11354400,0.006111422; 11358000,0.003429037; 11361600,
        0.002901643; 11365200,0.008605481; 11368800,0.005723806; 11372400,
        0.003511259; 11376000,0.004488131; 11379600,0.003145176; 11383200,
        0.002754819; 11386800,0.008148563; 11390400,0.014759971; 11394000,
        0.006883523; 11397600,0.003930589; 11401200,0.005912524; 11404800,
        0.001094723; 11408400,1e-06; 11412000,0.0060801; 11415600,0.002909474;
        11419200,0.002573148; 11422800,0.002375033; 11426400,0.006988062;
        11430000,0.010326264; 11433600,0.004115784; 11437200,0.003297874;
        11440800,0.00594737; 11444400,0.003430994; 11448000,0.002916913;
        11451600,0.008639152; 11455200,0.006057391; 11458800,0.003517131;
        11462400,0.004509665; 11466000,0.003152224; 11469600,0.002755993;
        11473200,0.008216298; 11476800,0.01481831; 11480400,0.007713179;
        11484000,0.003915319; 11487600,0.005989264; 11491200,0.001092766;
        11494800,1e-06; 11498400,0.006101634; 11502000,0.002918088; 11505600,
        0.002578629; 11509200,0.002378557; 11512800,0.006998242; 11516400,
        0.010328613; 11520000,0.004116567; 11523600,0.003301789; 11527200,
        0.00598574; 11530800,0.003443523; 11534400,0.002915347; 11538000,
        0.008437122; 11541600,0.006761365; 11545200,0.003524571; 11548800,
        0.004470512; 11552400,0.003135388; 11556000,0.002753253; 11559600,
        0.008053029; 11563200,0.014696935; 11566800,0.007889369; 11570400,
        0.003970917; 11574000,0.006084015; 11577600,0.001099422; 11581200,1e-06;
        11584800,0.00606992; 11588400,0.002916913; 11592000,0.002569624;
        11595600,0.002372292; 11599200,0.006981798; 11602800,0.010328221;
        11606400,0.004115001; 11610000,0.003300223; 11613600,0.005985349;
        11617200,0.003442349; 11620800,0.002932183; 11624400,0.008456699;
        11628000,0.006771545; 11631600,0.003500687; 11635200,0.004466596;
        11638800,0.00310524; 11642400,0.002744639; 11646000,0.008035019;
        11649600,0.014683623; 11653200,0.00788702; 11656800,0.00396661;
        11660400,0.006061306; 11664000,0.001096289; 11667600,1e-06; 11671200,
        0.006078142; 11674800,0.002899294; 11678400,0.002565709; 11682000,
        0.002369943; 11685600,0.006972792; 11689200,0.010325089; 11692800,
        0.004093075; 11696400,0.003259895; 11700000,0.005918788; 11703600,
        0.003376963; 11707200,0.002896162; 11710800,0.008185758; 11714400,
        0.005700705; 11718000,0.003450571; 11721600,0.004438406; 11725200,
        0.003091536; 11728800,0.002731327; 11732400,0.008228435; 11736000,
        0.014911886; 11739600,0.00775938; 11743200,0.003950557; 11746800,
        0.006153708; 11750400,0.001102162; 11754000,1e-06; 11757600,0.006158014;
        11761200,0.002933357; 11764800,0.002583719; 11768400,0.002382863;
        11772000,0.007011946; 11775600,0.010301597; 11779200,0.004066842;
        11782800,0.00328926; 11786400,0.005989656; 11790000,0.003434518;
        11793600,0.002911823; 11797200,0.008237832; 11800800,0.006832232;
        11804400,0.003528877; 11808000,0.004477951; 11811600,0.003125208;
        11815200,0.002753253; 11818800,0.008036585; 11822400,0.014761929;
        11826000,0.007074982; 11829600,0.00394625; 11833200,0.005862408;
        11836800,0.001065358; 11840400,1e-06; 11844000,0.006127475; 11847600,
        0.002925918; 11851200,0.002578629; 11854800,0.002376599; 11858400,
        0.006997067; 11862000,0.010316867; 11865600,0.004051181; 11869200,
        0.003274382; 11872800,0.006105941; 11876400,0.003434518; 11880000,
        0.002908691; 11883600,0.008186541; 11887200,0.006840846; 11890800,
        0.003527311; 11894400,0.004453284; 11898000,0.003104457; 11901600,
        0.002739158; 11905200,0.008021707; 11908800,0.01472121; 11912400,
        0.007434017; 11916000,0.003967785; 11919600,0.005964598; 11923200,
        0.001087284; 11926800,1e-06; 11930400,0.006127475; 11934000,0.002895379;
        11937600,0.002572365; 11941200,0.002376207; 11944800,0.006987671;
        11948400,0.010367374; 11952000,0.004120482; 11955600,0.003278297;
        11959200,0.005959508; 11962800,0.003436084; 11966400,0.002910257;
        11970000,0.008648549; 11973600,0.006035465; 11977200,0.003465449;
        11980800,0.004336999; 11984400,0.003093102; 11988000,0.002758343;
        11991600,0.008223345; 11995200,0.014770543; 11998800,0.007888194;
        12002400,0.003977182; 12006000,0.006096152; 12009600,0.001101379;
        12013200,1e-06; 12016800,0.006080491; 12020400,0.002900469; 12024000,
        0.002567667; 12027600,0.002373075; 12031200,0.006982972; 12034800,
        0.010332528; 12038400,0.004095033; 12042000,0.003264985; 12045600,
        0.005699922; 12049200,0.003418857; 12052800,0.002928659; 12056400,
        0.008677131; 12060000,0.006311103; 12063600,0.003476412; 12067200,
        0.004535506; 12070800,0.003136562; 12074400,0.002744247; 12078000,
        0.008094923; 12081600,0.014819093; 12085200,0.007889369; 12088800,
        0.003970917; 12092400,0.006083623; 12096000,0.001100205; 12099600,1e-06;
        12103200,0.006073444; 12106800,0.002920437; 12110400,0.002575106;
        12114000,0.002375816; 12117600,0.006990803; 12121200,0.010339967;
        12124800,0.004098165; 12128400,0.003275556; 12132000,0.005957942;
        12135600,0.003441957; 12139200,0.002930617; 12142800,0.008451609;
        12146400,0.005749647; 12150000,0.00348855; 12153600,0.004510056;
        12157200,0.00314361; 12160800,0.002769305; 12164400,0.008085135;
        12168000,0.014714945; 12171600,0.007889369; 12175200,0.003947817;
        12178800,0.00606992; 12182400,0.001100205; 12186000,1e-06; 12189600,
        0.006074227; 12193200,0.002918871; 12196800,0.00257119; 12200400,
        0.002373467; 12204000,0.006981015; 12207600,0.010328221; 12211200,
        0.004112652; 12214800,0.003275165; 12218400,0.005954418; 12222000,
        0.003368349; 12225600,0.002892246; 12229200,0.008397969; 12232800,
        0.006724953; 12236400,0.003477587; 12240000,0.004455242; 12243600,
        0.003123642; 12247200,0.002743856; 12250800,0.008031886; 12254400,
        0.01488996; 12258000,0.007979813; 12261600,0.003993626; 12265200,
        0.006118861; 12268800,0.001104512; 12272400,1e-06; 12276000,0.006096152;
        12279600,0.002920045; 12283200,0.002582936; 12286800,0.002382863;
        12290400,0.007010771; 12294000,0.010352105; 12297600,0.004120874;
        12301200,0.003299831; 12304800,0.005980259; 12308400,0.003445481;
        12312000,0.002933749; 12315600,0.008789892; 12319200,0.00631541;
        12322800,0.003519481; 12326400,0.004563305; 12330000,0.003140478;
        12333600,0.002753644; 12337200,0.008108627; 12340800,0.01488996;
        12344400,0.007670111; 12348000,0.003980705; 12351600,0.005970862;
        12355200,0.001103729; 12358800,1e-06; 12362400,0.006084015; 12366000,
        0.002909082; 12369600,0.00256845; 12373200,0.002374641; 12376800,
        0.006991194; 12380400,0.01033566; 12384000,0.004022208; 12387600,
        0.003273207; 12391200,0.005952852; 12394800,0.003367566; 12398400,
        0.002896945; 12402000,0.008406191; 12405600,0.00574025; 12409200,
        0.003481502; 12412800,0.004501834; 12416400,0.003120118; 12420000,
        0.002758343; 12423600,0.008072997; 12427200,0.014709464; 12430800,
        0.007890152; 12434400,0.003972483; 12438000,0.006109465; 12441600,
        0.001101379; 12445200,1e-06; 12448800,0.006087147; 12452400,0.002899294;
        12456000,0.002569233; 12459600,0.002373858; 12463200,0.006982581;
        12466800,0.010314518; 12470400,0.004044917; 12474000,0.003257546;
        12477600,0.005936799; 12481200,0.003432561; 12484800,0.002903209;
        12488400,0.008405799; 12492000,0.006753535; 12495600,0.003528877;
        12499200,0.004484998; 12502800,0.003145959; 12506400,0.002754427;
        12510000,0.008042458; 12513600,0.014698501; 12517200,0.007891718;
        12520800,0.003962303; 12524400,0.006043687; 12528000,0.001094723;
        12531600,1e-06; 12535200,0.006096152; 12538800,0.002896553; 12542400,
        0.002571973; 12546000,0.002375816; 12549600,0.006987671; 12553200,
        0.010372856; 12556800,0.004104038; 12560400,0.003281821; 12564000,
        0.005956376; 12567600,0.003389101; 12571200,0.00292122; 12574800,
        0.008453175; 12578400,0.006769979; 12582000,0.003506952; 12585600,
        0.004470512; 12589200,0.003145959; 12592800,0.002770872; 12596400,
        0.008366255; 12600000,0.014904447; 12603600,0.007985294; 12607200,
        0.003988144; 12610800,0.006107507; 12614400,0.001102162; 12618000,1e-06;
        12621600,0.006086364; 12625200,0.002918479; 12628800,0.002582545;
        12632400,0.002382472; 12636000,0.00700803; 12639600,0.010346623;
        12643200,0.004092292; 12646800,0.003266943; 12650400,0.005912524;
        12654000,0.003377746; 12657600,0.00290086; 12661200,0.008614094;
        12664800,0.005995529; 12668400,0.003481502; 12672000,0.004477951;
        12675600,0.003147134; 12679200,0.002759126; 12682800,0.008180669;
        12686400,0.014791294; 12690000,0.0070464; 12693600,0.003964652;
        12697200,0.00595246; 12700800,0.001095506; 12704400,1e-06; 12708000,
        0.006101634; 12711600,0.002919262; 12715200,0.002574714; 12718800,
        0.002378165; 12722400,0.007002549; 12726000,0.01033292; 12729600,
        0.004110694; 12733200,0.003292784; 12736800,0.005970471; 12740400,
        0.00344509; 12744000,0.002925135; 12747600,0.008657946; 12751200,
        0.006260596; 12754800,0.003525354; 12758400,0.004564871; 12762000,
        0.003140869; 12765600,0.002770089; 12769200,0.0081376; 12772800,
        0.01482105; 12776400,0.00790503; 12780000,0.003965827; 12783600,
        0.00593445; 12787200,0.001073581; 12790800,1e-06; 12794400,0.006103983;
        12798000,0.002911432; 12801600,0.002576672; 12805200,0.002377382;
        12808800,0.007019776; 12812400,0.010402221; 12816000,0.004069975;
        12819600,0.003265768; 12823200,0.00595246; 12826800,0.003429037;
        12830400,0.002927093; 12834000,0.008456699; 12837600,0.005753562;
        12841200,0.003506952; 12844800,0.004531199; 12848400,0.003116203;
        12852000,0.002763824; 12855600,0.0082347; 12859200,0.01477759; 12862800,
        0.00760081; 12866400,0.00396661; 12870000,0.005943846; 12873600,
        0.001097073; 12877200,1e-06; 12880800,0.006069137; 12884400,0.002914955;
        12888000,0.00257628; 12891600,0.002376599; 12895200,0.006984538;
        12898800,0.010332137; 12902400,0.004115392; 12906000,0.003300223;
        12909600,0.005986132; 12913200,0.00342982; 12916800,0.002911432;
        12920400,0.008427725; 12924000,0.006759408; 12927600,0.003503819;
        12931200,0.004465813; 12934800,0.003098975; 12938400,0.002753253;
        12942000,0.008051854; 12945600,0.014693019; 12949200,0.007888586;
        12952800,0.003968568; 12956400,0.006074618; 12960000,0.001099813;
        12963600,1e-06; 12967200,0.006083623; 12970800,0.002912606; 12974400,
        0.002574714; 12978000,0.002376207; 12981600,0.006986888; 12985200,
        0.010331353; 12988800,0.004104821; 12992400,0.003288477; 12996000,
        0.005964989; 12999600,0.00344; 13003200,0.002930225; 13006800,
        0.008449651; 13010400,0.00677037; 13014000,0.00353201; 13017600,
        0.004488131; 13021200,0.003127949; 13024800,0.002752861; 13028400,
        0.008046373; 13032000,0.014717686; 13035600,0.007905813; 13039200,
        0.00397679; 13042800,0.00609302; 13046400,0.001100205; 13050000,1e-06;
        13053600,0.006099285; 13057200,0.002904776; 13060800,0.002567667;
        13064400,0.002371509; 13068000,0.006979057; 13071600,0.009979758;
        13075200,0.004073107; 13078800,0.003266551; 13082400,0.00613648;
        13086000,0.003427862; 13089600,0.002894596; 13093200,0.00812233;
        13096800,0.006838497; 13100400,0.003496772; 13104000,0.004446237;
        13107600,0.003090753; 13111200,0.002741507; 13114800,0.008146214;
        13118400,0.014719252; 13122000,0.006809915; 13125600,0.003925108;
        13129200,0.006067571; 13132800,0.001099422; 13136400,1e-06; 13140000,
        0.006076576; 13143600,0.002907516; 13147200,0.002571973; 13150800,
        0.002374641; 13154400,0.00700803; 13158000,0.010395956; 13161600,
        0.004105212; 13165200,0.003277514; 13168800,0.00595755; 13172400,
        0.003425905; 13176000,0.002893813; 13179600,0.00862075; 13183200,
        0.005717933; 13186800,0.003510475; 13190400,0.004538638; 13194000,
        0.003111896; 13197600,0.002764216; 13201200,0.008240181; 13204800,
        0.014863336; 13208400,0.007274272; 13212000,0.003952907; 13215600,
        0.006032724; 13219200,0.001100596; 13222800,1e-06; 13226400,0.006100459;
        13230000,0.00291104; 13233600,0.00257119; 13237200,0.002376207;
        13240800,0.00699785; 13244400,0.01033801; 13248000,0.004085636;
        13251600,0.003272032; 13255200,0.006124343; 13258800,0.003412201;
        13262400,0.002916521; 13266000,0.008658337; 13269600,0.006388627;
        13273200,0.003536708; 13276800,0.004520628; 13280400,0.003119727;
        13284000,0.002756385; 13287600,0.007842776; 13291200,0.014790119;
        13294800,0.006865513; 13298400,0.003886738; 13302000,0.005886291;
        13305600,0.001102162; 13309200,1e-06; 13312800,0.006125126; 13316400,
        0.002918871; 13320000,0.002563751; 13323600,0.002370334; 13327200,
        0.006978274; 13330800,0.01028437; 13334400,0.004058229; 13338000,
        0.003286519; 13341600,0.005927011; 13345200,0.003382444; 13348800,
        0.002909865; 13352400,0.008619967; 13356000,0.005939148; 13359600,
        0.003479153; 13363200,0.004478342; 13366800,0.003145568; 13370400,
        0.002762649; 13374000,0.008070256; 13377600,0.014860987; 13381200,
        0.007941834; 13384800,0.003978356; 13388400,0.006084015; 13392000,
        0.001101379; 13395600,1e-06; 13399200,0.006094195; 13402800,0.002905559;
        13406400,0.002575497; 13410000,0.002378948; 13413600,0.007004898;
        13417200,0.010401046; 13420800,0.004129879; 13424400,0.003308053;
        13428000,0.005997878; 13431600,0.003416899; 13435200,0.002923178;
        13438800,0.008486063; 13442400,0.005764525; 13446000,0.003517523;
        13449600,0.004504575; 13453200,0.003136562; 13456800,0.002759126;
        13460400,0.008116457; 13464000,0.014916193; 13467600,0.007104739;
        13471200,0.003931764; 13474800,0.005952852; 13478400,0.001096681;
        13482000,1e-06; 13485600,0.006124343; 13489200,0.002914172; 13492800,
        0.002566492; 13496400,0.002372684; 13500000,0.006993935; 13503600,
        0.010291026; 13507200,0.0040457; 13510800,0.003257546; 13514400,
        0.005663118; 13518000,0.003394582; 13521600,0.002916913; 13525200,
        0.008076129; 13528800,0.006201083; 13532400,0.003451354; 13536000,
        0.004417655; 13539600,0.003130298; 13543200,0.002743856; 13546800,
        0.008168923; 13550400,0.014723559; 13554000,0.007282494; 13557600,
        0.00391806; 13561200,0.005923095; 13564800,0.001069665; 13568400,1e-06;
        13572000,0.006091063; 13575600,0.002908299; 13579200,0.002575106;
        13582800,0.002377382; 13586400,0.006992369; 13590000,0.010326655;
        13593600,0.004114218; 13597200,0.003288477; 13600800,0.005959508;
        13604400,0.003432169; 13608000,0.002914564; 13611600,0.008634454;
        13615200,0.006069137; 13618800,0.00347328; 13622400,0.004453676;
        13626000,0.003101325; 13629600,0.002743464; 13633200,0.008035019;
        13636800,0.01469067; 13640400,0.006977491; 13644000,0.00390788;
        13647600,0.005995137; 13651200,0.001092766; 13654800,1e-06; 13658400,
        0.00609811; 13662000,0.002869538; 13665600,0.002552788; 13669200,
        0.002362112; 13672800,0.006848677; 13676400,0.010985995; 13680000,
        0.004218365; 13683600,0.003296307; 13687200,0.006136089; 13690800,
        0.00344783; 13694400,0.002929834; 13698000,0.008386223; 13701600,
        0.006771937; 13705200,0.003525354; 13708800,0.004475993; 13712400,
        0.003134996; 13716000,0.002753253; 13719600,0.008044415; 13723200,
        0.014694586; 13726800,0.007878014; 13730400,0.00391806; 13734000,
        0.006051518; 13737600,0.001098247; 13741200,1e-06; 13744800,0.006132565;
        13748400,0.002886374; 13752000,0.002566883; 13755600,0.002371117;
        13759200,0.006972401; 13762800,0.01028711; 13766400,0.004095816;
        13770000,0.00327399; 13773600,0.005943455; 13777200,0.003418074;
        13780800,0.002891855; 13784400,0.008589428; 13788000,0.006055042;
        13791600,0.003508126; 13795200,0.004534331; 13798800,0.003154964;
        13802400,0.002766956; 13806000,0.008107844; 13809600,0.014727083;
        13813200,0.007872141; 13816800,0.003973658; 13820400,0.006090279;
        13824000,0.001099813; 13827600,1e-06; 13831200,0.006080883; 13834800,
        0.002921611; 13838400,0.002574714; 13842000,0.002375424; 13845600,
        0.006990411; 13849200,0.010334486; 13852800,0.004102863; 13856400,
        0.003293175; 13860000,0.005966555; 13863600,0.003367958; 13867200,
        0.00291104; 13870800,0.008657554; 13874400,0.0058859; 13878000,
        0.00351674; 13881600,0.004518279; 13885200,0.003156922; 13888800,
        0.002777528; 13892400,0.008165007; 13896000,0.01476467; 13899600,
        0.007859221; 13903200,0.003961912; 13906800,0.005879635; 13910400,
        0.001084935; 13914000,1e-06; 13917600,0.006045645; 13921200,0.002895379;
        13924800,0.002566883; 13928400,0.002371901; 13932000,0.006980232;
        13935600,0.010366983; 13939200,0.004124006; 13942800,0.003292784;
        13946400,0.005961465; 13950000,0.003439217; 13953600,0.002908691;
        13957200,0.008237441; 13960800,0.006831841; 13964400,0.003528877;
        13968000,0.004451327; 13971600,0.003085272; 13975200,0.002728195;
        13978800,0.008127812; 13982400,0.014737654; 13986000,0.00778757;
        13989600,0.0039717; 13993200,0.006094978; 13996800,0.001102554;
        14000400,1e-06; 14004000,0.00611847; 14007600,0.002896162; 14011200,
        0.00256845; 14014800,0.002373467; 14018400,0.006983755; 14022000,
        0.010325089; 14025600,0.004116175; 14029200,0.00330218; 14032800,
        0.005943846; 14036400,0.003357386; 14040000,0.002897728; 14043600,
        0.008596867; 14047200,0.006357304; 14050800,0.003513608; 14054400,
        0.004502226; 14058000,0.003141652; 14061600,0.002767348; 14065200,
        0.008150521; 14068800,0.01477485; 14072400,0.00716386; 14076000,
        0.003960346; 14079600,0.005968121; 14083200,0.001084935; 14086800,1e-06;
        14090400,0.006062481; 14094000,0.002884416; 14097600,0.002570407;
        14101200,0.002375424; 14104800,0.006988845; 14108400,0.010316475;
        14112000,0.004113043; 14115600,0.003299831; 14119200,0.005980259;
        14122800,0.003442349; 14126400,0.002910257; 14130000,0.008618401;
        14133600,0.00569679; 14137200,0.003453312; 14140800,0.004443888;
        14144400,0.003130298; 14148000,0.002741507; 14151600,0.008036976;
        14155200,0.014694586; 14158800,0.007101606; 14162400,0.003896526;
        14166000,0.005997486; 14169600,0.00109394; 14173200,1e-06; 14176800,
        0.00608793; 14180400,0.002916521; 14184000,0.002570799; 14187600,
        0.002373858; 14191200,0.006984147; 14194800,0.010081165; 14198400,
        0.00410208; 14202000,0.003284953; 14205600,0.006119253; 14209200,
        0.003453703; 14212800,0.002925918; 14216400,0.008419895; 14220000,
        0.00677272; 14223600,0.00350656; 14227200,0.004469337; 14230800,
        0.003135779; 14234400,0.002743856; 14238000,0.00803541; 14241600,
        0.014691453; 14245200,0.007468863; 14248800,0.003890261; 14252400,
        0.005905868; 14256000,0.001092766; 14259600,1e-06; 14263200,0.006091846;
        14266800,0.00289577; 14270400,0.002570407; 14274000,0.00237425;
        14277600,0.006980232; 14281200,0.01000599; 14284800,0.004088768;
        14288400,0.003282995; 14292000,0.005948936; 14295600,0.00339145;
        14299200,0.002906733; 14302800,0.008479407; 14306400,0.005738684;
        14310000,0.003461142; 14313600,0.004495178; 14317200,0.003088796;
        14320800,0.002732893; 14324400,0.008053812; 14328000,0.014728649;
        14331600,0.007881538; 14335200,0.003964652; 14338800,0.006078533;
        14342400,0.001101379; 14346000,1e-06; 14349600,0.006074618; 14353200,
        0.002921611; 14356800,0.002572365; 14360400,0.002374641; 14364000,
        0.006985713; 14367600,0.009985631; 14371200,0.00407389; 14374800,
        0.003257546; 14378400,0.005923095; 14382000,0.003384794; 14385600,
        0.002904384; 14389200,0.008602348; 14392800,0.006101242; 14396400,
        0.003495989; 14400000,0.00450575; 14403600,0.003114637; 14407200,
        0.002768131; 14410800,0.008173229; 14414400,0.014750966; 14418000,
        0.0078232; 14421600,0.003945859; 14425200,0.00607501; 14428800,
        0.001100205; 14432400,1e-06; 14436000,0.006067571; 14439600,0.002915347;
        14443200,0.002573931; 14446800,0.00237425; 14450400,0.006981798;
        14454000,0.010333311; 14457600,0.004115784; 14461200,0.003288868;
        14464800,0.005960682; 14468400,0.003395757; 14472000,0.002897728;
        14475600,0.008400709; 14479200,0.006750402; 14482800,0.003501862;
        14486400,0.004464247; 14490000,0.003106806; 14493600,0.002737591;
        14497200,0.008068299; 14500800,0.01481087; 14504400,0.00802523;
        14508000,0.003972875; 14511600,0.006080491; 14515200,0.001100205;
        14518800,1e-06; 14522400,0.006081666; 14526000,0.002920828; 14529600,
        0.002582153; 14533200,0.002382863; 14536800,0.00700803; 14540400,
        0.010379903; 14544000,0.00408916; 14547600,0.003274382; 14551200,
        0.005964206; 14554800,0.003414942; 14558400,0.00290086; 14562000,
        0.008414805; 14565600,0.00568152; 14569200,0.00345801; 14572800,
        0.004456025; 14576400,0.003092711; 14580000,0.002733676; 14583600,
        0.008145039; 14587200,0.014737262; 14590800,0.007915993; 14594400,
        0.003976007; 14598000,0.006090279; 14601600,0.001097856; 14605200,1e-06;
        14608800,0.006183856; 14612400,0.002906342; 14616000,0.002570016;
        14619600,0.002375033; 14623200,0.006988062; 14626800,0.010271449;
        14630400,0.004105212; 14634000,0.003283387; 14637600,0.005948936;
        14641200,0.003415333; 14644800,0.002904384; 14648400,0.008426551;
        14652000,0.006752751; 14655600,0.003503819; 14659200,0.004466596;
        14662800,0.003139695; 14666400,0.002751295; 14670000,0.008235091;
        14673600,0.014941251; 14677200,0.007666979; 14680800,0.003977965;
        14684400,0.005702663; 14688000,0.001077104; 14691600,1e-06; 14695200,
        0.006091454; 14698800,0.002897336; 14702400,0.002565709; 14706000,
        0.002371509; 14709600,0.006980623; 14713200,0.01032783; 14716800,
        0.004066451; 14720400,0.003285345; 14724000,0.005970079; 14727600,
        0.003440391; 14731200,0.002907908; 14734800,0.008416371; 14738400,
        0.006755101; 14742000,0.003503819; 14745600,0.00451084; 14749200,
        0.003107589; 14752800,0.002747771; 14756400,0.008100796; 14760000,
        0.014787379; 14763600,0.007881538; 14767200,0.003952515; 14770800,
        0.005918788; 14774400,0.001098639; 14778000,1e-06; 14781600,0.006107507;
        14785200,0.002905167; 14788800,0.002567275; 14792400,0.002372292;
        14796000,0.006982189; 14799600,0.010281629; 14803200,0.004107953;
        14806800,0.003297482; 14810400,0.005970079; 14814000,0.003418857;
        14817600,0.002922394; 14821200,0.008665385; 14824800,0.006247675;
        14828400,0.003524179; 14832000,0.004501051; 14835600,0.003119727;
        14839200,0.0027603; 14842800,0.008184975; 14846400,0.014756056;
        14850000,0.007950839; 14853600,0.003925499; 14857200,0.006057782;
        14860800,0.00109903; 14864400,1e-06; 14868000,0.006096935; 14871600,
        0.002917696; 14875200,0.002570799; 14878800,0.002375033; 14882400,
        0.006986105; 14886000,0.010330962; 14889600,0.004068017; 14893200,
        0.003285345; 14896800,0.005970862; 14900400,0.003411418; 14904000,
        0.002896945; 14907600,0.008399535; 14911200,0.006748445; 14914800,
        0.003520655; 14918400,0.00437811; 14922000,0.003138129; 14925600,
        0.002770872; 14929200,0.008146214; 14932800,0.014869209; 14936400,
        0.007874491; 14940000,0.003947034; 14943600,0.006094586; 14947200,
        0.001044216; 14950800,1e-06; 14954400,0.006134131; 14958000,0.002929442;
        14961600,0.002578629; 14965200,0.002378165; 14968800,0.007031522;
        14972400,0.01106665; 14976000,0.004222281; 14979600,0.00328926;
        14983200,0.005996703; 14986800,0.00344; 14990400,0.002925135; 14994000,
        0.008340414; 14997600,0.00680091; 15001200,0.003506169; 15004800,
        0.004459549; 15008400,0.003104065; 15012000,0.002751687; 15015600,
        0.008046373; 15019200,0.014694977; 15022800,0.006837322; 15026400,
        0.003921976; 15030000,0.005931709; 15033600,0.00108376; 15037200,1e-06;
        15040800,0.006114163; 15044400,0.002923178; 15048000,0.002568058;
        15051600,0.002370334; 15055200,0.006973184; 15058800,0.010303555;
        15062400,0.004061361; 15066000,0.003282995; 15069600,0.005704229;
        15073200,0.003364434; 15076800,0.002909865; 15080400,0.008609004;
        15084000,0.006359262; 15087600,0.003478761; 15091200,0.004542554;
        15094800,0.003116594; 15098400,0.002764216; 15102000,0.008125071;
        15105600,0.014862161; 15109200,0.008038934; 15112800,0.003988536;
        15116400,0.006103592; 15120000,0.001101771; 15123600,1e-06; 15127200,
        0.006149009; 15130800,0.002929442; 15134400,0.002584894; 15138000,
        0.002383255; 15141600,0.007009596; 15145200,0.010047101; 15148800,
        0.004094641; 15152400,0.003282604; 15156000,0.006145485; 15159600,
        0.003454486; 15163200,0.002919262; 15166800,0.00819124; 15170400,
        0.006849851; 15174000,0.003529269; 15177600,0.004476776; 15181200,
        0.003108372; 15184800,0.002748946; 15188400,0.008039325; 15192000,
        0.014774066; 15195600,0.007903855; 15199200,0.003976007; 15202800,
        0.006091846; 15206400,0.001101771; 15210000,1e-06; 15213600,0.006068354;
        15217200,0.002922003; 15220800,0.002581762; 15224400,0.002380906;
        15228000,0.00700294; 15231600,0.010343099; 15235200,0.004099339;
        15238800,0.003291609; 15242400,0.005972428; 15246000,0.003432169;
        15249600,0.002912215; 15253200,0.008444561; 15256800,0.006787989;
        15260400,0.003538274; 15264000,0.004496744; 15267600,0.003119335;
        15271200,0.002738766; 15274800,0.008131727; 15278400,0.014776416;
        15282000,0.007800099; 15285600,0.003934113; 15289200,0.005912524;
        15292800,0.001104512; 15296400,1e-06; 15300000,0.006125909; 15303600,
        0.00292631; 15307200,0.002579804; 15310800,0.002379731; 15314400,
        0.006997067; 15318000,0.0102922; 15321600,0.004105996; 15325200,
        0.003290826; 15328800,0.005668208; 15332400,0.003405545; 15336000,
        0.002927093; 15339600,0.008589819; 15343200,0.006556594; 15346800,
        0.003457227; 15350400,0.004448978; 15354000,0.003101716; 15357600,
        0.002732501; 15361200,0.008035019; 15364800,0.014688713; 15368400,
        0.006798952; 15372000,0.003920801; 15375600,0.005805636; 15379200,
        0.001058702; 15382800,1e-06; 15386400,0.00610829; 15390000,0.002918479;
        15393600,0.002577063; 15397200,0.00237699; 15400800,0.00699002;
        15404400,0.010306295; 15408000,0.004111869; 15411600,0.00329944;
        15415200,0.005978301; 15418800,0.003443523; 15422400,0.002932574;
        15426000,0.008461397; 15429600,0.00677037; 15433200,0.003533184;
        15436800,0.004489697; 15440400,0.003107198; 15444000,0.002741115;
        15447600,0.008308699; 15451200,0.014852764; 15454800,0.007646619;
        15458400,0.003964652; 15462000,0.005930534; 15465600,0.001101771;
        15469200,1e-06; 15472800,0.006051126; 15476400,0.002913389; 15480000,
        0.002569233; 15483600,0.002375033; 15487200,0.006853767; 15490800,
        0.011088185; 15494400,0.004244989; 15498000,0.003305313; 15501600,
        0.005848704; 15505200,0.003428645; 15508800,0.00290595; 15512400,
        0.008622708; 15516000,0.00598809; 15519600,0.003510084; 15523200,
        0.004499485; 15526800,0.003120118; 15530400,0.002743073; 15534000,
        0.008127812; 15537600,0.014811262; 15541200,0.007585148; 15544800,
        0.003929023; 15548400,0.005925836; 15552000,0.001104903; 15555600,1e-06;
        15559200,0.006125909; 15562800,0.002902818; 15566400,0.002566883;
        15570000,0.002373858; 15573600,0.006982972; 15577200,0.010301989;
        15580800,0.004061752; 15584400,0.003277514; 15588000,0.005943455;
        15591600,0.003438434; 15595200,0.00292905; 15598800,0.008453566;
        15602400,0.006769196; 15606000,0.003497555; 15609600,0.004452893;
        15613200,0.003140086; 15616800,0.002758734; 15620400,0.008048331;
        15624000,0.014717294; 15627600,0.007900332; 15631200,0.003912187;
        15634800,0.005959116; 15638400,0.001086501; 15642000,1e-06; 15645600,
        0.006053475; 15649200,0.002900469; 15652800,0.002575889; 15656400,
        0.002377774; 15660000,0.006992369; 15663600,0.010359152; 15667200,
        0.004072715; 15670800,0.003288477; 15674400,0.005832651; 15678000,
        0.003431778; 15681600,0.002934923; 15685200,0.008804379; 15688800,
        0.006237104; 15692400,0.003517131; 15696000,0.00453903; 15699600,
        0.003105631; 15703200,0.00274229; 15706800,0.00812742; 15710400,
        0.014760754; 15714000,0.006988454; 15717600,0.003957213; 15721200,
        0.005935233; 15724800,0.001090808; 15728400,1e-06; 15732000,0.006112597;
        15735600,0.002900077; 15739200,0.002570016; 15742800,0.002373467;
        15746400,0.006885481; 15750000,0.010034181; 15753600,0.004078588;
        15757200,0.003275948; 15760800,0.005881593; 15764400,0.003383619;
        15768000,0.002917305; 15771600,0.008658337; 15775200,0.006123951;
        15778800,0.003477195; 15782400,0.004491263; 15786000,0.003122076;
        15789600,0.002748554; 15793200,0.008111759; 15796800,0.014827706;
        15800400,0.007073416; 15804000,0.003968959; 15807600,0.005961857;
        15811200,0.001096289; 15814800,1e-06; 15818400,0.006119644; 15822000,
        0.002908691; 15825600,0.002572756; 15829200,0.00237699; 15832800,
        0.006875693; 15836400,0.011040418; 15840000,0.004216016; 15843600,
        0.00328926; 15847200,0.006091454; 15850800,0.003400455; 15854400,
        0.002903601; 15858000,0.008539703; 15861600,0.006610234; 15865200,
        0.003511259; 15868800,0.004451718; 15872400,0.003091536; 15876000,
        0.002732501; 15879600,0.008011135; 15883200,0.014705548; 15886800,
        0.007194791; 15890400,0.003961129; 15894000,0.005903519; 15897600,
        0.001073189; 15901200,1e-06; 15904800,0.00612356; 15908400,0.002886374;
        15912000,0.002570016; 15915600,0.002375033; 15919200,0.006991978;
        15922800,0.010373247; 15926400,0.004099339; 15930000,0.003280646;
        15933600,0.005967338; 15937200,0.003420815; 15940800,0.002903601;
        15944400,0.008080045; 15948000,0.006854158; 15951600,0.003523396;
        15955200,0.004466988; 15958800,0.003113071; 15962400,0.002731718;
        15966000,0.007954363; 15969600,0.01475958; 15973200,0.007946924;
        15976800,0.003984229; 15980400,0.006103592; 15984000,0.001101379;
        15987600,1e-06; 15991200,0.006099676; 15994800,0.002925135; 15998400,
        0.002574714; 16002000,0.002376599; 16005600,0.00699511; 16009200,
        0.010337618; 16012800,0.004105212; 16016400,0.003283387; 16020000,
        0.005963815; 16023600,0.003443132; 16027200,0.0029314; 16030800,
        0.008454741; 16034400,0.006772328; 16038000,0.003532401; 16041600,
        0.00448539; 16045200,0.003146742; 16048800,0.002773221; 16052400,
        0.008088658; 16056000,0.014743919; 16059600,0.007910903; 16063200,
        0.003953298; 16066800,0.00607501; 16070400,0.001099422; 16074000,1e-06;
        16077600,0.00606992; 16081200,0.002912606; 16084800,0.002566492;
        16088400,0.002372684; 16092000,0.006980232; 16095600,0.009978975;
        16099200,0.004075848; 16102800,0.003292001; 16106400,0.005961074;
        16110000,0.003426296; 16113600,0.002907125; 16117200,0.008489196;
        16120800,0.006728477; 16124400,0.003519481; 16128000,0.004475993;
        16131600,0.003147917; 16135200,0.002772046; 16138800,0.00808396;
        16142400,0.014715337; 16146000,0.007893284; 16149600,0.003954081;
        16153200,0.005911349; 16156800,0.001103729; 16160400,1e-06; 16164000,
        0.006062872; 16167600,0.002897728; 16171200,0.002575106; 16174800,
        0.002377774; 16178400,0.006874518; 16182000,0.010994609; 16185600,
        0.004214058; 16189200,0.003295916; 16192800,0.006138046; 16196400,
        0.003444307; 16200000,0.002905167; 16203600,0.00834981; 16207200,
        0.00675745; 16210800,0.003513216; 16214400,0.004459549; 16218000,
        0.003139695; 16221600,0.002766173; 16225200,0.008062034; 16228800,
        0.014698109; 16232400,0.007890935; 16236000,0.003968959; 16239600,
        0.005952069; 16243200,0.001080628; 16246800,1e-06; 16250400,0.006122777;
        16254000,0.002925918; 16257600,0.002580587; 16261200,0.002378948;
        16264800,0.00696966; 16268400,0.010765562; 16272000,0.004172556;
        16275600,0.003271641; 16279200,0.005978301; 16282800,0.003378921;
        16286400,0.002892638; 16290000,0.00830361; 16293600,0.00677272;
        16297200,0.003498338; 16300800,0.004453284; 16304400,0.003121684;
        16308000,0.00275756; 16311600,0.008046373; 16315200,0.01471103;
        16318800,0.00778483; 16322400,0.003967785; 16326000,0.006087147;
        16329600,0.001101771; 16333200,1e-06; 16336800,0.006048777; 16340400,
        0.002883241; 16344000,0.002572365; 16347600,0.002374641; 16351200,
        0.006850634; 16354800,0.009823537; 16358400,0.004011245; 16362000,
        0.003251673; 16365600,0.006052692; 16369200,0.003420032; 16372800,
        0.002905167; 16376400,0.008612137; 16380000,0.005793498; 16383600,
        0.003467015; 16387200,0.004376936; 16390800,0.003082531; 16394400,
        0.002732501; 16398000,0.008071823; 16401600,0.014708289; 16405200,
        0.006977882; 16408800,0.003951732; 16412400,0.005925836; 16416000,
        0.001089633; 16419600,1e-06; 16423200,0.006102417; 16426800,0.002905167;
        16430400,0.002562185; 16434000,0.002368377; 16437600,0.006907015;
        16441200,0.010926874; 16444800,0.004194873; 16448400,0.003283387;
        16452000,0.006144702; 16455600,0.00342473; 16459200,0.002901252;
        16462800,0.008335324; 16466400,0.005656854; 16470000,0.003465449;
        16473600,0.004444279; 16477200,0.003136954; 16480800,0.00275012;
        16484400,0.008186541; 16488000,0.014742744; 16491600,0.007419139;
        16495200,0.003959171; 16498800,0.005949328; 16502400,0.001097856;
        16506000,1e-06; 16509600,0.006286828; 16513200,0.002921611; 16516800,
        0.002579412; 16520400,0.00237934; 16524000,0.006993152; 16527600,
        0.010146159; 16531200,0.004082895; 16534800,0.003282212; 16538400,
        0.005920746; 16542000,0.003421989; 16545600,0.002894596; 16549200,
        0.008427725; 16552800,0.006736307; 16556400,0.003528094; 16560000,
        0.004481475; 16563600,0.003148308; 16567200,0.002772046; 16570800,
        0.008079262; 16574400,0.014707506; 16578000,0.007550694; 16581600,
        0.003917277; 16585200,0.005907042; 16588800,0.001101771; 16592400,1e-06;
        16596000,0.006141179; 16599600,0.002881675; 16603200,0.002557878;
        16606800,0.00236407; 16610400,0.006955957; 16614000,0.010265185;
        16617600,0.004061752; 16621200,0.003259503; 16624800,0.005930143;
        16628400,0.00339419; 16632000,0.002892638; 16635600,0.008179102;
        16639200,0.006825185; 16642800,0.003502253; 16646400,0.00445211;
        16650000,0.003100933; 16653600,0.002752861; 16657200,0.008038934;
        16660800,0.014678924; 16664400,0.007093384; 16668000,0.003912187;
        16671600,0.005904302; 16675200,0.001102162; 16678800,1e-06; 16682400,
        0.00610829; 16686000,0.002887548; 16689600,0.002562577; 16693200,
        0.002368377; 16696800,0.006965745; 16700400,0.010278105; 16704000,
        0.004037477; 16707600,0.00325089; 16711200,0.005960291; 16714800,
        0.00341455; 16718400,0.002891072; 16722000,0.008603131; 16725600,
        0.006071877; 16729200,0.003504602; 16732800,0.004519062; 16736400,
        0.003151049; 16740000,0.002760692; 16743600,0.008130161; 16747200,
        0.014898182; 16750800,0.007090252; 16754400,0.003954864; 16758000,
        0.00606483; 16761600,0.001067316; 16765200,1e-06; 16768800,0.006135306;
        16772400,0.002914955; 16776000,0.002580587; 16779600,0.002380514;
        16783200,0.00700294; 16786800,0.010048667; 16790400,0.004087985;
        16794000,0.003279472; 16797600,0.00594737; 16801200,0.003404762;
        16804800,0.002909474; 16808400,0.008506423; 16812000,0.006730826;
        16815600,0.003536708; 16819200,0.004499485; 16822800,0.003136562;
        16826400,0.002767348; 16830000,0.008082002; 16833600,0.014816743;
        16837200,0.007112178; 16840800,0.003893394; 16844400,0.006060915;
        16848000,0.001102554; 16851600,1e-06; 16855200,0.006100851; 16858800,
        0.002909474; 16862400,0.002578629; 16866000,0.002378948; 16869600,
        0.00699511; 16873200,0.010288285; 16876800,0.004058229; 16880400,
        0.003285345; 16884000,0.005918005; 16887600,0.003364042; 16891200,
        0.002889506; 16894800,0.008714327; 16898400,0.006152141; 16902000,
        0.003484243; 16905600,0.004478342; 16909200,0.003116203; 16912800,
        0.002765782; 16916400,0.008087092; 16920000,0.014738437; 16923600,
        0.007703391; 16927200,0.003945859; 16930800,0.005920355; 16934400,
        0.001097073; 16938000,1e-06; 16941600,0.006142745; 16945200,0.002878934;
        16948800,0.002562577; 16952400,0.002371509; 16956000,0.006890571;
        16959600,0.010796885; 16963200,0.004125181; 16966800,0.003271249;
        16970400,0.00597791; 16974000,0.003384794; 16977600,0.002883241;
        16981200,0.008292647; 16984800,0.006812656; 16988400,0.003483851;
        16992000,0.004456808; 16995600,0.003103674; 16999200,0.002753253;
        17002800,0.008038151; 17006400,0.014822225; 17010000,0.007299722;
        17013600,0.003928632; 17017200,0.006029592; 17020800,0.001100988;
        17024400,1e-06; 17028000,0.006111031; 17031600,0.002896945; 17035200,
        0.002569624; 17038800,0.002373075; 17042400,0.006966919; 17046000,
        0.01079571; 17049600,0.004168249; 17053200,0.003264985; 17056800,
        0.005950503; 17060400,0.003406719; 17064000,0.002889506; 17067600,
        0.008570634; 17071200,0.00576335; 17074800,0.003496772; 17078400,
        0.004494004; 17082000,0.003137345; 17085600,0.002757168; 17089200,
        0.008154436; 17092800,0.014784638; 17096400,0.007861178; 17100000,
        0.003982271; 17103600,0.006101242; 17107200,0.001100596; 17110800,1e-06;
        17114400,0.006119253; 17118000,0.00292122; 17121600,0.002569624;
        17125200,0.002376207; 17128800,0.006876084; 17132400,0.010427279;
        17136000,0.004087202; 17139600,0.003277905; 17143200,0.006048386;
        17146800,0.00344274; 17150400,0.002920828; 17154000,0.008519344;
        17157600,0.006704593; 17161200,0.003494423; 17164800,0.004459549;
        17168400,0.003106023; 17172000,0.00275756; 17175600,0.008059294;
        17179200,0.014879389; 17182800,0.007951231; 17186400,0.003960346;
        17190000,0.006071486; 17193600,0.001102162; 17197200,1e-06; 17200800,
        0.006149401; 17204400,0.002930225; 17208000,0.002579412; 17211600,
        0.00237934; 17215200,0.007003723; 17218800,0.010387343; 17222400,
        0.004131054; 17226000,0.003304921; 17229600,0.005982608; 17233200,
        0.003444698; 17236800,0.002905559; 17240400,0.008584338; 17244000,
        0.006493949; 17247600,0.003532793; 17251200,0.004494004; 17254800,
        0.003137737; 17258400,0.002752078; 17262000,0.008275811; 17265600,
        0.014811262; 17269200,0.007363541; 17272800,0.003925499; 17276400,
        0.005999444; 17280000,0.001093549; 17283600,1e-06; 17287200,0.00612121;
        17290800,0.00289577; 17294400,0.002566492; 17298000,0.002371117;
        17301600,0.006886655; 17305200,0.010066678; 17308800,0.003975224;
        17312400,0.003261461; 17316000,0.005797022; 17319600,0.003378529;
        17323200,0.00288794; 17326800,0.00819124; 17330400,0.006789947;
        17334000,0.003494031; 17337600,0.004454459; 17341200,0.00311816;
        17344800,0.00274738; 17348400,0.008031886; 17352000,0.014741569;
        17355600,0.007902681; 17359200,0.003940769; 17362800,0.005925053;
        17366400,0.001099813; 17370000,1e-06; 17373600,0.006090671; 17377200,
        0.00291613; 17380800,0.002571973; 17384400,0.002373858; 17388000,
        0.007033088; 17391600,0.011124206; 17395200,0.004239899; 17398800,
        0.003307662; 17402400,0.006163496; 17406000,0.003407894; 17409600,
        0.002918088; 17413200,0.008195155; 17416800,0.006850243; 17420400,
        0.003484243; 17424000,0.004415306; 17427600,0.003076267; 17431200,
        0.002722713; 17434800,0.008141907; 17438400,0.014713771; 17442000,
        0.007385859; 17445600,0.00393333; 17449200,0.005862016; 17452800,
        0.001067316; 17456400,1e-06; 17460000,0.006097327; 17463600,0.002920828;
        17467200,0.002573148; 17470800,0.00237425; 17474400,0.006981015;
        17478000,0.010315692; 17481600,0.004113435; 17485200,0.003292784;
        17488800,0.005967338; 17492400,0.003430211; 17496000,0.002905167;
        17499600,0.008192806; 17503200,0.006832232; 17506800,0.003503819;
        17510400,0.004453676; 17514000,0.003101716; 17517600,0.002753644;
        17521200,0.008201028; 17524800,0.014778765; 17528400,0.007002549;
        17532000,0.003962695; 17535600,0.00593954; 17539200,0.001091591;
        17542800,1e-06; 17546400,0.006127083; 17550000,0.002916521; 17553600,
        0.002574323; 17557200,0.002375424; 17560800,0.006991978; 17564400,
        0.01031256; 17568000,0.004087594; 17571600,0.003289651; 17575200,
        0.005732419; 17578800,0.003411026; 17582400,0.002895379; 17586000,
        0.008542444; 17589600,0.006589091; 17593200,0.0034631; 17596800,
        0.004436057; 17600400,0.003124425; 17604000,0.002765782; 17607600,
        0.008167356; 17611200,0.014746659; 17614800,0.007830247; 17618400,
        0.0039717; 17622000,0.006090671; 17625600,0.001101771; 17629200,1e-06;
        17632800,0.006141179; 17636400,0.002929834; 17640000,0.002581762;
        17643600,0.002380514; 17647200,0.006997459; 17650800,0.010294158;
        17654400,0.004057837; 17658000,0.00328417; 17661600,0.005966555;
        17665200,0.003432169; 17668800,0.002907125; 17672400,0.008616835;
        17676000,0.006219877; 17679600,0.003466232; 17683200,0.004442321;
        17686800,0.003100933; 17690400,0.002743856; 17694000,0.008179885;
        17697600,0.014750183; 17701200,0.007540122; 17704800,0.003944684;
        17708400,0.005907042; 17712000,0.001068099; 17715600,1e-06; 17719200,
        0.006116904; 17722800,0.002928267; 17726400,0.002577063; 17730000,
        0.00237699; 17733600,0.006993152; 17737200,0.010372464; 17740800,
        0.004125181; 17744400,0.003307662; 17748000,0.005994354; 17751600,
        0.003421598; 17755200,0.002898119; 17758800,0.008466095; 17762400,
        0.006708508; 17766000,0.003462709; 17769600,0.004455634; 17773200,
        0.003141261; 17776800,0.002770089; 17780400,0.008188108; 17784000,
        0.014786204; 17787600,0.007759772; 17791200,0.00393333; 17794800,
        0.005768832; 17798400,0.001099422; 17802000,1e-06; 17805600,0.006049169;
        17809200,0.002897336; 17812800,0.002574323; 17816400,0.002378165;
        17820000,0.006995501; 17823600,0.010314909; 17827200,0.00406371;
        17830800,0.003260678; 17834400,0.006025677; 17838000,0.00339654;
        17841600,0.002892638; 17845200,0.008185367; 17848800,0.006826751;
        17852400,0.003525354; 17856000,0.004451718; 17859600,0.003109938;
        17863200,0.002760692; 17866800,0.00806086; 17870400,0.014694977;
        17874000,0.007268791; 17877600,0.003936854; 17881200,0.006066396;
        17884800,0.001036777; 17888400,1e-06; 17892000,0.006081666; 17895600,
        0.002894987; 17899200,0.002569624; 17902800,0.002373467; 17906400,
        0.006980232; 17910000,0.01001617; 17913600,0.004084853; 17917200,
        0.003264202; 17920800,0.006026851; 17924400,0.003379704; 17928000,
        0.002912998; 17931600,0.008170097; 17935200,0.006801693; 17938800,
        0.003497946; 17942400,0.004463464; 17946000,0.003137737; 17949600,
        0.002749729; 17953200,0.008036976; 17956800,0.014801082; 17960400,
        0.006905449; 17964000,0.003926674; 17967600,0.005914482; 17971200,
        0.0010912; 17974800,1e-06; 17978400,0.006052301; 17982000,0.002874236;
        17985600,0.002568058; 17989200,0.002373858; 17992800,0.00662707;
        17996400,0.009712341; 18000000,0.00403043; 18003600,0.003266943;
        18007200,0.005766874; 18010800,0.003406719; 18014400,0.002898511;
        18018000,0.008527957; 18021600,0.005911741; 18025200,0.003512042;
        18028800,0.004508099; 18032400,0.003149875; 18036000,0.002753253;
        18039600,0.007927739; 18043200,0.014655824; 18046800,0.006934422;
        18050400,0.003924716; 18054000,0.006028417; 18057600,0.001096681;
        18061200,1e-06; 18064800,0.006089105; 18068400,0.002893813; 18072000,
        0.002560619; 18075600,0.002369943; 18079200,0.006704985; 18082800,
        0.009757759; 18086400,0.004039827; 18090000,0.003275948; 18093600,
        0.006094586; 18097200,0.003372656; 18100800,0.002877368; 18104400,
        0.008521693; 18108000,0.005753562; 18111600,0.003460751; 18115200,
        0.004457983; 18118800,0.00311542; 18122400,0.002741115; 18126000,
        0.008156394; 18129600,0.014729823; 18133200,0.007615296; 18136800,
        0.003944684; 18140400,0.005931709; 18144000,0.001078671; 18147600,1e-06;
        18151200,0.006121602; 18154800,0.002903601; 18158400,0.002562577;
        18162000,0.002368377; 18165600,0.006966528; 18169200,0.010268708;
        18172800,0.004079371; 18176400,0.003273207; 18180000,0.00597282;
        18183600,0.003390667; 18187200,0.002894204; 18190800,0.008215515;
        18194400,0.006774677; 18198000,0.003497946; 18201600,0.004464247;
        18205200,0.003137737; 18208800,0.002749337; 18212400,0.008036585;
        18216000,0.014703199; 18219600,0.007403478; 18223200,0.003941161;
        18226800,0.005705404; 18230400,0.001070448; 18234000,1e-06; 18237600,
        0.006039772; 18241200,0.002856617; 18244800,0.002555921; 18248400,
        0.00236407; 18252000,0.006843195; 18255600,0.010965635; 18259200,
        0.004171773; 18262800,0.003279472; 18266400,0.005979867; 18270000,
        0.003376572; 18273600,0.002878543; 18277200,0.00807378; 18280800,
        0.005697964; 18284400,0.003479936; 18288000,0.004494787; 18291600,
        0.003129515; 18295200,0.002739549; 18298800,0.008047156; 18302400,
        0.014676575; 18306000,0.007874099; 18309600,0.003970917; 18313200,
        0.006084406; 18316800,0.001099813; 18320400,1e-06; 18324000,0.006048386;
        18327600,0.002876977; 18331200,0.002571973; 18334800,0.002377382;
        18338400,0.006919153; 18342000,0.01093627; 18345600,0.004177646;
        18349200,0.00325598; 18352800,0.006014714; 18356400,0.003380878;
        18360000,0.002893813; 18363600,0.008197113; 18367200,0.006822836;
        18370800,0.003524571; 18374400,0.004471686; 18378000,0.003094669;
        18381600,0.002734068; 18385200,0.008158743; 18388800,0.014723559;
        18392400,0.007649751; 18396000,0.003957605; 18399600,0.00592936;
        18403200,0.001051655; 18406800,1e-06; 18410400,0.006104766; 18414000,
        0.002921611; 18417600,0.002579021; 18421200,0.002378948; 18424800,
        0.006992369; 18428400,0.010303163; 18432000,0.00404061; 18435600,
        0.003262636; 18439200,0.00613139; 18442800,0.003423947; 18446400,
        0.002902818; 18450000,0.008378784; 18453600,0.005683478; 18457200,
        0.003436867; 18460800,0.004425094; 18464400,0.003081356; 18468000,
        0.002727803; 18471600,0.007645444; 18475200,0.014607665; 18478800,
        0.007207712; 18482400,0.003906706; 18486000,0.005917222; 18489600,
        0.001097464; 18493200,1e-06; 18496800,0.006060523; 18500400,0.002919262;
        18504000,0.002573539; 18507600,0.002375424; 18511200,0.006981406;
        18514800,0.010331745; 18518400,0.00407898; 18522000,0.003271249;
        18525600,0.005783318; 18529200,0.003364434; 18532800,0.002903601;
        18536400,0.008640327; 18540000,0.006442658; 18543600,0.003498338;
        18547200,0.004551167; 18550800,0.00312051; 18554400,0.002759909;
        18558000,0.008090225; 18561600,0.014728257; 18565200,0.00787958;
        18568800,0.003941944; 18572400,0.00606483; 18576000,0.001086893;
        18579600,1e-06; 18583200,0.006233189; 18586800,0.002917305; 18590400,
        0.002569624; 18594000,0.002375424; 18597600,0.006995501; 18601200,
        0.010775742; 18604800,0.00409425; 18608400,0.003264593; 18612000,
        0.006162713; 18615600,0.003411809; 18619200,0.002896162; 18622800,
        0.008630147; 18626400,0.006000227; 18630000,0.003472105; 18633600,
        0.004468554; 18637200,0.003146742; 18640800,0.002763432; 18644400,
        0.008279726; 18648000,0.014912669; 18651600,0.00778483; 18655200,
        0.003982271; 18658800,0.006029984; 18662400,0.001097073; 18666000,1e-06;
        18669600,0.006116904; 18673200,0.002928267; 18676800,0.002578238;
        18680400,0.002379731; 18684000,0.007004898; 18687600,0.010333703;
        18691200,0.004117741; 18694800,0.003283387; 18698400,0.006203041;
        18702000,0.003454095; 18705600,0.002918088; 18709200,0.008652073;
        18712800,0.006390193; 18716400,0.003489724; 18720000,0.004521802;
        18723600,0.003134213; 18727200,0.002743856; 18730800,0.008094923;
        18734400,0.014761929; 18738000,0.007416007; 18741600,0.0039486;
        18745200,0.005946587; 18748800,0.001099422; 18752400,1e-06; 18756000,
        0.006090671; 18759600,0.002922394; 18763200,0.002570016; 18766800,
        0.002375033; 18770400,0.006980623; 18774000,0.009956657; 18777600,
        0.004013986; 18781200,0.003278297; 18784800,0.00610829; 18788400,
        0.003379704; 18792000,0.002915738; 18795600,0.008475101; 18799200,
        0.006681884; 18802800,0.003465449; 18806400,0.004460723; 18810000,
        0.003088404; 18813600,0.002726628; 18817200,0.008215515; 18820800,
        0.014909145; 18824400,0.007878797; 18828000,0.003986187; 18831600,
        0.005925444; 18835200,0.001061835; 18838800,1e-06; 18842400,0.006111031;
        18846000,0.002906342; 18849600,0.002571973; 18853200,0.002376599;
        18856800,0.006996676; 18860400,0.010392824; 18864000,0.004129096;
        18867600,0.003296699; 18871200,0.005956376; 18874800,0.003393799;
        18878400,0.002906733; 18882000,0.008216689; 18885600,0.006838497;
        18889200,0.003526137; 18892800,0.004475602; 18896400,0.003141652;
        18900000,0.002752078; 18903600,0.008044415; 18907200,0.014691062;
        18910800,0.007466123; 18914400,0.003901224; 18918000,0.00591409;
        18921600,0.001082977; 18925200,1e-06; 18928800,0.006096152; 18932400,
        0.002892638; 18936000,0.002566492; 18939600,0.002372292; 18943200,
        0.006975533; 18946800,0.010305904; 18950400,0.004083287; 18954000,
        0.003272424; 18957600,0.00594737; 18961200,0.003425513; 18964800,
        0.002900077; 18968400,0.008086701; 18972000,0.005780969; 18975600,
        0.003466624; 18979200,0.004460332; 18982800,0.003135779; 18986400,
        0.002754819; 18990000,0.00804559; 18993600,0.014711421; 18997200,
        0.007885062; 19000800,0.003908663; 19004400,0.005907042; 19008000,
        0.001102554; 19011600,1e-06; 19015200,0.006129433; 19018800,0.002887548;
        19022400,0.00256845; 19026000,0.002373858; 19029600,0.006978274;
        19033200,0.010283978; 19036800,0.004104429; 19040400,0.003269683;
        19044000,0.005945804; 19047600,0.00342982; 19051200,0.00292905;
        19054800,0.008502116; 19058400,0.006745704; 19062000,0.003534359;
        19065600,0.004494004; 19069200,0.003151049; 19072800,0.002774787;
        19076400,0.008091008; 19080000,0.01471612; 19083600,0.006869036;
        19087200,0.003889087; 19090800,0.006053867; 19094400,0.001096681;
        19098000,1e-06; 19101600,0.006073052; 19105200,0.002896553; 19108800,
        0.002570016; 19112400,0.00237425; 19116000,0.006982189; 19119600,
        0.010378337; 19123200,0.004118133; 19126800,0.003264593; 19130400,
        0.005907042; 19134000,0.003372265; 19137600,0.002886765; 19141200,
        0.008637978; 19144800,0.005746906; 19148400,0.0034862; 19152000,
        0.004484607; 19155600,0.003151832; 19159200,0.002776353; 19162800,
        0.008106277; 19166400,0.014754881; 19170000,0.007055797; 19173600,
        0.00393333; 19177200,0.006054258; 19180800,0.001099813; 19184400,1e-06;
        19188000,0.006065613; 19191600,0.002913781; 19195200,0.002569624;
        19198800,0.002375424; 19202400,0.006987279; 19206000,0.010338401;
        19209600,0.004073498; 19213200,0.003255197; 19216800,0.005963032;
        19220400,0.003369915; 19224000,0.002880892; 19227600,0.008506815;
        19231200,0.006618065; 19234800,0.003524179; 19238400,0.004484998;
        19242000,0.003149091; 19245600,0.002772438; 19249200,0.008081219;
        19252800,0.014714945; 19256400,0.006982581; 19260000,0.003947034;
        19263600,0.005801329; 19267200,0.001059485; 19270800,1e-06; 19274400,
        0.006104766; 19278000,0.002923569; 19281600,0.002578629; 19285200,
        0.002378948; 19288800,0.006991194; 19292400,0.010299248; 19296000,
        0.004100514; 19299600,0.00326381; 19303200,0.005970471; 19306800,
        0.003375397; 19310400,0.002875019; 19314000,0.008381916; 19317600,
        0.006732392; 19321200,0.003524571; 19324800,0.004478734; 19328400,
        0.003109547; 19332000,0.002755993; 19335600,0.008054987; 19339200,
        0.014830056; 19342800,0.007413657; 19346400,0.003972483; 19350000,
        0.005970079; 19353600,0.001099813; 19357200,1e-06; 19360800,0.006193252;
        19364400,0.002920045; 19368000,0.002581762; 19371600,0.002382472;
        19375200,0.006946951; 19378800,0.01093353; 19382400,0.004167075;
        19386000,0.003280255; 19389600,0.00557659; 19393200,0.003335461;
        19396800,0.002894204; 19400400,0.008522476; 19404000,0.005679562;
        19407600,0.003438825; 19411200,0.004432533; 19414800,0.003118943;
        19418400,0.002735242; 19422000,0.008079262; 19425600,0.01470085;
        19429200,0.007847866; 19432800,0.003970525; 19436400,0.006086756;
        19440000,0.001099813; 19443600,1e-06; 19447200,0.006142745; 19450800,
        0.00290086; 19454400,0.002559836; 19458000,0.002369943; 19461600,
        0.00700529; 19465200,0.011001265; 19468800,0.004140842; 19472400,
        0.003296307; 19476000,0.006102025; 19479600,0.003407503; 19483200,
        0.002907908; 19486800,0.008199854; 19490400,0.00683928; 19494000,
        0.003527703; 19497600,0.00447521; 19501200,0.003104065; 19504800,
        0.002738374; 19508400,0.008020923; 19512000,0.014674226; 19515600,
        0.00788467; 19519200,0.003969742; 19522800,0.006081274; 19526400,
        0.001101379; 19530000,1e-06; 19533600,0.006107898; 19537200,0.002900469;
        19540800,0.002561794; 19544400,0.002371117; 19548000,0.006975925;
        19551600,0.01037638; 19555200,0.004117741; 19558800,0.003295916;
        19562400,0.005975952; 19566000,0.003412984; 19569600,0.00291613;
        19573200,0.008620359; 19576800,0.006312278; 19580400,0.003478761;
        19584000,0.004499485; 19587600,0.003099367; 19591200,0.002746597;
        19594800,0.008304001; 19598400,0.014976097; 19602000,0.007538165;
        19605600,0.003973658; 19609200,0.005964989; 19612800,0.001102554;
        19616400,1e-06; 19620000,0.006085973; 19623600,0.002924744; 19627200,
        0.002576672; 19630800,0.002376599; 19634400,0.006995893; 19638000,
        0.01034584; 19641600,0.004099731; 19645200,0.003279472; 19648800,
        0.005959508; 19652400,0.00344274; 19656000,0.002926701; 19659600,
        0.008637195; 19663200,0.006099676; 19666800,0.003517523; 19670400,
        0.004541379; 19674000,0.003139695; 19677600,0.002759909; 19681200,
        0.00773902; 19684800,0.014619803; 19688400,0.007022125; 19692000,
        0.003939986; 19695600,0.005929751; 19699200,0.001092766; 19702800,1e-06;
        19706400,0.00609811; 19710000,0.002907125; 19713600,0.002570016;
        19717200,0.002373075; 19720800,0.006983755; 19724400,0.010317258;
        19728000,0.004093075; 19731600,0.003277514; 19735200,0.005954026;
        19738800,0.003428645; 19742400,0.002926701; 19746000,0.008448868;
        19749600,0.006768804; 19753200,0.003505777; 19756800,0.004467771;
        19760400,0.003139695; 19764000,0.002749337; 19767600,0.008037368;
        19771200,0.014687146; 19774800,0.007887803; 19778400,0.003970525;
        19782000,0.006083232; 19785600,0.001100988; 19789200,1e-06; 19792800,
        0.006084798; 19796400,0.00291613; 19800000,0.002568841; 19803600,
        0.002373858; 19807200,0.006856899; 19810800,0.011047074; 19814400,
        0.004235593; 19818000,0.003282604; 19821600,0.006120819; 19825200,
        0.003418465; 19828800,0.002914172; 19832400,0.008412455; 19836000,
        0.00674218; 19839600,0.003474063; 19843200,0.004447803; 19846800,
        0.003091145; 19850400,0.002728195; 19854000,0.008054595; 19857600,
        0.014826532; 19861200,0.007888977; 19864800,0.003977182; 19868400,
        0.006093412; 19872000,0.001101379; 19875600,1e-06; 19879200,0.00607266;
        19882800,0.00289577; 19886400,0.00256845; 19890000,0.002373858;
        19893600,0.006963396; 19897200,0.010837996; 19900800,0.004126747;
        19904400,0.00326616; 19908000,0.005592642; 19911600,0.00339928;
        19915200,0.002901643; 19918800,0.008596867; 19922400,0.006185813;
        19926000,0.003489333; 19929600,0.00449557; 19933200,0.003104065;
        19936800,0.002753644; 19940400,0.007713571; 19944000,0.014720818;
        19947600,0.008034236; 19951200,0.003967002; 19954800,0.005938365;
        19958400,0.001102945; 19962000,1e-06; 19965600,0.006144702; 19969200,
        0.002928267; 19972800,0.002580196; 19976400,0.00237934; 19980000,
        0.006994718; 19983600,0.01028946; 19987200,0.004110302; 19990800,
        0.003286519; 19994400,0.005954418; 19998000,0.00344; 20001600,
        0.002930617; 20005200,0.008461005; 20008800,0.006768804; 20012400,
        0.003533184; 20016000,0.004490088; 20019600,0.003151441; 20023200,
        0.002774004; 20026800,0.008085135; 20030400,0.014712204; 20034000,
        0.007891326; 20037600,0.003971309; 20041200,0.006084015; 20044800,
        0.001099813; 20048400,1e-06; 20052000,0.00607501; 20055600,0.002924352;
        20059200,0.002575106; 20062800,0.002374641; 20066400,0.006853375;
        20070000,0.009878743; 20073600,0.004019075; 20077200,0.00325598;
        20080800,0.006006883; 20084400,0.00343491; 20088000,0.002917305;
        20091600,0.008424201; 20095200,0.005739075; 20098800,0.003500687;
        20102400,0.004524152; 20106000,0.003112287; 20109600,0.0027603;
        20113200,0.008063992; 20116800,0.014696543; 20120400,0.007885845;
        20124000,0.003970525; 20127600,0.00608284; 20131200,0.001101379;
        20134800,1e-06; 20138400,0.006076967; 20142000,0.002922786; 20145600,
        0.002579021; 20149200,0.002380123; 20152800,0.007039744; 20156400,
        0.010487966; 20160000,0.00407389; 20163600,0.003279472; 20167200,
        0.006124734; 20170800,0.003451746; 20174400,0.002912606; 20178000,
        0.008202986; 20181600,0.006841238; 20185200,0.003528486; 20188800,
        0.004475993; 20192400,0.003135779; 20196000,0.002742681; 20199600,
        0.008026796; 20203200,0.014806955; 20206800,0.008047939; 20210400,
        0.003979922; 20214000,0.006083623; 20217600,0.001100988; 20221200,1e-06;
        20224800,0.006101634; 20228400,0.002913781; 20232000,0.002573931;
        20235600,0.002375816; 20239200,0.006889005; 20242800,0.010404961;
        20246400,0.004107562; 20250000,0.003289651; 20253600,0.005983; 20257200,
        0.003409852; 20260800,0.002908691; 20264400,0.008220996; 20268000,
        0.006827143; 20271600,0.003475238; 20275200,0.004459157; 20278800,
        0.003097018; 20282400,0.00275247; 20286000,0.008052638; 20289600,
        0.014859812; 20293200,0.007903855; 20296800,0.003987361; 20300400,
        0.006114163; 20304000,0.001103337; 20307600,1e-06; 20311200,0.006086364;
        20314800,0.002928659; 20318400,0.002585285; 20322000,0.002383646;
        20325600,0.007011163; 20329200,0.010353671; 20332800,0.004120874;
        20336400,0.003291609; 20340000,0.005966164; 20343600,0.003411418;
        20347200,0.002908299; 20350800,0.008415979; 20354400,0.006756275;
        20358000,0.003527311; 20361600,0.004476385; 20365200,0.003147134;
        20368800,0.002771655; 20372400,0.008082394; 20376000,0.014837103;
        20379600,0.00783847; 20383200,0.003980705; 20386800,0.006107898;
        20390400,0.001103337; 20394000,1e-06; 20397600,0.00608519; 20401200,
        0.002926701; 20404800,0.002582153; 20408400,0.002381689; 20412000,
        0.007004507; 20415600,0.010395956; 20419200,0.004128704; 20422800,
        0.003308445; 20426400,0.005995529; 20430000,0.003393799; 20433600,
        0.00290086; 20437200,0.008077304; 20440800,0.006850243; 20444400,
        0.003523004; 20448000,0.004466596; 20451600,0.003095452; 20455200,
        0.002741507; 20458800,0.00802758; 20462400,0.01485668; 20466000,
        0.007179521; 20469600,0.003965436; 20473200,0.005972037; 20476800,
        0.001099422; 20480400,1e-06; 20484000,0.006092237; 20487600,0.002923178;
        20491200,0.002584502; 20494800,0.002384821; 20498400,0.007029956;
        20502000,0.011142608; 20505600,0.004243423; 20509200,0.003299048;
        20512800,0.006125517; 20516400,0.003420032; 20520000,0.00290595;
        20523600,0.008650507; 20527200,0.005747297; 20530800,0.003517915;
        20534400,0.004494004; 20538000,0.003123642; 20541600,0.002766565;
        20545200,0.00821943; 20548800,0.014962785; 20552400,0.007990776;
        20556000,0.003970134; 20559600,0.006098893; 20563200,0.001102554;
        20566800,1e-06; 20570400,0.00626412; 20574000,0.00287776; 20577600,
        0.00257119; 20581200,0.002374641; 20584800,0.006965353; 20588400,
        0.010841911; 20592000,0.004167075; 20595600,0.003262636; 20599200,
        0.006158406; 20602800,0.003438042; 20606400,0.002901643; 20610000,
        0.008665777; 20613600,0.005643933; 20617200,0.003508518; 20620800,
        0.00454921; 20624400,0.003127166; 20628000,0.002745814; 20631600,
        0.008129769; 20635200,0.014743527; 20638800,0.007834554; 20642400,
        0.00394351; 20646000,0.00581699; 20649600,0.001072406; 20653200,1e-06;
        20656800,0.006122777; 20660400,0.002888723; 20664000,0.002565709;
        20667600,0.002373075; 20671200,0.006982581; 20674800,0.010296507;
        20678400,0.00404335; 20682000,0.003272424; 20685600,0.005959508;
        20689200,0.003428645; 20692800,0.002903601; 20696400,0.008466878;
        20700000,0.006731609; 20703600,0.003531618; 20707200,0.004488522;
        20710800,0.003130689; 20714400,0.002746205; 20718000,0.008042849;
        20721600,0.014789728; 20725200,0.007896416; 20728800,0.003932155;
        20732400,0.005923878; 20736000,0.001103729; 20739600,1e-06; 20743200,
        0.006131782; 20746800,0.002897728; 20750400,0.002564926; 20754000,
        0.00236916; 20757600,0.006867862; 20761200,0.01014381; 20764800,
        0.004033954; 20768400,0.003287694; 20772000,0.005972037; 20775600,
        0.003420423; 20779200,0.002899294; 20782800,0.008220605; 20786400,
        0.006819703; 20790000,0.003526137; 20793600,0.004474036; 20797200,
        0.003144785; 20800800,0.002769305; 20804400,0.008070648; 20808000,
        0.014697326; 20811600,0.007888586; 20815200,0.003944684; 20818800,
        0.006059348; 20822400,0.001098247; 20826000,1e-06; 20829600,0.006070311;
        20833200,0.002918479; 20836800,0.002577063; 20840400,0.002377382;
        20844000,0.006987671; 20847600,0.010331745; 20851200,0.004115001;
        20854800,0.003287694; 20858400,0.00595755; 20862000,0.003440783;
        20865600,0.002928659; 20869200,0.008440254; 20872800,0.006766455;
        20876400,0.003510867; 20880000,0.004458374; 20883600,0.003104457;
        20887200,0.00274738; 20890800,0.008181452; 20894400,0.014740786;
        20898000,0.007576926; 20901600,0.003958388; 20905200,0.005940323;
        20908800,0.001099813; 20912400,1e-06; 20916000,0.006069528; 20919600,
        0.002914955; 20923200,0.002572756; 20926800,0.00237425; 20930400,
        0.006980232; 20934000,0.010351322; 20937600,0.004054705; 20941200,
        0.003269292; 20944800,0.005932101; 20948400,0.003401238; 20952000,
        0.002912606; 20955600,0.008498201; 20959200,0.006104375; 20962800,
        0.003472105; 20966400,0.004469729; 20970000,0.003145959; 20973600,
        0.002761475; 20977200,0.00807378; 20980800,0.014831622; 20984400,
        0.007825549; 20988000,0.003980314; 20991600,0.006084015; 20995200,
        0.001051655; 20998800,1e-06; 21002400,0.006120819; 21006000,0.002925135;
        21009600,0.002574714; 21013200,0.002376207; 21016800,0.006990411;
        21020400,0.010344274; 21024000,0.004120874; 21027600,0.003297874;
        21031200,0.005975169; 21034800,0.003423164; 21038400,0.002902035;
        21042000,0.008420678; 21045600,0.006699503; 21049200,0.003492073;
        21052800,0.0044572; 21056400,0.003097409; 21060000,0.002752861;
        21063600,0.008054204; 21067200,0.014703982; 21070800,0.007892501;
        21074400,0.003968568; 21078000,0.006073835; 21081600,0.001100596;
        21085200,1e-06; 21088800,0.006095369; 21092400,0.002920045; 21096000,
        0.002574714; 21099600,0.00237425; 21103200,0.007012337; 21106800,
        0.011167666; 21110400,0.004218757; 21114000,0.003264593; 21117600,
        0.006104766; 21121200,0.003385577; 21124800,0.00289303; 21128400,
        0.00838544; 21132000,0.005636494; 21135600,0.003464275; 21139200,
        0.004517104; 21142800,0.003104065; 21146400,0.002758343; 21150000,
        0.008151695; 21153600,0.014843368; 21157200,0.007914818; 21160800,
        0.003972092; 21164400,0.006091454; 21168000,0.001097464; 21171600,1e-06;
        21175200,0.006073052; 21178800,0.002891855; 21182400,0.00257119;
        21186000,0.00237425; 21189600,0.006986496; 21193200,0.010330179;
        21196800,0.004066059; 21200400,0.003268117; 21204000,0.005955592;
        21207600,0.003404762; 21211200,0.002900469; 21214800,0.008406974;
        21218400,0.005739467; 21222000,0.003497946; 21225600,0.004524152;
        21229200,0.003104848; 21232800,0.002757168; 21236400,0.008075738;
        21240000,0.014833188; 21243600,0.007919125; 21247200,0.003957996;
        21250800,0.006084406; 21254400,0.001100596; 21258000,1e-06; 21261600,
        0.006098893; 21265200,0.002916521; 21268800,0.002573539; 21272400,
        0.002375424; 21276000,0.006989628; 21279600,0.010338401; 21283200,
        0.004117741; 21286800,0.003294741; 21290400,0.005970862; 21294000,
        0.003405545; 21297600,0.002891855; 21301200,0.008394053; 21304800,
        0.005735943; 21308400,0.003494423; 21312000,0.004517496; 21315600,
        0.003103282; 21319200,0.002749337; 21322800,0.008046373; 21326400,
        0.014695369; 21330000,0.00788702; 21333600,0.0039717; 21337200,
        0.00585262; 21340800,0.001073581; 21344400,1e-06; 21348000,0.006141179;
        21351600,0.002927484; 21355200,0.002576672; 21358800,0.002377774;
        21362400,0.00702839; 21366000,0.011022799; 21369600,0.004184693;
        21373200,0.003274382; 21376800,0.005921921; 21380400,0.003412592;
        21384000,0.002898903; 21387600,0.008494677; 21391200,0.0056917;
        21394800,0.003508126; 21398400,0.004491654; 21402000,0.003104457;
        21405600,0.002755602; 21409200,0.008136425; 21412800,0.014887219;
        21416400,0.007895633; 21420000,0.003982663; 21423600,0.006103983;
        21427200,0.001102554; 21430800,1e-06; 21434400,0.006170152; 21438000,
        0.002897336; 21441600,0.002574323; 21445200,0.002378165; 21448800,
        0.006999417; 21452400,0.010296899; 21456000,0.004105604; 21459600,
        0.003295524; 21463200,0.005970471; 21466800,0.003408677; 21470400,
        0.002918479; 21474000,0.008452783; 21477600,0.00575043; 21481200,
        0.003503036; 21484800,0.00446229; 21488400,0.003092319; 21492000,
        0.00274229; 21495600,0.008131335; 21499200,0.014810479; 21502800,
        0.00783612; 21506400,0.003978356; 21510000,0.006103983; 21513600,
        0.001102162; 21517200,1e-06; 21520800,0.006081274; 21524400,0.002922003;
        21528000,0.002580587; 21531600,0.002380514; 21535200,0.006997067;
        21538800,0.01034075; 21542400,0.004058229; 21546000,0.003268509;
        21549600,0.005949328; 21553200,0.003370307; 21556800,0.002892246;
        21560400,0.008400318; 21564000,0.005674081; 21567600,0.00350147;
        21571200,0.004483041; 21574800,0.003095452; 21578400,0.002748163;
        21582000,0.008121939; 21585600,0.014882129; 21589200,0.00788702;
        21592800,0.003983054; 21596400,0.006112988; 21600000,0.001054787;
        21603600,1e-06; 21607200,0.006331072; 21610800,0.002930225; 21614400,
        0.002578238; 21618000,0.00237699; 21621600,0.006995893; 21625200,
        0.010169259; 21628800,0.004039827; 21632400,0.003272424; 21636000,
        0.00592427; 21639600,0.003387534; 21643200,0.002902035; 21646800,
        0.00844182; 21650400,0.00574534; 21654000,0.003504211; 21657600,
        0.004529633; 21661200,0.003098975; 21664800,0.002748946; 21668400,
        0.008058511; 21672000,0.014792468; 21675600,0.00790503; 21679200,
        0.00396152; 21682800,0.006046428; 21686400,0.001061443; 21690000,1e-06;
        21693600,0.006081274; 21697200,0.002891855; 21700800,0.002568058;
        21704400,0.002372292; 21708000,0.006982581; 21711600,0.010308645;
        21715200,0.004051181; 21718800,0.003264985; 21722400,0.005927402;
        21726000,0.003355429; 21729600,0.002894204; 21733200,0.008614877;
        21736800,0.00623358; 21740400,0.003473671; 21744000,0.004464639;
        21747600,0.00310015; 21751200,0.002747771; 21754800,0.008129769;
        21758400,0.014860595; 21762000,0.007840819; 21765600,0.003952123;
        21769200,0.006076576; 21772800,0.001066925; 21776400,1e-06; 21780000,
        0.006135306; 21783600,0.002932574; 21787200,0.002583719; 21790800,
        0.002381689; 21794400,0.007006073; 21798000,0.010314518; 21801600,
        0.004083287; 21805200,0.003271249; 21808800,0.005948153; 21812400,
        0.003369132; 21816000,0.002905559; 21819600,0.008603131; 21823200,
        0.006325982; 21826800,0.003526137; 21830400,0.004525326; 21834000,
        0.003129515; 21837600,0.002752078; 21841200,0.008154827; 21844800,
        0.01474431; 21848400,0.007747634; 21852000,0.003963478; 21855600,
        0.006088713; 21859200,0.001101771; 21862800,1e-06; 21866400,0.006152925;
        21870000,0.002924744; 21873600,0.002579412; 21877200,0.002378165;
        21880800,0.006993544; 21884400,0.010339967; 21888000,0.004120091;
        21891600,0.003305704; 21895200,0.005984957; 21898800,0.003403587;
        21902400,0.002901643; 21906000,0.008426942; 21909600,0.006751577;
        21913200,0.003514391; 21916800,0.004474036; 21920400,0.003145568;
        21924000,0.002770872; 21927600,0.008085135; 21931200,0.014788945;
        21934800,0.006998634; 21938400,0.00395134; 21942000,0.005932101;
        21945600,0.001092374; 21949200,1e-06; 21952800,0.00609302; 21956400,
        0.002920437; 21960000,0.002580587; 21963600,0.002381297; 21967200,
        0.007046009; 21970800,0.010336052; 21974400,0.004125572; 21978000,
        0.003310403; 21981600,0.005986915; 21985200,0.003450963; 21988800,
        0.002940013; 21992400,0.008504465; 21996000,0.006777026; 21999600,
        0.0035371; 22003200,0.00449048; 22006800,0.003151441; 22010400,
        0.002762258; 22014000,0.008064384; 22017600,0.014711813; 22021200,
        0.007892501; 22024800,0.003967002; 22028400,0.00579389; 22032000,
        0.001076713; 22035600,1e-06; 22039200,0.006104375; 22042800,0.00290595;
        22046400,0.002572365; 22050000,0.002374641; 22053600,0.006994718;
        22057200,0.010527511; 22060800,0.00415063; 22064400,0.003285736;
        22068000,0.005983783; 22071600,0.003419248; 22075200,0.002906342;
        22078800,0.008417937; 22082400,0.006764889; 22086000,0.003512042;
        22089600,0.004473252; 22093200,0.003147134; 22096800,0.002772046;
        22100400,0.008085135; 22104000,0.014719644; 22107600,0.00789485;
        22111200,0.003970134; 22114800,0.006068354; 22118400,0.00109903;
        22122000,1e-06; 22125600,0.006125909; 22129200,0.002926701; 22132800,
        0.002580979; 22136400,0.002380906; 22140000,0.006996676; 22143600,
        0.010303163; 22147200,0.004089551; 22150800,0.003279472; 22154400,
        0.005951286; 22158000,0.003416899; 22161600,0.002920045; 22165200,
        0.008440254; 22168800,0.006762148; 22172400,0.003530444; 22176000,
        0.004483432; 22179600,0.003145176; 22183200,0.002766173; 22186800,
        0.008066341; 22190400,0.014702416; 22194000,0.006963004; 22197600,
        0.003904357; 22201200,0.005913307; 22204800,0.001093549; 22208400,1e-06;
        22212000,0.00606992; 22215600,0.002914955; 22219200,0.002575889;
        22222800,0.002378165; 22226400,0.007023692; 22230000,0.009926509;
        22233600,0.004003806; 22237200,0.003259112; 22240800,0.005967338;
        22244400,0.003423164; 22248000,0.002907516; 22251600,0.008300869;
        22255200,0.00565842; 22258800,0.003472497; 22262400,0.004506924;
        22266000,0.003095843; 22269600,0.00275012; 22273200,0.008069082;
        22276800,0.014814394; 22280400,0.007915601; 22284000,0.003982663;
        22287600,0.006103983; 22291200,0.001102554; 22294800,1e-06; 22298400,
        0.006089496; 22302000,0.002916521; 22305600,0.002578629; 22309200,
        0.002380123; 22312800,0.006998634; 22316400,0.010375597; 22320000,
        0.004101297; 22323600,0.003295133; 22327200,0.005983; 22330800,
        0.003430994; 22334400,0.002912998; 22338000,0.008438297; 22341600,
        0.005746123; 22345200,0.003475238; 22348800,0.004516713; 22352400,
        0.003100933; 22356000,0.002746988; 22359600,0.00804559; 22363200,
        0.01473139; 22366800,0.007914818; 22370400,0.003979922; 22374000,
        0.00611847; 22377600,0.001100205; 22381200,1e-06; 22384800,0.00609302;
        22388400,0.002907516; 22392000,0.002571973; 22395600,0.002375816;
        22399200,0.006990803; 22402800,0.010332528; 22406400,0.004066842;
        22410000,0.00325872; 22413600,0.005938365; 22417200,0.003404762;
        22420800,0.002911432; 22424400,0.008424984; 22428000,0.005682695;
        22431600,0.003488941; 22435200,0.004519453; 22438800,0.003099367;
        22442400,0.002743856; 22446000,0.008041675; 22449600,0.014692236;
        22453200,0.007885845; 22456800,0.003959171; 22460400,0.006068354;
        22464000,0.001099813; 22467600,1e-06; 22471200,0.0060801; 22474800,
        0.002919654; 22478400,0.002578238; 22482000,0.002378948; 22485600,
        0.006991194; 22489200,0.010332137; 22492800,0.004115392; 22496400,
        0.003295524; 22500000,0.005965381; 22503600,0.00335582; 22507200,
        0.002899686; 22510800,0.008410889; 22514400,0.005739467; 22518000,
        0.00350147; 22521600,0.00452376; 22525200,0.003104848; 22528800,
        0.002757168; 22532400,0.008069473; 22536000,0.014763104; 22539600,
        0.007904247; 22543200,0.003964652; 22546800,0.006074227; 22550400,
        0.001095115; 22554000,1e-06; 22557600,0.006066004; 22561200,0.002915738;
        22564800,0.002577063; 22568400,0.002377774; 22572000,0.00699002;
        22575600,0.010325481; 22579200,0.004004589; 22582800,0.003257154;
        22586400,0.00590391; 22590000,0.003420815; 22593600,0.00291104;
        22597200,0.008504465; 22600800,0.006720254; 22604400,0.003523396;
        22608000,0.004473644; 22611600,0.003143218; 22615200,0.002764216;
        22618800,0.008067516; 22622400,0.014754881; 22626000,0.007903464;
        22629600,0.003963086; 22633200,0.006060915; 22636800,0.001098639;
        22640400,1e-06; 22644000,0.006072269; 22647600,0.002901643; 22651200,
        0.002561794; 22654800,0.002369551; 22658400,0.006851418; 22662000,
        0.010550611; 22665600,0.00407898; 22669200,0.00326616; 22672800,
        0.005820905; 22676400,0.003374222; 22680000,0.002904384; 22683600,
        0.008603523; 22687200,0.006329897; 22690800,0.003520264; 22694400,
        0.004517104; 22698000,0.003151441; 22701600,0.002773612; 22705200,
        0.008188891; 22708800,0.014804606; 22712400,0.007823983; 22716000,
        0.003939203; 22719600,0.005933275; 22723200,0.001102945; 22726800,1e-06;
        22730400,0.006143528; 22734000,0.002925135; 22737600,0.002575106;
        22741200,0.002372684; 22744800,0.006998634; 22748400,0.010502453;
        22752000,0.004102863; 22755600,0.003266551; 22759200,0.005975169;
        22762800,0.003392624; 22766400,0.00289577; 22770000,0.00845709;
        22773600,0.006715164; 22777200,0.003492073; 22780800,0.004472078;
        22784400,0.003111896; 22788000,0.002743856; 22791600,0.008038934;
        22795200,0.014696543; 22798800,0.007859221; 22802400,0.003935288;
        22806000,0.005923878; 22809600,0.001102554; 22813200,1e-06; 22816800,
        0.006078533; 22820400,0.002878934; 22824000,0.002566492; 22827600,
        0.002372292; 22831200,0.006863163; 22834800,0.010993042; 22838400,
        0.004218757; 22842000,0.003295916; 22845600,0.006134914; 22849200,
        0.003448222; 22852800,0.002912998; 22856400,0.008365863; 22860000,
        0.006763714; 22863600,0.003523396; 22867200,0.004473252; 22870800,
        0.003097801; 22874400,0.002735242; 22878000,0.008012701; 22881600,
        0.014713379; 22885200,0.007894067; 22888800,0.0039717; 22892400,
        0.006084015; 22896000,0.001099813; 22899600,1e-06; 22903200,0.006094586;
        22906800,0.002924352; 22910400,0.002577063; 22914000,0.00237699;
        22917600,0.006990803; 22921200,0.010332528; 22924800,0.004093858;
        22928400,0.003279863; 22932000,0.005958725; 22935600,0.003372265;
        22939200,0.002896945; 22942800,0.008406974; 22946400,0.006697937;
        22950000,0.003503036; 22953600,0.004474819; 22957200,0.003146351;
        22960800,0.002770872; 22964400,0.008077696; 22968000,0.014707898;
        22971600,0.007890935; 22975200,0.003957996; 22978800,0.006019804;
        22982400,0.001094332; 22986000,1e-06; 22989600,0.006092237; 22993200,
        0.002918871; 22996800,0.002578629; 23000400,0.002379731; 23004000,
        0.007019385; 23007600,0.01061404; 23011200,0.004102472; 23014800,
        0.0032689; 23018400,0.005967338; 23022000,0.003392624; 23025600,
        0.002891855; 23029200,0.008348636; 23032800,0.00566351; 23036400,
        0.003474454; 23040000,0.004506533; 23043600,0.003096626; 23047200,
        0.002751295; 23050800,0.008060468; 23054400,0.014741961; 23058000,
        0.007876057; 23061600,0.003922367; 23065200,0.005906651; 23068800,
        0.001101771; 23072400,1e-06; 23076000,0.006129824; 23079600,0.002897336;
        23083200,0.002558661; 23086800,0.002367202; 23090400,0.006708117;
        23094000,0.011099539; 23097600,0.004279444; 23101200,0.003271641;
        23104800,0.006040163; 23108400,0.003436476; 23112000,0.002923961;
        23115600,0.00840854; 23119200,0.006761365; 23122800,0.003510475;
        23126400,0.004462681; 23130000,0.00311033; 23133600,0.002754819;
        23137200,0.008044415; 23140800,0.014752141; 23144400,0.007903464;
        23148000,0.003974832; 23151600,0.006089888; 23155200,0.001100988;
        23158800,1e-06; 23162400,0.006107507; 23166000,0.00292122; 23169600,
        0.002579412; 23173200,0.00237934; 23176800,0.006992761; 23180400,
        0.010316084; 23184000,0.004071149; 23187600,0.003263419; 23191200,
        0.005938365; 23194800,0.003421598; 23198400,0.002907516; 23202000,
        0.008476275; 23205600,0.006675228; 23209200,0.003506952; 23212800,
        0.004481475; 23216400,0.003102499; 23220000,0.002739941; 23223600,
        0.008027971; 23227200,0.014686755; 23230800,0.007887803; 23234400,
        0.00396152; 23238000,0.006091846; 23241600,0.001092374; 23245200,1e-06;
        23248800,0.006160755; 23252400,0.002921611; 23256000,0.00257628;
        23259600,0.002375424; 23263200,0.007035829; 23266800,0.011072915;
        23270400,0.004192916; 23274000,0.003275556; 23277600,0.006009624;
        23281200,0.003412592; 23284800,0.002905167; 23288400,0.008448476;
        23292000,0.006744529; 23295600,0.003529661; 23299200,0.004480692;
        23302800,0.003139303; 23306400,0.002755993; 23310000,0.008047548;
        23313600,0.014730606; 23317200,0.007785221; 23320800,0.003971309;
        23324400,0.006094978; 23328000,0.001051263; 23331600,1e-06; 23335200,
        0.006155665; 23338800,0.002906733; 23342400,0.002570407; 23346000,
        0.002373858; 23349600,0.006986496; 23353200,0.010286719; 23356800,
        0.004078197; 23360400,0.003268117; 23364000,0.00594737; 23367600,
        0.003396148; 23371200,0.002904776; 23374800,0.008424984; 23378400,
        0.006701069; 23382000,0.003504602; 23385600,0.004476776; 23389200,
        0.003101325; 23392800,0.002743856; 23396400,0.008097664; 23400000,
        0.014873124; 23403600,0.007997432; 23407200,0.00399206; 23410800,
        0.005885117; 23414400,0.001075538; 23418000,1e-06; 23421600,0.00617485;
        23425200,0.002922394; 23428800,0.002583328; 23432400,0.002382863;
        23436000,0.007008813; 23439600,0.010301206; 23443200,0.004061752;
        23446800,0.003289651; 23450400,0.005974778; 23454000,0.003411418;
        23457600,0.002914955; 23461200,0.008448476; 23464800,0.006761757;
        23468400,0.003533184; 23472000,0.004491263; 23475600,0.003147134;
        23479200,0.002764607; 23482800,0.008064384; 23486400,0.014705157;
        23490000,0.007890543; 23493600,0.003971309; 23497200,0.006084798;
        23500800,0.001100988; 23504400,1e-06; 23508000,0.006084798; 23511600,
        0.002925135; 23515200,0.002580979; 23518800,0.002380123; 23522400,
        0.006993544; 23526000,0.010334877; 23529600,0.004116175; 23533200,
        0.003300614; 23536800,0.005703837; 23540400,0.003394582; 23544000,
        0.002914955; 23547600,0.0085722; 23551200,0.006604361; 23554800,
        0.003478761; 23558400,0.004466596; 23562000,0.003102891; 23565600,
        0.002735242; 23569200,0.007806364; 23572800,0.014632332; 23576400,
        0.007926564; 23580000,0.003965827; 23583600,0.00606992; 23587200,
        0.001098247; 23590800,1e-06; 23594400,0.006071877; 23598000,0.002910648;
        23601600,0.002574714; 23605200,0.002376207; 23608800,0.006987279;
        23612400,0.010330962; 23616000,0.004095816; 23619600,0.003290043;
        23623200,0.005694441; 23626800,0.003398497; 23630400,0.002902426;
        23634000,0.008351376; 23637600,0.006769979; 23641200,0.003525745;
        23644800,0.004478734; 23648400,0.00310015; 23652000,0.002741507;
        23655600,0.008024839; 23659200,0.014675792; 23662800,0.00788467;
        23666400,0.003944684; 23670000,0.006003751; 23673600,0.00108611;
        23677200,1e-06; 23680800,0.006127867; 23684400,0.002898511; 23688000,
        0.002570799; 23691600,0.002375033; 23695200,0.006984147; 23698800,
        0.010298856; 23702400,0.004060578; 23706000,0.003282212; 23709600,
        0.005791541; 23713200,0.00339654; 23716800,0.002902035; 23720400,
        0.008516603; 23724000,0.005743382; 23727600,0.003477195; 23731200,
        0.004457983; 23734800,0.003138912; 23738400,0.002757951; 23742000,
        0.008093748; 23745600,0.014776807; 23749200,0.00774137; 23752800,
        0.003971309; 23756400,0.006100459; 23760000,0.001105295; 23763600,1e-06;
        23767200,0.006157231; 23770800,0.002917305; 23774400,0.002580587;
        23778000,0.002380906; 23781600,0.007000983; 23785200,0.010020869;
        23788800,0.004057446; 23792400,0.003293175; 23796000,0.00614157;
        23799600,0.003405936; 23803200,0.002922394; 23806800,0.00840345;
        23810400,0.006773503; 23814000,0.003499121; 23817600,0.004456417;
        23821200,0.003140478; 23824800,0.002767348; 23828400,0.008072214;
        23832000,0.014790902; 23835600,0.007894067; 23839200,0.003920018;
        23842800,0.005917222; 23846400,0.001075538; 23850000,1e-06; 23853600,
        0.006154882; 23857200,0.002915738; 23860800,0.002576672; 23864400,
        0.002377774; 23868000,0.00699511; 23871600,0.010289068; 23875200,
        0.004074281; 23878800,0.003270075; 23882400,0.00604956; 23886000,
        0.003447439; 23889600,0.002922394; 23893200,0.008502116; 23896800,
        0.006745704; 23900400,0.003536708; 23904000,0.004497919; 23907600,
        0.003108372; 23911200,0.002741115; 23914800,0.008187325; 23918400,
        0.014793252; 23922000,0.007650926; 23925600,0.003974832; 23929200,
        0.005954026; 23932800,0.001100205; 23936400,1e-06; 23940000,0.006132173;
        23943600,0.002893813; 23947200,0.002571973; 23950800,0.002373467;
        23954400,0.006984538; 23958000,0.010388517; 23961600,0.004110694;
        23965200,0.003281821; 23968800,0.006127083; 23972400,0.003444698;
        23976000,0.002916521; 23979600,0.00840854; 23983200,0.006774286;
        23986800,0.003530835; 23990400,0.004511231; 23994000,0.003152615;
        23997600,0.002777919; 24001200,0.008169314; 24004800,0.014754098;
        24008400,0.007841993; 24012000,0.003972875; 24015600,0.006092237;
        24019200,0.001099813; 24022800,1e-06; 24026400,0.00607775; 24030000,
        0.002905559; 24033600,0.002562185; 24037200,0.002370334; 24040800,
        0.006866687; 24044400,0.010180222; 24048000,0.004034737; 24051600,
        0.003278297; 24055200,0.005820122; 24058800,0.003397323; 24062400,
        0.002903992; 24066000,0.008555756; 24069600,0.00663725; 24073200,
        0.003513999; 24076800,0.004477168; 24080400,0.003129906; 24084000,
        0.00275012; 24087600,0.008044024; 24091200,0.014698501; 24094800,
        0.006932856; 24098400,0.003949774; 24102000,0.005900386; 24105600,
        0.001082194; 24109200,1e-06; 24112800,0.006056999; 24116400,0.002892246;
        24120000,0.002562968; 24123600,0.002368768; 24127200,0.006968486;
        24130800,0.01003144; 24134400,0.004087985; 24138000,0.003280255;
        24141600,0.006167803; 24145200,0.003449788; 24148800,0.002920045;
        24152400,0.008340805; 24156000,0.006439526; 24159600,0.003492073;
        24163200,0.004464639; 24166800,0.00309506; 24170400,0.002731327;
        24174000,0.008011527; 24177600,0.014768194; 24181200,0.007908554;
        24184800,0.003959171; 24188400,0.005876503; 24192000,0.001073581;
        24195600,1e-06; 24199200,0.006113771; 24202800,0.002901252; 24206400,
        0.002575497; 24210000,0.002377774; 24213600,0.006991978; 24217200,
        0.010288285; 24220800,0.004109519; 24224400,0.003285736; 24228000,
        0.005955592; 24231600,0.003427471; 24235200,0.002907908; 24238800,
        0.008420678; 24242400,0.006751968; 24246000,0.003530444; 24249600,
        0.004487739; 24253200,0.003122859; 24256800,0.002748163; 24260400,
        0.008040109; 24264000,0.014788553; 24267600,0.007911686; 24271200,
        0.003978356; 24274800,0.006095369; 24278400,0.001096681; 24282000,1e-06;
        24285600,0.006322849; 24289200,0.002901643; 24292800,0.002570799;
        24296400,0.00237425; 24300000,0.006984147; 24303600,0.010144984;
        24307200,0.00403552; 24310800,0.003270466; 24314400,0.005918788;
        24318000,0.003432169; 24321600,0.002915738; 24325200,0.008453566;
        24328800,0.00674727; 24332400,0.003503819; 24336000,0.004467771;
        24339600,0.003099367; 24343200,0.002749729; 24346800,0.00804559;
        24350400,0.014812437; 24354000,0.007912469; 24357600,0.003954473;
        24361200,0.00607775; 24364800,0.00109903; 24368400,1e-06; 24372000,
        0.006094195; 24375600,0.002902035; 24379200,0.002566883; 24382800,
        0.002372292; 24386400,0.006981406; 24390000,0.010383427; 24393600,
        0.004075456; 24397200,0.003279863; 24400800,0.005964989; 24404400,
        0.00340163; 24408000,0.002893421; 24411600,0.008622317; 24415200,
        0.006258638; 24418800,0.003524179; 24422400,0.00455939; 24426000,
        0.003119727; 24429600,0.002765782; 24433200,0.008244097; 24436800,
        0.014850024; 24440400,0.007551477; 24444000,0.00394625; 24447600,
        0.005945021; 24451200,0.001097856; 24454800,1e-06; 24458400,0.006071486;
        24462000,0.002909474; 24465600,0.002565317; 24469200,0.002371509;
        24472800,0.007011554; 24476400,0.011213866; 24480000,0.004231286;
        24483600,0.003278689; 24487200,0.006142353; 24490800,0.003407503;
        24494400,0.002913389; 24498000,0.008389355; 24501600,0.005731245;
        24505200,0.003459576; 24508800,0.004510056; 24512400,0.003096626;
        24516000,0.002736025; 24519600,0.008031886; 24523200,0.014725125;
        24526800,0.007401128; 24530400,0.003914536; 24534000,0.005930534;
        24537600,0.001093549; 24541200,1e-06; 24544800,0.006152533; 24548400,
        0.002875411; 24552000,0.002559053; 24555600,0.002367594; 24559200,
        0.007012729; 24562800,0.01094645; 24566400,0.004192916; 24570000,
        0.003286911; 24573600,0.006129433; 24577200,0.00344274; 24580800,
        0.002914564; 24584400,0.008401884; 24588000,0.006773894; 24591600,
        0.00350656; 24595200,0.004468946; 24598800,0.003127557; 24602400,
        0.002749729; 24606000,0.008050288; 24609600,0.014701242; 24613200,
        0.007891326; 24616800,0.003945467; 24620400,0.005762567; 24624000,
        0.001078671; 24627600,1e-06; 24631200,0.006051126; 24634800,0.002892246;
        24638400,0.002564534; 24642000,0.002371901; 24645600,0.006978665;
        24649200,0.010303163; 24652800,0.004105996; 24656400,0.003272032;
        24660000,0.005950894; 24663600,0.003427079; 24667200,0.002906733;
        24670800,0.008507206; 24674400,0.006697154; 24678000,0.00353201;
        24681600,0.004494395; 24685200,0.003153398; 24688800,0.00277557;
        24692400,0.008089442; 24696000,0.014717686; 24699600,0.006956348;
        24703200,0.003923933; 24706800,0.005913307; 24710400,0.001088067;
        24714000,1e-06; 24717600,0.006091454; 24721200,0.002880892; 24724800,
        0.00256101; 24728400,0.002368768; 24732000,0.006933639; 24735600,
        0.010828991; 24739200,0.004172164; 24742800,0.003289651; 24746400,
        0.006163104; 24750000,0.00344783; 24753600,0.002927876; 24757200,
        0.008349027; 24760800,0.005731636; 24764400,0.003496772; 24768000,
        0.004516321; 24771600,0.003148308; 24775200,0.002757951; 24778800,
        0.008061251; 24782400,0.014690279; 24786000,0.007878797; 24789600,
        0.003944684; 24793200,0.006061698; 24796800,0.00109903; 24800400,1e-06;
        24804000,0.006120036; 24807600,0.002920045; 24811200,0.002578629;
        24814800,0.002378948; 24818400,0.006992369; 24822000,0.010304729;
        24825600,0.004111869; 24829200,0.003296699; 24832800,0.005757477;
        24836400,0.003431778; 24840000,0.002931008; 24843600,0.008650898;
        24847200,0.006179157; 24850800,0.003509692; 24854400,0.004502617;
        24858000,0.003148308; 24861600,0.002763824; 24865200,0.007950448;
        24868800,0.014676967; 24872400,0.007932829; 24876000,0.003972092;
        24879600,0.006082449; 24883200,0.00109903; 24886800,1e-06; 24890400,
        0.006077359; 24894000,0.00288559; 24897600,0.002572756; 24901200,
        0.002376207; 24904800,0.006857682; 24908400,0.011014577; 24912000,
        0.004225804; 24915600,0.003295524; 24919200,0.006130999; 24922800,
        0.003449788; 24926400,0.002927093; 24930000,0.00840345; 24933600,
        0.006763323; 24937200,0.00350147; 24940800,0.004460723; 24944400,
        0.003138912; 24948000,0.00275012; 24951600,0.008034627; 24955200,
        0.014765061; 24958800,0.007849824; 24962400,0.003918843; 24966000,
        0.006058565; 24969600,0.001097464; 24973200,1e-06; 24976800,0.006073052;
        24980400,0.002918088; 24984000,0.002577846; 24987600,0.002378948;
        24991200,0.006993544; 24994800,0.010383036; 24998400,0.004100906;
        25002000,0.003278689; 25005600,0.005984957; 25009200,0.003423555;
        25012800,0.002903601; 25016400,0.008466095; 25020000,0.006739439;
        25023600,0.003533967; 25027200,0.004494395; 25030800,0.003151832;
        25034400,0.002762649; 25038000,0.008061251; 25041600,0.014737654;
        25045200,0.007703783; 25048800,0.003972483; 25052400,0.005943846;
        25056000,0.001100205; 25059600,1e-06; 25063200,0.006091846; 25066800,
        0.002908691; 25070400,0.002575106; 25074000,0.002376207; 25077600,
        0.007032697; 25081200,0.01067551; 25084800,0.004158461; 25088400,
        0.003279472; 25092000,0.005838524; 25095600,0.003405545; 25099200,
        0.002907908; 25102800,0.008621533; 25106400,0.006308754; 25110000,
        0.003479936; 25113600,0.004506533; 25117200,0.003101325; 25120800,
        0.002756776; 25124400,0.00814269; 25128000,0.014749008; 25131600,
        0.007844734; 25135200,0.003971309; 25138800,0.006087147; 25142400,
        0.001099422; 25146000,1e-06; 25149600,0.006073835; 25153200,0.002922394;
        25156800,0.002580979; 25160400,0.002379731; 25164000,0.006999808;
        25167600,0.010386559; 25171200,0.004129096; 25174800,0.003308836;
        25178400,0.006001402; 25182000,0.003423555; 25185600,0.002906733;
        25189200,0.008211991; 25192800,0.006840063; 25196400,0.003519872;
        25200000,0.004465422; 25203600,0.003097018; 25207200,0.00274503;
        25210800,0.008034627; 25214400,0.014682056; 25218000,0.007881538;
        25221600,0.003933721; 25225200,0.005910566; 25228800,0.001100988;
        25232400,1e-06; 25236000,0.006062872; 25239600,0.002882067; 25243200,
        0.002565709; 25246800,0.002371509; 25250400,0.006970443; 25254000,
        0.01035602; 25257600,0.004089943; 25261200,0.003269292; 25264800,
        0.005912132; 25268400,0.003355429; 25272000,0.002896945; 25275600,
        0.008474709; 25279200,0.006725344; 25282800,0.003532793; 25286400,
        0.004494004; 25290000,0.003113462; 25293600,0.002753253; 25297200,
        0.008051463; 25300800,0.014806955; 25304400,0.006985321; 25308000,
        0.003901224; 25311600,0.005747297; 25315200,0.001077496; 25318800,1e-06;
        25322400,0.006113771; 25326000,0.002923961; 25329600,0.002578629;
        25333200,0.002378948; 25336800,0.006995501; 25340400,0.010325481;
        25344000,0.004114609; 25347600,0.003282212; 25351200,0.005950894;
        25354800,0.003385577; 25358400,0.00289303; 25362000,0.008185758;
        25365600,0.006828709; 25369200,0.003502253; 25372800,0.0044572;
        25376400,0.003114245; 25380000,0.002741507; 25383600,0.008042066;
        25387200,0.014735305; 25390800,0.007725317; 25394400,0.003967785;
        25398000,0.006094586; 25401600,0.001100596; 25405200,1e-06; 25408800,
        0.006150184; 25412400,0.002927093; 25416000,0.002574323; 25419600,
        0.002375816; 25423200,0.006989237; 25426800,0.010283978; 25430400,
        0.004076239; 25434000,0.003264593; 25437600,0.00593445; 25441200,
        0.003434518; 25444800,0.002925135; 25448400,0.008443778; 25452000,
        0.006762931; 25455600,0.003503819; 25459200,0.004468163; 25462800,
        0.003124816; 25466400,0.002759517; 25470000,0.008058119; 25473600,
        0.014698501; 25477200,0.00788976; 25480800,0.003968568; 25484400,
        0.00607501; 25488000,0.001095898; 25491600,1e-06; 25495200,0.006067179;
        25498800,0.002916521; 25502400,0.002577846; 25506000,0.002377774;
        25509600,0.006988454; 25513200,0.010330962; 25516800,0.004115392;
        25520400,0.003300223; 25524000,0.005984957; 25527600,0.003447439;
        25531200,0.002932574; 25534800,0.008452; 25538400,0.006769196; 25542000,
        0.003529661; 25545600,0.004477559; 25549200,0.003147525; 25552800,
        0.002771655; 25556400,0.00807887; 25560000,0.014707898; 25563600,
        0.007890543; 25567200,0.003970525; 25570800,0.006081274; 25574400,
        0.001096681; 25578000,1e-06; 25581600,0.006067962; 25585200,0.002916913;
        25588800,0.002577846; 25592400,0.002378165; 25596000,0.006988454;
        25599600,0.010330962; 25603200,0.004115392; 25606800,0.003300223;
        25610400,0.005984566; 25614000,0.003447047; 25617600,0.002932966;
        25621200,0.008453958; 25624800,0.006769979; 25628400,0.003532401;
        25632000,0.004488522; 25635600,0.003150658; 25639200,0.002768522;
        25642800,0.008065558; 25646400,0.01470085; 25650000,0.007888977;
        25653600,0.003970525; 25657200,0.006082449; 25660800,0.001095898;
        25664400,1e-06; 25668000,0.006069528; 25671600,0.002916913; 25675200,
        0.002577455; 25678800,0.00237699; 25682400,0.007016644; 25686000,
        0.010714663; 25689600,0.004167858; 25693200,0.003305313; 25696800,
        0.006009624; 25700400,0.003445873; 25704000,0.002929442; 25707600,
        0.00837526; 25711200,0.006783683; 25714800,0.003527311; 25718400,
        0.004479517; 25722000,0.00314361; 25725600,0.002770872; 25729200,
        0.008078479; 25732800,0.014702808; 25736400,0.007888977; 25740000,
        0.003969742; 25743600,0.006081274; 25747200,0.00109394; 25750800,1e-06;
        25754400,0.006068745; 25758000,0.002917305; 25761600,0.002577455;
        25765200,0.002377774; 25768800,0.006988454; 25772400,0.010329396;
        25776000,0.004115001; 25779600,0.003298265; 25783200,0.005977518;
        25786800,0.003421989; 25790400,0.002921611; 25794000,0.008435556;
        25797600,0.006762931; 25801200,0.003530835; 25804800,0.004486956;
        25808400,0.003112287; 25812000,0.002754427; 25815600,0.008107844;
        25819200,0.014717686; 25822800,0.007857655; 25826400,0.003971309;
        25830000,0.006087147; 25833600,0.001094332; 25837200,1e-06; 25840800,
        0.006082057; 25844400,0.002915347; 25848000,0.002569233; 25851600,
        0.002375816; 25855200,0.006856116; 25858800,0.009885399; 25862400,
        0.004062927; 25866000,0.003294741; 25869600,0.006114554; 25873200,
        0.003454095; 25876800,0.002935315; 25880400,0.00843673; 25884000,
        0.006775852; 25887600,0.003531618; 25891200,0.004487348; 25894800,
        0.003112287; 25898400,0.002753253; 25902000,0.008046373; 25905600,
        0.014689887; 25909200,0.007887411; 25912800,0.003945467; 25916400,
        0.006061306; 25920000,0.001093157; 25923600,1e-06; 25927200,0.006133348;
        25930800,0.002922003; 25934400,0.002566883; 25938000,0.002371509;
        25941600,0.006977491; 25945200,0.011039635; 25948800,0.004210535;
        25952400,0.003304138; 25956000,0.006176025; 25959600,0.003456444;
        25963200,0.002935315; 25966800,0.008674782; 25970400,0.006407029;
        25974000,0.003532401; 25977600,0.004524152; 25981200,0.003106023;
        25984800,0.002748946; 25988400,0.008213166; 25992000,0.014853156;
        25995600,0.007368631; 25999200,0.003968568; 26002800,0.005964598;
        26006400,0.001096289; 26010000,1e-06; 26013600,0.006164279; 26017200,
        0.002927093; 26020800,0.002575889; 26024400,0.002376599; 26028000,
        0.00699511; 26031600,0.010293375; 26035200,0.004069583; 26038800,
        0.003291609; 26042400,0.006129824; 26046000,0.003449005; 26049600,
        0.002933749; 26053200,0.008426551; 26056800,0.005733985; 26060400,
        0.003459968; 26064000,0.004508882; 26067600,0.003142827; 26071200,
        0.002753644; 26074800,0.008058902; 26078400,0.014698501; 26082000,
        0.007885062; 26085600,0.00394625; 26089200,0.006064047; 26092800,
        0.00109394; 26096400,1e-06; 26100000,0.006149401; 26103600,0.002890289;
        26107200,0.002570407; 26110800,0.002374641; 26114400,0.00697984;
        26118000,0.009933165; 26121600,0.003986187; 26125200,0.003256763;
        26128800,0.005959899; 26132400,0.003386751; 26136000,0.002909082;
        26139600,0.008323969; 26143200,0.00677037; 26146800,0.003469756;
        26150400,0.004451327; 26154000,0.003092319; 26157600,0.002741507;
        26161200,0.008019749; 26164800,0.014725908; 26168400,0.007901898;
        26172000,0.003972875; 26175600,0.006079317; 26179200,0.001095115;
        26182800,1e-06; 26186400,0.006075401; 26190000,0.002919654; 26193600,
        0.002579804; 26197200,0.002381297; 26200800,0.002234081; 26204400,
        0.006498256; 26208000,0.01005689; 26211600,0.004040218; 26215200,
        0.003237578; 26218800,0.005861233; 26222400,0.003383619; 26226000,
        0.00288794; 26229600,0.008461397; 26233200,0.006242585; 26236800,
        0.003506952; 26240400,0.004428226; 26244000,0.003108372; 26247600,
        0.002750512; 26251200,0.007811454; 26254800,0.014568121; 26258400,
        0.0079434; 26262000,0.00395369; 26265600,0.006038989; 26269200,
        0.00105557; 26272800,1e-06; 26276400,0.006097327; 26280000,0.002915738;
        26283600,0.002573931; 26287200,0.002375424; 26290800,0.006973184;
        26294400,0.010355237; 26298000,0.004069192; 26301600,0.003270075;
        26305200,0.005950894; 26308800,0.003406328; 26312400,0.002913781;
        26316000,0.008489587; 26319600,0.006486901; 26323200,0.00349364;
        26326800,0.004528067; 26330400,0.003116986; 26334000,0.002762258;
        26337600,0.008123113; 26341200,0.01473922; 26344800,0.007868226;
        26348400,0.003969742; 26352000,0.006080883; 26355600,0.001057528;
        26359200,1e-06; 26362800,0.006146269; 26366400,0.002909082; 26370000,
        0.002566883; 26373600,0.002373467; 26377200,0.006982581; 26380800,
        0.010081165; 26384400,0.004041784; 26388000,0.003281429; 26391600,
        0.005844397; 26395200,0.003390667; 26398800,0.002911823; 26402400,
        0.008609004; 26406000,0.006431695; 26409600,0.003469756; 26413200,
        0.004460723; 26416800,0.003098975; 26420400,0.002746597; 26424000,
        0.00820651; 26427600,0.01476976; 26431200,0.007627825; 26434800,
        0.003930589; 26438400,0.005798588; 26442000,0.001050872; 26445600,1e-06;
        26449200,0.006068354; 26452800,0.002869146; 26456400,0.002554746;
        26460000,0.002363678; 26463600,0.006840063; 26467200,0.009995028;
        26470800,0.004069192; 26474400,0.00326107; 26478000,0.005963032;
        26481600,0.003424338; 26485200,0.002916913; 26488800,0.008316139;
        26492400,0.006793862; 26496000,0.003524962; 26499600,0.004474819;
        26503200,0.003141261; 26506800,0.002759517; 26510400,0.008045198;
        26514000,0.014679707; 26517600,0.007885453; 26521200,0.003968959;
        26524800,0.006079317; 26528400,0.001057919; 26532000,1e-06; 26535600,
        0.006101634; 26539200,0.00289303; 26542800,0.002560227; 26546400,
        0.002367594; 26550000,0.006972792; 26553600,0.010297682; 26557200,
        0.004109519; 26560800,0.003292784; 26564400,0.005964206; 26568000,
        0.003418857; 26571600,0.002920437; 26575200,0.00843908; 26578800,
        0.006746879; 26582400,0.00349638; 26586000,0.00449048; 26589600,
        0.003097018; 26593200,0.002740332; 26596800,0.008253885; 26600400,
        0.014840235; 26604000,0.00758045; 26607600,0.003974832; 26611200,
        0.005728895; 26614800,0.001055179; 26618400,1e-06; 26622000,0.00611847;
        26625600,0.002913389; 26629200,0.002578238; 26632800,0.002378557;
        26636400,0.007045617; 26640000,0.011139084; 26643600,0.004243423;
        26647200,0.003298657; 26650800,0.006184247; 26654400,0.003440391;
        26658000,0.002906733; 26661600,0.008399143; 26665200,0.005741424;
        26668800,0.003503036; 26672400,0.00452885; 26676000,0.003114245;
        26679600,0.002748554; 26683200,0.008057336; 26686800,0.014790511;
        26690400,0.007901506; 26694000,0.003944293; 26697600,0.005872588;
        26701200,0.001054787; 26704800,1e-06; 26708400,0.006091846; 26712000,
        0.002902035; 26715600,0.002572365; 26719200,0.002376207; 26722800,
        0.006993544; 26726400,0.010337226; 26730000,0.004117741; 26733600,
        0.003301789; 26737200,0.005988481; 26740800,0.00342473; 26744400,
        0.002923569; 26748000,0.008446127; 26751600,0.006766847; 26755200,
        0.003532793; 26758800,0.004489697; 26762400,0.00312834; 26766000,
        0.00274738; 26769600,0.007820851; 26773200,0.014610406; 26776800,
        0.007950056; 26780400,0.003929415; 26784000,0.006050735; 26787600,
        0.001092766; 26791200,1e-06; 26794800,0.006194035; 26798400,0.002915738;
        26802000,0.002574323; 26805600,0.002376599; 26809200,0.007031522;
        26812800,0.01096172; 26816400,0.004209751; 26820000,0.003310011;
        26823600,0.006200691; 26827200,0.003449005; 26830800,0.002930225;
        26834400,0.008668517; 26838000,0.006426605; 26841600,0.00353201;
        26845200,0.004521411; 26848800,0.003116594; 26852400,0.002751295;
        26856000,0.008145039; 26859600,0.014789728; 26863200,0.006998634;
        26866800,0.003919626; 26870400,0.006090671; 26874000,0.001090025;
        26877600,1e-06; 26881200,0.006181115; 26884800,0.00288285; 26888400,
        0.002567275; 26892000,0.002373858; 26895600,0.006881174; 26899200,
        0.011009095; 26902800,0.004222281; 26906400,0.003291609; 26910000,
        0.005800546; 26913600,0.003349164; 26917200,0.002893421; 26920800,
        0.008162267; 26924400,0.005717149; 26928000,0.003484243; 26931600,
        0.004382417; 26935200,0.003075092; 26938800,0.002739549; 26942400,
        0.007730015; 26946000,0.014628417; 26949600,0.007230812; 26953200,
        0.003939203; 26956800,0.005887466; 26960400,0.001079062; 26964000,1e-06;
        26967600,0.006011973; 26971200,0.002878543; 26974800,0.002568058;
        26978400,0.002373467; 26982000,0.006959089; 26985600,0.010771044;
        26989200,0.00415572; 26992800,0.003293958; 26996400,0.005963032;
        27000000,0.003402413; 27003600,0.002914172; 27007200,0.008208076;
        27010800,0.006830275; 27014400,0.003495989; 27018000,0.004454459;
        27021600,0.003094277; 27025200,0.002729369; 27028800,0.008058902;
        27032400,0.014687929; 27036000,0.007302854; 27039600,0.003902007;
        27043200,0.005628272; 27046800,0.00104539; 27050400,1e-06; 27054000,
        0.006058565; 27057600,0.002883241; 27061200,0.002564926; 27064800,
        0.002368377; 27068400,0.007006856; 27072000,0.010505194; 27075600,
        0.004130271; 27079200,0.003261461; 27082800,0.006020587; 27086400,
        0.003395757; 27090000,0.002920828; 27093600,0.008245271; 27097200,
        0.006840455; 27100800,0.003530052; 27104400,0.004465422; 27108000,
        0.003095452; 27111600,0.00275012; 27115200,0.008042849; 27118800,
        0.014701633; 27122400,0.007893284; 27126000,0.003972092; 27129600,
        0.006084015; 27133200,0.001049697; 27136800,1e-06; 27140400,0.006170152;
        27144000,0.002917305; 27147600,0.002568058; 27151200,0.002373075;
        27154800,0.006963396; 27158400,0.010743637; 27162000,0.004171773;
        27165600,0.003303355; 27169200,0.006008058; 27172800,0.003443523;
        27176400,0.002911823; 27180000,0.00833963; 27183600,0.006782116;
        27187200,0.003501079; 27190800,0.004456417; 27194400,0.003100541;
        27198000,0.0027372; 27201600,0.008015442; 27205200,0.014666787;
        27208800,0.007883496; 27212400,0.003952123; 27216000,0.005789583;
        27219600,0.001035994; 27223200,1e-06; 27226800,0.006059348; 27230400,
        0.002913389; 27234000,0.002569624; 27237600,0.002370334; 27241200,
        0.006974359; 27244800,0.010372464; 27248400,0.004113435; 27252000,
        0.003299831; 27255600,0.005983; 27259200,0.00341455; 27262800,
        0.002912606; 27266400,0.00843164; 27270000,0.006760582; 27273600,
        0.003505386; 27277200,0.00444702; 27280800,0.003111113; 27284400,
        0.002754427; 27288000,0.008251927; 27291600,0.014896224; 27295200,
        0.007421097; 27298800,0.003972875; 27302400,0.005971645; 27306000,
        0.001046956; 27309600,1e-06; 27313200,0.006116904; 27316800,0.002930225;
        27320400,0.002584111; 27324000,0.002382472; 27327600,0.007049924;
        27331200,0.010168476; 27334800,0.004058229; 27338400,0.003300223;
        27342000,0.005921138; 27345600,0.003421989; 27349200,0.002909082;
        27352800,0.008504857; 27356400,0.006734349; 27360000,0.003508518;
        27363600,0.004478734; 27367200,0.003110721; 27370800,0.002743856;
        27374400,0.008200637; 27378000,0.01476741; 27381600,0.007628217;
        27385200,0.003967785; 27388800,0.00594228; 27392400,0.001040692;
        27396000,1e-06; 27399600,0.006172893; 27403200,0.002918479; 27406800,
        0.002577846; 27410400,0.002377774; 27414000,0.007041311; 27417600,
        0.010976598; 27421200,0.004212884; 27424800,0.003311186; 27428400,
        0.006201866; 27432000,0.003459576; 27435600,0.00293649; 27439200,
        0.008381916; 27442800,0.005741424; 27446400,0.003501079; 27450000,
        0.004522977; 27453600,0.00311033; 27457200,0.0027603; 27460800,
        0.008086701; 27464400,0.01472395; 27468000,0.007888194; 27471600,
        0.003973266; 27475200,0.006088322; 27478800,0.001039517; 27482400,1e-06;
        27486000,0.006047602; 27489600,0.002902818; 27493200,0.002575497;
        27496800,0.00237699; 27500400,0.006994327; 27504000,0.010317258;
        27507600,0.004052747; 27511200,0.003269292; 27514800,0.005951286;
        27518400,0.00344; 27522000,0.002922394; 27525600,0.008426551; 27529200,
        0.006758624; 27532800,0.003530444; 27536400,0.004486956; 27540000,
        0.003125991; 27543600,0.002761083; 27547200,0.008224912; 27550800,
        0.014837886; 27554400,0.007650143; 27558000,0.003974049; 27561600,
        0.00595246; 27565200,0.001034819; 27568800,1e-06; 27572400,0.006144311;
        27576000,0.002893813; 27579600,0.002573931; 27583200,0.002377774;
        27586800,0.006997067; 27590400,0.01029729; 27594000,0.004089943;
        27597600,0.00328926; 27601200,0.005964598; 27604800,0.003432169;
        27608400,0.00292905; 27612000,0.008461005; 27615600,0.006768804;
        27619200,0.003533576; 27622800,0.004490871; 27626400,0.003120118;
        27630000,0.002761475; 27633600,0.008063992; 27637200,0.014703591;
        27640800,0.007885453; 27644400,0.00393333; 27648000,0.006058565;
        27651600,0.001036777; 27655200,1e-06; 27658800,0.006120819; 27662400,
        0.002923178; 27666000,0.002567275; 27669600,0.002373075; 27673200,
        0.007040919; 27676800,0.01086971; 27680400,0.00419409; 27684000,
        0.003313143; 27687600,0.006027243; 27691200,0.003439217; 27694800,
        0.002924352; 27698400,0.008358816; 27702000,0.00679582; 27705600,
        0.003528877; 27709200,0.004480692; 27712800,0.003144002; 27716400,
        0.002751687; 27720000,0.008038934; 27723600,0.014684797; 27727200,
        0.007886236; 27730800,0.003969742; 27734400,0.006081274; 27738000,
        0.001036385; 27741600,1e-06; 27745200,0.006073444; 27748800,0.002923178;
        27752400,0.002570407; 27756000,0.002372684; 27759600,0.006851026;
        27763200,0.01101027; 27766800,0.004213275; 27770400,0.00327399;
        27774000,0.006103592; 27777600,0.00343491; 27781200,0.002924352;
        27784800,0.008381916; 27788400,0.00571989; 27792000,0.003451746;
        27795600,0.004454459; 27799200,0.003092319; 27802800,0.002747771;
        27806400,0.008188891; 27810000,0.014743527; 27813600,0.007564006;
        27817200,0.003961912; 27820800,0.005896471; 27824400,0.001034427;
        27828000,1e-06; 27831600,0.006153316; 27835200,0.002911432; 27838800,
        0.002570799; 27842400,0.002373858; 27846000,0.007018993; 27849600,
        0.011063518; 27853200,0.004228937; 27856800,0.003297482; 27860400,
        0.005792715; 27864000,0.003383619; 27867600,0.002914172; 27871200,
        0.008657946; 27874800,0.006005709; 27878400,0.003519089; 27882000,
        0.004492438; 27885600,0.003111113; 27889200,0.002764607; 27892800,
        0.007849041; 27896400,0.014641729; 27900000,0.006982972; 27903600,
        0.003929415; 27907200,0.005910566; 27910800,0.001032861; 27914400,1e-06;
        27918000,0.00608284; 27921600,0.002870712; 27925200,0.002555921;
        27928800,0.002364853; 27932400,0.006994327; 27936000,0.010307862;
        27939600,0.004108736; 27943200,0.003274382; 27946800,0.005948153;
        27950400,0.003427471; 27954000,0.002917305; 27957600,0.008430074;
        27961200,0.006760191; 27964800,0.003527703; 27968400,0.004475993;
        27972000,0.00312325; 27975600,0.002756776; 27979200,0.008053421;
        27982800,0.01469576; 27986400,0.007888977; 27990000,0.003970917;
        27993600,0.006083623; 27997200,0.00103756; 28000800,1e-06; 28004400,
        0.006053084; 28008000,0.002901643; 28011600,0.002577063; 28015200,
        0.002378557; 28018800,0.006992761; 28022400,0.010311385; 28026000,
        0.004113043; 28029600,0.003287302; 28033200,0.005955984; 28036800,
        0.003414942; 28040400,0.002903601; 28044000,0.008659512; 28047600,
        0.006250808; 28051200,0.003495989; 28054800,0.004477168; 28058400,
        0.003105631; 28062000,0.002758734; 28065600,0.008072606; 28069200,
        0.01471886; 28072800,0.007894459; 28076400,0.003973658; 28080000,
        0.006089105; 28083600,0.001039909; 28087200,1e-06; 28090800,0.006127867;
        28094400,0.002912606; 28098000,0.00257628; 28101600,0.00237699;
        28105200,0.006965353; 28108800,0.010803541; 28112400,0.004179604;
        28116000,0.003306879; 28119600,0.006015105; 28123200,0.003444698;
        28126800,0.002928267; 28130400,0.008355683; 28134000,0.006793079;
        28137600,0.003527703; 28141200,0.004479517; 28144800,0.003146742;
        28148400,0.00277048; 28152000,0.008073389; 28155600,0.014700067;
        28159200,0.007888586; 28162800,0.00396661; 28166400,0.006070703;
        28170000,0.001039517; 28173600,1e-06; 28177200,0.006176416; 28180800,
        0.002896945; 28184400,0.00257119; 28188000,0.002373075; 28191600,
        0.006978274; 28195200,0.009901451; 28198800,0.003970134; 28202400,
        0.003244625; 28206000,0.00575552; 28209600,0.0033429; 28213200,
        0.002883633; 28216800,0.008546751; 28220400,0.006472806; 28224000,
        0.00347328; 28227600,0.00446229; 28231200,0.003117769; 28234800,
        0.002758343; 28238400,0.00806869; 28242000,0.014788945; 28245600,
        0.007914818; 28249200,0.003977573; 28252800,0.006090279; 28256400,
        0.001044216; 28260000,1e-06; 28263600,0.006145094; 28267200,0.002887548;
        28270800,0.0025661; 28274400,0.002373467; 28278000,0.006725344;
        28281600,0.009912414; 28285200,0.003991277; 28288800,0.003242276;
        28292400,0.005788017; 28296000,0.00339654; 28299600,0.002913781;
        28303200,0.008612528; 28306800,0.005692875; 28310400,0.003504211;
        28314000,0.004485782; 28317600,0.003145959; 28321200,0.002753253;
        28324800,0.008087484; 28328400,0.014816352; 28332000,0.007901115;
        28335600,0.003980705; 28339200,0.006120427; 28342800,0.001047348;
        28346400,1e-06; 28350000,0.006166237; 28353600,0.002896162; 28357200,
        0.002564143; 28360800,0.002371509; 28364400,0.006980623; 28368000,
        0.010351322; 28371600,0.004106387; 28375200,0.003269683; 28378800,
        0.005965772; 28382400,0.003369915; 28386000,0.002909082; 28389600,
        0.008483714; 28393200,0.005756694; 28396800,0.003509301; 28400400,
        0.004486173; 28404000,0.003111113; 28407600,0.002746597; 28411200,
        0.008044415; 28414800,0.01470085; 28418400,0.007890935; 28422000,
        0.003972875; 28425600,0.006087539; 28429200,0.001049697; 28432800,1e-06;
        28436400,0.006080491; 28440000,0.002901643; 28443600,0.002577063;
        28447200,0.00237699; 28450800,0.007017427; 28454400,0.010072942;
        28458000,0.004095816; 28461600,0.003303355; 28465200,0.006067179;
        28468800,0.003416899; 28472400,0.002925135; 28476000,0.008725289;
        28479600,0.006245718; 28483200,0.003487375; 28486800,0.004504184;
        28490400,0.003125208; 28494000,0.002755602; 28497600,0.008172838;
        28501200,0.014763104; 28504800,0.00778757; 28508400,0.003947425;
        28512000,0.00608793; 28515600,0.001051655; 28519200,1e-06; 28522800,
        0.006073052; 28526400,0.002922003; 28530000,0.002573931; 28533600,
        0.002376207; 28537200,0.006992369; 28540800,0.010403004; 28544400,
        0.004083287; 28548000,0.003277122; 28551600,0.005964206; 28555200,
        0.003417682; 28558800,0.002932966; 28562400,0.008611745; 28566000,
        0.006654869; 28569600,0.003517523; 28573200,0.004483041; 28576800,
        0.003112679; 28580400,0.002753253; 28584000,0.008054204; 28587600,
        0.014733739; 28591200,0.00699785; 28594800,0.003952515; 28598400,
        0.005932101; 28602000,0.001053612; 28605600,1e-06; 28609200,0.006099676;
        28612800,0.002918871; 28616400,0.002573539; 28620000,0.002375816;
        28623600,0.006988062; 28627200,0.010323523; 28630800,0.004111085;
        28634400,0.003277514; 28638000,0.005831477; 28641600,0.003400455;
        28645200,0.002918479; 28648800,0.008713935; 28652400,0.006232014;
        28656000,0.003512433; 28659600,0.004531982; 28663200,0.003162012;
        28666800,0.002784967; 28670400,0.008197896; 28674000,0.014784246;
        28677600,0.0078463; 28681200,0.003973658; 28684800,0.006091454;
        28688400,0.00106066; 28692000,1e-06; 28695600,0.006234755; 28699200,
        0.002919654; 28702800,0.002564534; 28706400,0.002370726; 28710000,
        0.006963396; 28713600,0.01073424; 28717200,0.004170598; 28720800,
        0.003297091; 28724400,0.00598809; 28728000,0.003398889; 28731600,
        0.002910257; 28735200,0.008665777; 28738800,0.005963815; 28742400,
        0.003508518; 28746000,0.004538247; 28749600,0.003142435; 28753200,
        0.002763041; 28756800,0.008197504; 28760400,0.014781897; 28764000,
        0.00807378; 28767600,0.003984229; 28771200,0.006089105; 28774800,
        0.001066141; 28778400,1e-06; 28782000,0.006067571; 28785600,0.00288285;
        28789200,0.002575106; 28792800,0.002378948; 28796400,0.006985713;
        28800000,0.010852483; 28803600,0.004191349; 28807200,0.003311969;
        28810800,0.006025677; 28814400,0.003422381; 28818000,0.002906733;
        28821600,0.008334541; 28825200,0.006785249; 28828800,0.003501862;
        28832400,0.004371846; 28836000,0.003135779; 28839600,0.002752861;
        28843200,0.008096881; 28846800,0.014774458; 28850400,0.007863136;
        28854000,0.003925108; 28857600,0.005830302; 28861200,0.001066141;
        28864800,1e-06; 28868400,0.006105941; 28872000,0.002905167; 28875600,
        0.00256845; 28879200,0.002373467; 28882800,0.006986888; 28886400,
        0.01028711; 28890000,0.004105604; 28893600,0.003263419; 28897200,
        0.005930143; 28900800,0.003419248; 28904400,0.002902035; 28908000,
        0.008409715; 28911600,0.005729679; 28915200,0.003456052; 28918800,
        0.004498702; 28922400,0.003139695; 28926000,0.002750512; 28929600,
        0.008042066; 28933200,0.014698892; 28936800,0.00788976; 28940400,
        0.003972483; 28944000,0.006086756; 28947600,0.001072014; 28951200,1e-06;
        28954800,0.006138829; 28958400,0.002889506; 28962000,0.00256845;
        28965600,0.002373467; 28969200,0.006963396; 28972800,0.010790229;
        28976400,0.004169032; 28980000,0.003289651; 28983600,0.005996703;
        28987200,0.003433735; 28990800,0.002923961; 28994400,0.008352943;
        28998000,0.006791905; 29001600,0.003527703; 29005200,0.004479517;
        29008800,0.00312325; 29012400,0.002744639; 29016000,0.008167748;
        29019600,0.014826923; 29023200,0.007655624; 29026800,0.003976007;
        29030400,0.005954026; 29034000,0.00107593; 29037600,1e-06; 29041200,
        0.006139221; 29044800,0.002925135; 29048400,0.002573539; 29052000,
        0.002377382; 29055600,0.006996284; 29059200,0.010355628; 29062800,
        0.004122831; 29066400,0.003306879; 29070000,0.005755128; 29073600,
        0.003406719; 29077200,0.002914172; 29080800,0.008578073; 29084400,
        0.005747297; 29088000,0.003488941; 29091600,0.004471686; 29095200,
        0.003102891; 29098800,0.002733285; 29102400,0.008084352; 29106000,
        0.014722776; 29109600,0.006977882; 29113200,0.0039486; 29116800,
        0.005925053; 29120400,0.001082977; 29124000,1e-06; 29127600,0.006127475;
        29131200,0.002891463; 29134800,0.002562577; 29138400,0.002369943;
        29142000,0.00695439; 29145600,0.010181005; 29149200,0.004042567;
        29152800,0.003278689; 29156400,0.005929751; 29160000,0.003436476;
        29163600,0.002917696; 29167200,0.008484106; 29170800,0.006752751;
        29174400,0.003535142; 29178000,0.004492438; 29181600,0.003153398;
        29185200,0.002770089; 29188800,0.008075738; 29192400,0.014721601;
        29196000,0.007895242; 29199600,0.003973266; 29203200,0.006088322;
        29206800,0.0010912; 29210400,1e-06; 29214000,0.006118078; 29217600,
        0.002923178; 29221200,0.002567667; 29224800,0.00237425; 29228400,
        0.006868645; 29232000,0.009828626; 29235600,0.003960346; 29239200,
        0.003252847; 29242800,0.00598574; 29246400,0.003407111; 29250000,
        0.002894596; 29253600,0.008417937; 29257200,0.00673709; 29260800,
        0.003500687; 29264400,0.004463464; 29268000,0.003140869; 29271600,
        0.002754819; 29275200,0.008043632; 29278800,0.014747051; 29282400,
        0.00789994; 29286000,0.003949774; 29289600,0.006069137; 29293200,
        0.001092766; 29296800,1e-06; 29300400,0.006130216; 29304000,0.002898119;
        29307600,0.002567275; 29311200,0.002371901; 29314800,0.006978274;
        29318400,0.010295724; 29322000,0.004109128; 29325600,0.003294741;
        29329200,0.005960682; 29332800,0.003370699; 29336400,0.002912606;
        29340000,0.00843908; 29343600,0.006760582; 29347200,0.003504602;
        29350800,0.004466988; 29354400,0.003118943; 29358000,0.002744639;
        29361600,0.00803541; 29365200,0.014685189; 29368800,0.007887411;
        29372400,0.003936462; 29376000,0.00603429; 29379600,0.00109903;
        29383200,1e-06; 29386800,0.006036248; 29390400,0.002894596; 29394000,
        0.002575497; 29397600,0.002378165; 29401200,0.006867079; 29404800,
        0.010300814; 29408400,0.004113826; 29412000,0.003298657; 29415600,
        0.005977518; 29419200,0.003432169; 29422800,0.002927484; 29426400,
        0.008449651; 29430000,0.006767238; 29433600,0.003530835; 29437200,
        0.004481866; 29440800,0.003124425; 29444400,0.002759909; 29448000,
        0.008065167; 29451600,0.014701242; 29455200,0.007888977; 29458800,
        0.003970525; 29462400,0.006083232; 29466000,0.001045782; 29469600,1e-06;
        29473200,0.00613139; 29476800,0.002896553; 29480400,0.002573148;
        29484000,0.00237425; 29487600,0.006986496; 29491200,0.010290243;
        29494800,0.004084461; 29498400,0.003261461; 29502000,0.005936016;
        29505600,0.003422772; 29509200,0.002902035; 29512800,0.008402667;
        29516400,0.006746487; 29520000,0.003522221; 29523600,0.004504184;
        29527200,0.003125991; 29530800,0.00274738; 29534400,0.007742936;
        29538000,0.014574777; 29541600,0.007970416; 29545200,0.00395643;
        29548800,0.00604447; 29552400,0.001044607; 29556000,1e-06; 29559600,
        0.00612865; 29563200,0.002887548; 29566800,0.00256101; 29570400,
        0.002369551; 29574000,0.007003723; 29577600,0.011114809; 29581200,
        0.004239899; 29584800,0.003288868; 29588400,0.006175633; 29592000,
        0.003453703; 29595600,0.002933749; 29599200,0.008668517; 29602800,
        0.006357304; 29606400,0.003495597; 29610000,0.004514363; 29613600,
        0.003153007; 29617200,0.002755993; 29620800,0.007842776; 29624400,
        0.014694194; 29628000,0.007980204; 29631600,0.003977573; 29635200,
        0.006089105; 29638800,0.001048914; 29642400,1e-06; 29646000,0.0061032;
        29649600,0.002888723; 29653200,0.002568841; 29656800,0.002374641;
        29660400,0.006881957; 29664000,0.011047074; 29667600,0.004235201;
        29671200,0.003305704; 29674800,0.00615684; 29678400,0.003455661;
        29682000,0.002934923; 29685600,0.008401101; 29689200,0.006778201;
        29692800,0.003528486; 29696400,0.004482258; 29700000,0.003110721;
        29703600,0.002759126; 29707200,0.008054595; 29710800,0.014692236;
        29714400,0.006973967; 29718000,0.003932547; 29721600,0.005910958;
        29725200,0.001063009; 29728800,1e-06; 29732400,0.006095761; 29736000,
        0.002886765; 29739600,0.002564926; 29743200,0.002371509; 29746800,
        0.007026432; 29750400,0.011150047; 29754000,0.004245381; 29757600,
        0.003300614; 29761200,0.006182289; 29764800,0.003407503; 29768400,
        0.002904384; 29772000,0.008361556; 29775600,0.005734377; 29779200,
        0.003492856; 29782800,0.004506141; 29786400,0.00312051; 29790000,
        0.002741898; 29793600,0.008185367; 29797200,0.01475958; 29800800,
        0.007569879; 29804400,0.003939203; 29808000,0.005928577; 29811600,
        0.001047348; 29815200,1e-06; 29818800,0.006091846; 29822400,0.002892638;
        29826000,0.002565709; 29829600,0.002372292; 29833200,0.006981798;
        29836800,0.009979366; 29840400,0.004025731; 29844000,0.003273207;
        29847600,0.005934841; 29851200,0.00342982; 29854800,0.002918871;
        29858400,0.00850055; 29862000,0.006730826; 29865600,0.003533967;
        29869200,0.004494787; 29872800,0.003118943; 29876400,0.002762258;
        29880000,0.00806595; 29883600,0.014714945; 29887200,0.007894067;
        29890800,0.003970134; 29894400,0.006076967; 29898000,0.001051263;
        29901600,1e-06; 29905200,0.006114163; 29908800,0.002902818; 29912400,
        0.002561794; 29916000,0.002368768; 29919600,0.006947343; 29923200,
        0.010799234; 29926800,0.004183127; 29930400,0.003302572; 29934000,
        0.006003751; 29937600,0.003409852; 29941200,0.002903992; 29944800,
        0.008613311; 29948400,0.006419558; 29952000,0.003478761; 29955600,
        0.004535506; 29959200,0.003150658; 29962800,0.002764999; 29966400,
        0.008088267; 29970000,0.014727474; 29973600,0.007888586; 29977200,
        0.003974441; 29980800,0.006090279; 29984400,0.001052046; 29988000,1e-06;
        29991600,0.006078925; 29995200,0.002922394; 29998800,0.002575889;
        30002400,0.00237699; 30006000,0.006994718; 30009600,0.010330179;
        30013200,0.004114609; 30016800,0.003278297; 30020400,0.005952852;
        30024000,0.003440391; 30027600,0.002929834; 30031200,0.008449651;
        30034800,0.006769979; 30038400,0.003532401; 30042000,0.004488914;
        30045600,0.003146351; 30049200,0.00275521; 30052800,0.008048722;
        30056400,0.014704765; 30060000,0.007892893; 30063600,0.003957213;
        30067200,0.006071094; 30070800,0.001081803; 30074400,1e-06; 30078000,
        0.006140004; 30081600,0.002917305; 30085200,0.002564926; 30088800,
        0.002370726; 30092400,0.006958306; 30096000,0.010705266; 30099600,
        0.004149847; 30103200,0.003292784; 30106800,0.005992396; 30110400,
        0.003429428; 30114000,0.002918088; 30117600,0.00834707; 30121200,
        0.006781725; 30124800,0.003524962; 30128400,0.004475993; 30132000,
        0.003140478; 30135600,0.002755993; 30139200,0.008042458; 30142800,
        0.014681273; 30146400,0.007885062; 30150000,0.003954081; 30153600,
        0.006062481; 30157200,0.001080237; 30160800,1e-06; 30164400,0.00613648;
        30168000,0.002927484; 30171600,0.002579804; 30175200,0.002378948;
        30178800,0.006993152; 30182400,0.010288285; 30186000,0.004107953;
        30189600,0.003281429; 30193200,0.005948545; 30196800,0.003412984;
        30200400,0.002918088; 30204000,0.008441429; 30207600,0.006761365;
        30211200,0.003530835; 30214800,0.004487348; 30218400,0.003148308;
        30222000,0.002762649; 30225600,0.008059294; 30229200,0.014705548;
        30232800,0.007892501; 30236400,0.003969742; 30240000,0.006076576;
        30243600,0.001081803; 30247200,1e-06; 30250800,0.006141962; 30254400,
        0.002909082; 30258000,0.002572365; 30261600,0.002373075; 30265200,
        0.006973576; 30268800,0.010684515; 30272400,0.004126747; 30276000,
        0.003292392; 30279600,0.00600101; 30283200,0.003400455; 30286800,
        0.002919262; 30290400,0.008390138; 30294000,0.006776635; 30297600,
        0.003528486; 30301200,0.004482649; 30304800,0.00314361; 30308400,
        0.002751687; 30312000,0.008040892; 30315600,0.014793252; 30319200,
        0.007911686; 30322800,0.003963478; 30326400,0.00608284; 30330000,
        0.001083369; 30333600,1e-06; 30337200,0.006146269; 30340800,0.002900469;
        30344400,0.002564926; 30348000,0.002371901; 30351600,0.006980623;
        30355200,0.010332137; 30358800,0.004118133; 30362400,0.003281429;
        30366000,0.005957942; 30369600,0.003403979; 30373200,0.002918871;
        30376800,0.008453566; 30380400,0.006765672; 30384000,0.003533184;
        30387600,0.004487348; 30391200,0.003120901; 30394800,0.002748163;
        30398400,0.008045198; 30402000,0.014709464; 30405600,0.00789485;
        30409200,0.003970525; 30412800,0.00607775; 30416400,0.001082586;
        30420000,1e-06; 30423600,0.006143136; 30427200,0.002913781; 30430800,
        0.002573539; 30434400,0.002374641; 30438000,0.006985713; 30441600,
        0.010285153; 30445200,0.004109128; 30448800,0.003298657; 30452400,
        0.005973211; 30456000,0.003431778; 30459600,0.002927876; 30463200,
        0.008456307; 30466800,0.006765281; 30470400,0.003532793; 30474000,
        0.004489697; 30477600,0.003121293; 30481200,0.00275247; 30484800,
        0.008046765; 30488400,0.014693411; 30492000,0.007887803; 30495600,
        0.003970525; 30499200,0.006083232; 30502800,0.001082194; 30506400,1e-06;
        30510000,0.006140396; 30513600,0.002927093; 30517200,0.002579804;
        30520800,0.002378557; 30524400,0.006993935; 30528000,0.010287893;
        30531600,0.004109519; 30535200,0.003298657; 30538800,0.005972428;
        30542400,0.003437259; 30546000,0.002932574; 30549600,0.008468053;
        30553200,0.00677037; 30556800,0.003514391; 30560400,0.004474819;
        30564000,0.003111113; 30567600,0.002749337; 30571200,0.0080405;
        30574800,0.014689104; 30578400,0.00788702; 30582000,0.003970134;
        30585600,0.00608284; 30589200,0.001080628; 30592800,1e-06; 30596400,
        0.006143528; 30600000,0.002927484; 30603600,0.002578629; 30607200,
        0.002376207; 30610800,0.006985713; 30614400,0.010282804; 30618000,
        0.004108736; 30621600,0.003298265; 30625200,0.005972037; 30628800,
        0.003440391; 30632400,0.002932183; 30636000,0.008464921; 30639600,
        0.006769587; 30643200,0.003533184; 30646800,0.004489697; 30650400,
        0.003149091; 30654000,0.00276539; 30657600,0.0080636; 30661200,
        0.014713379; 30664800,0.00789485; 30668400,0.003959954; 30672000,
        0.006069137; 30675600,0.001078671; 30679200,1e-06; 30682800,0.006091063;
        30686400,0.002915738; 30690000,0.002565317; 30693600,0.002371901;
        30697200,0.006953607; 30700800,0.010769869; 30704400,0.004176471;
        30708000,0.003303355; 30711600,0.006009232; 30715200,0.003443132;
        30718800,0.002913389; 30722400,0.008325535; 30726000,0.006782508;
        30729600,0.003524571; 30733200,0.004474819; 30736800,0.003114245;
        30740400,0.002745814; 30744000,0.008025622; 30747600,0.014679316;
        30751200,0.00788702; 30754800,0.003969742; 30758400,0.006081274;
        30762000,0.001079062; 30765600,1e-06; 30769200,0.006140004; 30772800,
        0.002927484; 30776400,0.002580979; 30780000,0.002379731; 30783600,
        0.006992369; 30787200,0.010286327; 30790800,0.004108736; 30794400,
        0.003298265; 30798000,0.005971254; 30801600,0.003443915; 30805200,
        0.002932574; 30808800,0.008463746; 30812400,0.006768804; 30816000,
        0.003532793; 30819600,0.004489305; 30823200,0.00312051; 30826800,
        0.002748946; 30830400,0.008038542; 30834000,0.014687538; 30837600,
        0.007886628; 30841200,0.003961129; 30844800,0.006065613; 30848400,
        0.001079062; 30852000,1e-06; 30855600,0.006145877; 30859200,0.002902426;
        30862800,0.002561402; 30866400,0.00236916; 30870000,0.006970052;
        30873600,0.010072942; 30877200,0.004074673; 30880800,0.003278689;
        30884400,0.005846355; 30888000,0.00342982; 30891600,0.002916521;
        30895200,0.008639544; 30898800,0.005912132; 30902400,0.003477978;
        30906000,0.004510056; 30909600,0.003114637; 30913200,0.002754819;
        30916800,0.008201811; 30920400,0.014887219; 30924000,0.006959872;
        30927600,0.003945859; 30931200,0.006015497; 30934800,0.001076321;
        30938400,1e-06; 30942000,0.006135697; 30945600,0.002900469; 30949200,
        0.002565709; 30952800,0.002371117; 30956400,0.006873735; 30960000,
        0.011036503; 30963600,0.00421954; 30967200,0.003297874; 30970800,
        0.00614157; 30974400,0.003427862; 30978000,0.002917305; 30981600,
        0.008384265; 30985200,0.006768413; 30988800,0.003520264; 30992400,
        0.004463073; 30996000,0.00310524; 30999600,0.00275521; 31003200,
        0.008047156; 31006800,0.014688321; 31010400,0.007887411; 31014000,
        0.003969742; 31017600,0.006081666; 31021200,0.00108102; 31024800,1e-06;
        31028400,0.006130999; 31032000,0.002919262; 31035600,0.002570799;
        31039200,0.002372292; 31042800,0.006946951; 31046400,0.01081607;
        31050000,0.004183519; 31053600,0.003301006; 31057200,0.006190903;
        31060800,0.003439217; 31064400,0.00289577; 31068000,0.008311832;
        31071600,0.006758233; 31075200,0.003468973; 31078800,0.004450544;
        31082400,0.003082923; 31086000,0.002728978; 31089600,0.008003696;
        31093200,0.014758797; 31096800,0.007906205; 31100400,0.003976398;
        31104000,0.006092629; 31107600,0.001082194; 31111200,1e-06; 31114800,
        0.006099676; 31118400,0.002885199; 31122000,0.002570016; 31125600,
        0.002372684; 31129200,0.0070002; 31132800,0.010272624; 31136400,
        0.004048832; 31140000,0.003263027; 31143600,0.006097719; 31147200,
        0.003456052; 31150800,0.002940796; 31154400,0.008526391; 31158000,
        0.006043687; 31161600,0.003465058; 31165200,0.004461115; 31168800,
        0.003114245; 31172400,0.002739549; 31176000,0.008258975; 31179600,
        0.014906404; 31183200,0.007908162; 31186800,0.003983446; 31190400,
        0.006106724; 31194000,0.001084935; 31197600,1e-06; 31201200,0.006188162;
        31204800,0.002922003; 31208400,0.002570016; 31212000,0.002375424;
        31215600,0.006995893; 31219200,0.010283195; 31222800,0.004108345;
        31226400,0.003298265; 31230000,0.005971645; 31233600,0.00344509;
        31237200,0.002932183; 31240800,0.008467661; 31244400,0.006768804;
        31248000,0.003534359; 31251600,0.004492438; 31255200,0.003135779;
        31258800,0.002765782; 31262400,0.008063992; 31266000,0.014706723;
        31269600,0.007890543; 31273200,0.003968959; 31276800,0.00607501;
        31280400,0.001082194; 31284000,1e-06; 31287600,0.006158014; 31291200,
        0.002925527; 31294800,0.002577063; 31298400,0.002377382; 31302000,
        0.007069892; 31305600,0.010810589; 31309200,0.004181953; 31312800,
        0.003310794; 31316400,0.005833826; 31320000,0.003445873; 31323600,
        0.00294158; 31327200,0.00868966; 31330800,0.006104375; 31334400,
        0.003502645; 31338000,0.004522977; 31341600,0.003154573; 31345200,
        0.002779877; 31348800,0.008153653; 31352400,0.014760363; 31356000,
        0.006900359; 31359600,0.003954473; 31363200,0.005972428; 31366800,
        0.001071623; 31370400,1e-06; 31374000,0.00605974; 31377600,0.002906733;
        31381200,0.002579412; 31384800,0.00237934; 31388400,0.006975533;
        31392000,0.010392824; 31395600,0.004074281; 31399200,0.003279863;
        31402800,0.006122385; 31406400,0.003384011; 31410000,0.002897728;
        31413600,0.008104711; 31417200,0.006846719; 31420800,0.003503036;
        31424400,0.004453284; 31428000,0.003116203; 31431600,0.002747771;
        31435200,0.008022881; 31438800,0.014674226; 31442400,0.007879189;
        31446000,0.003914928; 31449600,0.00599592; 31453200,0.001074364;
        31456800,1e-06; 31460400,0.00611338; 31464000,0.002892638; 31467600,
        0.002570407; 31471200,0.002372292; 31474800,0.007003723; 31478400,
        0.010097217; 31482000,0.004042567; 31485600,0.003268509; 31489200,
        0.006109465; 31492800,0.003406719; 31496400,0.002898119; 31500000,
        0.008258583; 31503600,0.005569933; 31507200,0.003435301; 31510800,
        0.004448194; 31514400,0.003121684; 31518000,0.00274503; 31521600,
        0.008126637; 31525200,0.014775633; 31528800,0.006990411; 31532400,
        0.003953298; 31536000,0.005932492], smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
    annotation (Placement(transformation(extent={{242,104},{222,124}})));
  Modelica.Blocks.Sources.CombiTimeTable combiTimeTable_compressor(
                             smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table=[0,
        0.0183848; 3600,0.0149319; 7200,0.000536; 10800,0.0058154; 14400,
        0.004297; 18000,0.0050126; 21600,0.002257; 25200,0.0066349; 28800,
        0.0107734; 32400,0.0093511; 36000,0.0184698; 39600,0.0178298; 43200,
        0.0049127; 46800,0.004507; 50400,0.0108587; 54000,0.0106179; 57600,
        0.0133626; 61200,0.0162087; 64800,0.0094988; 68400,0.0075695; 72000,
        0.0118561; 75600,0.0201694; 79200,0.0162599; 82800,0.0166062; 86400,
        0.0181046; 90000,0.0496434; 93600,0.0608404; 97200,0.044002; 100800,
        0.0279403; 104400,0.0317161; 108000,0.0236671; 111600,0.0205071; 115200,
        0.0379104; 118800,0.039728; 122400,0.033762; 126000,0.0251671; 129600,
        0.0133325; 133200,0.0158524; 136800,0.0218218; 140400,0.0144034; 144000,
        0.0222618; 147600,0.0340633; 151200,0.026996; 154800,0.0158405; 158400,
        0.0172672; 162000,0.0225972; 165600,0.0199856; 169200,0.0261884; 172800,
        0.0256611; 176400,0.0191968; 180000,0.0208314; 183600,0.0295901; 187200,
        0.0203843; 190800,0.0162072; 194400,0.0156315; 198000,0.0223819; 201600,
        0.0242681; 205200,0.0144089; 208800,0.0180916; 212400,0.0180966; 216000,
        0.0063669; 219600,0.014478; 223200,0.0233491; 226800,0.0151126; 230400,
        0.0212656; 234000,0.0334283; 237600,0.0310488; 241200,0.0207135; 244800,
        0.0182475; 248400,0.0207502; 252000,0.0194482; 255600,0.025406; 259200,
        0.0236108; 262800,0.019284; 266400,0.0223457; 270000,0.0244533; 273600,
        0.022214; 277200,0.0187593; 280800,0.0126715; 284400,0.0129684; 288000,
        0.031198; 291600,0.0341673; 295200,0.0456277; 298800,0.042357; 302400,
        0.0204258; 306000,0.0170616; 309600,0.0261193; 313200,0.0273683; 316800,
        0.0262711; 320400,0.0198453; 324000,0.0136245; 327600,0.0071371; 331200,
        0.0103881; 334800,0.0168979; 338400,0.0101153; 342000,0.0079499; 345600,
        0.0088741; 349200,0.0070825; 352800,0.0106238; 356400,0.0174825; 360000,
        0.0116259; 363600,0.009661; 367200,0.0070335; 370800,0.0084818; 374400,
        0.0199419; 378000,0.0224277; 381600,0.0275821; 385200,0.0188929; 388800,
        0.0101693; 392400,0.0106554; 396000,0.0176369; 399600,0.01457; 403200,
        0.0176547; 406800,0.0147522; 410400,0.005135; 414000,0.0041418; 417600,
        0.0087379; 421200,0.0147229; 424800,0.0084098; 428400,0.0046533; 432000,
        0.0051691; 435600,0.0057547; 439200,0.0060936; 442800,0.0088003; 446400,
        0.0073193; 450000,0.0086474; 453600,0.0045434; 457200,0.0072822; 460800,
        0.0120595; 464400,0.0107589; 468000,0.0177672; 471600,0.020568; 475200,
        0.0137887; 478800,0.0092538; 482400,0.014047; 486000,0.0136618; 489600,
        0.0122343; 493200,0.0121103; 496800,0.0048478; 500400,0.0038137; 504000,
        0.008412; 507600,0.0144527; 511200,0.0084618; 514800,0.0053622; 518400,
        0.0072948; 522000,0.0052182; 525600,0.0064204; 529200,0.011407; 532800,
        0.0083289; 536400,0.0092642; 540000,0.0051955; 543600,0.0071371; 547200,
        0.0115725; 550800,0.0092327; 554400,0.0178459; 558000,0.021461; 561600,
        0.0124011; 565200,0.0070621; 568800,0.0130906; 572400,0.0128797; 576000,
        0.013805; 579600,0.012493; 583200,0.0061242; 586800,0.0040048; 590400,
        0.0079603; 594000,0.0143466; 597600,0.0090653; 601200,0.0067774; 604800,
        0.0095986; 608400,0.0061546; 612000,0.007136; 615600,0.0154537; 619200,
        0.0182393; 622800,0.0260648; 626400,0.0274949; 630000,0.0120847; 633600,
        0.0200024; 637200,0.0257073; 640800,0.0449974; 644400,0.0476602; 648000,
        0.0199125; 651600,0.0128998; 655200,0.0178448; 658800,0.0170516; 662400,
        0.0316786; 666000,0.044254; 669600,0.0253815; 673200,0.0101597; 676800,
        0.0125702; 680400,0.0200558; 684000,0.0135775; 687600,0.0204112; 691200,
        0.0398613; 694800,0.0453222; 698400,0.0407335; 702000,0.051685; 705600,
        0.042769; 709200,0.0312488; 712800,0.0401378; 716400,0.0436765; 720000,
        0.0404678; 723600,0.0355472; 727200,0.0306531; 730800,0.0294572; 734400,
        0.0188057; 738000,0.0184327; 741600,0.0268312; 745200,0.0142081; 748800,
        0.0211676; 752400,0.0370575; 756000,0.03058; 759600,0.0186565; 763200,
        0.0205617; 766800,0.0213976; 770400,0.0162213; 774000,0.0151383; 777600,
        0.0188785; 781200,0.0153931; 784800,0.0122016; 788400,0.0244369; 792000,
        0.0180883; 795600,0.0155859; 799200,0.0127743; 802800,0.0119474; 806400,
        0.0212543; 810000,0.0158; 813600,0.012487; 817200,0.0150804; 820800,
        0.0101016; 824400,0.0121177; 828000,0.0212105; 831600,0.0179357; 835200,
        0.0189828; 838800,0.0258966; 842400,0.0180159; 846000,0.0150869; 849600,
        0.0138825; 853200,0.0160862; 856800,0.0099735; 860400,0.0110518; 864000,
        0.0132746; 867600,0.008593; 871200,0.0142445; 874800,0.0210372; 878400,
        0.0117499; 882000,0.0131351; 885600,0.0095255; 889200,0.0079169; 892800,
        0.01788; 896400,0.0244038; 900000,0.0314351; 903600,0.0332991; 907200,
        0.0171908; 910800,0.0124718; 914400,0.02183; 918000,0.026904; 921600,
        0.0195826; 925200,0.0178414; 928800,0.0119606; 932400,0.0052412; 936000,
        0.0104219; 939600,0.0171511; 943200,0.0140559; 946800,0.0138537; 950400,
        0.0135816; 954000,0.0159559; 957600,0.0205871; 961200,0.0158227; 964800,
        0.0165932; 968400,0.0165761; 972000,0.010274; 975600,0.0082365; 979200,
        0.0192541; 982800,0.026528; 986400,0.0366158; 990000,0.0306735; 993600,
        0.0091607; 997200,0.0106142; 1000800,0.0155766; 1004400,0.0112366;
        1008000,0.012336; 1011600,0.0126737; 1015200,0.0070254; 1018800,
        0.0052416; 1022400,0.0089714; 1026000,0.0147244; 1029600,0.0093748;
        1033200,0.0056599; 1036800,0.0060596; 1040400,0.0021824; 1044000,
        0.0055391; 1047600,0.0089847; 1051200,0.0053704; 1054800,0.0067344;
        1058400,0.0041693; 1062000,0.0070087; 1065600,0.011453; 1069200,
        0.0072069; 1072800,0.0105228; 1076400,0.0149612; 1080000,0.0080346;
        1083600,0.0066345; 1087200,0.0128296; 1090800,0.0118549; 1094400,
        0.0138366; 1098000,0.0124164; 1101600,0.004487; 1105200,0.0040197;
        1108800,0.0084763; 1112400,0.0153231; 1116000,0.0112284; 1119600,
        0.0088912; 1123200,0.0084722; 1126800,0.0020507; 1130400,0.0070876;
        1134000,0.0120921; 1137600,0.0080116; 1141200,0.0065789; 1144800,
        0.0049008; 1148400,0.0071542; 1152000,0.0119667; 1155600,0.0080984;
        1159200,0.0117711; 1162800,0.0111286; 1166400,0.0070473; 1170000,
        0.007764; 1173600,0.0130345; 1177200,0.0113216; 1180800,0.0100155;
        1184400,0.0078041; 1188000,0.0051696; 1191600,0.0041678; 1195200,
        0.0084276; 1198800,0.0152092; 1202400,0.0097356; 1206000,0.0089833;
        1209600,0.0142219; 1213200,0.0212304; 1216800,0.0173623; 1220400,
        0.0209503; 1224000,0.0228176; 1227600,0.017562; 1231200,0.0112034;
        1234800,0.0100667; 1238400,0.0227727; 1242000,0.0328162; 1245600,
        0.0395302; 1249200,0.0226092; 1252800,0.0065469; 1256400,0.0069229;
        1260000,0.010963; 1263600,0.0096432; 1267200,0.0134799; 1270800,
        0.0117588; 1274400,0.0083489; 1278000,0.011241; 1281600,0.0137457;
        1285200,0.0169391; 1288800,0.0134465; 1292400,0.0168103; 1296000,
        0.0213582; 1299600,0.0268041; 1303200,0.037491; 1306800,0.0394537;
        1310400,0.0375434; 1314000,0.0366121; 1317600,0.0257779; 1321200,
        0.0230147; 1324800,0.0376684; 1328400,0.0441664; 1332000,0.035228;
        1335600,0.0174798; 1339200,0.0049446; 1342800,0.0068179; 1346400,
        0.0183002; 1350000,0.0180237; 1353600,0.0198708; 1357200,0.0331146;
        1360800,0.0512363; 1364400,0.0439374; 1368000,0.0340975; 1371600,
        0.0386301; 1375200,0.0379542; 1378800,0.0408979; 1382400,0.046998;
        1386000,0.0445932; 1389600,0.0391743; 1393200,0.0411336; 1396800,
        0.0452532; 1400400,0.0473124; 1404000,0.0396003; 1407600,0.0353717;
        1411200,0.0422894; 1414800,0.0483357; 1418400,0.0447287; 1422000,
        0.0302185; 1425600,0.0116052; 1429200,0.0219519; 1432800,0.0257368;
        1436400,0.0140905; 1440000,0.022038; 1443600,0.0455909; 1447200,
        0.0532662; 1450800,0.042334; 1454400,0.0343072; 1458000,0.0343592;
        1461600,0.0352718; 1465200,0.0402551; 1468800,0.0429171; 1472400,
        0.0367502; 1476000,0.0386962; 1479600,0.0496819; 1483200,0.0471305;
        1486800,0.0360899; 1490400,0.012794; 1494000,0.0172806; 1497600,
        0.0348428; 1501200,0.0284859; 1504800,0.0348231; 1508400,0.0403464;
        1512000,0.0152288; 1515600,0.0094012; 1519200,0.018825; 1522800,
        0.0192927; 1526400,0.0195471; 1530000,0.0222091; 1533600,0.011991;
        1537200,0.0060292; 1540800,0.0111293; 1544400,0.0179862; 1548000,
        0.0141046; 1551600,0.0129161; 1555200,0.0159871; 1558800,0.018005;
        1562400,0.0168054; 1566000,0.0156408; 1569600,0.0170702; 1573200,
        0.0153227; 1576800,0.0104648; 1580400,0.0088378; 1584000,0.0188172;
        1587600,0.0256713; 1591200,0.0329914; 1594800,0.0228993; 1598400,
        0.0120237; 1602000,0.0100266; 1605600,0.0148513; 1609200,0.0143993;
        1612800,0.01455; 1616400,0.0151921; 1620000,0.0113355; 1623600,
        0.0056402; 1627200,0.0107797; 1630800,0.0168786; 1634400,0.0153086;
        1638000,0.0166979; 1641600,0.0186792; 1645200,0.0232506; 1648800,
        0.0271924; 1652400,0.0212877; 1656000,0.0143614; 1659600,0.0206222;
        1663200,0.0134408; 1666800,0.0105156; 1670400,0.0193762; 1674000,
        0.0251228; 1677600,0.0150377; 1681200,0.0103661; 1684800,0.0049676;
        1688400,0.0055931; 1692000,0.0118115; 1695600,0.0076593; 1699200,
        0.0071631; 1702800,0.0085947; 1706400,0.0039091; 1710000,0.002607;
        1713600,0.0076118; 1717200,0.0140107; 1720800,0.0082684; 1724400,
        0.0050204; 1728000,0.0060804; 1731600,0.0042201; 1735200,0.0065319;
        1738800,0.0082591; 1742400,0.0058826; 1746000,0.005475; 1749600,
        0.0031489; 1753200,0.0066241; 1756800,0.0113416; 1760400,0.0095188;
        1764000,0.0103343; 1767600,0.0106216; 1771200,0.0072199; 1774800,
        0.0062188; 1778400,0.0125631; 1782000,0.0095849; 1785600,0.0089673;
        1789200,0.0161218; 1792800,0.0133023; 1796400,0.0035888; 1800000,
        0.0076419; 1803600,0.0148098; 1807200,0.0077907; 1810800,0.0067537;
        1814400,0.0079566; 1818000,0.005243; 1821600,0.0056376; 1825200,
        0.0123954; 1828800,0.0076018; 1832400,0.013687; 1836000,0.015881;
        1839600,0.0088411; 1843200,0.0146494; 1846800,0.0224626; 1850400,
        0.0276686; 1854000,0.0159027; 1857600,0.0055485; 1861200,0.0042561;
        1864800,0.0096499; 1868400,0.0098251; 1872000,0.007077; 1875600,
        0.0063302; 1879200,0.0059935; 1882800,0.0036222; 1886400,0.0083029;
        1890000,0.0157859; 1893600,0.011957; 1897200,0.0115962; 1900800,
        0.0107043; 1904400,0.0117561; 1908000,0.0118171; 1911600,0.013769;
        1915200,0.0091722; 1918800,0.0161007; 1922400,0.0201033; 1926000,
        0.0162412; 1929600,0.0151631; 1933200,0.0117507; 1936800,0.0059182;
        1940400,0.0062808; 1944000,0.0050137; 1947600,0.0058826; 1951200,
        0.0122666; 1954800,0.0127572; 1958400,0.0091863; 1962000,0.0163828;
        1965600,0.012753; 1969200,0.0054309; 1972800,0.0102434; 1976400,
        0.0158427; 1980000,0.010832; 1983600,0.0098919; 1987200,0.0212034;
        1990800,0.0122725; 1994400,0.0084521; 1998000,0.0290192; 2001600,
        0.0210197; 2005200,0.0095356; 2008800,0.0162703; 2012400,0.0230366;
        2016000,0.0256819; 2019600,0.0250426; 2023200,0.0064404; 2026800,
        0.0064768; 2030400,0.0039948; 2034000,0.0042788; 2037600,0.0090152;
        2041200,0.0071634; 2044800,0.0051187; 2048400,0.0060385; 2052000,
        0.0054869; 2055600,0.0093941; 2059200,0.008703; 2062800,0.0144516;
        2066400,0.007872; 2070000,0.0047947; 2073600,0.007525; 2077200,
        0.0039963; 2080800,0.0088439; 2084400,0.0184505; 2088000,0.0123761;
        2091600,0.0108981; 2095200,0.0135961; 2098800,0.0151193; 2102400,
        0.0304909; 2106000,0.046409; 2109600,0.0639995; 2113200,0.0539369;
        2116800,0.0260525; 2120400,0.0173029; 2124000,0.0218578; 2127600,
        0.016997; 2131200,0.0296636; 2134800,0.0333993; 2138400,0.0146407;
        2142000,0.0071141; 2145600,0.0119366; 2149200,0.0174075; 2152800,
        0.0152682; 2156400,0.0147734; 2160000,0.010508; 2163600,0.0151452;
        2167200,0.0125906; 2170800,0.0133886; 2174400,0.0165116; 2178000,
        0.0147422; 2181600,0.0080155; 2185200,0.0084068; 2188800,0.0178355;
        2192400,0.0262259; 2196000,0.0331718; 2199600,0.023469; 2203200,
        0.0095667; 2206800,0.0120814; 2210400,0.0192363; 2214000,0.017392;
        2217600,0.0158; 2221200,0.0311538; 2224800,0.037075; 2228400,0.012817;
        2232000,0.0166153; 2235600,0.0190439; 2239200,0.0143336; 2242800,
        0.021845; 2246400,0.0147285; 2250000,0.0191986; 2253600,0.0237914;
        2257200,0.0148599; 2260800,0.0199055; 2264400,0.0179747; 2268000,
        0.0075018; 2271600,0.0074537; 2275200,0.0158353; 2278800,0.0220325;
        2282400,0.0322491; 2286000,0.0369079; 2289600,0.0201939; 2293200,
        0.0123579; 2296800,0.0155145; 2300400,0.011797; 2304000,0.0142271;
        2307600,0.0228564; 2311200,0.0227544; 2314800,0.0169269; 2318400,
        0.0171929; 2322000,0.0165724; 2325600,0.0180567; 2329200,0.0164514;
        2332800,0.0092472; 2336400,0.017328; 2340000,0.0191771; 2343600,
        0.0116348; 2347200,0.0128953; 2350800,0.0121478; 2354400,0.0071017;
        2358000,0.00764; 2361600,0.0178463; 2365200,0.0260477; 2368800,
        0.0348981; 2372400,0.0340656; 2376000,0.0178997; 2379600,0.0159418;
        2383200,0.0189119; 2386800,0.0226094; 2390400,0.0270521; 2394000,
        0.028461; 2397600,0.0185443; 2401200,0.0123857; 2404800,0.0161712;
        2408400,0.0357102; 2412000,0.04656; 2415600,0.0321244; 2419200,
        0.0386528; 2422800,0.0421124; 2426400,0.0340066; 2430000,0.0354871;
        2433600,0.0508176; 2437200,0.0521787; 2440800,0.0363961; 2444400,
        0.0306917; 2448000,0.0431223; 2451600,0.0512701; 2455200,0.0645814;
        2458800,0.0552694; 2462400,0.0228423; 2466000,0.0095404; 2469600,
        0.0173767; 2473200,0.0233638; 2476800,0.0290155; 2480400,0.039388;
        2484000,0.0319536; 2487600,0.0198242; 2491200,0.0187946; 2494800,
        0.0238372; 2498400,0.0227657; 2502000,0.0177171; 2505600,0.0170713;
        2509200,0.0232302; 2512800,0.0247572; 2516400,0.0197498; 2520000,
        0.0132141; 2523600,0.01404; 2527200,0.0063502; 2530800,0.0097931;
        2534400,0.0167955; 2538000,0.0122543; 2541600,0.010691; 2545200,
        0.0124343; 2548800,0.0068784; 2552400,0.0114333; 2556000,0.0247056;
        2559600,0.0185882; 2563200,0.0161571; 2566800,0.0231283; 2570400,
        0.0173864; 2574000,0.0142916; 2577600,0.015016; 2581200,0.0162347;
        2584800,0.0098358; 2588400,0.0097104; 2592000,0.0145102; 2595600,
        0.0136998; 2599200,0.0196284; 2602800,0.0339898; 2606400,0.0214143;
        2610000,0.0258165; 2613600,0.039646; 2617200,0.0277942; 2620800,
        0.0273238; 2624400,0.0162054; 2628000,0.0189668; 2631600,0.0162835;
        2635200,0.0077642; 2638800,0.0075038; 2642400,0.0163865; 2646000,
        0.0115673; 2649600,0.0143566; 2653200,0.0237142; 2656800,0.0192975;
        2660400,0.0136874; 2664000,0.014365; 2667600,0.0151524; 2671200,
        0.0108584; 2674800,0.0117024; 2678400,0.0136436; 2682000,0.0050601;
        2685600,0.0135504; 2689200,0.0237849; 2692800,0.0141725; 2696400,
        0.017517; 2700000,0.0119027; 2703600,0.0108242; 2707200,0.0324744;
        2710800,0.0356389; 2714400,0.0339; 2718000,0.0171353; 2721600,0.0066809;
        2725200,0.0059197; 2728800,0.0089781; 2732400,0.0071913; 2736000,
        0.006152; 2739600,0.0075194; 2743200,0.0053381; 2746800,0.0040037;
        2750400,0.0089677; 2754000,0.0150874; 2757600,0.0097404; 2761200,
        0.0065347; 2764800,0.0088415; 2768400,0.0112476; 2772000,0.0121786;
        2775600,0.0261438; 2779200,0.0217327; 2782800,0.0166422; 2786400,
        0.0118993; 2790000,0.011293; 2793600,0.0228462; 2797200,0.0248203;
        2800800,0.0326522; 2804400,0.0182059; 2808000,0.0066694; 2811600,
        0.0069923; 2815200,0.0105581; 2818800,0.0102059; 2822400,0.0114318;
        2826000,0.0152915; 2829600,0.0096877; 2833200,0.0050742; 2836800,
        0.0088222; 2840400,0.0139413; 2844000,0.008009; 2847600,0.0069652;
        2851200,0.0115569; 2854800,0.0147833; 2858400,0.0204068; 2862000,
        0.0190947; 2865600,0.0039874; 2869200,0.0029971; 2872800,0.0029318;
        2876400,0.0065985; 2880000,0.010034; 2883600,0.0071133; 2887200,
        0.0108806; 2890800,0.0105503; 2894400,0.0073101; 2898000,0.0048377;
        2901600,0.0113613; 2905200,0.0106769; 2908800,0.009779; 2912400,
        0.0102753; 2916000,0.005897; 2919600,0.0036456; 2923200,0.0085386;
        2926800,0.0147419; 2930400,0.0088415; 2934000,0.0059171; 2937600,
        0.0088144; 2941200,0.0051395; 2944800,0.0071642; 2948400,0.011198;
        2952000,0.0099687; 2955600,0.0078605; 2959200,0.0067218; 2962800,
        0.007241; 2966400,0.0119062; 2970000,0.009465; 2973600,0.0094762;
        2977200,0.0077569; 2980800,0.0052015; 2984400,0.0090523; 2988000,
        0.0140359; 2991600,0.0097315; 2995200,0.0075383; 2998800,0.0072065;
        3002400,0.0080884; 3006000,0.0068242; 3009600,0.0084566; 3013200,
        0.013909; 3016800,0.0076296; 3020400,0.0068094; 3024000,0.0096417;
        3027600,0.0062946; 3031200,0.0042201; 3034800,0.0111453; 3038400,
        0.006577; 3042000,0.0061324; 3045600,0.0052237; 3049200,0.0082023;
        3052800,0.0160944; 3056400,0.0116475; 3060000,0.0201709; 3063600,
        0.0187517; 3067200,0.008482; 3070800,0.0054591; 3074400,0.0172346;
        3078000,0.0182334; 3081600,0.0109842; 3085200,0.0111163; 3088800,
        0.0067303; 3092400,0.0030584; 3096000,0.0076393; 3099600,0.0148306;
        3103200,0.0094183; 3106800,0.0057812; 3110400,0.0074737; 3114000,
        0.0062697; 3117600,0.0118089; 3121200,0.0189334; 3124800,0.0088972;
        3128400,0.0103217; 3132000,0.0121842; 3135600,0.0090705; 3139200,
        0.0150518; 3142800,0.0101795; 3146400,0.0071746; 3150000,0.0091436;
        3153600,0.003254; 3157200,0.0038504; 3160800,0.0105741; 3164400,
        0.0076229; 3168000,0.0062311; 3171600,0.0080776; 3175200,0.0084399;
        3178800,0.011564; 3182400,0.0139665; 3186000,0.0166196; 3189600,
        0.0136818; 3193200,0.0190859; 3196800,0.0231416; 3200400,0.0186823;
        3204000,0.016555; 3207600,0.0294843; 3211200,0.0256981; 3214800,
        0.0221484; 3218400,0.025671; 3222000,0.0271404; 3225600,0.0368497;
        3229200,0.0340177; 3232800,0.0205012; 3236400,0.0137737; 3240000,
        0.0040999; 3243600,0.0038089; 3247200,0.0125665; 3250800,0.011679;
        3254400,0.0127981; 3258000,0.016634; 3261600,0.021779; 3265200,
        0.0266275; 3268800,0.0246998; 3272400,0.024839; 3276000,0.0173589;
        3279600,0.0293061; 3283200,0.0293971; 3286800,0.0259093; 3290400,
        0.0320327; 3294000,0.0390796; 3297600,0.0357956; 3301200,0.0212465;
        3304800,0.0150993; 3308400,0.0260032; 3312000,0.0377104; 3315600,
        0.0389222; 3319200,0.0453653; 3322800,0.0236178; 3326400,0.0120857;
        3330000,0.0080554; 3333600,0.0129417; 3337200,0.010155; 3340800,
        0.0122068; 3344400,0.0185849; 3348000,0.0212133; 3351600,0.0242179;
        3355200,0.0319685; 3358800,0.0349298; 3362400,0.0382976; 3366000,
        0.0323545; 3369600,0.0381328; 3373200,0.0424279; 3376800,0.0407985;
        3380400,0.0360075; 3384000,0.0389835; 3387600,0.0392982; 3391200,
        0.0164637; 3394800,0.0138834; 3398400,0.0347853; 3402000,0.0370456;
        3405600,0.0458107; 3409200,0.0350213; 3412800,0.0134679; 3416400,
        0.0094825; 3420000,0.0158401; 3423600,0.0147504; 3427200,0.0130378;
        3430800,0.0162525; 3434400,0.0105833; 3438000,0.0072562; 3441600,
        0.0113038; 3445200,0.017245; 3448800,0.014449; 3452400,0.0137059;
        3456000,0.0146643; 3459600,0.0235375; 3463200,0.0343603; 3466800,
        0.0361088; 3470400,0.0384449; 3474000,0.0371815; 3477600,0.0153524;
        3481200,0.0132524; 3484800,0.0340452; 3488400,0.041903; 3492000,
        0.0458622; 3495600,0.0294123; 3499200,0.0142579; 3502800,0.0149735;
        3506400,0.0159285; 3510000,0.0117651; 3513600,0.0123412; 3517200,
        0.0172862; 3520800,0.0187716; 3524400,0.0193591; 3528000,0.0283953;
        3531600,0.0356256; 3535200,0.0307901; 3538800,0.0268761; 3542400,
        0.0394044; 3546000,0.0417828; 3549600,0.0359548; 3553200,0.035718;
        3556800,0.0372513; 3560400,0.0427226; 3564000,0.0287008; 3567600,
        0.0188265; 3571200,0.0363675; 3574800,0.0400517; 3578400,0.0503288;
        3582000,0.0458652; 3585600,0.0166378; 3589200,0.0122306; 3592800,
        0.0184179; 3596400,0.0124032; 3600000,0.0143358; 3603600,0.0184034;
        3607200,0.015008; 3610800,0.016156; 3614400,0.0214057; 3618000,
        0.0292335; 3621600,0.033249; 3625200,0.0325831; 3628800,0.0354652;
        3632400,0.0358999; 3636000,0.0314715; 3639600,0.0176856; 3643200,
        0.0260243; 3646800,0.037056; 3650400,0.0250448; 3654000,0.0202328;
        3657600,0.0385125; 3661200,0.0362421; 3664800,0.0464565; 3668400,
        0.0241289; 3672000,0.0049476; 3675600,0.0052976; 3679200,0.0104159;
        3682800,0.0077276; 3686400,0.0054932; 3690000,0.007699; 3693600,
        0.0072622; 3697200,0.0097905; 3700800,0.0150566; 3704400,0.019397;
        3708000,0.0162922; 3711600,0.0280312; 3715200,0.0343614; 3718800,
        0.0311003; 3722400,0.0347266; 3726000,0.0352425; 3729600,0.0254984;
        3733200,0.0352125; 3736800,0.0309344; 3740400,0.0259137; 3744000,
        0.0354288; 3747600,0.0254405; 3751200,0.0161677; 3754800,0.0129976;
        3758400,0.0065739; 3762000,0.0039377; 3765600,0.0119986; 3769200,
        0.0094858; 3772800,0.0062125; 3776400,0.0123363; 3780000,0.0146465;
        3783600,0.0202245; 3787200,0.0205832; 3790800,0.0216975; 3794400,
        0.0173237; 3798000,0.0291588; 3801600,0.0303038; 3805200,0.0183245;
        3808800,0.0175076; 3812400,0.0277246; 3816000,0.0164752; 3819600,
        0.0195681; 3823200,0.0151427; 3826800,0.0173929; 3830400,0.0228258;
        3834000,0.0124282; 3837600,0.0049936; 3841200,0.0075372; 3844800,
        0.0031994; 3848400,0.0027399; 3852000,0.0082806; 3855600,0.0061672;
        3859200,0.0049432; 3862800,0.0059249; 3866400,0.0052757; 3870000,
        0.0057493; 3873600,0.0083501; 3877200,0.0143904; 3880800,0.0085438;
        3884400,0.0049565; 3888000,0.0057289; 3891600,0.0014835; 3895200,
        0.0049564; 3898800,0.0106283; 3902400,0.0049368; 3906000,0.0056164;
        3909600,0.0061814; 3913200,0.0075595; 3916800,0.0113576; 3920400,
        0.0073286; 3924000,0.0074567; 3927600,0.0115294; 3931200,0.0062318;
        3934800,0.0046158; 3938400,0.0116308; 3942000,0.0117737; 3945600,
        0.0083282; 3949200,0.0060247; 3952800,0.0056205; 3956400,0.004857;
        3960000,0.0078167; 3963600,0.0147007; 3967200,0.009903; 3970800,
        0.006485; 3974400,0.0069905; 3978000,0.0052735; 3981600,0.0021067;
        3985200,0.0144434; 3988800,0.0138325; 3992400,0.0098247; 3996000,
        0.0040958; 3999600,0.0082283; 4003200,0.0136963; 4006800,0.0104275;
        4010400,0.0064326; 4014000,0.0090412; 4017600,0.0061398; 4021200,
        0.0059338; 4024800,0.0128872; 4028400,0.0101391; 4032000,0.0095203;
        4035600,0.0076278; 4039200,0.0057675; 4042800,0.00781; 4046400,
        0.0125709; 4050000,0.0194801; 4053600,0.0123516; 4057200,0.009406;
        4060800,0.0110191; 4064400,0.0181683; 4068000,0.020664; 4071600,
        0.0154812; 4075200,0.013628; 4078800,0.0109356; 4082400,0.0058881;
        4086000,0.0089346; 4089600,0.0166734; 4093200,0.0221431; 4096800,
        0.0181417; 4100400,0.013067; 4104000,0.0057178; 4107600,0.0147519;
        4111200,0.0174679; 4114800,0.0083083; 4118400,0.0065473; 4122000,
        0.0058328; 4125600,0.0040802; 4129200,0.0044087; 4132800,0.008343;
        4136400,0.0139999; 4140000,0.0070792; 4143600,0.0051573; 4147200,
        0.0089291; 4150800,0.0102777; 4154400,0.0132917; 4158000,0.0181361;
        4161600,0.0123404; 4165200,0.0159088; 4168800,0.0115948; 4172400,
        0.010613; 4176000,0.0203067; 4179600,0.0140652; 4183200,0.0089621;
        4186800,0.0094966; 4190400,0.0032622; 4194000,0.0027722; 4197600,
        0.0097976; 4201200,0.0081021; 4204800,0.0052735; 4208400,0.0062114;
        4212000,0.0046896; 4215600,0.0045111; 4219200,0.0093214; 4222800,
        0.0175033; 4226400,0.0130638; 4230000,0.0124002; 4233600,0.0209429;
        4237200,0.0176863; 4240800,0.0222637; 4244400,0.0180619; 4248000,
        0.0106375; 4251600,0.0117544; 4255200,0.0061613; 4258800,0.0073869;
        4262400,0.0121667; 4266000,0.0141721; 4269600,0.0162436; 4273200,
        0.0128061; 4276800,0.0046971; 4280400,0.0054387; 4284000,0.0106576;
        4287600,0.0081467; 4291200,0.0074196; 4294800,0.0067537; 4298400,
        0.0047962; 4302000,0.0035955; 4305600,0.007659; 4309200,0.0139461;
        4312800,0.0074819; 4316400,0.0042981; 4320000,0.0089829; 4323600,
        0.0198537; 4327200,0.0338726; 4330800,0.0267026; 4334400,0.011293;
        4338000,0.0313453; 4341600,0.0269481; 4345200,0.0146122; 4348800,
        0.0173779; 4352400,0.009808; 4356000,0.0079139; 4359600,0.0084154;
        4363200,0.0032172; 4366800,0.002744; 4370400,0.0081945; 4374000,
        0.0062263; 4377600,0.0041923; 4381200,0.0051543; 4384800,0.0055244;
        4388400,0.0085527; 4392000,0.0101725; 4395600,0.0156783; 4399200,
        0.0091507; 4402800,0.0105644; 4406400,0.0252727; 4410000,0.0261346;
        4413600,0.0094762; 4417200,0.0127717; 4420800,0.0239362; 4424400,
        0.0258476; 4428000,0.0103688; 4431600,0.0107975; 4435200,0.0183548;
        4438800,0.0094416; 4442400,0.0052757; 4446000,0.0080234; 4449600,
        0.0037506; 4453200,0.003454; 4456800,0.0107593; 4460400,0.0081908;
        4464000,0.0046065; 4467600,0.0086629; 4471200,0.0080164; 4474800,
        0.0057081; 4478400,0.008667; 4482000,0.0143276; 4485600,0.008546;
        4489200,0.0055018; 4492800,0.0069998; 4496400,0.0023914; 4500000,
        0.0067212; 4503600,0.0120231; 4507200,0.0071824; 4510800,0.0064701;
        4514400,0.0050174; 4518000,0.0075112; 4521600,0.0125371; 4525200,
        0.0107782; 4528800,0.0115569; 4532400,0.0139249; 4536000,0.0077128;
        4539600,0.0070718; 4543200,0.0136866; 4546800,0.0121433; 4550400,
        0.0088686; 4554000,0.0075483; 4557600,0.0054349; 4561200,0.0050478;
        4564800,0.0087724; 4568400,0.0146724; 4572000,0.0097389; 4575600,
        0.0107147; 4579200,0.0186149; 4582800,0.020327; 4586400,0.0239755;
        4590000,0.0335066; 4593600,0.0221941; 4597200,0.0268798; 4600800,
        0.0196438; 4604400,0.0193315; 4608000,0.0322428; 4611600,0.0211036;
        4615200,0.0145429; 4618800,0.0110792; 4622400,0.0076471; 4626000,
        0.0062868; 4629600,0.0120261; 4633200,0.0112247; 4636800,0.0101064;
        4640400,0.0104857; 4644000,0.0083415; 4647600,0.0096784; 4651200,
        0.0120895; 4654800,0.0183139; 4658400,0.017435; 4662000,0.0169818;
        4665600,0.0085824; 4669200,0.0224689; 4672800,0.0236058; 4676400,
        0.0148929; 4680000,0.0133188; 4683600,0.0153472; 4687200,0.0073913;
        4690800,0.0084681; 4694400,0.0191565; 4698000,0.0249242; 4701600,
        0.0176919; 4705200,0.0144492; 4708800,0.0057092; 4712400,0.0068788;
        4716000,0.0099468; 4719600,0.0068788; 4723200,0.0089142; 4726800,
        0.0054049; 4730400,0.0043949; 4734000,0.0046355; 4737600,0.0076192;
        4741200,0.0145956; 4744800,0.0081574; 4748400,0.0045234; 4752000,
        0.0081095; 4755600,0.0172864; 4759200,0.0306509; 4762800,0.0262167;
        4766400,0.0298833; 4770000,0.0184285; 4773600,0.0089415; 4777200,
        0.0137453; 4780800,0.0314266; 4784400,0.0260291; 4788000,0.0167784;
        4791600,0.0123395; 4795200,0.0036437; 4798800,0.0034745; 4802400,
        0.0085497; 4806000,0.0088248; 4809600,0.0071816; 4813200,0.0075391;
        4816800,0.0059561; 4820400,0.0057334; 4824000,0.01024; 4827600,
        0.0149341; 4831200,0.0088734; 4834800,0.006116; 4838400,0.0086793;
        4842000,0.0076326; 4845600,0.007964; 4849200,0.0108168; 4852800,
        0.0110592; 4856400,0.0123453; 4860000,0.0057504; 4863600,0.0075981;
        4867200,0.0129302; 4870800,0.0071367; 4874400,0.0051336; 4878000,
        0.0065763; 4881600,0.0032228; 4885200,0.0041533; 4888800,0.0099535;
        4892400,0.0061814; 4896000,0.00449; 4899600,0.0048756; 4903200,
        0.0036496; 4906800,0.0031608; 4910400,0.007852; 4914000,0.0150195;
        4917600,0.0081845; 4921200,0.0042198; 4924800,0.0064519; 4928400,
        0.0049294; 4932000,0.0128797; 4935600,0.0346041; 4939200,0.0279796;
        4942800,0.0143922; 4946400,0.0195744; 4950000,0.0305128; 4953600,
        0.0290472; 4957200,0.0126615; 4960800,0.0086834; 4964400,0.0086451;
        4968000,0.0035895; 4971600,0.0032603; 4975200,0.0101391; 4978800,
        0.0087008; 4982400,0.0060258; 4986000,0.0102296; 4989600,0.0066553;
        4993200,0.0050671; 4996800,0.0085713; 5000400,0.0144189; 5004000,
        0.0086054; 5007600,0.0053756; 5011200,0.0066397; 5014800,0.0021683;
        5018400,0.0063367; 5022000,0.0101647; 5025600,0.006126; 5029200,
        0.0070128; 5032800,0.0057167; 5036400,0.0078516; 5040000,0.0106695;
        5043600,0.004304; 5047200,0.0036582; 5050800,0.0069675; 5054400,
        0.0039039; 5058000,0.0040772; 5061600,0.0104724; 5065200,0.0068584;
        5068800,0.0042636; 5072400,0.0064464; 5076000,0.0057564; 5079600,
        0.0052534; 5083200,0.009883; 5086800,0.0160391; 5090400,0.0115877;
        5094000,0.0194534; 5097600,0.0376254; 5101200,0.0367049; 5104800,
        0.0429616; 5108400,0.0622104; 5112000,0.0580462; 5115600,0.0486441;
        5119200,0.0376859; 5122800,0.0269513; 5126400,0.0376729; 5130000,
        0.0393684; 5133600,0.0319945; 5137200,0.0174883; 5140800,0.0080268;
        5144400,0.0106297; 5148000,0.0138566; 5151600,0.0112062; 5155200,
        0.0127944; 5158800,0.0118086; 5162400,0.009926; 5166000,0.0148773;
        5169600,0.0284937; 5173200,0.0419665; 5176800,0.039286; 5180400,
        0.0380437; 5184000,0.0380218; 5187600,0.0305818; 5191200,0.0318356;
        5194800,0.0308995; 5198400,0.0285263; 5202000,0.0285749; 5205600,
        0.0147318; 5209200,0.0169536; 5212800,0.0362131; 5216400,0.03459;
        5220000,0.0388168; 5223600,0.0295392; 5227200,0.0145435; 5230800,
        0.010943; 5234400,0.020077; 5238000,0.0184583; 5241600,0.0145258;
        5245200,0.0141484; 5248800,0.0095389; 5252400,0.0088174; 5256000,
        0.0129762; 5259600,0.0187307; 5263200,0.0140752; 5266800,0.0127101;
        5270400,0.0145604; 5274000,0.0211335; 5277600,0.0220235; 5281200,
        0.0187912; 5284800,0.0240401; 5288400,0.0293035; 5292000,0.0205721;
        5295600,0.0182067; 5299200,0.030446; 5302800,0.0270239; 5306400,
        0.0322903; 5310000,0.0198557; 5313600,0.0063985; 5317200,0.0085731;
        5320800,0.0150592; 5324400,0.0093277; 5328000,0.0160495; 5331600,
        0.0184386; 5335200,0.0105869; 5338800,0.0046733; 5342400,0.0097364;
        5346000,0.0154478; 5349600,0.0112897; 5353200,0.009661; 5356800,
        0.0094235; 5360400,0.0121276; 5364000,0.0124425; 5367600,0.0134276;
        5371200,0.0132535; 5374800,0.0159819; 5378400,0.0136321; 5382000,
        0.0199222; 5385600,0.0350692; 5389200,0.0326288; 5392800,0.0289153;
        5396400,0.0127526; 5400000,0.0047015; 5403600,0.0051373; 5407200,
        0.0117121; 5410800,0.0111219; 5414400,0.0059865; 5418000,0.0066267;
        5421600,0.0059215; 5425200,0.0048678; 5428800,0.00884; 5432400,
        0.0147355; 5436000,0.0089521; 5439600,0.0055893; 5443200,0.007332;
        5446800,0.0039169; 5450400,0.0065368; 5454000,0.0088604; 5457600,
        0.0064074; 5461200,0.0056283; 5464800,0.004255; 5468400,0.0065919;
        5472000,0.0108194; 5475600,0.0087691; 5479200,0.0094457; 5482800,
        0.009681; 5486400,0.0071167; 5490000,0.0073579; 5493600,0.0111282;
        5497200,0.0118613; 5500800,0.0158279; 5504400,0.0146229; 5508000,
        0.0046243; 5511600,0.0037027; 5515200,0.0087134; 5518800,0.0149876;
        5522400,0.0094847; 5526000,0.0065213; 5529600,0.0068947; 5533200,
        0.0046314; 5536800,0.0090521; 5540400,0.0119767; 5544000,0.0100106;
        5547600,0.0101023; 5551200,0.0066253; 5554800,0.0104998; 5558400,
        0.0126385; 5562000,0.0055314; 5565600,0.0042301; 5569200,0.0073958;
        5572800,0.0038452; 5576400,0.0035758; 5580000,0.0087925; 5583600,
        0.0070191; 5587200,0.0042524; 5590800,0.0051336; 5594400,0.0044684;
        5598000,0.0050909; 5601600,0.0089499; 5605200,0.0140018; 5608800,
        0.0099886; 5612400,0.0037443; 5616000,0.0059909; 5619600,0.0033754;
        5623200,0.0074287; 5626800,0.0106795; 5630400,0.0068743; 5634000,
        0.0064315; 5637600,0.0047327; 5641200,0.0079091; 5644800,0.0114207;
        5648400,0.0051298; 5652000,0.0046696; 5655600,0.0082112; 5659200,
        0.0045597; 5662800,0.0038638; 5666400,0.0109957; 5670000,0.0084417;
        5673600,0.0053607; 5677200,0.0077751; 5680800,0.0062645; 5684400,
        0.0054966; 5688000,0.0086403; 5691600,0.0146836; 5695200,0.0077896;
        5698800,0.0066995; 5702400,0.0099312; 5706000,0.0031757; 5709600,
        0.0055339; 5713200,0.0113168; 5716800,0.0093533; 5720400,0.0073513;
        5724000,0.0048363; 5727600,0.0079384; 5731200,0.010878; 5734800,
        0.0066932; 5738400,0.0055511; 5742000,0.0085449; 5745600,0.0071991;
        5749200,0.006714; 5752800,0.0115736; 5756400,0.0089287; 5760000,
        0.0082784; 5763600,0.0070224; 5767200,0.004104; 5770800,0.0036983;
        5774400,0.0090207; 5778000,0.0141023; 5781600,0.0079195; 5785200,
        0.0054212; 5788800,0.0076415; 5792400,0.0039581; 5796000,0.0083261;
        5799600,0.0107066; 5803200,0.0064608; 5806800,0.0082591; 5810400,
        0.0057697; 5814000,0.0070413; 5817600,0.0109148; 5821200,0.0047802;
        5824800,0.0048808; 5828400,0.0068506; 5832000,0.0042732; 5835600,
        0.0039855; 5839200,0.0097349; 5842800,0.0058677; 5846400,0.0044183;
        5850000,0.0051588; 5853600,0.0034225; 5857200,0.0029994; 5860800,
        0.0077176; 5864400,0.0139587; 5868000,0.0079533; 5871600,0.0040965;
        5875200,0.006348; 5878800,0.0024307; 5882400,0.0058553; 5886000,
        0.0109166; 5889600,0.0084343; 5893200,0.0069675; 5896800,0.0038245;
        5900400,0.007192; 5904000,0.0095474; 5907600,0.0052679; 5911200,
        0.0067867; 5914800,0.0084406; 5918400,0.0037732; 5922000,0.0056903;
        5925600,0.010747; 5929200,0.0094305; 5932800,0.0070343; 5936400,
        0.0050448; 5940000,0.0033568; 5943600,0.0026026; 5947200,0.0085494;
        5950800,0.0151854; 5954400,0.0065703; 5958000,0.0037554; 5961600,
        0.0058391; 5965200,0.0014119; 5968800,0.0021717; 5972400,0.0101131;
        5976000,0.0070391; 5979600,0.0063153; 5983200,0.0051866; 5986800,
        0.0065328; 5990400,0.0100277; 5994000,0.0080052; 5997600,0.0089276;
        6001200,0.0097798; 6004800,0.005952; 6008400,0.0062749; 6012000,
        0.0115131; 6015600,0.0090801; 6019200,0.0072098; 6022800,0.0064905;
        6026400,0.0036779; 6030000,0.0026286; 6033600,0.0077131; 6037200,
        0.0139672; 6040800,0.0079756; 6044400,0.0055712; 6048000,0.0084002;
        6051600,0.0036667; 6055200,0.0054548; 6058800,0.0098544; 6062400,
        0.0075784; 6066000,0.0063873; 6069600,0.00348; 6073200,0.0075569;
        6076800,0.0117091; 6080400,0.0076994; 6084000,0.0076241; 6087600,
        0.0086407; 6091200,0.0055511; 6094800,0.0047743; 6098400,0.0102998;
        6102000,0.0092676; 6105600,0.0059687; 6109200,0.0055519; 6112800,
        0.0036727; 6116400,0.0035286; 6120000,0.0076519; 6123600,0.0147727;
        6127200,0.0067251; 6130800,0.0036879; 6134400,0.0070194; 6138000,
        0.0052007; 6141600,0.0067247; 6145200,0.0117507; 6148800,0.0074136;
        6152400,0.0089658; 6156000,0.006381; 6159600,0.0076931; 6163200,
        0.0114522; 6166800,0.0071141; 6170400,0.0056933; 6174000,0.0080921;
        6177600,0.0063536; 6181200,0.0093956; 6184800,0.0138351; 6188400,
        0.0085171; 6192000,0.0061223; 6195600,0.0077287; 6199200,0.0080361;
        6202800,0.0063291; 6206400,0.0084169; 6210000,0.0140136; 6213600,
        0.007473; 6217200,0.0041756; 6220800,0.0086518; 6224400,0.0061747;
        6228000,0.0075435; 6231600,0.0155072; 6235200,0.0121897; 6238800,
        0.016359; 6242400,0.0328433; 6246000,0.0254358; 6249600,0.0213499;
        6253200,0.0089487; 6256800,0.0047732; 6260400,0.0064965; 6264000,
        0.0032087; 6267600,0.0027399; 6271200,0.0079199; 6274800,0.006404;
        6278400,0.003342; 6282000,0.004713; 6285600,0.0047164; 6289200,
        0.0042758; 6292800,0.0078512; 6296400,0.0145192; 6300000,0.0083167;
        6303600,0.0040798; 6307200,0.0065726; 6310800,0.0100131; 6314400,
        0.0098106; 6318000,0.0139528; 6321600,0.0087947; 6325200,0.0068086;
        6328800,0.0103065; 6332400,0.0094684; 6336000,0.0134034; 6339600,
        0.0050382; 6343200,0.0035995; 6346800,0.0076448; 6350400,0.0032391;
        6354000,0.0027681; 6357600,0.0097772; 6361200,0.0088611; 6364800,
        0.0051581; 6368400,0.0049565; 6372000,0.0029441; 6375600,0.0026085;
        6379200,0.0077362; 6382800,0.0140248; 6386400,0.006688; 6390000,
        0.0040765; 6393600,0.0056038; 6397200,0.0010211; 6400800,0.0013195;
        6404400,0.010596; 6408000,0.0093455; 6411600,0.0070057; 6415200,
        0.0050341; 6418800,0.0088474; 6422400,0.0123493; 6426000,0.0072507;
        6429600,0.007509; 6433200,0.0076708; 6436800,0.0031831; 6440400,
        0.0054672; 6444000,0.010783; 6447600,0.0073694; 6451200,0.0056328;
        6454800,0.0057668; 6458400,0.0046577; 6462000,0.0040568; 6465600,
        0.0084967; 6469200,0.014812; 6472800,0.0084191; 6476400,0.0047557;
        6480000,0.0066602; 6483600,0.0069519; 6487200,0.0133997; 6490800,
        0.018599; 6494400,0.0135905; 6498000,0.0244714; 6501600,0.028536;
        6505200,0.0177986; 6508800,0.015211; 6512400,0.0069745; 6516000,
        0.0051766; 6519600,0.0070733; 6523200,0.0057514; 6526800,0.0027566;
        6530400,0.0081058; 6534000,0.0075925; 6537600,0.0042335; 6541200,
        0.0042413; 6544800,0.0029378; 6548400,0.0031126; 6552000,0.0077324;
        6555600,0.0141075; 6559200,0.0065807; 6562800,0.0043886; 6566400,
        0.0066594; 6570000,0.0050816; 6573600,0.0090831; 6577200,0.0121211;
        6580800,0.0102322; 6584400,0.0057463; 6588000,0.0048786; 6591600,
        0.0096343; 6595200,0.0168419; 6598800,0.0146958; 6602400,0.010129;
        6606000,0.0097499; 6609600,0.0032343; 6613200,0.0040865; 6616800,
        0.0095845; 6620400,0.0071935; 6624000,0.0057393; 6627600,0.0060396;
        6631200,0.0043222; 6634800,0.0047951; 6638400,0.0105789; 6642000,
        0.0191027; 6645600,0.0143907; 6649200,0.0139231; 6652800,0.0195692;
        6656400,0.028307; 6660000,0.0312856; 6663600,0.0266727; 6667200,
        0.0306238; 6670800,0.0317432; 6674400,0.0312789; 6678000,0.0261854;
        6681600,0.0230039; 6685200,0.0141977; 6688800,0.0154595; 6692400,
        0.0103022; 6696000,0.0032128; 6699600,0.0027641; 6703200,0.0079499;
        6706800,0.0064156; 6710400,0.004104; 6714000,0.0041392; 6717600,
        0.0029474; 6721200,0.0034114; 6724800,0.0087791; 6728400,0.0166752;
        6732000,0.0108695; 6735600,0.0076489; 6739200,0.0139001; 6742800,
        0.0252746; 6746400,0.034096; 6750000,0.0391728; 6753600,0.0282828;
        6757200,0.0282981; 6760800,0.0349849; 6764400,0.0339461; 6768000,
        0.0274047; 6771600,0.0135944; 6775200,0.006737; 6778800,0.0068695;
        6782400,0.003185; 6786000,0.0027611; 6789600,0.0079967; 6793200,
        0.0064011; 6796800,0.0033074; 6800400,0.0056788; 6804000,0.0039429;
        6807600,0.0030231; 6811200,0.0075981; 6814800,0.0144004; 6818400,
        0.0102972; 6822000,0.0096714; 6825600,0.0189761; 6829200,0.0145179;
        6832800,0.0121582; 6836400,0.0310766; 6840000,0.02956; 6843600,
        0.0296914; 6847200,0.0242201; 6850800,0.0226569; 6854400,0.0235265;
        6858000,0.0079934; 6861600,0.0057434; 6865200,0.0068873; 6868800,
        0.0032302; 6872400,0.0027782; 6876000,0.0082116; 6879600,0.0065514;
        6883200,0.0033683; 6886800,0.0042736; 6890400,0.0029504; 6894000,
        0.0026059; 6897600,0.0077896; 6901200,0.0164869; 6904800,0.0065792;
        6908400,0.0058566; 6912000,0.0128961; 6915600,0.0162672; 6919200,
        0.0210351; 6922800,0.0352058; 6926400,0.0269997; 6930000,0.0306947;
        6933600,0.0207814; 6937200,0.0157923; 6940800,0.0165208; 6944400,
        0.012994; 6948000,0.0062166; 6951600,0.0073394; 6955200,0.0037183;
        6958800,0.0044083; 6962400,0.0104701; 6966000,0.0065091; 6969600,
        0.0052982; 6973200,0.0042814; 6976800,0.0029489; 6980400,0.0026163;
        6984000,0.00765; 6987600,0.013942; 6991200,0.0074786; 6994800,0.0037651;
        6998400,0.005769; 7002000,0.0010311; 7005600,1e-06; 7009200,0.0066472;
        7012800,0.0040082; 7016400,0.0039484; 7020000,0.0029641; 7023600,
        0.0069356; 7027200,0.0101109; 7030800,0.0039317; 7034400,0.0039436;
        7038000,0.0072321; 7041600,0.0037937; 7045200,0.0044061; 7048800,
        0.0095111; 7052400,0.0070324; 7056000,0.0047372; 7059600,0.0048815;
        7063200,0.0034321; 7066800,0.0035643; 7070400,0.008317; 7074000,
        0.0144319; 7077600,0.0078987; 7081200,0.0042138; 7084800,0.0057619;
        7088400,0.0014483; 7092000,0.0014286; 7095600,0.0075495; 7099200,
        0.005275; 7102800,0.0054056; 7106400,0.0035561; 7110000,0.0072436;
        7113600,0.0099145; 7117200,0.0038144; 7120800,0.004392; 7124400,
        0.0073045; 7128000,0.0058792; 7131600,0.0043712; 7135200,0.0096339;
        7138800,0.0078453; 7142400,0.0043322; 7146000,0.0042546; 7149600,
        0.0029526; 7153200,0.0047189; 7156800,0.0078; 7160400,0.0140058;
        7164000,0.0072299; 7167600,0.0037473; 7171200,0.0059876; 7174800,
        0.0025896; 7178400,0.007023; 7182000,0.0110941; 7185600,0.0132698;
        7189200,0.0188465; 7192800,0.0108465; 7196400,0.0105891; 7200000,
        0.009782; 7203600,0.003902; 7207200,0.0037784; 7210800,0.0059861;
        7214400,0.0032284; 7218000,0.002777; 7221600,0.0079228; 7225200,
        0.0069326; 7228800,0.0041941; 7232400,0.0048474; 7236000,0.0033672;
        7239600,0.0026204; 7243200,0.0076404; 7246800,0.0140133; 7250400,
        0.0077194; 7254000,0.0050404; 7257600,0.0070102; 7261200,0.0046982;
        7264800,0.006863; 7268400,0.0100047; 7272000,0.0134936; 7275600,
        0.0122194; 7279200,0.0090107; 7282800,0.0078404; 7286400,0.0110814;
        7290000,0.0060106; 7293600,0.0082803; 7297200,0.0093362; 7300800,
        0.0044072; 7304400,0.0047628; 7308000,0.0104816; 7311600,0.0070339;
        7315200,0.0050853; 7318800,0.0042639; 7322400,0.0029459; 7326000,
        0.0026108; 7329600,0.0077053; 7333200,0.0140968; 7336800,0.0074901;
        7340400,0.0037603; 7344000,0.0056896; 7347600,0.0018829; 7351200,
        0.0047229; 7354800,0.0101457; 7358400,0.0104538; 7362000,0.0093496;
        7365600,0.0060615; 7369200,0.007977; 7372800,0.0098206; 7376400,
        0.0039032; 7380000,0.00311; 7383600,0.0056918; 7387200,0.0032573;
        7390800,0.0027629; 7394400,0.0078991; 7398000,0.0064438; 7401600,
        0.0058453; 7405200,0.0042483; 7408800,0.0029489; 7412400,0.0026063;
        7416000,0.0076244; 7419600,0.0139969; 7423200,0.0079592; 7426800,
        0.0060243; 7430400,0.0116152; 7434000,0.0137358; 7437600,0.0116946;
        7441200,0.0260366; 7444800,0.0214599; 7448400,0.0170136; 7452000,
        0.0138988; 7455600,0.0141821; 7459200,0.0058993; 7462800,0.0036638;
        7466400,0.0064868; 7470000,0.0043612; 7473600,0.0027852; 7477200,
        0.007934; 7480800,0.0065269; 7484400,0.0033709; 7488000,0.0042858;
        7491600,0.0029667; 7495200,0.0035832; 7498800,0.0084113; 7502400,
        0.0140901; 7506000,0.0074994; 7509600,0.0037287; 7513200,0.0055303;
        7516800,0.0020284; 7520400,0.001364; 7524000,0.0070168; 7527600,
        0.0042246; 7531200,0.0042435; 7534800,0.0033145; 7538400,0.0070684;
        7542000,0.0110788; 7545600,0.0048411; 7549200,0.0048593; 7552800,
        0.007813; 7556400,0.0041448; 7560000,0.0032618; 7563600,0.0098982;
        7567200,0.0068235; 7570800,0.0038761; 7574400,0.0042387; 7578000,
        0.0054378; 7581600,0.0025948; 7585200,0.0076137; 7588800,0.0140207;
        7592400,0.0066364; 7596000,0.0037517; 7599600,0.0056268; 7603200,
        0.0010259; 7606800,1e-06; 7610400,0.0066138; 7614000,0.0037179; 7617600,
        0.0035765; 7621200,0.0028773; 7624800,0.0066182; 7628400,0.0097653;
        7632000,0.0038159; 7635600,0.0040123; 7639200,0.0073331; 7642800,
        0.0036088; 7646400,0.0027525; 7650000,0.0079492; 7653600,0.0054361;
        7657200,0.0033156; 7660800,0.0042869; 7664400,0.0029756; 7668000,
        0.0051122; 7671600,0.007646; 7675200,0.0139368; 7678800,0.0074756;
        7682400,0.0037651; 7686000,0.006031; 7689600,0.0021735; 7693200,
        0.0044646; 7696800,0.0076144; 7700400,0.0038401; 7704000,0.0038204;
        7707600,0.0031133; 7711200,0.0073179; 7714800,0.0108075; 7718400,
        0.0056428; 7722000,0.0066613; 7725600,0.0075521; 7729200,0.004693;
        7732800,0.0055519; 7736400,0.011371; 7740000,0.0081177; 7743600,
        0.0051851; 7747200,0.0055637; 7750800,0.0037989; 7754400,0.0025996;
        7758000,0.0076345; 7761600,0.0139223; 7765200,0.0078635; 7768800,
        0.0053718; 7772400,0.0066761; 7776000,0.0020121; 7779600,0.005829;
        7783200,0.0106516; 7786800,0.0066687; 7790400,0.0080064; 7794000,
        0.0064375; 7797600,0.0079136; 7801200,0.0132943; 7804800,0.0116155;
        7808400,0.0110566; 7812000,0.0085486; 7815600,0.0050486; 7819200,
        0.0074173; 7822800,0.0131295; 7826400,0.0090827; 7830000,0.007581;
        7833600,0.0056706; 7837200,0.003666; 7840800,0.0037599; 7844400,
        0.0073683; 7848000,0.0138347; 7851600,0.0080732; 7855200,0.0047531;
        7858800,0.0072329; 7862400,0.0056576; 7866000,0.0083196; 7869600,
        0.0139272; 7873200,0.0104234; 7876800,0.0072165; 7880400,0.0052267;
        7884000,0.0115985; 7887600,0.0198687; 7891200,0.0147136; 7894800,
        0.0156716; 7898400,0.0152555; 7902000,0.0067967; 7905600,0.0075598;
        7909200,0.0176648; 7912800,0.0147779; 7916400,0.0068105; 7920000,
        0.0086771; 7923600,0.0064144; 7927200,0.0038749; 7930800,0.0084399;
        7934400,0.0146168; 7938000,0.0108038; 7941600,0.009923; 7945200,
        0.0116115; 7948800,0.014983; 7952400,0.0179831; 7956000,0.0145785;
        7959600,0.0118349; 7963200,0.0155139; 7966800,0.0096154; 7970400,
        0.0106936; 7974000,0.0157796; 7977600,0.0081429; 7981200,0.0048507;
        7984800,0.0082201; 7988400,0.0043897; 7992000,0.0039948; 7995600,
        0.0124915; 7999200,0.0079488; 8002800,0.0042279; 8006400,0.0059601;
        8010000,0.0059961; 8013600,0.0048051; 8017200,0.0081827; 8020800,
        0.0145693; 8024400,0.0087171; 8028000,0.0058944; 8031600,0.0085679;
        8035200,0.0036645; 8038800,0.006539; 8042400,0.0110261; 8046000,
        0.0074455; 8049600,0.0076541; 8053200,0.0066423; 8056800,0.0082409;
        8060400,0.0109783; 8064000,0.0055901; 8067600,0.0046191; 8071200,
        0.0073498; 8074800,0.0045486; 8078400,0.0036663; 8082000,0.0093091;
        8085600,0.0071557; 8089200,0.0051224; 8092800,0.0066479; 8096400,
        0.0054665; 8100000,0.0043801; 8103600,0.0082524; 8107200,0.0144264;
        8110800,0.0085835; 8114400,0.0062693; 8118000,0.0089372; 8121600,
        0.0029099; 8125200,0.0057956; 8128800,0.0109025; 8132400,0.0065555;
        8136000,0.0069426; 8139600,0.0048786; 8143200,0.0070439; 8146800,
        0.0121875; 8150400,0.0097378; 8154000,0.0110588; 8157600,0.0117391;
        8161200,0.0050233; 8164800,0.0034707; 8168400,0.009857; 8172000,
        0.0087405; 8175600,0.0053785; 8179200,0.0059022; 8182800,0.0043222;
        8186400,0.0032967; 8190000,0.0076192; 8193600,0.0139331; 8197200,
        0.0078958; 8200800,0.0044313; 8204400,0.0070287; 8208000,0.0047995;
        8211600,0.0057779; 8215200,0.010426; 8218800,0.0074411; 8222400,
        0.0084328; 8226000,0.004945; 8229600,0.0072689; 8233200,0.0104742;
        8236800,0.0050397; 8240400,0.0061305; 8244000,0.0081879; 8247600,
        0.0039325; 8251200,0.0032532; 8254800,0.0115287; 8258400,0.0091002;
        8262000,0.0042246; 8265600,0.00556; 8269200,0.0039425; 8272800,
        0.0031371; 8276400,0.0076371; 8280000,0.0139309; 8283600,0.0069838;
        8287200,0.0041748; 8290800,0.0062712; 8294400,0.0038052; 8298000,
        0.0089545; 8301600,0.012925; 8305200,0.0088853; 8308800,0.0079733;
        8312400,0.0053689; 8316000,0.0073694; 8319600,0.0110866; 8323200,
        0.0061216; 8326800,0.0095177; 8330400,0.0134973; 8334000,0.0055003;
        8337600,0.0035802; 8341200,0.0091889; 8344800,0.0077488; 8348400,
        0.0033427; 8352000,0.0042398; 8355600,0.0029585; 8359200,0.0026074;
        8362800,0.0076189; 8366400,0.0140036; 8370000,0.0075008; 8373600,
        0.0045074; 8377200,0.0067143; 8380800,0.0023509; 8384400,0.0045544;
        8388000,0.0087973; 8391600,0.0084384; 8395200,0.009697; 8398800,
        0.0047984; 8402400,0.0073873; 8406000,0.0111839; 8409600,0.0052731;
        8413200,0.0051113; 8416800,0.006848; 8420400,0.0038527; 8424000,
        0.0027466; 8427600,0.0085857; 8431200,0.0068342; 8434800,0.0037799;
        8438400,0.0042517; 8442000,0.0054667; 8445600,0.0026171; 8449200,
        0.0076408; 8452800,0.014017; 8456400,0.0075031; 8460000,0.003771;
        8463600,0.0057727; 8467200,0.0026538; 8470800,0.0064967; 8474400,
        0.0095615; 8478000,0.0065135; 8481600,0.0068238; 8485200,0.0051625;
        8488800,0.0083475; 8492400,0.0114077; 8496000,0.0060303; 8499600,
        0.0045943; 8503200,0.0065232; 8506800,0.0032558; 8510400,0.0027618;
        8514000,0.008614; 8517600,0.0068468; 8521200,0.0033397; 8524800,
        0.0042398; 8528400,0.0029823; 8532000,0.0026171; 8535600,0.0076345;
        8539200,0.0140422; 8542800,0.007509; 8546400,0.0037703; 8550000,
        0.0057378; 8553600,0.0010344; 8557200,0.0009513; 8560800,0.0077588;
        8564400,0.0052553; 8568000,0.005818; 8571600,0.0053878; 8575200,
        0.008163; 8578800,0.0101431; 8582400,0.0039432; 8586000,0.0036667;
        8589600,0.0067533; 8593200,0.0037484; 8596800,0.0027566; 8600400,
        0.0087594; 8604000,0.0063187; 8607600,0.0033137; 8611200,0.0041949;
        8614800,0.0029418; 8618400,0.0026011; 8622000,0.0076697; 8625600,
        0.0139854; 8629200,0.0074723; 8632800,0.0043292; 8636400,0.006557;
        8640000,0.0041016; 8643600,0.0038812; 8647200,0.0063389; 8650800,
        0.0080793; 8654400,0.0067849; 8658000,0.005445; 8661600,0.0074411;
        8665200,0.0104605; 8668800,0.00399; 8672400,0.0031315; 8676000,
        0.0061583; 8679600,0.0032291; 8683200,0.0027518; 8686800,0.0080847;
        8690400,0.0063205; 8694000,0.0058178; 8697600,0.0042402; 8701200,
        0.0029597; 8704800,0.0026163; 8708400,0.0076512; 8712000,0.0139943;
        8715600,0.0075064; 8719200,0.0037506; 8722800,0.0057653; 8726400,
        0.0010393; 8730000,1e-06; 8733600,0.0064219; 8737200,0.0036374; 8740800,
        0.003064; 8744400,0.0022507; 8748000,0.0066553; 8751600,0.0105666;
        8755200,0.0048348; 8758800,0.0047579; 8762400,0.0070514; 8766000,
        0.0037001; 8769600,0.0032031; 8773200,0.0087955; 8776800,0.0070777;
        8780400,0.0033535; 8784000,0.0042658; 8787600,0.0029919; 8791200,
        0.0026334; 8794800,0.0076764; 8798400,0.013968; 8802000,0.0066227;
        8805600,0.0037179; 8809200,0.0056053; 8812800,0.001043; 8816400,
        0.0005237; 8820000,0.0075743; 8823600,0.0049873; 8827200,0.0044495;
        8830800,0.0032718; 8834400,0.0071891; 8838000,0.0097445; 8841600,
        0.0043174; 8845200,0.0044295; 8848800,0.0085928; 8852400,0.0064007;
        8856000,0.0065985; 8859600,0.0123397; 8863200,0.010083; 8866800,
        0.0083334; 8870400,0.0081352; 8874000,0.0059683; 8877600,0.0041233;
        8881200,0.007627; 8884800,0.0139268; 8888400,0.0074775; 8892000,
        0.0037643; 8895600,0.0062823; 8899200,0.002499; 8902800,0.0059236;
        8906400,0.0108832; 8910000,0.0085557; 8913600,0.0083879; 8917200,
        0.0057627; 8920800,0.0074845; 8924400,0.0126218; 8928000,0.0101825;
        8931600,0.0082053; 8935200,0.0080665; 8938800,0.0057931; 8942400,
        0.0058065; 8946000,0.0104913; 8949600,0.0086681; 8953200,0.0064746;
        8956800,0.0064761; 8960400,0.0041552; 8964000,0.0036652; 8967600,
        0.0086693; 8971200,0.0139628; 8974800,0.0073008; 8978400,0.0049799;
        8982000,0.0097642; 8985600,0.0126955; 8989200,0.0124956; 8992800,
        0.0177045; 8996400,0.0170022; 9000000,0.0175208; 9003600,0.0059208;
        9007200,0.0076285; 9010800,0.0126088; 9014400,0.012506; 9018000,
        0.0098503; 9021600,0.009876; 9025200,0.0100496; 9028800,0.0121252;
        9032400,0.0136696; 9036000,0.007264; 9039600,0.0049821; 9043200,
        0.0092126; 9046800,0.0050029; 9050400,0.0040331; 9054000,0.0086767;
        9057600,0.0143774; 9061200,0.0074181; 9064800,0.0037632; 9068400,
        0.0071738; 9072000,0.0115259; 9075600,0.0158969; 9079200,0.0210839;
        9082800,0.0176651; 9086400,0.0197644; 9090000,0.0113565; 9093600,
        0.0099501; 9097200,0.0149623; 9100800,0.0104108; 9104400,0.0066887;
        9108000,0.0067867; 9111600,0.0032473; 9115200,0.0037565; 9118800,
        0.0095716; 9122400,0.0082476; 9126000,0.0039729; 9129600,0.0042391;
        9133200,0.0029786; 9136800,0.0026238; 9140400,0.00765; 9144000,
        0.0139869; 9147600,0.007473; 9151200,0.0037224; 9154800,0.0055953;
        9158400,0.0029188; 9162000,0.0086116; 9165600,0.0137965; 9169200,
        0.0230587; 9172800,0.0273642; 9176400,0.0134988; 9180000,0.0138413;
        9183600,0.0136874; 9187200,0.0050155; 9190800,0.0055948; 9194400,
        0.0056506; 9198000,0.0032239; 9201600,0.0027503; 9205200,0.0080216;
        9208800,0.0063836; 9212400,0.0033215; 9216000,0.0042376; 9219600,
        0.0029548; 9223200,0.0026067; 9226800,0.0076244; 9230400,0.0139735;
        9234000,0.0066249; 9237600,0.0037228; 9241200,0.0055786; 9244800,
        0.0010036; 9248400,0.0006269; 9252000,0.0070566; 9255600,0.0039291;
        9259200,0.0034084; 9262800,0.0028383; 9266400,0.006655; 9270000,
        0.0105681; 9273600,0.0040249; 9277200,0.0031263; 9280800,0.0063758;
        9284400,0.0036237; 9288000,0.0027789; 9291600,0.008775; 9295200,
        0.0068413; 9298800,0.0032959; 9302400,0.0042272; 9306000,0.0029441;
        9309600,0.0026137; 9313200,0.0076385; 9316800,0.0140519; 9320400,
        0.0066431; 9324000,0.0041114; 9327600,0.0055994; 9331200,0.0027185;
        9334800,0.0039789; 9338400,0.0069678; 9342000,0.0049632; 9345600,
        0.0052831; 9349200,0.0046982; 9352800,0.0075075; 9356400,0.0095452;
        9360000,0.0080236; 9363600,0.012717; 9367200,0.011468; 9370800,
        0.0032351; 9374400,0.0049569; 9378000,0.0144245; 9381600,0.0113075;
        9385200,0.0040171; 9388800,0.004252; 9392400,0.0036908; 9396000,
        0.0039091; 9399600,0.0076679; 9403200,0.0140203; 9406800,0.0074875;
        9410400,0.0040999; 9414000,0.0063814; 9417600,0.0015392; 9421200,
        0.0011005; 9424800,0.0071727; 9428400,0.0042606; 9432000,0.0045033;
        9435600,0.0032239; 9439200,0.0071408; 9442800,0.009844; 9446400,
        0.0054843; 9450000,0.0052779; 9453600,0.0072566; 9457200,0.0043998;
        9460800,0.0030962; 9464400,0.0097033; 9468000,0.0069433; 9471600,
        0.0033457; 9475200,0.0042506; 9478800,0.0029511; 9482400,0.0026045;
        9486000,0.0076333; 9489600,0.0139583; 9493200,0.0074882; 9496800,
        0.0044766; 9500400,0.0068591; 9504000,0.0020948; 9507600,0.0016841;
        9511200,0.009235; 9514800,0.0056573; 9518400,0.0059523; 9522000,
        0.0063109; 9525600,0.0075409; 9529200,0.0104505; 9532800,0.004631;
        9536400,0.0039265; 9540000,0.0056112; 9543600,0.0037243; 9547200,
        0.00277; 9550800,0.0080464; 9554400,0.0063844; 9558000,0.0033334;
        9561600,0.0042391; 9565200,0.0029819; 9568800,0.0026215; 9572400,
        0.0076389; 9576000,0.01437; 9579600,0.0081303; 9583200,0.0047305;
        9586800,0.0068777; 9590400,0.0029185; 9594000,0.0066507; 9597600,
        0.011862; 9601200,0.0098128; 9604800,0.0116664; 9608400,0.0089573;
        9612000,0.0098637; 9615600,0.0107619; 9619200,0.0045764; 9622800,
        0.0041381; 9626400,0.0058351; 9630000,0.0036422; 9633600,0.0027618;
        9637200,0.0079447; 9640800,0.0069125; 9644400,0.0038378; 9648000,
        0.0042442; 9651600,0.002983; 9655200,0.0026275; 9658800,0.0076656;
        9662400,0.0139665; 9666000,0.0074893; 9669600,0.0043656; 9673200,
        0.006302; 9676800,0.0022682; 9680400,0.004717; 9684000,0.0087817;
        9687600,0.0064271; 9691200,0.0079752; 9694800,0.0062159; 9698400,
        0.0076404; 9702000,0.010142; 9705600,0.0047086; 9709200,0.0046243;
        9712800,0.0063369; 9716400,0.0037105; 9720000,0.0027666; 9723600,
        0.0085638; 9727200,0.0067849; 9730800,0.0033501; 9734400,0.0042602;
        9738000,0.0029519; 9741600,0.0026045; 9745200,0.0076241; 9748800,
        0.0139405; 9752400,0.0074834; 9756000,0.0037666; 9759600,0.0057708;
        9763200,0.0022864; 9766800,0.0054311; 9770400,0.0097152; 9774000,
        0.0074883; 9777600,0.0137278; 9781200,0.0192293; 9784800,0.0174735;
        9788400,0.0130496; 9792000,0.0038512; 9795600,0.0030877; 9799200,
        0.0056142; 9802800,0.0032057; 9806400,0.002741; 9810000,0.0081626;
        9813600,0.0053782; 9817200,0.0032766; 9820800,0.0042127; 9824400,
        0.002947; 9828000,0.00261; 9831600,0.0077328; 9835200,0.0139695;
        9838800,0.0073594; 9842400,0.0037625; 9846000,0.0057534; 9849600,
        0.0010426; 9853200,0.0009439; 9856800,0.0077024; 9860400,0.0045527;
        9864000,0.0041169; 9867600,0.003058; 9871200,0.0071182; 9874800,
        0.0099416; 9878400,0.0044105; 9882000,0.0035502; 9885600,0.0061064;
        9889200,0.0038475; 9892800,0.0033501; 9896400,0.0088649; 9900000,
        0.0071234; 9903600,0.0033442; 9907200,0.0042454; 9910800,0.0029656;
        9914400,0.0026178; 9918000,0.0076441; 9921600,0.0139394; 9925200,
        0.0074804; 9928800,0.0042301; 9932400,0.0065514; 9936000,0.002875;
        9939600,0.006137; 9943200,0.0095252; 9946800,0.0067188; 9950400,
        0.0072908; 9954000,0.0062986; 9957600,0.0078353; 9961200,0.0109671;
        9964800,0.0040052; 9968400,0.0035721; 9972000,0.0056832; 9975600,
        0.0032172; 9979200,0.0027477; 9982800,0.0079815; 9986400,0.0063888;
        9990000,0.0033282; 9993600,0.0042346; 9997200,0.002953; 10000800,
        0.0025967; 10004400,0.0076033; 10008000,0.0139316; 10011600,0.0069875;
        10015200,0.0037558; 10018800,0.005645; 10022400,0.0010385; 10026000,
        1e-06; 10029600,0.0064404; 10033200,0.0039959; 10036800,0.0039495;
        10040400,0.0031326; 10044000,0.0070061; 10047600,0.0108317; 10051200,
        0.0055366; 10054800,0.006538; 10058400,0.0080706; 10062000,0.0050957;
        10065600,0.003195; 10069200,0.0092683; 10072800,0.0101845; 10076400,
        0.0060668; 10080000,0.0046707; 10083600,0.0029467; 10087200,0.0025926;
        10090800,0.0075996; 10094400,0.0140196; 10098000,0.0068105; 10101600,
        0.0037521; 10105200,0.0061387; 10108800,0.002037; 10112400,0.0042044;
        10116000,0.0076033; 10119600,0.0044699; 10123200,0.0041036; 10126800,
        0.0032974; 10130400,0.0066394; 10134000,0.0097701; 10137600,0.003895;
        10141200,0.003735; 10144800,0.007401; 10148400,0.0048203; 10152000,
        0.0037773; 10155600,0.0090605; 10159200,0.007898; 10162800,0.0040423;
        10166400,0.0047286; 10170000,0.003326; 10173600,0.0026019; 10177200,
        0.0076107; 10180800,0.0140263; 10184400,0.0067915; 10188000,0.0041021;
        10191600,0.0062148; 10195200,0.0047875; 10198800,0.0035256; 10202400,
        0.0081996; 10206000,0.0060411; 10209600,0.0053993; 10213200,0.0044569;
        10216800,0.0076178; 10220400,0.0121569; 10224000,0.008234; 10227600,
        0.0089242; 10231200,0.0099394; 10234800,0.0052976; 10238400,0.0058462;
        10242000,0.012438; 10245600,0.0070291; 10249200,0.0046848; 10252800,
        0.0055036; 10256400,0.0041789; 10260000,0.0026186; 10263600,0.007663;
        10267200,0.0139613; 10270800,0.00748; 10274400,0.003732; 10278000,
        0.0056766; 10281600,0.0024011; 10285200,0.0067739; 10288800,0.0116779;
        10292400,0.0077918; 10296000,0.0082224; 10299600,0.0070031; 10303200,
        0.0076226; 10306800,0.0104553; 10310400,0.0039922; 10314000,0.0031263;
        10317600,0.0058265; 10321200,0.0035743; 10324800,0.0027525; 10328400,
        0.0088073; 10332000,0.0064081; 10335600,0.0058412; 10339200,0.0042446;
        10342800,0.0029444; 10346400,0.0026148; 10350000,0.0076363; 10353600,
        0.0139309; 10357200,0.0074789; 10360800,0.0037528; 10364400,0.0057051;
        10368000,0.0010162; 10371600,0.0006781; 10375200,0.0073457; 10378800,
        0.0043615; 10382400,0.0049038; 10386000,0.0040587; 10389600,0.0071252;
        10393200,0.010207; 10396800,0.0044079; 10400400,0.0036574; 10404000,
        0.0063283; 10407600,0.0039503; 10411200,0.0027577; 10414800,0.0090553;
        10418400,0.0065473; 10422000,0.0032889; 10425600,0.0042383; 10429200,
        0.0029749; 10432800,0.0026037; 10436400,0.0077154; 10440000,0.0140456;
        10443600,0.0074726; 10447200,0.003774; 10450800,0.0057861; 10454400,
        0.0040426; 10458000,0.0016295; 10461600,0.0070739; 10465200,0.0074585;
        10468800,0.0076797; 10472400,0.0053904; 10476000,0.0073093; 10479600,
        0.0098384; 10483200,0.003895; 10486800,0.0031141; 10490400,0.0056576;
        10494000,0.0037298; 10497600,0.0027741; 10501200,0.0105015; 10504800,
        0.0054502; 10508400,0.0033; 10512000,0.004222; 10515600,0.0029767;
        10519200,0.0026134; 10522800,0.0101471; 10526400,0.0140764; 10530000,
        0.0075506; 10533600,0.003728; 10537200,0.0055849; 10540800,0.0010099;
        10544400,1e-06; 10548000,0.006469; 10551600,0.0037859; 10555200,
        0.0035324; 10558800,0.0026742; 10562400,0.0066253; 10566000,0.0097582;
        10569600,0.0038957; 10573200,0.0031155; 10576800,0.0060578; 10580400,
        0.0036107; 10584000,0.0027459; 10587600,0.0079793; 10591200,0.0054427;
        10594800,0.0033182; 10598400,0.0042803; 10602000,0.0029849; 10605600,
        0.002623; 10609200,0.0076526; 10612800,0.0139431; 10616400,0.0074789;
        10620000,0.0037421; 10623600,0.005753; 10627200,0.00104; 10630800,
        0.000713; 10634400,0.0072039; 10638000,0.0046548; 10641600,0.0061342;
        10645200,0.0051603; 10648800,0.008045; 10652400,0.0114467; 10656000,
        0.0083656; 10659600,0.0086024; 10663200,0.0074203; 10666800,0.0042854;
        10670400,0.0046759; 10674000,0.0100088; 10677600,0.0054405; 10681200,
        0.0033193; 10684800,0.0042903; 10688400,0.0029533; 10692000,0.0026056;
        10695600,0.0076281; 10699200,0.0139342; 10702800,0.0074778; 10706400,
        0.004415; 10710000,0.0065436; 10713600,0.0059575; 10717200,0.0022708;
        10720800,0.0081655; 10724400,0.0060915; 10728000,0.0052616; 10731600,
        0.0041132; 10735200,0.0074537; 10738800,0.009749; 10742400,0.0038913;
        10746000,0.0042439; 10749600,0.0067737; 10753200,0.0043111; 10756800,
        0.0034411; 10760400,0.0084785; 10764000,0.0054424; 10767600,0.0044695;
        10771200,0.0055574; 10774800,0.0029771; 10778400,0.0026048; 10782000,
        0.0076274; 10785600,0.0139283; 10789200,0.007476; 10792800,0.0037647;
        10796400,0.0057682; 10800000,0.0010396; 10803600,0.0015821; 10807200,
        0.0120192; 10810800,0.0059149; 10814400,0.0054728; 10818000,0.0051625;
        10821600,0.007264; 10825200,0.0097898; 10828800,0.004461; 10832400,
        0.0057159; 10836000,0.0069192; 10839600,0.0040164; 10843200,0.0035112;
        10846800,0.0091046; 10850400,0.006322; 10854000,0.0033163; 10857600,
        0.0042398; 10861200,0.0029827; 10864800,0.0026278; 10868400,0.007741;
        10872000,0.0139836; 10875600,0.0066156; 10879200,0.0037372; 10882800,
        0.0055934; 10886400,0.0010307; 10890000,0.0005894; 10893600,0.0066583;
        10897200,0.0036359; 10900800,0.0037692; 10904400,0.0040223; 10908000,
        0.0073906; 10911600,0.0097698; 10915200,0.0038983; 10918800,0.0031278;
        10922400,0.005668; 10926000,0.003244; 10929600,0.0027644; 10933200,
        0.0080572; 10936800,0.006106; 10940400,0.0032837; 10944000,0.0042506;
        10947600,0.0029478; 10951200,0.0026037; 10954800,0.0076775; 10958400,
        0.013958; 10962000,0.0064256; 10965600,0.0037261; 10969200,0.005802;
        10972800,0.0010415; 10976400,1e-06; 10980000,0.0065083; 10983600,
        0.0039495; 10987200,0.0038256; 10990800,0.003666; 10994400,0.0073275;
        10998000,0.0098009; 11001600,0.0038864; 11005200,0.0031207; 11008800,
        0.0056584; 11012400,0.0031887; 11016000,0.0027496; 11019600,0.0077777;
        11023200,0.0055778; 11026800,0.0032855; 11030400,0.0042257; 11034000,
        0.0029778; 11037600,0.0026238; 11041200,0.0078059; 11044800,0.0141164;
        11048400,0.0069222; 11052000,0.0037083; 11055600,0.0057909; 11059200,
        0.0010452; 11062800,1e-06; 11066400,0.0057593; 11070000,0.0034689;
        11073600,0.0033015; 11077200,0.0022585; 11080800,0.0066409; 11084400,
        0.0098098; 11088000,0.0038994; 11091600,0.0031159; 11095200,0.0053897;
        11098800,0.0031831; 11102400,0.0027425; 11106000,0.0081411; 11109600,
        0.0058844; 11113200,0.003336; 11116800,0.0042743; 11120400,0.0029853;
        11124000,0.0026111; 11127600,0.0077477; 11131200,0.0140983; 11134800,
        0.0067789; 11138400,0.0037205; 11142000,0.0056183; 11145600,0.0010404;
        11149200,1e-06; 11152800,0.0057798; 11156400,0.003172; 11160000,
        0.0029745; 11163600,0.0022578; 11167200,0.0066442; 11170800,0.009805;
        11174400,0.0038909; 11178000,0.003104; 11181600,0.0055181; 11185200,
        0.0032184; 11188800,0.0027481; 11192400,0.0077926; 11196000,0.0064675;
        11199600,0.0033308; 11203200,0.0041975; 11206800,0.0029266; 11210400,
        0.0026093; 11214000,0.0077859; 11217600,0.0140563; 11221200,0.0063929;
        11224800,0.0036938; 11228400,0.0057501; 11232000,0.0010393; 11235600,
        1e-06; 11239200,0.0057794; 11242800,0.0031519; 11246400,0.0028813;
        11250000,0.0022492; 11253600,0.0066212; 11257200,0.0097909; 11260800,
        0.0039024; 11264400,0.0031237; 11268000,0.0054888; 11271600,0.003225;
        11275200,0.0027529; 11278800,0.008094; 11282400,0.0053789; 11286000,
        0.0033052; 11289600,0.0042558; 11293200,0.0029496; 11296800,0.0026122;
        11300400,0.0077543; 11304000,0.0140058; 11307600,0.006714; 11311200,
        0.0037042; 11314800,0.0057252; 11318400,0.0010404; 11322000,1e-06;
        11325600,0.0061739; 11329200,0.0034214; 11332800,0.0030844; 11336400,
        0.0022541; 11340000,0.0066331; 11343600,0.0097954; 11347200,0.0039028;
        11350800,0.0031256; 11354400,0.0057935; 11358000,0.0032506; 11361600,
        0.0027507; 11365200,0.0081578; 11368800,0.005426; 11372400,0.0033286;
        11376000,0.0042546; 11379600,0.0029816; 11383200,0.0026115; 11386800,
        0.0077246; 11390400,0.0139921; 11394000,0.0065254; 11397600,0.0037261;
        11401200,0.0056049; 11404800,0.0010378; 11408400,1e-06; 11412000,
        0.0057638; 11415600,0.0027581; 11419200,0.0030302; 11422800,0.0022515;
        11426400,0.0066245; 11430000,0.0097891; 11433600,0.0039017; 11437200,
        0.0031263; 11440800,0.005638; 11444400,0.0032525; 11448000,0.0027652;
        11451600,0.0081897; 11455200,0.0057423; 11458800,0.0033342; 11462400,
        0.0042751; 11466000,0.0029882; 11469600,0.0026126; 11473200,0.0077889;
        11476800,0.0140474; 11480400,0.0073119; 11484000,0.0037116; 11487600,
        0.0056777; 11491200,0.0010359; 11494800,1e-06; 11498400,0.0063127;
        11502000,0.0034533; 11505600,0.0030083; 11509200,0.0028116; 11512800,
        0.0070369; 11516400,0.0097913; 11520000,0.0039024; 11523600,0.00313;
        11527200,0.0056743; 11530800,0.0036738; 11534400,0.0027637; 11538000,
        0.0079982; 11541600,0.0064096; 11545200,0.0033412; 11548800,0.0042379;
        11552400,0.0029723; 11556000,0.00261; 11559600,0.0076341; 11563200,
        0.0139323; 11566800,0.0074789; 11570400,0.0037643; 11574000,0.0057675;
        11577600,0.0010422; 11581200,1e-06; 11584800,0.0062819; 11588400,
        0.0034247; 11592000,0.0035543; 11595600,0.0038527; 11599200,0.0070814;
        11602800,0.0097909; 11606400,0.0039009; 11610000,0.0031285; 11613600,
        0.005674; 11617200,0.0032633; 11620800,0.0027796; 11624400,0.0080168;
        11628000,0.0064193; 11631600,0.0033186; 11635200,0.0042342; 11638800,
        0.0029437; 11642400,0.0026019; 11646000,0.007617; 11649600,0.0139197;
        11653200,0.0074767; 11656800,0.0037603; 11660400,0.005746; 11664000,
        0.0010393; 11667600,1e-06; 11671200,0.0063183; 11674800,0.0033869;
        11678400,0.0028205; 11682000,0.0022467; 11685600,0.00661; 11689200,
        0.0104913; 11692800,0.0052972; 11696400,0.0042012; 11700000,0.0062422;
        11703600,0.0037235; 11707200,0.0027455; 11710800,0.0077599; 11714400,
        0.0059026; 11718000,0.0032711; 11721600,0.0042075; 11725200,0.0033735;
        11728800,0.0030124; 11732400,0.0078004; 11736000,0.0141361; 11739600,
        0.0073557; 11743200,0.003745; 11746800,0.0058336; 11750400,0.0010448;
        11754000,1e-06; 11757600,0.0058377; 11761200,0.0027808; 11764800,
        0.0024493; 11768400,0.0022589; 11772000,0.0066472; 11775600,0.0097657;
        11779200,0.0038553; 11782800,0.0031181; 11786400,0.0056781; 11790000,
        0.0032558; 11793600,0.0027603; 11797200,0.0078093; 11800800,0.0064768;
        11804400,0.0033453; 11808000,0.004245; 11811600,0.0029626; 11815200,
        0.00261; 11818800,0.0076185; 11822400,0.013994; 11826000,0.0067069;
        11829600,0.003741; 11833200,0.0055574; 11836800,0.0010099; 11840400,
        1e-06; 11844000,0.0058087; 11847600,0.0027737; 11851200,0.0024445;
        11854800,0.002253; 11858400,0.0066331; 11862000,0.0097801; 11865600,
        0.0038404; 11869200,0.003104; 11872800,0.0057883; 11876400,0.0032558;
        11880000,0.0027574; 11883600,0.0077606; 11887200,0.006485; 11890800,
        0.0033438; 11894400,0.0042216; 11898000,0.002943; 11901600,0.0025967;
        11905200,0.0076044; 11908800,0.0139554; 11912400,0.0070473; 11916000,
        0.0037614; 11919600,0.0056543; 11923200,0.0010307; 11926800,1e-06;
        11930400,0.0058087; 11934000,0.0027448; 11937600,0.0024385; 11941200,
        0.0022526; 11944800,0.0066241; 11948400,0.009828; 11952000,0.0039061;
        11955600,0.0031077; 11959200,0.0056495; 11962800,0.0032573; 11966400,
        0.0027589; 11970000,0.0081986; 11973600,0.0057215; 11977200,0.0032852;
        11980800,0.0041114; 11984400,0.0029322; 11988000,0.0026148; 11991600,
        0.0077955; 11995200,0.0140021; 11998800,0.0074778; 12002400,0.0037703;
        12006000,0.005779; 12009600,0.0010441; 12013200,1e-06; 12016800,
        0.0057642; 12020400,0.0027496; 12024000,0.0024341; 12027600,0.0022496;
        12031200,0.0066197; 12034800,0.009795; 12038400,0.003882; 12042000,
        0.0030951; 12045600,0.0054034; 12049200,0.003241; 12052800,0.0027763;
        12056400,0.0082257; 12060000,0.0059828; 12063600,0.0032956; 12067200,
        0.0042996; 12070800,0.0029734; 12074400,0.0026015; 12078000,0.0076738;
        12081600,0.0140482; 12085200,0.0074789; 12088800,0.0037643; 12092400,
        0.0057671; 12096000,0.001043; 12099600,1e-06; 12103200,0.0057575;
        12106800,0.0027685; 12110400,0.0024411; 12114000,0.0022522; 12117600,
        0.0066271; 12121200,0.009802; 12124800,0.003885; 12128400,0.0031052;
        12132000,0.005648; 12135600,0.0032629; 12139200,0.0027782; 12142800,
        0.0080119; 12146400,0.0054505; 12150000,0.0033071; 12153600,0.0042754;
        12157200,0.0029801; 12160800,0.0026252; 12164400,0.0076645; 12168000,
        0.0139494; 12171600,0.0074789; 12175200,0.0037424; 12178800,0.0057541;
        12182400,0.001043; 12186000,1e-06; 12189600,0.0057582; 12193200,
        0.002767; 12196800,0.0024374; 12200400,0.00225; 12204000,0.0066178;
        12207600,0.0097909; 12211200,0.0038987; 12214800,0.0031048; 12218400,
        0.0056446; 12222000,0.0031931; 12225600,0.0027418; 12229200,0.0079611;
        12232800,0.0063751; 12236400,0.0032967; 12240000,0.0042235; 12243600,
        0.0029611; 12247200,0.0026011; 12250800,0.007614; 12254400,0.0141153;
        12258000,0.0075647; 12261600,0.0037859; 12265200,0.0058005; 12268800,
        0.0010471; 12272400,1e-06; 12276000,0.005779; 12279600,0.0027681;
        12283200,0.0024486; 12286800,0.0022589; 12290400,0.006646; 12294000,
        0.0098136; 12297600,0.0039065; 12301200,0.0031282; 12304800,0.0056691;
        12308400,0.0032662; 12312000,0.0027811; 12315600,0.0083326; 12319200,
        0.0059869; 12322800,0.0033364; 12326400,0.0043259; 12330000,0.0029771;
        12333600,0.0026104; 12337200,0.0076868; 12340800,0.0141153; 12344400,
        0.0072711; 12348000,0.0037736; 12351600,0.0056602; 12355200,0.0010463;
        12358800,1e-06; 12362400,0.0057675; 12366000,0.0027577; 12369600,
        0.0024348; 12373200,0.0022511; 12376800,0.0066275; 12380400,0.009798;
        12384000,0.003813; 12387600,0.0031029; 12391200,0.0056432; 12394800,
        0.0031924; 12398400,0.0027462; 12402000,0.0079689; 12405600,0.0054416;
        12409200,0.0033004; 12412800,0.0042676; 12416400,0.0029578; 12420000,
        0.0026148; 12423600,0.007653; 12427200,0.0139442; 12430800,0.0074797;
        12434400,0.0037658; 12438000,0.0057916; 12441600,0.0010441; 12445200,
        1e-06; 12448800,0.0057705; 12452400,0.0027485; 12456000,0.0024356;
        12459600,0.0022504; 12463200,0.0066193; 12466800,0.0097779; 12470400,
        0.0038345; 12474000,0.0030881; 12477600,0.0056279; 12481200,0.003254;
        12484800,0.0027522; 12488400,0.0079685; 12492000,0.0064022; 12495600,
        0.0033453; 12499200,0.0042517; 12502800,0.0029823; 12506400,0.0026111;
        12510000,0.0076241; 12513600,0.0139338; 12517200,0.0074812; 12520800,
        0.0037562; 12524400,0.0057293; 12528000,0.0010378; 12531600,1e-06;
        12535200,0.005779; 12538800,0.0027459; 12542400,0.0024382; 12546000,
        0.0022522; 12549600,0.0066241; 12553200,0.0098332; 12556800,0.0038905;
        12560400,0.0031111; 12564000,0.0056465; 12567600,0.0032128; 12571200,
        0.0027692; 12574800,0.0080134; 12578400,0.0064178; 12582000,0.0033245;
        12585600,0.0042379; 12589200,0.0029823; 12592800,0.0026267; 12596400,
        0.007931; 12600000,0.0141291; 12603600,0.0075699; 12607200,0.0037807;
        12610800,0.0057898; 12614400,0.0010448; 12618000,1e-06; 12621600,
        0.0057697; 12625200,0.0027666; 12628800,0.0024482; 12632400,0.0022585;
        12636000,0.0066434; 12639600,0.0098084; 12643200,0.0038794; 12646800,
        0.003097; 12650400,0.0056049; 12654000,0.003202; 12657600,0.0027499;
        12661200,0.008166; 12664800,0.0056836; 12668400,0.0033004; 12672000,
        0.004245; 12675600,0.0029834; 12679200,0.0026156; 12682800,0.0077551;
        12686400,0.0140218; 12690000,0.0066798; 12693600,0.0037584; 12697200,
        0.0056428; 12700800,0.0010385; 12704400,1e-06; 12708000,0.0057842;
        12711600,0.0027674; 12715200,0.0024408; 12718800,0.0022544; 12722400,
        0.0066383; 12726000,0.0097954; 12729600,0.0038968; 12733200,0.0031215;
        12736800,0.0056599; 12740400,0.0032659; 12744000,0.002773; 12747600,
        0.0082075; 12751200,0.0059349; 12754800,0.003342; 12758400,0.0043274;
        12762000,0.0029775; 12765600,0.002626; 12769200,0.0077143; 12772800,
        0.01405; 12776400,0.0074938; 12780000,0.0037595; 12783600,0.0056257;
        12787200,0.0010177; 12790800,1e-06; 12794400,0.0057864; 12798000,
        0.00276; 12801600,0.0024426; 12805200,0.0022537; 12808800,0.0066546;
        12812400,0.0098611; 12816000,0.0038582; 12819600,0.0030959; 12823200,
        0.0056428; 12826800,0.0032506; 12830400,0.0027748; 12834000,0.0080168;
        12837600,0.0054542; 12841200,0.0033245; 12844800,0.0042955; 12848400,
        0.0029541; 12852000,0.00262; 12855600,0.0078063; 12859200,0.0140088;
        12862800,0.0072054; 12866400,0.0037603; 12870000,0.0056346; 12873600,
        0.00104; 12877200,1e-06; 12880800,0.0057534; 12884400,0.0027633;
        12888000,0.0024423; 12891600,0.002253; 12895200,0.0066212; 12898800,
        0.0097946; 12902400,0.0039013; 12906000,0.0031285; 12909600,0.0056747;
        12913200,0.0032514; 12916800,0.00276; 12920400,0.0079893; 12924000,
        0.0064078; 12927600,0.0033215; 12931200,0.0042335; 12934800,0.0029378;
        12938400,0.00261; 12942000,0.007633; 12945600,0.0139286; 12949200,
        0.0074782; 12952800,0.0037621; 12956400,0.0057586; 12960000,0.0010426;
        12963600,1e-06; 12967200,0.0057671; 12970800,0.0027611; 12974400,
        0.0024408; 12978000,0.0022526; 12981600,0.0066234; 12985200,0.0097939;
        12988800,0.0038913; 12992400,0.0031174; 12996000,0.0056547; 12999600,
        0.003261; 13003200,0.0027778; 13006800,0.0080101; 13010400,0.0064182;
        13014000,0.0033483; 13017600,0.0042546; 13021200,0.0029652; 13024800,
        0.0026096; 13028400,0.0076278; 13032000,0.013952; 13035600,0.0074945;
        13039200,0.0037699; 13042800,0.005776; 13046400,0.001043; 13050000,
        1e-06; 13053600,0.005782; 13057200,0.0027537; 13060800,0.0024341;
        13064400,0.0022481; 13068000,0.006616; 13071600,0.0094606; 13075200,
        0.0038612; 13078800,0.0030966; 13082400,0.0058172; 13086000,0.0032495;
        13089600,0.002744; 13093200,0.0076998; 13096800,0.0064827; 13100400,
        0.0033149; 13104000,0.0042149; 13107600,0.00293; 13111200,0.0025989;
        13114800,0.0077224; 13118400,0.0139535; 13122000,0.0064556; 13125600,
        0.0037209; 13129200,0.0057519; 13132800,0.0010422; 13136400,1e-06;
        13140000,0.0057605; 13143600,0.0027563; 13147200,0.0024382; 13150800,
        0.0022511; 13154400,0.0066434; 13158000,0.0098551; 13161600,0.0038916;
        13165200,0.003107; 13168800,0.0056476; 13172400,0.0032477; 13176000,
        0.0027433; 13179600,0.0081723; 13183200,0.0054205; 13186800,0.0033278;
        13190400,0.0043025; 13194000,0.00295; 13197600,0.0026204; 13201200,
        0.0078115; 13204800,0.0140901; 13208400,0.0068958; 13212000,0.0037473;
        13215600,0.0057189; 13219200,0.0010433; 13222800,1e-06; 13226400,
        0.0057831; 13230000,0.0027596; 13233600,0.0024374; 13237200,0.0022526;
        13240800,0.0066338; 13244400,0.0098002; 13248000,0.0038731; 13251600,
        0.0031018; 13255200,0.0058057; 13258800,0.0032347; 13262400,0.0027648;
        13266000,0.0082079; 13269600,0.0060563; 13273200,0.0033527; 13276800,
        0.0042854; 13280400,0.0029574; 13284000,0.002613; 13287600,0.0074348;
        13291200,0.0140207; 13294800,0.0065083; 13298400,0.0036845; 13302000,
        0.0055801; 13305600,0.0010448; 13309200,1e-06; 13312800,0.0058065;
        13316400,0.002767; 13320000,0.0024304; 13323600,0.002247; 13327200,
        0.0066152; 13330800,0.0097493; 13334400,0.0038471; 13338000,0.0031155;
        13341600,0.0056187; 13345200,0.0032065; 13348800,0.0027585; 13352400,
        0.0081715; 13356000,0.0056302; 13359600,0.0032982; 13363200,0.0042454;
        13366800,0.0029819; 13370400,0.0026189; 13374000,0.0076504; 13377600,
        0.0140879; 13381200,0.0075287; 13384800,0.0037714; 13388400,0.0057675;
        13392000,0.0010441; 13395600,1e-06; 13399200,0.0057772; 13402800,
        0.0027544; 13406400,0.0024415; 13410000,0.0022552; 13413600,0.0066405;
        13417200,0.0098599; 13420800,0.003915; 13424400,0.003136; 13428000,
        0.0056858; 13431600,0.0032391; 13435200,0.0027711; 13438800,0.0080446;
        13442400,0.0054646; 13446000,0.0033345; 13449600,0.0042702; 13453200,
        0.0029734; 13456800,0.0026156; 13460400,0.0076942; 13464000,0.0141402;
        13467600,0.0067351; 13471200,0.0037272; 13474800,0.0056432; 13478400,
        0.0010396; 13482000,1e-06; 13485600,0.0058057; 13489200,0.0027626;
        13492800,0.002433; 13496400,0.0022492; 13500000,0.0066301; 13503600,
        0.0097557; 13507200,0.0038352; 13510800,0.0030881; 13514400,0.0053685;
        13518000,0.003218; 13521600,0.0027652; 13525200,0.007656; 13528800,
        0.0058785; 13532400,0.0032718; 13536000,0.0041878; 13539600,0.0029674;
        13543200,0.0026011; 13546800,0.0077439; 13550400,0.0139576; 13554000,
        0.0069036; 13557600,0.0037142; 13561200,0.005615; 13564800,0.001014;
        13568400,1e-06; 13572000,0.0057742; 13575600,0.002757; 13579200,
        0.0024411; 13582800,0.0022537; 13586400,0.0066286; 13590000,0.0097894;
        13593600,0.0039002; 13597200,0.0031174; 13600800,0.0056495; 13604400,
        0.0032536; 13608000,0.0027629; 13611600,0.0081853; 13615200,0.0057534;
        13618800,0.0032926; 13622400,0.004222; 13626000,0.00294; 13629600,
        0.0026007; 13633200,0.007617; 13636800,0.0139264; 13640400,0.0066145;
        13644000,0.0037046; 13647600,0.0056832; 13651200,0.0010359; 13654800,
        1e-06; 13658400,0.0057809; 13662000,0.0027203; 13665600,0.00242;
        13669200,0.0022392; 13672800,0.0064924; 13676400,0.0104145; 13680000,
        0.0039989; 13683600,0.0031248; 13687200,0.0058169; 13690800,0.0032685;
        13694400,0.0027774; 13698000,0.0079499; 13701600,0.0064196; 13705200,
        0.003342; 13708800,0.0042431; 13712400,0.0029719; 13716000,0.00261;
        13719600,0.0076259; 13723200,0.0139301; 13726800,0.0074682; 13730400,
        0.0037142; 13734000,0.0057367; 13737600,0.0010411; 13741200,1e-06;
        13744800,0.0058135; 13748400,0.0027362; 13752000,0.0024333; 13755600,
        0.0022478; 13759200,0.0066097; 13762800,0.0097519; 13766400,0.0038827;
        13770000,0.0031037; 13773600,0.0056343; 13777200,0.0032403; 13780800,
        0.0027414; 13784400,0.0081426; 13788000,0.00574; 13791600,0.0033256;
        13795200,0.0042984; 13798800,0.0029908; 13802400,0.002623; 13806000,
        0.007686; 13809600,0.0139609; 13813200,0.0074626; 13816800,0.0037669;
        13820400,0.0057734; 13824000,0.0010426; 13827600,1e-06; 13831200,
        0.0057645; 13834800,0.0027696; 13838400,0.0024408; 13842000,0.0042518;
        13845600,0.0066267; 13849200,0.0097968; 13852800,0.0038894; 13856400,
        0.0031219; 13860000,0.0056562; 13863600,0.0031927; 13867200,0.0027596;
        13870800,0.0082072; 13874400,0.0055797; 13878000,0.0033338; 13881600,
        0.0042832; 13885200,0.0029927; 13888800,0.002633; 13892400,0.0077402;
        13896000,0.0139966; 13899600,0.0074504; 13903200,0.0037558; 13906800,
        0.0055738; 13910400,0.0010285; 13914000,1e-06; 13917600,0.0057311;
        13921200,0.0027448; 13924800,0.0024333; 13928400,0.0022485; 13932000,
        0.0066171; 13935600,0.0098277; 13939200,0.0039095; 13942800,0.0031215;
        13946400,0.0056513; 13950000,0.0032603; 13953600,0.0027574; 13957200,
        0.0078089; 13960800,0.0064764; 13964400,0.0033453; 13968000,0.0042198;
        13971600,0.0029248; 13975200,0.0025863; 13978800,0.007705; 13982400,
        0.0139709; 13986000,0.0073824; 13989600,0.0037651; 13993200,0.0057779;
        13996800,0.0010452; 14000400,1e-06; 14004000,0.0058002; 14007600,
        0.0027455; 14011200,0.0024348; 14014800,0.00225; 14018400,0.0066204;
        14022000,0.0097879; 14025600,0.003902; 14029200,0.0031304; 14032800,
        0.0056346; 14036400,0.0031827; 14040000,0.002747; 14043600,0.0081496;
        14047200,0.0060266; 14050800,0.0033308; 14054400,0.004268; 14058000,
        0.0029782; 14061600,0.0026234; 14065200,0.0077265; 14068800,0.0140062;
        14072400,0.0067912; 14076000,0.0037543; 14079600,0.0056576; 14083200,
        0.0010285; 14086800,1e-06; 14090400,0.0057471; 14094000,0.0027344;
        14097600,0.0024367; 14101200,0.0022518; 14104800,0.0066253; 14108400,
        0.0097798; 14112000,0.0038991; 14115600,0.0031282; 14119200,0.0056691;
        14122800,0.0032633; 14126400,0.0027589; 14130000,0.00817; 14133600,
        0.0054004; 14137200,0.0032737; 14140800,0.0042127; 14144400,0.0029674;
        14148000,0.0025989; 14151600,0.0076189; 14155200,0.0139301; 14158800,
        0.0067322; 14162400,0.0036938; 14166000,0.0056855; 14169600,0.001037;
        14173200,1e-06; 14176800,0.0057712; 14180400,0.0027648; 14184000,
        0.0024371; 14187600,0.0022504; 14191200,0.0066208; 14194800,0.0095567;
        14198400,0.0038887; 14202000,0.0031141; 14205600,0.0058009; 14209200,
        0.003274; 14212800,0.0027737; 14216400,0.0079819; 14220000,0.0064204;
        14223600,0.0033241; 14227200,0.0042368; 14230800,0.0029726; 14234400,
        0.0026011; 14238000,0.0076174; 14241600,0.0139272; 14245200,0.0070803;
        14248800,0.0036879; 14252400,0.0055986; 14256000,0.0010359; 14259600,
        1e-06; 14263200,0.0057749; 14266800,0.0027451; 14270400,0.0024367;
        14274000,0.0022507; 14277600,0.0066171; 14281200,0.0094854; 14284800,
        0.0038761; 14288400,0.0031122; 14292000,0.0056395; 14295600,0.003215;
        14299200,0.0027555; 14302800,0.0080383; 14306400,0.0054401; 14310000,
        0.0032811; 14313600,0.0042613; 14317200,0.0029281; 14320800,0.0025907;
        14324400,0.0076348; 14328000,0.0139624; 14331600,0.0074715; 14335200,
        0.0037584; 14338800,0.0057623; 14342400,0.0010441; 14346000,1e-06;
        14349600,0.0057586; 14353200,0.0027696; 14356800,0.0024385; 14360400,
        0.0022511; 14364000,0.0066223; 14367600,0.0094661; 14371200,0.003862;
        14374800,0.0030881; 14378400,0.005615; 14382000,0.0032087; 14385600,
        0.0027533; 14389200,0.0081548; 14392800,0.0057838; 14396400,0.0033141;
        14400000,0.0042713; 14403600,0.0029526; 14407200,0.0026241; 14410800,
        0.007748; 14414400,0.0139836; 14418000,0.0074162; 14421600,0.0037406;
        14425200,0.005759; 14428800,0.001043; 14432400,1e-06; 14436000,
        0.0057519; 14439600,0.0027637; 14443200,0.00244; 14446800,0.0022507;
        14450400,0.0066186; 14454000,0.0097957; 14457600,0.0039017; 14461200,
        0.0031178; 14464800,0.0056506; 14468400,0.0032191; 14472000,0.002747;
        14475600,0.0079637; 14479200,0.0063992; 14482800,0.00332; 14486400,
        0.004232; 14490000,0.0029452; 14493600,0.0025952; 14497200,0.0076486;
        14500800,0.0140404; 14504400,0.0076077; 14508000,0.0037662; 14511600,
        0.0057642; 14515200,0.001043; 14518800,1e-06; 14522400,0.0057653;
        14526000,0.0027689; 14529600,0.0024478; 14533200,0.0022589; 14536800,
        0.0066434; 14540400,0.0098399; 14544000,0.0038764; 14547600,0.003104;
        14551200,0.0056539; 14554800,0.0032373; 14558400,0.0027499; 14562000,
        0.007977; 14565600,0.0053859; 14569200,0.0032781; 14572800,0.0042242;
        14576400,0.0029318; 14580000,0.0025915; 14583600,0.0077213; 14587200,
        0.0139706; 14590800,0.0075042; 14594400,0.0037692; 14598000,0.0057734;
        14601600,0.0010407; 14605200,1e-06; 14608800,0.0058621; 14612400,
        0.0027551; 14616000,0.0024363; 14619600,0.0022515; 14623200,0.0066245;
        14626800,0.0097371; 14630400,0.0038916; 14634000,0.0031126; 14637600,
        0.0056395; 14641200,0.0032377; 14644800,0.0027533; 14648400,0.0079882;
        14652000,0.0064014; 14655600,0.0033215; 14659200,0.0042342; 14662800,
        0.0029764; 14666400,0.0026082; 14670000,0.0078067; 14673600,0.014164;
        14677200,0.0072681; 14680800,0.003771; 14684400,0.005406; 14688000,
        0.0010211; 14691600,1e-06; 14695200,0.0057746; 14698800,0.0027466;
        14702400,0.0024322; 14706000,0.0022481; 14709600,0.0066175; 14713200,
        0.0097905; 14716800,0.0038549; 14720400,0.0031144; 14724000,0.0056595;
        14727600,0.0032614; 14731200,0.0027566; 14734800,0.0079785; 14738400,
        0.0064037; 14742000,0.0033215; 14745600,0.0042762; 14749200,0.0029459;
        14752800,0.0026048; 14756400,0.0076794; 14760000,0.0140181; 14763600,
        0.0074715; 14767200,0.0037469; 14770800,0.0056109; 14774400,0.0010415;
        14778000,1e-06; 14781600,0.0057898; 14785200,0.002754; 14788800,
        0.0024337; 14792400,0.0022489; 14796000,0.006619; 14799600,0.0097467;
        14803200,0.0038942; 14806800,0.0031259; 14810400,0.0056595; 14814000,
        0.003241; 14817600,0.0027704; 14821200,0.0082146; 14824800,0.0059226;
        14828400,0.0033408; 14832000,0.0042669; 14835600,0.0029574; 14839200,
        0.0026167; 14842800,0.0077592; 14846400,0.0139884; 14850000,0.0075372;
        14853600,0.0037213; 14857200,0.0057426; 14860800,0.0010419; 14864400,
        1e-06; 14868000,0.0057798; 14871600,0.0027659; 14875200,0.0024371;
        14878800,0.0022515; 14882400,0.0066227; 14886000,0.0097935; 14889600,
        0.0038564; 14893200,0.0031144; 14896800,0.0056602; 14900400,0.0032339;
        14904000,0.0027462; 14907600,0.0079626; 14911200,0.0063974; 14914800,
        0.0033375; 14918400,0.0041503; 14922000,0.0029749; 14925600,0.0026267;
        14929200,0.0077224; 14932800,0.0140957; 14936400,0.0074648; 14940000,
        0.0037417; 14943600,0.0057775; 14947200,0.0009899; 14950800,1e-06;
        14954400,0.005815; 14958000,0.002777; 14961600,0.0024445; 14965200,
        0.0022544; 14968800,0.0066657; 14972400,0.0104909; 14976000,0.0040026;
        14979600,0.0031181; 14983200,0.0056847; 14986800,0.003261; 14990400,
        0.002773; 14994000,0.0079065; 14997600,0.0064471; 15001200,0.0033238;
        15004800,0.0042275; 15008400,0.0029426; 15012000,0.0026085; 15015600,
        0.0076278; 15019200,0.0139305; 15022800,0.0064816; 15026400,0.0037179;
        15030000,0.0056231; 15033600,0.0010274; 15037200,1e-06; 15040800,
        0.0057961; 15044400,0.0027711; 15048000,0.0024345; 15051600,0.002247;
        15055200,0.0066104; 15058800,0.0097675; 15062400,0.0038501; 15066000,
        0.0031122; 15069600,0.0054075; 15073200,0.0031894; 15076800,0.0027585;
        15080400,0.0081611; 15084000,0.0060284; 15087600,0.0032978; 15091200,
        0.0043062; 15094800,0.0029545; 15098400,0.0026204; 15102000,0.0077024;
        15105600,0.014089; 15109200,0.0076207; 15112800,0.003781; 15116400,
        0.0057861; 15120000,0.0010445; 15123600,1e-06; 15127200,0.0058291;
        15130800,0.002777; 15134400,0.0024504; 15138000,0.0022593; 15141600,
        0.0066449; 15145200,0.0095244; 15148800,0.0038816; 15152400,0.0031118;
        15156000,0.0058258; 15159600,0.0032748; 15163200,0.0027674; 15166800,
        0.0077651; 15170400,0.0064935; 15174000,0.0033457; 15177600,0.0042439;
        15181200,0.0029467; 15184800,0.0026059; 15188400,0.0076211; 15192000,
        0.0140055; 15195600,0.0074927; 15199200,0.0037692; 15202800,0.0057749;
        15206400,0.0010445; 15210000,1e-06; 15213600,0.0057527; 15217200,
        0.00277; 15220800,0.0024474; 15224400,0.002257; 15228000,0.0066386;
        15231600,0.009805; 15235200,0.0038861; 15238800,0.0031204; 15242400,
        0.0056617; 15246000,0.0032536; 15249600,0.0027607; 15253200,0.0080052;
        15256800,0.0064349; 15260400,0.0033542; 15264000,0.0042628; 15267600,
        0.0029571; 15271200,0.0025963; 15274800,0.0077087; 15278400,0.0140077;
        15282000,0.0073943; 15285600,0.0037294; 15289200,0.0056049; 15292800,
        0.0010471; 15296400,1e-06; 15300000,0.0058072; 15303600,0.0027741;
        15307200,0.0024456; 15310800,0.0022559; 15314400,0.0066331; 15318000,
        0.0097568; 15321600,0.0038924; 15325200,0.0031196; 15328800,0.0053733;
        15332400,0.0032284; 15336000,0.0027748; 15339600,0.0081429; 15343200,
        0.0062155; 15346800,0.0032774; 15350400,0.0042175; 15354000,0.0029404;
        15357600,0.0025903; 15361200,0.007617; 15364800,0.0139246; 15368400,
        0.0064452; 15372000,0.0037168; 15375600,0.0055036; 15379200,0.0010036;
        15382800,1e-06; 15386400,0.0057905; 15390000,0.0027666; 15393600,
        0.002443; 15397200,0.0022533; 15400800,0.0066264; 15404400,0.0097701;
        15408000,0.003898; 15411600,0.0031278; 15415200,0.0056673; 15418800,
        0.0032644; 15422400,0.00278; 15426000,0.0080212; 15429600,0.0064182;
        15433200,0.0033494; 15436800,0.0042561; 15440400,0.0029456; 15444000,
        0.0025985; 15447600,0.0078765; 15451200,0.0140801; 15454800,0.0072488;
        15458400,0.0037584; 15462000,0.005622; 15465600,0.0010445; 15469200,
        1e-06; 15472800,0.0057363; 15476400,0.0027618; 15480000,0.0024356;
        15483600,0.0022515; 15487200,0.0064972; 15490800,0.0105113; 15494400,
        0.0040242; 15498000,0.0031334; 15501600,0.0055444; 15505200,0.0032503;
        15508800,0.0027548; 15512400,0.0081741; 15516000,0.0056766; 15519600,
        0.0033275; 15523200,0.0042654; 15526800,0.0029578; 15530400,0.0026004;
        15534000,0.007705; 15537600,0.0140407; 15541200,0.0071905; 15544800,
        0.0037246; 15548400,0.0056176; 15552000,0.0010474; 15555600,1e-06;
        15559200,0.0058072; 15562800,0.0027518; 15566400,0.0024333; 15570000,
        0.0022504; 15573600,0.0066197; 15577200,0.009766; 15580800,0.0038504;
        15584400,0.003107; 15588000,0.0056343; 15591600,0.0032596; 15595200,
        0.0027767; 15598800,0.0080138; 15602400,0.006417; 15606000,0.0033156;
        15609600,0.0042212; 15613200,0.0029767; 15616800,0.0026152; 15620400,
        0.0076296; 15624000,0.0139516; 15627600,0.0074893; 15631200,0.0037087;
        15634800,0.0056491; 15638400,0.00103; 15642000,1e-06; 15645600,
        0.0057386; 15649200,0.0027496; 15652800,0.0024419; 15656400,0.0022541;
        15660000,0.0066286; 15663600,0.0098202; 15667200,0.0038608; 15670800,
        0.0031174; 15674400,0.0055292; 15678000,0.0032532; 15681600,0.0027822;
        15685200,0.0083463; 15688800,0.0059126; 15692400,0.0033342; 15696000,
        0.0043029; 15699600,0.0029441; 15703200,0.0025996; 15706800,0.0077046;
        15710400,0.0139928; 15714000,0.0066249; 15717600,0.0037513; 15721200,
        0.0056265; 15724800,0.0010341; 15728400,1e-06; 15732000,0.0057946;
        15735600,0.0027492; 15739200,0.0024363; 15742800,0.00225; 15746400,
        0.0065273; 15750000,0.0095122; 15753600,0.0038664; 15757200,0.0031055;
        15760800,0.0055756; 15764400,0.0032076; 15768000,0.0027655; 15771600,
        0.0082079; 15775200,0.0058054; 15778800,0.0032963; 15782400,0.0042576;
        15786000,0.0029597; 15789600,0.0026056; 15793200,0.0076898; 15796800,
        0.0140563; 15800400,0.0067054; 15804000,0.0037625; 15807600,0.0056517;
        15811200,0.0010393; 15814800,1e-06; 15818400,0.0058013; 15822000,
        0.0027574; 15825600,0.0024389; 15829200,0.0022533; 15832800,0.006518;
        15836400,0.0104661; 15840000,0.0039967; 15843600,0.0031181; 15847200,
        0.0057746; 15850800,0.0032236; 15854400,0.0027525; 15858000,0.0080954;
        15861600,0.0062663; 15865200,0.0033286; 15868800,0.0042201; 15872400,
        0.0029307; 15876000,0.0025903; 15879600,0.0075944; 15883200,0.0139405;
        15886800,0.0068205; 15890400,0.0037551; 15894000,0.0055964; 15897600,
        0.0010174; 15901200,1e-06; 15904800,0.005805; 15908400,0.0027362;
        15912000,0.0024363; 15915600,0.0022515; 15919200,0.0066282; 15922800,
        0.0098336; 15926400,0.0038861; 15930000,0.00311; 15933600,0.0056569;
        15937200,0.0032429; 15940800,0.0027525; 15944400,0.0076597; 15948000,
        0.0064976; 15951600,0.0033401; 15955200,0.0042346; 15958800,0.0029511;
        15962400,0.0025896; 15966000,0.0075405; 15969600,0.0139917; 15973200,
        0.0075335; 15976800,0.003777; 15980400,0.0057861; 15984000,0.0010441;
        15987600,1e-06; 15991200,0.0057823; 15994800,0.002773; 15998400,
        0.0024408; 16002000,0.002253; 16005600,0.0066312; 16009200,0.0097998;
        16012800,0.0038916; 16016400,0.0031126; 16020000,0.0056536; 16023600,
        0.003264; 16027200,0.0027789; 16030800,0.0080149; 16034400,0.00642;
        16038000,0.0033486; 16041600,0.004252; 16045200,0.002983; 16048800,
        0.0026289; 16052400,0.0076679; 16056000,0.0139769; 16059600,0.0074994;
        16063200,0.0037476; 16066800,0.005759; 16070400,0.0010422; 16074000,
        1e-06; 16077600,0.0057541; 16081200,0.0027611; 16084800,0.002433;
        16088400,0.0022492; 16092000,0.0066171; 16095600,0.0094598; 16099200,
        0.0038638; 16102800,0.0031207; 16106400,0.005651; 16110000,0.003248;
        16113600,0.0027559; 16117200,0.0080476; 16120800,0.0063784; 16124400,
        0.0033364; 16128000,0.0042431; 16131600,0.0029842; 16135200,0.0026278;
        16138800,0.0076634; 16142400,0.0139498; 16146000,0.0074826; 16149600,
        0.0037484; 16153200,0.0056038; 16156800,0.0010463; 16160400,1e-06;
        16164000,0.0057475; 16167600,0.002747; 16171200,0.0024411; 16174800,
        0.0022541; 16178400,0.0065169; 16182000,0.0104226; 16185600,0.0039948;
        16189200,0.0031245; 16192800,0.0058187; 16196400,0.0032651; 16200000,
        0.002754; 16203600,0.0079154; 16207200,0.0064059; 16210800,0.0033304;
        16214400,0.0042275; 16218000,0.0029764; 16221600,0.0026223; 16225200,
        0.0076426; 16228800,0.0139335; 16232400,0.0074804; 16236000,0.0037625;
        16239600,0.0056424; 16243200,0.0010244; 16246800,1e-06; 16250400,
        0.0058042; 16254000,0.0027737; 16257600,0.0024463; 16261200,0.0022552;
        16264800,0.0066071; 16268400,0.0102055; 16272000,0.0039555; 16275600,
        0.0031014; 16279200,0.0056673; 16282800,0.0032031; 16286400,0.0027422;
        16290000,0.0078716; 16293600,0.0064204; 16297200,0.0033163; 16300800,
        0.0042216; 16304400,0.0029593; 16308000,0.0026141; 16311600,0.0076278;
        16315200,0.0139457; 16318800,0.0073798; 16322400,0.0037614; 16326000,
        0.0057705; 16329600,0.0010445; 16333200,1e-06; 16336800,0.0057341;
        16340400,0.0027332; 16344000,0.0024385; 16347600,0.0022511; 16351200,
        0.0064942; 16354800,0.0093125; 16358400,0.0038026; 16362000,0.0030825;
        16365600,0.0057378; 16369200,0.0032421; 16372800,0.002754; 16376400,
        0.0081641; 16380000,0.0054921; 16383600,0.0032866; 16387200,0.0041492;
        16390800,0.0029222; 16394400,0.0025903; 16398000,0.0076519; 16401600,
        0.0139431; 16405200,0.0066149; 16408800,0.0037461; 16412400,0.0056176;
        16416000,0.0010329; 16419600,1e-06; 16423200,0.0057849; 16426800,
        0.002754; 16430400,0.0024289; 16434000,0.0022452; 16437600,0.0065477;
        16441200,0.0103584; 16444800,0.0039766; 16448400,0.0031126; 16452000,
        0.005825; 16455600,0.0032466; 16459200,0.0027503; 16462800,0.0079017;
        16466400,0.0053626; 16470000,0.0032852; 16473600,0.0042131; 16477200,
        0.0029738; 16480800,0.002607; 16484400,0.0077606; 16488000,0.0139758;
        16491600,0.0070332; 16495200,0.0037532; 16498800,0.0056398; 16502400,
        0.0010407; 16506000,1e-06; 16509600,0.0059598; 16513200,0.0027696;
        16516800,0.0024452; 16520400,0.0022556; 16524000,0.0066293; 16527600,
        0.0096183; 16531200,0.0038705; 16534800,0.0031115; 16538400,0.0056127;
        16542000,0.003244; 16545600,0.002744; 16549200,0.0079893; 16552800,
        0.0063859; 16556400,0.0033446; 16560000,0.0042483; 16563600,0.0029845;
        16567200,0.0026278; 16570800,0.007659; 16574400,0.0139424; 16578000,
        0.0071579; 16581600,0.0037135; 16585200,0.0055997; 16588800,0.0010445;
        16592400,1e-06; 16596000,0.0058217; 16599600,0.0027318; 16603200,
        0.0024248; 16606800,0.0022411; 16610400,0.0065941; 16614000,0.0097312;
        16617600,0.0038504; 16621200,0.0030899; 16624800,0.0056216; 16628400,
        0.0032176; 16632000,0.0027422; 16635600,0.0077536; 16639200,0.0064701;
        16642800,0.0033201; 16646400,0.0042205; 16650000,0.0029396; 16653600,
        0.0026096; 16657200,0.0076207; 16660800,0.0139153; 16664400,0.0067244;
        16668000,0.0037087; 16671600,0.0055971; 16675200,0.0010448; 16678800,
        1e-06; 16682400,0.0057905; 16686000,0.0027373; 16689600,0.0024293;
        16693200,0.0022452; 16696800,0.0066034; 16700400,0.0097434; 16704000,
        0.0038274; 16707600,0.0030818; 16711200,0.0056502; 16714800,0.0032369;
        16718400,0.0027407; 16722000,0.0081556; 16725600,0.005756; 16729200,
        0.0033223; 16732800,0.004284; 16736400,0.0029871; 16740000,0.0026171;
        16743600,0.0077072; 16747200,0.0141231; 16750800,0.0067214; 16754400,
        0.0037491; 16758000,0.0057493; 16761600,0.0010118; 16765200,1e-06;
        16768800,0.0058161; 16772400,0.0027633; 16776000,0.0024463; 16779600,
        0.0022567; 16783200,0.0066386; 16786800,0.0095259; 16790400,0.0038753;
        16794000,0.0031089; 16797600,0.005638; 16801200,0.0032276; 16804800,
        0.0027581; 16808400,0.0080639; 16812000,0.0063807; 16815600,0.0033527;
        16819200,0.0042654; 16822800,0.0029734; 16826400,0.0026234; 16830000,
        0.0076615; 16833600,0.0140459; 16837200,0.0067422; 16840800,0.0036908;
        16844400,0.0057456; 16848000,0.0010452; 16851600,1e-06; 16855200,
        0.0057835; 16858800,0.0027581; 16862400,0.0024445; 16866000,0.0022552;
        16869600,0.0066312; 16873200,0.0097531; 16876800,0.0038471; 16880400,
        0.0031144; 16884000,0.0056101; 16887600,0.003189; 16891200,0.0027392;
        16894800,0.008261; 16898400,0.0058321; 16902000,0.003303; 16905600,
        0.0042454; 16909200,0.0029541; 16912800,0.0026219; 16916400,0.0076664;
        16920000,0.0139717; 16923600,0.0073026; 16927200,0.0037406; 16930800,
        0.0056124; 16934400,0.00104; 16938000,1e-06; 16941600,0.0058232;
        16945200,0.0027292; 16948800,0.0024293; 16952400,0.0022481; 16956000,
        0.0065321; 16959600,0.0102352; 16963200,0.0039106; 16966800,0.0031011;
        16970400,0.0056669; 16974000,0.0032087; 16977600,0.0027332; 16981200,
        0.0078612; 16984800,0.0064582; 16988400,0.0033026; 16992000,0.0042249;
        16995600,0.0029422; 16999200,0.00261; 17002800,0.00762; 17006400,
        0.0140511; 17010000,0.00692; 17013600,0.0037243; 17017200,0.0057159;
        17020800,0.0010437; 17024400,1e-06; 17028000,0.0057931; 17031600,
        0.0027462; 17035200,0.0024359; 17038800,0.0022496; 17042400,0.0066045;
        17046000,0.0102341; 17049600,0.0039514; 17053200,0.0030951; 17056800,
        0.0056409; 17060400,0.0032295; 17064000,0.0027392; 17067600,0.0081248;
        17071200,0.0054635; 17074800,0.0033149; 17078400,0.0042602; 17082000,
        0.0029741; 17085600,0.0026137; 17089200,0.0077302; 17092800,0.0140155;
        17096400,0.0074522; 17100000,0.0037751; 17103600,0.0057838; 17107200,
        0.0010433; 17110800,1e-06; 17114400,0.0058009; 17118000,0.0027692;
        17121600,0.0024359; 17125200,0.0022526; 17128800,0.0065184; 17132400,
        0.0098848; 17136000,0.0038746; 17139600,0.0031074; 17143200,0.0057337;
        17146800,0.0032636; 17150400,0.0027689; 17154000,0.0080761; 17157600,
        0.0063558; 17161200,0.0033126; 17164800,0.0042275; 17168400,0.0029444;
        17172000,0.0026141; 17175600,0.00764; 17179200,0.0141053; 17182800,
        0.0075376; 17186400,0.0037543; 17190000,0.0057556; 17193600,0.0010448;
        17197200,1e-06; 17200800,0.0058295; 17204400,0.0027778; 17208000,
        0.0024452; 17211600,0.0022556; 17215200,0.0066394; 17218800,0.009847;
        17222400,0.0039161; 17226000,0.003133; 17229600,0.0056714; 17233200,
        0.0032655; 17236800,0.0027544; 17240400,0.0081378; 17244000,0.0061561;
        17247600,0.003349; 17251200,0.0042602; 17254800,0.0029745; 17258400,
        0.0026089; 17262000,0.0078453; 17265600,0.0140407; 17269200,0.0069805;
        17272800,0.0037213; 17276400,0.0056873; 17280000,0.0010367; 17283600,
        1e-06; 17287200,0.0058028; 17290800,0.0027451; 17294400,0.002433;
        17298000,0.0022478; 17301600,0.0065284; 17305200,0.009543; 17308800,
        0.0037684; 17312400,0.0030918; 17316000,0.0054954; 17319600,0.0032028;
        17323200,0.0027377; 17326800,0.0077651; 17330400,0.0064367; 17334000,
        0.0033123; 17337600,0.0042227; 17341200,0.0029559; 17344800,0.0026045;
        17348400,0.007614; 17352000,0.0139747; 17355600,0.0074916; 17359200,
        0.0037358; 17362800,0.0056168; 17366400,0.0010426; 17370000,1e-06;
        17373600,0.0057738; 17377200,0.0027644; 17380800,0.0024382; 17384400,
        0.0022504; 17388000,0.0066672; 17391600,0.0105455; 17395200,0.0040193;
        17398800,0.0031356; 17402400,0.0058428; 17406000,0.0032306; 17409600,
        0.0027663; 17413200,0.0077688; 17416800,0.0064939; 17420400,0.003303;
        17424000,0.0041856; 17427600,0.0029162; 17431200,0.0025811; 17434800,
        0.0077183; 17438400,0.0139483; 17442000,0.0070016; 17445600,0.0037287;
        17449200,0.0055571; 17452800,0.0010118; 17456400,1e-06; 17460000,
        0.0057801; 17463600,0.0027689; 17467200,0.0024393; 17470800,0.0022507;
        17474400,0.0066178; 17478000,0.009779; 17481600,0.0038994; 17485200,
        0.0031215; 17488800,0.0056569; 17492400,0.0032518; 17496000,0.002754;
        17499600,0.0077666; 17503200,0.0064768; 17506800,0.0033215; 17510400,
        0.004222; 17514000,0.0029404; 17517600,0.0026104; 17521200,0.0077744;
        17524800,0.0140099; 17528400,0.0066383; 17532000,0.0037565; 17535600,
        0.0056305; 17539200,0.0010348; 17542800,1e-06; 17546400,0.0058083;
        17550000,0.0027648; 17553600,0.0024404; 17557200,0.0022518; 17560800,
        0.0066282; 17564400,0.0097761; 17568000,0.0038749; 17571600,0.0031185;
        17575200,0.0054342; 17578800,0.0032336; 17582400,0.0027448; 17586000,
        0.008098; 17589600,0.0062463; 17593200,0.0032829; 17596800,0.0042053;
        17600400,0.0029619; 17604000,0.0026219; 17607600,0.0077425; 17611200,
        0.0139795; 17614800,0.0074229; 17618400,0.0037651; 17622000,0.0057738;
        17625600,0.0010445; 17629200,1e-06; 17632800,0.0058217; 17636400,
        0.0027774; 17640000,0.0024474; 17643600,0.0022567; 17647200,0.0066334;
        17650800,0.0097586; 17654400,0.0038467; 17658000,0.0031133; 17661600,
        0.0056562; 17665200,0.0032536; 17668800,0.0027559; 17672400,0.0081686;
        17676000,0.0058963; 17679600,0.0032859; 17683200,0.0042112; 17686800,
        0.0029396; 17690400,0.0026011; 17694000,0.0077543; 17697600,0.0139828;
        17701200,0.0071479; 17704800,0.0037395; 17708400,0.0055997; 17712000,
        0.0010125; 17715600,1e-06; 17719200,0.0057987; 17722800,0.0027759;
        17726400,0.002443; 17730000,0.0022533; 17733600,0.0066293; 17737200,
        0.0098329; 17740800,0.0039106; 17744400,0.0031356; 17748000,0.0056825;
        17751600,0.0032436; 17755200,0.0027473; 17758800,0.0080257; 17762400,
        0.0063595; 17766000,0.0032826; 17769600,0.0042238; 17773200,0.0029778;
        17776800,0.002626; 17780400,0.0077621; 17784000,0.014017; 17787600,
        0.0073561; 17791200,0.0037287; 17794800,0.0054687; 17798400,0.0010422;
        17802000,1e-06; 17805600,0.0057345; 17809200,0.0027466; 17812800,
        0.0024404; 17816400,0.0022544; 17820000,0.0066316; 17823600,0.0097783;
        17827200,0.0038523; 17830800,0.003091; 17834400,0.0057122; 17838000,
        0.0032198; 17841600,0.0027422; 17845200,0.0077595; 17848800,0.0064716;
        17852400,0.003342; 17856000,0.0042201; 17859600,0.0029481; 17863200,
        0.0026171; 17866800,0.0076415; 17870400,0.0139305; 17874000,0.0068906;
        17877600,0.003732; 17881200,0.0057508; 17884800,0.0009828; 17888400,
        1e-06; 17892000,0.0057653; 17895600,0.0027444; 17899200,0.0024359;
        17902800,0.00225; 17906400,0.0066171; 17910000,0.0094951; 17913600,
        0.0038723; 17917200,0.0030944; 17920800,0.0057133; 17924400,0.0032039;
        17928000,0.0027615; 17931600,0.0077451; 17935200,0.0064478; 17938800,
        0.003316; 17942400,0.0042313; 17946000,0.0029745; 17949600,0.0026067;
        17953200,0.0076189; 17956800,0.0140311; 17960400,0.0065462; 17964000,
        0.0037224; 17967600,0.0056068; 17971200,0.0010344; 17974800,1e-06;
        17978400,0.0057374; 17982000,0.0027247; 17985600,0.0024345; 17989200,
        0.0022504; 17992800,0.0062823; 17996400,0.0092071; 18000000,0.0038208;
        18003600,0.003097; 18007200,0.0054669; 18010800,0.0032295; 18014400,
        0.0027477; 18018000,0.0080843; 18021600,0.0056042; 18025200,0.0033293;
        18028800,0.0042736; 18032400,0.002986; 18036000,0.00261; 18039600,
        0.0075153; 18043200,0.0138934; 18046800,0.0065737; 18050400,0.0037205;
        18054000,0.0057148; 18057600,0.0010396; 18061200,1e-06; 18064800,
        0.0057723; 18068400,0.0027433; 18072000,0.0024274; 18075600,0.0022467;
        18079200,0.0063562; 18082800,0.0092501; 18086400,0.0038297; 18090000,
        0.0031055; 18093600,0.0057775; 18097200,0.0031972; 18100800,0.0027277;
        18104400,0.0080784; 18108000,0.0054542; 18111600,0.0032807; 18115200,
        0.0042261; 18118800,0.0029533; 18122400,0.0025985; 18126000,0.0077321;
        18129600,0.0139635; 18133200,0.0072191; 18136800,0.0037395; 18140400,
        0.0056231; 18144000,0.0010226; 18147600,1e-06; 18151200,0.0058031;
        18154800,0.0027525; 18158400,0.0024293; 18162000,0.0022452; 18165600,
        0.0066041; 18169200,0.0097345; 18172800,0.0038671; 18176400,0.0031029;
        18180000,0.0056621; 18183600,0.0032143; 18187200,0.0027436; 18190800,
        0.0077881; 18194400,0.0064222; 18198000,0.003316; 18201600,0.004232;
        18205200,0.0029745; 18208800,0.0026063; 18212400,0.0076185; 18216000,
        0.0139383; 18219600,0.0070183; 18223200,0.0037361; 18226800,0.0054086;
        18230400,0.0010148; 18234000,1e-06; 18237600,0.0057256; 18241200,
        0.002708; 18244800,0.002423; 18248400,0.0022411; 18252000,0.0064872;
        18255600,0.0103952; 18259200,0.0039547; 18262800,0.0031089; 18266400,
        0.0056688; 18270000,0.0032009; 18273600,0.0027288; 18277200,0.0076538;
        18280800,0.0054015; 18284400,0.0032989; 18288000,0.004261; 18291600,
        0.0029667; 18295200,0.002597; 18298800,0.0076285; 18302400,0.013913;
        18306000,0.0074645; 18309600,0.0037643; 18313200,0.0057679; 18316800,
        0.0010426; 18320400,1e-06; 18324000,0.0057337; 18327600,0.0027273;
        18331200,0.0024382; 18334800,0.0022537; 18338400,0.0065592; 18342000,
        0.0103673; 18345600,0.0039603; 18349200,0.0030866; 18352800,0.0057018;
        18356400,0.003205; 18360000,0.0027433; 18363600,0.0077707; 18367200,
        0.0064679; 18370800,0.0033412; 18374400,0.0042391; 18378000,0.0029337;
        18381600,0.0025918; 18385200,0.0077343; 18388800,0.0139576; 18392400,
        0.0072518; 18396000,0.0037517; 18399600,0.0056209; 18403200,0.0009969;
        18406800,1e-06; 18410400,0.0057872; 18414000,0.0027696; 18417600,
        0.0024449; 18421200,0.0022552; 18424800,0.0066286; 18428400,0.0097672;
        18432000,0.0038304; 18435600,0.0030929; 18439200,0.0058124; 18442800,
        0.0032458; 18446400,0.0027518; 18450000,0.0079429; 18453600,0.0053878;
        18457200,0.0032581; 18460800,0.0041949; 18464400,0.0029211; 18468000,
        0.0025859; 18471600,0.0072477; 18475200,0.0138477; 18478800,0.0068327;
        18482400,0.0037035; 18486000,0.0056094; 18489600,0.0010404; 18493200,
        1e-06; 18496800,0.0057452; 18500400,0.0027674; 18504000,0.0024397;
        18507600,0.0022518; 18511200,0.0066182; 18514800,0.0097943; 18518400,
        0.0038668; 18522000,0.0031011; 18525600,0.0054825; 18529200,0.0031894;
        18532800,0.0027525; 18536400,0.0081908; 18540000,0.0061075; 18543600,
        0.0033163; 18547200,0.0043144; 18550800,0.0029582; 18554400,0.0026163;
        18558000,0.0076693; 18561600,0.013962; 18565200,0.0074697; 18568800,
        0.0037369; 18572400,0.0057493; 18576000,0.0010303; 18579600,1e-06;
        18583200,0.0059089; 18586800,0.0027655; 18590400,0.0024359; 18594000,
        0.0022518; 18597600,0.0066316; 18601200,0.0102152; 18604800,0.0038813;
        18608400,0.0030948; 18612000,0.0058421; 18615600,0.0032343; 18619200,
        0.0027455; 18622800,0.0081812; 18626400,0.0056881; 18630000,0.0032915;
        18633600,0.0042361; 18637200,0.002983; 18640800,0.0026197; 18644400,
        0.007849; 18648000,0.0141369; 18651600,0.0073798; 18655200,0.0037751;
        18658800,0.0057163; 18662400,0.00104; 18666000,1e-06; 18669600,
        0.0057987; 18673200,0.0027759; 18676800,0.0024441; 18680400,0.0022559;
        18684000,0.0066405; 18687600,0.0097961; 18691200,0.0039035; 18694800,
        0.0031126; 18698400,0.0058803; 18702000,0.0032744; 18705600,0.0027663;
        18709200,0.008202; 18712800,0.0060578; 18716400,0.0033082; 18720000,
        0.0042866; 18723600,0.0029712; 18727200,0.0026011; 18730800,0.0076738;
        18734400,0.013994; 18738000,0.0070302; 18741600,0.0037432; 18745200,
        0.0056372; 18748800,0.0010422; 18752400,1e-06; 18756000,0.0057738;
        18759600,0.0027704; 18763200,0.0024363; 18766800,0.0022515; 18770400,
        0.0066175; 18774000,0.0094387; 18777600,0.0038052; 18781200,0.0031077;
        18784800,0.0057905; 18788400,0.0032039; 18792000,0.0027641; 18795600,
        0.0080342; 18799200,0.0063343; 18802800,0.0032852; 18806400,0.0042287;
        18810000,0.0029277; 18813600,0.0025848; 18817200,0.0077881; 18820800,
        0.0141335; 18824400,0.0074689; 18828000,0.0037788; 18831600,0.0056172;
        18835200,0.0010066; 18838800,1e-06; 18842400,0.0057931; 18846000,
        0.0027551; 18849600,0.0024382; 18853200,0.002253; 18856800,0.0066327;
        18860400,0.0098522; 18864000,0.0039143; 18867600,0.0031252; 18871200,
        0.0056465; 18874800,0.0032172; 18878400,0.0027555; 18882000,0.0077892;
        18885600,0.0064827; 18889200,0.0033427; 18892800,0.0042428; 18896400,
        0.0029782; 18900000,0.0026089; 18903600,0.0076259; 18907200,0.0139268;
        18910800,0.0070777; 18914400,0.0036983; 18918000,0.0056064; 18921600,
        0.0010266; 18925200,1e-06; 18928800,0.005779; 18932400,0.0027422;
        18936000,0.002433; 18939600,0.0022489; 18943200,0.0066126; 18946800,
        0.0097698; 18950400,0.0038709; 18954000,0.0031022; 18957600,0.005638;
        18961200,0.0032473; 18964800,0.0027492; 18968400,0.007666; 18972000,
        0.0054802; 18975600,0.0032863; 18979200,0.0042283; 18982800,0.0029726;
        18986400,0.0026115; 18990000,0.007627; 18993600,0.0139461; 18997200,
        0.0074749; 19000800,0.0037053; 19004400,0.0055997; 19008000,0.0010452;
        19011600,1e-06; 19015200,0.0058106; 19018800,0.0027373; 19022400,
        0.0024348; 19026000,0.0022504; 19029600,0.0066152; 19033200,0.009749;
        19036800,0.0038909; 19040400,0.0030996; 19044000,0.0056365; 19047600,
        0.0032514; 19051200,0.0027767; 19054800,0.0080598; 19058400,0.0063948;
        19062000,0.0033505; 19065600,0.0042602; 19069200,0.0029871; 19072800,
        0.0026304; 19076400,0.0076701; 19080000,0.0139505; 19083600,0.0065117;
        19087200,0.0036868; 19090800,0.0057389; 19094400,0.0010396; 19098000,
        1e-06; 19101600,0.0057571; 19105200,0.0027459; 19108800,0.0024363;
        19112400,0.0022507; 19116000,0.006619; 19119600,0.0098384; 19123200,
        0.0039039; 19126800,0.0030948; 19130400,0.0055997; 19134000,0.0031968;
        19137600,0.0027366; 19141200,0.0081886; 19144800,0.0054479; 19148400,
        0.0033048; 19152000,0.0042513; 19155600,0.0029879; 19159200,0.0026319;
        19162800,0.0076846; 19166400,0.0139873; 19170000,0.0066887; 19173600,
        0.0037287; 19177200,0.0057393; 19180800,0.0010426; 19184400,1e-06;
        19188000,0.0057501; 19191600,0.0027622; 19195200,0.0024359; 19198800,
        0.0022518; 19202400,0.0066238; 19206000,0.0098006; 19209600,0.0038616;
        19213200,0.0030858; 19216800,0.0056528; 19220400,0.0031946; 19224000,
        0.002731; 19227600,0.0080643; 19231200,0.0062738; 19234800,0.0033408;
        19238400,0.0042517; 19242000,0.0029853; 19245600,0.0026282; 19249200,
        0.0076608; 19252800,0.0139494; 19256400,0.0066193; 19260000,0.0037417;
        19263600,0.0054995; 19267200,0.0010044; 19270800,1e-06; 19274400,
        0.0057872; 19278000,0.0027715; 19281600,0.0024445; 19285200,0.0022552;
        19288800,0.0066275; 19292400,0.0097634; 19296000,0.0038872; 19299600,
        0.003094; 19303200,0.0056599; 19306800,0.0031998; 19310400,0.0027255;
        19314000,0.0079459; 19317600,0.0063821; 19321200,0.0033412; 19324800,
        0.0042457; 19328400,0.0029478; 19332000,0.0026126; 19335600,0.0076359;
        19339200,0.0140585; 19342800,0.007028; 19346400,0.0037658; 19350000,
        0.0056595; 19353600,0.0010426; 19357200,1e-06; 19360800,0.0058711;
        19364400,0.0027681; 19368000,0.0024474; 19371600,0.0022585; 19375200,
        0.0065855; 19378800,0.0103647; 19382400,0.0039503; 19386000,0.0031096;
        19389600,0.0052865; 19393200,0.0031619; 19396800,0.0027436; 19400400,
        0.0080791; 19404000,0.0053841; 19407600,0.0032599; 19411200,0.0042019;
        19414800,0.0029567; 19418400,0.0025929; 19422000,0.007659; 19425600,
        0.0139361; 19429200,0.0074396; 19432800,0.003764; 19436400,0.0057701;
        19440000,0.0010426; 19443600,1e-06; 19447200,0.0058232; 19450800,
        0.0027499; 19454400,0.0024267; 19458000,0.0022467; 19461600,0.0066409;
        19465200,0.0104289; 19468800,0.0039254; 19472400,0.0031248; 19476000,
        0.0057846; 19479600,0.0032302; 19483200,0.0027566; 19486800,0.0077733;
        19490400,0.0064835; 19494000,0.0033442; 19497600,0.0042424; 19501200,
        0.0029426; 19504800,0.0025959; 19508400,0.0076036; 19512000,0.0139108;
        19515600,0.0074745; 19519200,0.0037632; 19522800,0.0057649; 19526400,
        0.0010441; 19530000,1e-06; 19533600,0.0057901; 19537200,0.0027496;
        19540800,0.0024285; 19544400,0.0022478; 19548000,0.006613; 19551600,
        0.0098366; 19555200,0.0039035; 19558800,0.0031245; 19562400,0.0056651;
        19566000,0.0032354; 19569600,0.0027644; 19573200,0.0081719; 19576800,
        0.0059839; 19580400,0.0032978; 19584000,0.0042654; 19587600,0.0029381;
        19591200,0.0026037; 19594800,0.007872; 19598400,0.014197; 19602000,
        0.007146; 19605600,0.0037669; 19609200,0.0056547; 19612800,0.0010452;
        19616400,1e-06; 19620000,0.0057694; 19623600,0.0027726; 19627200,
        0.0024426; 19630800,0.002253; 19634400,0.0066319; 19638000,0.0098076;
        19641600,0.0038864; 19645200,0.0031089; 19648800,0.0056495; 19652400,
        0.0032636; 19656000,0.0027744; 19659600,0.0081879; 19663200,0.0057823;
        19666800,0.0033345; 19670400,0.0043051; 19674000,0.0029764; 19677600,
        0.0026163; 19681200,0.0073364; 19684800,0.0138592; 19688400,0.0066568;
        19692000,0.003735; 19695600,0.0056213; 19699200,0.0010359; 19702800,
        1e-06; 19706400,0.0057809; 19710000,0.0027559; 19713600,0.0024363;
        19717200,0.0022496; 19720800,0.0066204; 19724400,0.0097805; 19728000,
        0.0038801; 19731600,0.003107; 19735200,0.0056443; 19738800,0.0032503;
        19742400,0.0027744; 19746000,0.0080093; 19749600,0.0064167; 19753200,
        0.0033234; 19756800,0.0042353; 19760400,0.0029764; 19764000,0.0026063;
        19767600,0.0076192; 19771200,0.0139231; 19774800,0.0074775; 19778400,
        0.003764; 19782000,0.0057668; 19785600,0.0010437; 19789200,1e-06;
        19792800,0.0057682; 19796400,0.0027644; 19800000,0.0024352; 19803600,
        0.0022504; 19807200,0.0065002; 19810800,0.0104724; 19814400,0.0040152;
        19818000,0.0031118; 19821600,0.0058024; 19825200,0.0032406; 19828800,
        0.0027626; 19832400,0.0079748; 19836000,0.0063914; 19839600,0.0032933;
        19843200,0.0042164; 19846800,0.0029303; 19850400,0.0025863; 19854000,
        0.0076356; 19857600,0.0140552; 19861200,0.0074786; 19864800,0.0037703;
        19868400,0.0057764; 19872000,0.0010441; 19875600,1e-06; 19879200,
        0.0057567; 19882800,0.0027451; 19886400,0.0024348; 19890000,0.0022504;
        19893600,0.0066011; 19897200,0.0102742; 19900800,0.0039121; 19904400,
        0.0030962; 19908000,0.0053017; 19911600,0.0032224; 19915200,0.0027507;
        19918800,0.0081496; 19922400,0.005864; 19926000,0.0033078; 19929600,
        0.0042617; 19933200,0.0029426; 19936800,0.0026104; 19940400,0.0073123;
        19944000,0.013955; 19947600,0.0076163; 19951200,0.0037606; 19954800,
        0.0056294; 19958400,0.0010456; 19962000,1e-06; 19965600,0.005825;
        19969200,0.0027759; 19972800,0.002446; 19976400,0.0022556; 19980000,
        0.0066308; 19983600,0.0097542; 19987200,0.0038965; 19990800,0.0031155;
        19994400,0.0056446; 19998000,0.003261; 20001600,0.0027782; 20005200,
        0.0080208; 20008800,0.0064167; 20012400,0.0033494; 20016000,0.0042565;
        20019600,0.0029875; 20023200,0.0026297; 20026800,0.0076645; 20030400,
        0.0139468; 20034000,0.0074808; 20037600,0.0037647; 20041200,0.0057675;
        20044800,0.0010426; 20048400,1e-06; 20052000,0.005759; 20055600,
        0.0027722; 20059200,0.0024411; 20062800,0.0022511; 20066400,0.0064968;
        20070000,0.0093648; 20073600,0.00381; 20077200,0.0030866; 20080800,
        0.0056944; 20084400,0.0032562; 20088000,0.0027655; 20091600,0.0079859;
        20095200,0.0054405; 20098800,0.0033186; 20102400,0.0042888; 20106000,
        0.0029504; 20109600,0.0026167; 20113200,0.0076445; 20116800,0.013932;
        20120400,0.0074756; 20124000,0.003764; 20127600,0.0057664; 20131200,
        0.0010441; 20134800,1e-06; 20138400,0.0057608; 20142000,0.0027707;
        20145600,0.0024449; 20149200,0.0022563; 20152800,0.0066735; 20156400,
        0.0099423; 20160000,0.003862; 20163600,0.0031089; 20167200,0.0058061;
        20170800,0.0032722; 20174400,0.0027611; 20178000,0.0077762; 20181600,
        0.0064853; 20185200,0.0033449; 20188800,0.0042431; 20192400,0.0029726;
        20196000,0.0026; 20199600,0.0076092; 20203200,0.0140366; 20206800,
        0.0076293; 20210400,0.0037729; 20214000,0.0057671; 20217600,0.0010437;
        20221200,1e-06; 20224800,0.0057842; 20228400,0.0027622; 20232000,
        0.00244; 20235600,0.0022522; 20239200,0.0065306; 20242800,0.0098637;
        20246400,0.0038939; 20250000,0.0031185; 20253600,0.0056717; 20257200,
        0.0032325; 20260800,0.0027574; 20264400,0.0077933; 20268000,0.006472;
        20271600,0.0032944; 20275200,0.0042272; 20278800,0.0029359; 20282400,
        0.0026093; 20286000,0.0076337; 20289600,0.0140868; 20293200,0.0074927;
        20296800,0.0037799; 20300400,0.0057961; 20304000,0.0010459; 20307600,
        1e-06; 20311200,0.0057697; 20314800,0.0027763; 20318400,0.0024508;
        20322000,0.0022596; 20325600,0.0066464; 20329200,0.009815; 20332800,
        0.0039065; 20336400,0.0031204; 20340000,0.0056558; 20343600,0.0032339;
        20347200,0.002757; 20350800,0.0079782; 20354400,0.0064048; 20358000,
        0.0033438; 20361600,0.0042435; 20365200,0.0029834; 20368800,0.0026275;
        20372400,0.0076619; 20376000,0.0140652; 20379600,0.0074307; 20383200,
        0.0037736; 20386800,0.0057901; 20390400,0.0010459; 20394000,1e-06;
        20397600,0.0057686; 20401200,0.0027744; 20404800,0.0024478; 20408400,
        0.0022578; 20412000,0.0066401; 20415600,0.0098551; 20419200,0.0039139;
        20422800,0.0031363; 20426400,0.0056836; 20430000,0.0032172; 20433600,
        0.0027499; 20437200,0.0076571; 20440800,0.0064939; 20444400,0.0033397;
        20448000,0.0042342; 20451600,0.0029344; 20455200,0.0025989; 20458800,
        0.00761; 20462400,0.0140838; 20466000,0.006806; 20469600,0.0037591;
        20473200,0.0056614; 20476800,0.0010422; 20480400,1e-06; 20484000,
        0.0057753; 20487600,0.0027711; 20491200,0.00245; 20494800,0.0022608;
        20498400,0.0066642; 20502000,0.0105629; 20505600,0.0040227; 20509200,
        0.0031274; 20512800,0.0058068; 20516400,0.0032421; 20520000,0.0027548;
        20523600,0.0082005; 20527200,0.0054483; 20530800,0.0033349; 20534400,
        0.0042602; 20538000,0.0029611; 20541600,0.0026226; 20545200,0.0077918;
        20548800,0.0141844; 20552400,0.0075751; 20556000,0.0037636; 20559600,
        0.0057816; 20563200,0.0010452; 20566800,1e-06; 20570400,0.0059382;
        20574000,0.002728; 20577600,0.0024374; 20581200,0.0022511; 20584800,
        0.006603; 20588400,0.0102779; 20592000,0.0039503; 20595600,0.0030929;
        20599200,0.005838; 20602800,0.0032592; 20606400,0.0027507; 20610000,
        0.008215; 20613600,0.0053503; 20617200,0.003326; 20620800,0.0043125;
        20624400,0.0029645; 20628000,0.002603; 20631600,0.0077068; 20635200,
        0.0139765; 20638800,0.007427; 20642400,0.0037384; 20646000,0.0055144;
        20649600,0.0010166; 20653200,1e-06; 20656800,0.0058042; 20660400,
        0.0027384; 20664000,0.0024322; 20667600,0.0022496; 20671200,0.0066193;
        20674800,0.0097608; 20678400,0.003833; 20682000,0.0031022; 20685600,
        0.0056495; 20689200,0.0032503; 20692800,0.0027525; 20696400,0.0080264;
        20700000,0.0063814; 20703600,0.0033479; 20707200,0.004255; 20710800,
        0.0029678; 20714400,0.0026033; 20718000,0.0076244; 20721600,0.0140203;
        20725200,0.0074856; 20728800,0.0037276; 20732400,0.0056157; 20736000,
        0.0010463; 20739600,1e-06; 20743200,0.0058128; 20746800,0.002747;
        20750400,0.0024315; 20754000,0.0022459; 20757600,0.0065106; 20761200,
        0.0096161; 20764800,0.0038241; 20768400,0.0031167; 20772000,0.0056614;
        20775600,0.0032425; 20779200,0.0027485; 20782800,0.0077929; 20786400,
        0.0064649; 20790000,0.0033427; 20793600,0.0042413; 20797200,0.0029812;
        20800800,0.0026252; 20804400,0.0076508; 20808000,0.0139327; 20811600,
        0.0074782; 20815200,0.0037395; 20818800,0.0057441; 20822400,0.0010411;
        20826000,1e-06; 20829600,0.0057545; 20833200,0.0027666; 20836800,
        0.002443; 20840400,0.0022537; 20844000,0.0066241; 20847600,0.0097943;
        20851200,0.0039009; 20854800,0.0031167; 20858400,0.0056476; 20862000,
        0.0032618; 20865600,0.0027763; 20869200,0.0080012; 20872800,0.0064144;
        20876400,0.0033282; 20880000,0.0042264; 20883600,0.002943; 20887200,
        0.0026045; 20890800,0.0077558; 20894400,0.0139739; 20898000,0.0071827;
        20901600,0.0037525; 20905200,0.0056313; 20908800,0.0009449; 20912400,
        1e-06; 20916000,0.0052144; 20919600,0.0025042; 20923200,0.0022103;
        20926800,0.0020397; 20930400,0.0059967; 20934000,0.0088929; 20937600,
        0.0034834; 20941200,0.0028087; 20944800,0.0050963; 20948400,0.002922;
        20952000,0.0025022; 20955600,0.0073008; 20959200,0.0052443; 20962800,
        0.0029829; 20966400,0.00384; 20970000,0.0027027; 20973600,0.0023724;
        20977200,0.0069362; 20980800,0.0127419; 20984400,0.006723; 20988000,
        0.0034195; 20991600,0.0052268; 20995200,0.013529; 20998800,0.0059201;
        21002400,0.007671; 21006000,0.003748; 21009600,0.003727; 21013200,
        0.003965; 21016800,0.007357; 21020400,0.010179; 21024000,0.005543;
        21027600,0.004971; 21031200,0.006706; 21034800,0.003993; 21038400,
        0.003065; 21042000,0.007234; 21045600,0.006122; 21049200,0.003632;
        21052800,0.004449; 21056400,0.003197; 21060000,0.002752; 21063600,
        0.006919; 21067200,0.012632; 21070800,0.006781; 21074400,0.003409;
        21078000,0.005218; 21081600,0.000946; 21085200,1e-06; 21088800,0.007292;
        21092400,0.004809; 21096000,0.004111; 21099600,0.003331; 21103200,
        0.00664; 21106800,0.010468; 21110400,0.005112; 21114000,0.004379;
        21117600,0.006154; 21121200,0.003762; 21124800,0.004874; 21128400,
        0.008983; 21132000,0.005704; 21135600,0.009585; 21139200,0.007142;
        21142800,0.002667; 21146400,0.00237; 21150000,0.007003; 21153600,
        0.012752; 21157200,0.0068; 21160800,0.003412; 21164400,0.005233;
        21168000,0.001518; 21171600,0.002305; 21175200,0.006508; 21178800,
        0.005952; 21182400,0.004798; 21186000,0.002745; 21189600,0.006655;
        21193200,0.009675; 21196800,0.004296; 21200400,0.005591; 21204000,
        0.007532; 21207600,0.002925; 21211200,0.003018; 21214800,0.007682;
        21218400,0.004931; 21222000,0.003005; 21225600,0.003887; 21229200,
        0.002667; 21232800,0.002769; 21236400,0.007338; 21240000,0.013943;
        21243600,0.008003; 21247200,0.0029; 21250800,0.005227; 21254400,
        0.000946; 21258000,0.000474; 21261600,0.006909; 21265200,0.004362;
        21268800,0.003553; 21272400,0.004085; 21276000,0.007599; 21279600,
        0.009937; 21283200,0.004121; 21286800,0.003161; 21290400,0.00513;
        21294000,0.003309; 21297600,0.002894; 21301200,0.007211; 21304800,
        0.004928; 21308400,0.003002; 21312000,0.003881; 21315600,0.002666;
        21319200,0.002362; 21322800,0.006913; 21326400,0.012625; 21330000,
        0.006776; 21333600,0.003412; 21337200,0.005396; 21340800,0.001576;
        21344400,0.000997; 21348000,0.006594; 21351600,0.003669; 21355200,
        0.003789; 21358800,0.004048; 21362400,0.007389; 21366000,0.010672;
        21369600,0.004849; 21373200,0.003205; 21376800,0.005525; 21380400,
        0.002932; 21384000,0.002491; 21387600,0.007298; 21391200,0.00489;
        21394800,0.003014; 21398400,0.003859; 21402000,0.002667; 21405600,
        0.002367; 21409200,0.00699; 21412800,0.01279; 21416400,0.006783;
        21420000,0.003422; 21423600,0.005244; 21427200,0.000947; 21430800,1e-06;
        21434400,0.006744; 21438000,0.003833; 21441600,0.004175; 21445200,
        0.003314; 21448800,0.006013; 21452400,0.008846; 21456000,0.00407;
        21459600,0.004459; 21463200,0.006877; 21466800,0.004047; 21470400,
        0.00319; 21474000,0.008727; 21477600,0.006527; 21481200,0.004492;
        21484800,0.00514; 21488400,0.003402; 21492000,0.002356; 21495600,
        0.006986; 21499200,0.012724; 21502800,0.006732; 21506400,0.003418;
        21510000,0.005244; 21513600,0.000947; 21517200,1e-06; 21520800,0.005924;
        21524400,0.003562; 21528000,0.003425; 21531600,0.002662; 21535200,
        0.006011; 21538800,0.009284; 21542400,0.003901; 21546000,0.003497;
        21549600,0.006403; 21553200,0.003909; 21556800,0.003329; 21560400,
        0.008591; 21564000,0.005841; 21567600,0.00346; 21571200,0.00452;
        21574800,0.003215; 21578400,0.002966; 21582000,0.006978; 21585600,
        0.012785; 21589200,0.006776; 21592800,0.003422; 21596400,0.005252;
        21600000,0.000906; 21603600,1e-06; 21607200,0.006087; 21610800,0.004847;
        21614400,0.004166; 21618000,0.002391; 21621600,0.00601; 21625200,
        0.008736; 21628800,0.003471; 21632400,0.002811; 21636000,0.005907;
        21639600,0.003607; 21643200,0.002993; 21646800,0.007865; 21650400,
        0.004936; 21654000,0.00363; 21657600,0.004476; 21661200,0.002662;
        21664800,0.002362; 21668400,0.006923; 21672000,0.012708; 21675600,
        0.006791; 21679200,0.003403; 21682800,0.005195; 21686400,0.000912;
        21690000,0.000541; 21693600,0.00665; 21697200,0.004702; 21700800,
        0.004351; 21704400,0.002875; 21708000,0.006495; 21711600,0.009456;
        21715200,0.00348; 21718800,0.002805; 21722400,0.005549; 21726000,
        0.002883; 21729600,0.002963; 21733200,0.008004; 21736800,0.005737;
        21740400,0.002984; 21744000,0.003836; 21747600,0.002663; 21751200,
        0.002361; 21754800,0.006984; 21758400,0.012767; 21762000,0.006736;
        21765600,0.003395; 21769200,0.00522; 21772800,0.000917; 21776400,1e-06;
        21780000,0.006019; 21783600,0.003964; 21787200,0.004112; 21790800,
        0.003272; 21794400,0.006669; 21798000,0.008861; 21801600,0.003508;
        21805200,0.003132; 21808800,0.005564; 21812400,0.002894; 21816000,
        0.003005; 21819600,0.007391; 21823200,0.005435; 21826800,0.003029;
        21830400,0.003888; 21834000,0.002689; 21837600,0.002826; 21841200,
        0.007006; 21844800,0.012667; 21848400,0.006656; 21852000,0.003405;
        21855600,0.005231; 21859200,0.000947; 21862800,1e-06; 21866400,0.006836;
        21870000,0.004979; 21873600,0.004527; 21877200,0.003297; 21880800,
        0.007359; 21884400,0.010554; 21888000,0.00403; 21891600,0.00284;
        21895200,0.005142; 21898800,0.002924; 21902400,0.002925; 21906000,
        0.007573; 21909600,0.0058; 21913200,0.003019; 21916800,0.003144;
        21920400,0.002202; 21924000,0.001981; 21927600,0.004646; 21931200,
        0.013405; 21934800,0.006413; 21938400,0.0028095; 21942000,0.005796;
        21945600,0.000915; 21949200,0.002799; 21952800,0.005504; 21956400,
        0.005136; 21960000,0.00566; 21963600,0.005401; 21967200,0.006018;
        21970800,0.010062; 21974400,0.004141; 21978000,0.002844; 21981600,
        0.005143; 21985200,0.002965; 21988800,0.002526; 21992400,0.007306;
        21996000,0.005822; 21999600,0.003039; 22003200,0.003858; 22006800,
        0.002707; 22010400,0.002373; 22014000,0.006928; 22017600,0.012639;
        22021200,0.006781; 22024800,0.003408; 22028400,0.004978; 22032000,
        0.000925; 22035600,0.002403; 22039200,0.006065; 22042800,0.00419;
        22046400,0.004425; 22050000,0.003536; 22053600,0.006763; 22057200,
        0.009909; 22060800,0.005564; 22064400,0.005677; 22068000,0.006237;
        22071600,0.002938; 22075200,0.002903; 22078800,0.007957; 22082400,
        0.005812; 22086000,0.004295; 22089600,0.004544; 22093200,0.002704;
        22096800,0.002727; 22100400,0.006946; 22104000,0.012646; 22107600,
        0.006783; 22111200,0.003411; 22114800,0.005213; 22118400,0.000944;
        22122000,0.001972; 22125600,0.006003; 22129200,0.004491; 22132800,
        0.004181; 22136400,0.002958; 22140000,0.006524; 22143600,0.009568;
        22147200,0.005874; 22150800,0.006979; 22154400,0.007235; 22158000,
        0.003656; 22161600,0.002509; 22165200,0.007779; 22168800,0.006489;
        22172400,0.003461; 22176000,0.003852; 22179600,0.002702; 22183200,
        0.002913; 22186800,0.00693; 22190400,0.012983; 22194000,0.006494;
        22197600,0.004056; 22201200,0.00583; 22204800,0.002085; 22208400,
        0.003873; 22212000,0.009253; 22215600,0.006163; 22219200,0.007372;
        22222800,0.005921; 22226400,0.006469; 22230000,0.010778; 22233600,
        0.01004; 22237200,0.005138; 22240800,0.00619; 22244400,0.003906;
        22248000,0.003023; 22251600,0.007648; 22255200,0.005199; 22258800,
        0.003598; 22262400,0.004339; 22266000,0.00266; 22269600,0.002363;
        22273200,0.006932; 22276800,0.012727; 22280400,0.0068; 22284000,
        0.003422; 22287600,0.005244; 22291200,0.001341; 22294800,0.000864;
        22298400,0.006824; 22302000,0.004112; 22305600,0.004553; 22309200,
        0.003451; 22312800,0.006528; 22316400,0.009859; 22320000,0.006455;
        22323600,0.006774; 22327200,0.007187; 22330800,0.003617; 22334400,
        0.002503; 22338000,0.007939; 22341600,0.004937; 22345200,0.002986;
        22348800,0.004314; 22352400,0.003062; 22356000,0.00236; 22359600,
        0.006912; 22363200,0.012656; 22366800,0.0068; 22370400,0.003419;
        22374000,0.005256; 22377600,0.001351; 22381200,0.000898; 22384800,
        0.007567; 22388400,0.005243; 22392000,0.004467; 22395600,0.003629;
        22399200,0.006689; 22402800,0.0101; 22406400,0.006539; 22410000,
        0.005457; 22413600,0.006526; 22417200,0.003548; 22420800,0.002501;
        22424400,0.00766; 22428000,0.00577; 22431600,0.003868; 22435200,
        0.004362; 22438800,0.003089; 22442400,0.002357; 22446000,0.006909;
        22449600,0.012622; 22453200,0.007193; 22456800,0.003896; 22460400,
        0.005704; 22464000,0.000945; 22467600,1e-06; 22471200,0.005882;
        22474800,0.003602; 22478400,0.003903; 22482000,0.003409; 22485600,
        0.006558; 22489200,0.009767; 22492800,0.004508; 22496400,0.003452;
        22500000,0.005603; 22503600,0.002883; 22507200,0.002491; 22510800,
        0.007226; 22514400,0.004931; 22518000,0.003008; 22521600,0.003886;
        22525200,0.002667; 22528800,0.002369; 22532400,0.006933; 22536000,
        0.012683; 22539600,0.006791; 22543200,0.003406; 22546800,0.005218;
        22550400,0.001727; 22554000,0.003094; 22557600,0.009364; 22561200,
        0.008603; 22564800,0.007392; 22568400,0.004452; 22572000,0.006739;
        22575600,0.010977; 22579200,0.00469; 22582800,0.002798; 22586400,
        0.005534; 22590000,0.003305; 22593600,0.002501; 22597200,0.007306;
        22600800,0.005773; 22604400,0.003027; 22608000,0.003843; 22611600,
        0.0027; 22615200,0.002375; 22618800,0.006931; 22622400,0.012676;
        22626000,0.00679; 22629600,0.003405; 22633200,0.005207; 22636800,
        0.001457; 22640400,0.002856; 22644000,0.007148; 22647600,0.006235;
        22651200,0.006692; 22654800,0.003681; 22658400,0.005454; 22662000,
        0.009869; 22665600,0.006338; 22669200,0.004923; 22672800,0.005686;
        22676400,0.003512; 22680000,0.002495; 22683600,0.007971; 22687200,
        0.006278; 22690800,0.003024; 22694400,0.003881; 22698000,0.002707;
        22701600,0.002383; 22705200,0.007035; 22708800,0.012719; 22712400,
        0.006722; 22716000,0.003384; 22719600,0.005097; 22723200,0.001348;
        22726800,0.001449; 22730400,0.007471; 22734000,0.004977; 22737600,
        0.004732; 22741200,0.003222; 22744800,0.007142; 22748400,0.010505;
        22752000,0.007056; 22755600,0.005839; 22759200,0.00632; 22762800,
        0.003368; 22766400,0.002488; 22770000,0.007266; 22773600,0.005769;
        22777200,0.003; 22780800,0.003842; 22784400,0.002673; 22788000,0.002357;
        22791600,0.006906; 22795200,0.012626; 22798800,0.006752; 22802400,
        0.003381; 22806000,0.005089; 22809600,0.000947; 22813200,0.0000001;
        22816800,0.006909; 22820400,0.003548; 22824000,0.003348; 22827600,
        0.002478; 22831200,0.005896; 22834800,0.009444; 22838400,0.004908;
        22842000,0.005688; 22845600,0.007083; 22849200,0.003683; 22852800,
        0.002503; 22856400,0.007929; 22860000,0.006225; 22863600,0.003616;
        22867200,0.00419; 22870800,0.002661; 22874400,0.00235; 22878000,
        0.006884; 22881600,0.01264; 22885200,0.006782; 22888800,0.003412;
        22892400,0.005227; 22896000,0.000945; 22899600,1e-06; 22903200,0.005713;
        22906800,0.002998; 22910400,0.00261; 22914000,0.002042; 22917600,
        0.006006; 22921200,0.008877; 22924800,0.003517; 22928400,0.003233;
        22932000,0.005703; 22935600,0.00337; 22939200,0.002989; 22942800,
        0.008158; 22946400,0.006368; 22950000,0.003435; 22953600,0.003844;
        22957200,0.003089; 22960800,0.002381; 22964400,0.00694; 22968000,
        0.012636; 22971600,0.006779; 22975200,0.0034; 22978800,0.005172;
        22982400,0.00094; 22986000,1e-06; 22989600,0.007407; 22993200,0.004734;
        22996800,0.00424; 23000400,0.003169; 23004000,0.006487; 23007600,
        0.009999; 23011200,0.004792; 23014800,0.004691; 23018400,0.006074;
        23022000,0.002915; 23025600,0.002484; 23029200,0.007172; 23032800,
        0.004866; 23036400,0.002985; 23040000,0.003072; 23043600,0.00186;
        23047200,0.001564; 23050800,0.006125; 23054400,0.011865; 23058000,
        0.005966; 23061600,0.00257; 23065200,0.004274; 23068800,0.000847;
        23072400,0.001201; 23076000,0.006623; 23079600,0.004339; 23083200,
        0.004625; 23086800,0.004399; 23090400,0.006594; 23094000,0.009066;
        23097600,0.003677; 23101200,0.002811; 23104800,0.005869; 23108400,
        0.003462; 23112000,0.002512; 23115600,0.007224; 23119200,0.005809;
        23122800,0.003016; 23126400,0.003034; 23130000,0.001872; 23133600,
        0.001567; 23137200,0.005711; 23140800,0.011874; 23144400,0.00679;
        23148000,0.002615; 23151600,0.004432; 23155200,0.000146; 23158800,
        0.001501; 23162400,0.005503; 23166000,0.00335; 23169600,0.003214;
        23173200,0.003418; 23176800,0.007219; 23180400,0.009448; 23184000,
        0.003498; 23187600,0.002804; 23191200,0.005102; 23194800,0.00294;
        23198400,0.002498; 23202000,0.007282; 23205600,0.005735; 23209200,
        0.003013; 23212800,0.00285; 23216400,0.001465; 23220000,0.002354;
        23223600,0.007397; 23227200,0.012617; 23230800,0.006776; 23234400,
        0.002103; 23238000,0.004434; 23241600,0.000839; 23245200,0.000701;
        23248800,0.006324; 23252400,0.003451; 23256000,0.003561; 23259600,
        0.003122; 23263200,0.00678; 23266800,0.010956; 23270400,0.007393;
        23274000,0.005974; 23277600,0.006685; 23281200,0.003826; 23284800,
        0.00291; 23288400,0.007786; 23292000,0.006294; 23295600,0.003795;
        23299200,0.004226; 23302800,0.003092; 23306400,0.002368; 23310000,
        0.007114; 23313600,0.011655; 23317200,0.006688; 23320800,0.002112;
        23324400,0.004436; 23328000,0.000103; 23331600,1e-06; 23335200,0.005288;
        23338800,0.002497; 23342400,0.002208; 23346000,0.002039; 23349600,
        0.006002; 23353200,0.008837; 23356800,0.003504; 23360400,0.001508;
        23364000,0.004809; 23367600,0.003618; 23371200,0.002884; 23374800,
        0.007886; 23378400,0.006426; 23382000,0.003776; 23385600,0.004198;
        23389200,0.003074; 23392800,0.001557; 23396400,0.004957; 23400000,
        0.011778; 23403600,0.006871; 23407200,0.00343; 23410800,0.005056;
        23414400,0.000624; 23418000,1e-06; 23421600,0.004105; 23425200,0.002511;
        23428800,0.002219; 23432400,0.002047; 23436000,0.006021; 23439600,
        0.00885; 23443200,0.00349; 23446800,0.002126; 23450400,0.003733;
        23454000,0.003131; 23457600,0.003204; 23461200,0.007631; 23464800,
        0.006336; 23468400,0.003035; 23472000,0.003859; 23475600,0.003053;
        23479200,0.002375; 23482800,0.006928; 23486400,0.012633; 23490000,
        0.006779; 23493600,0.003412; 23497200,0.003528; 23500800,0.000646;
        23504400,1e-06; 23508000,0.004228; 23511600,0.002513; 23515200,0.002217;
        23518800,0.002045; 23522400,0.006008; 23526000,0.008879; 23529600,
        0.003536; 23533200,0.002836; 23536800,0.0039; 23540400,0.002916;
        23544000,0.002504; 23547600,0.007364; 23551200,0.005674; 23554800,
        0.002989; 23558400,0.003837; 23562000,0.002666; 23565600,0.00235;
        23569200,0.006707; 23572800,0.012571; 23576400,0.00681; 23580000,
        0.003407; 23583600,0.005215; 23587200,0.000784; 23590800,0.000001;
        23594400,0.006316; 23598000,0.003916; 23601600,0.003618; 23605200,
        0.003022; 23608800,0.006524; 23612400,0.009726; 23616000,0.005459;
        23619600,0.004944; 23623200,0.006574; 23626800,0.00365; 23630400,
        0.003059; 23634000,0.008638; 23637600,0.006797; 23641200,0.004035;
        23644800,0.004469; 23648400,0.002663; 23652000,0.002355; 23655600,
        0.005594; 23659200,0.012608; 23662800,0.006774; 23666400,0.003389;
        23670000,0.005637; 23673600,0.001637; 23677200,0.00118; 23680800,
        0.006972; 23684400,0.005028; 23688000,0.005836; 23691600,0.0059;
        23695200,0.004589; 23698800,0.008848; 23702400,0.003489; 23706000,
        0.003176; 23709600,0.005708; 23713200,0.003383; 23716800,0.002493;
        23720400,0.007926; 23724000,0.005426; 23727600,0.002987; 23731200,
        0.004476; 23734800,0.003037; 23738400,0.002369; 23742000,0.005753;
        23745600,0.008695; 23749200,0.006651; 23752800,0.002112; 23756400,
        0.005241; 23760000,0.00095; 23763600,1e-06; 23767200,0.005896; 23770800,
        0.003257; 23774400,0.002724; 23778000,0.002594; 23781600,0.004015;
        23785200,0.008909; 23788800,0.002386; 23792400,0.003129; 23796000,
        0.005276; 23799600,0.002926; 23803200,0.002511; 23806800,0.007219;
        23810400,0.006253; 23814000,0.003006; 23817600,0.003829; 23821200,
        0.003211; 23824800,0.002377; 23828400,0.006935; 23832000,0.007707;
        23835600,0.009582; 23839200,0.002168; 23842800,0.005784; 23846400,
        0.001124; 23850000,0.0000601; 23853600,0.004552; 23857200,0.003821;
        23860800,0.003177; 23864400,0.002043; 23868000,0.004501; 23871600,
        0.004839; 23875200,0.0038; 23878800,0.003262; 23882400,0.007524;
        23886000,0.0047; 23889600,0.003796; 23893200,0.00751; 23896800,0.006586;
        23900400,0.004167; 23904000,0.004745; 23907600,0.00267; 23911200,
        0.002355; 23914800,0.004334; 23918400,0.014209; 23922000,0.005073;
        23925600,0.002615; 23929200,0.004816; 23932800,0.002442; 23936400,
        0.001563; 23940000,0.008154; 23943600,0.008575; 23947200,0.006588;
        23950800,0.003565; 23954400,0.0055; 23958000,0.008925; 23961600,
        0.003961; 23965200,0.004049; 23968800,0.006337; 23972400,0.004095;
        23976000,0.003581; 23979600,0.007744; 23983200,0.007742; 23986800,
        0.00581; 23990400,0.005802; 23994000,0.004219; 23997600,0.003275;
        24001200,0.007395; 24004800,0.009675; 24008400,0.004737; 24012000,
        0.004613; 24015600,0.005234; 24019200,0.000945; 24022800,0.001827;
        24026400,0.004101; 24030000,0.005979; 24033600,0.004933; 24037200,
        0.003606; 24040800,0.006603; 24044400,0.009231; 24048000,0.004;
        24051600,0.004474; 24055200,0.006609; 24058800,0.003715; 24062400,
        0.001495; 24066000,0.007724; 24069600,0.006402; 24073200,0.003389;
        24076800,0.003846; 24080400,0.002689; 24084000,0.002363; 24087600,
        0.006911; 24091200,0.011828; 24094800,0.005156; 24098400,0.003393;
        24102000,0.005559; 24105600,0.001705; 24109200,0.002556; 24112800,
        0.005773; 24116400,0.0041; 24120000,0.003603; 24123600,0.002965;
        24127200,0.005987; 24130800,0.010224; 24134400,0.010971; 24138000,
        0.01121; 24141600,0.011565; 24145200,0.006776; 24148800,0.007705;
        24152400,0.010268; 24156000,0.006715; 24159600,0.006511; 24163200,
        0.004505; 24166800,0.002659; 24170400,0.002347; 24174000,0.004583;
        24177600,0.011887; 24181200,0.006794; 24184800,0.003401; 24188400,
        0.005387; 24192000,0.001407; 24195600,0.001001; 24199200,0.007488;
        24202800,0.008786; 24206400,0.010333; 24210000,0.006282; 24213600,
        0.005823; 24217200,0.010834; 24220800,0.006521; 24224400,0.006652;
        24228000,0.007392; 24231600,0.002945; 24235200,0.002498; 24238800,
        0.008678; 24242400,0.00664; 24246000,0.003033; 24249600,0.00422;
        24253200,0.002683; 24256800,0.002361; 24260400,0.006107; 24264000,
        0.011905; 24267600,0.005997; 24271200,0.002618; 24274800,0.004437;
        24278400,0.000142; 24282000,0.001501; 24285600,0.005844; 24289200,
        0.003508; 24292800,0.003611; 24296400,0.003302; 24300000,0.005583;
        24303600,0.007916; 24307200,0.002667; 24310800,0.00329; 24314400,
        0.004699; 24318000,0.003082; 24321600,0.003274; 24325200,0.007775;
        24328800,0.00546; 24332400,0.00291; 24336000,0.003738; 24339600,
        0.003363; 24343200,0.003138; 24346800,0.006112; 24350400,0.011925;
        24354000,0.005998; 24357600,0.002597; 24361200,0.004421; 24364800,
        0.000534; 24368400,0.003201; 24372000,0.006497; 24375600,0.005402;
        24379200,0.005077; 24382800,0.006584; 24386400,0.004466; 24390000,
        0.00772; 24393600,0.004367; 24397200,0.003227; 24400800,0.005125;
        24404400,0.002922; 24408000,0.003276; 24411600,0.008252; 24415200,
        0.004577; 24418800,0.003028; 24422400,0.003917; 24426000,0.00268;
        24429600,0.002376; 24433200,0.006283; 24436800,0.009958; 24440400,
        0.005688; 24444000,0.00259; 24447600,0.005007; 24451200,0.002305;
        24454800,0.001743; 24458400,0.005596; 24462000,0.00357; 24465600,
        0.003823; 24469200,0.003709; 24472800,0.007002; 24476400,0.010594;
        24480000,0.008127; 24483600,0.008438; 24487200,0.004835; 24490800,
        0.0041; 24494400,0.003591; 24498000,0.007921; 24501600,0.006045;
        24505200,0.004167; 24508800,0.003629; 24512400,0.003084; 24516000,
        0.003051; 24519600,0.0069; 24523200,0.01185; 24526800,0.007148;
        24530400,0.004277; 24534000,0.005927; 24537600,0.002413; 24541200,
        0.004875; 24544800,0.014887; 24548400,0.010224; 24552000,0.003158;
        24555600,0.003164; 24559200,0.006182; 24562800,0.014396; 24566400,
        0.012581; 24570000,0.006649; 24573600,0.006548; 24577200,0.002608;
        24580800,0.003296; 24584400,0.00769; 24588000,0.006944; 24591600,
        0.004619; 24595200,0.004839; 24598800,0.002323; 24602400,0.002362;
        24606000,0.006116; 24609600,0.01183; 24613200,0.00598; 24616800,0.00259;
        24620400,0.004151; 24624000,0.000427; 24627600,0.001501; 24631200,
        0.00531; 24634800,0.003637; 24638400,0.003005; 24642000,0.002504;
        24645600,0.005195; 24649200,0.008052; 24652800,0.00308; 24656400,
        0.004333; 24660000,0.006479; 24663600,0.002744; 24667200,0.00351;
        24670800,0.00932; 24674400,0.007697; 24678000,0.004749; 24681600,
        0.005176; 24685200,0.003619; 24688800,0.002385; 24692400,0.00695;
        24696000,0.011844; 24699600,0.005176; 24703200,0.002571; 24706800,
        0.00428; 24710400,0.000135; 24714000,0.001501; 24717600,0.00665;
        24721200,0.0045; 24724800,0.003976; 24728400,0.00288; 24732000,0.005157;
        24735600,0.009303; 24739200,0.003584; 24742800,0.003293; 24746400,
        0.006562; 24750000,0.003845; 24753600,0.003039; 24757200,0.007918;
        24760800,0.006827; 24764400,0.004424; 24768000,0.005011; 24771600,
        0.003341; 24775200,0.001569; 24778800,0.006126; 24782400,0.011821;
        24786000,0.005969; 24789600,0.002589; 24793200,0.004408; 24796800,
        0.000144; 24800400,0.001501; 24804000,0.004916; 24807600,0.003475;
        24811200,0.003384; 24814800,0.002425; 24818400,0.005207; 24822000,
        0.008053; 24825600,0.003533; 24829200,0.004534; 24832800,0.007279;
        24836400,0.005268; 24840000,0.004302; 24843600,0.009161; 24847200,
        0.007553; 24850800,0.005347; 24854400,0.004968; 24858000,0.003706;
        24861600,0.002374; 24865200,0.00683; 24868800,0.011809; 24872400,
        0.006815; 24876000,0.003412; 24879600,0.005226; 24883200,0.000944;
        24886800,0.00128; 24890400,0.006346; 24894000,0.00439; 24897600,
        0.003449; 24901200,0.002788; 24904800,0.005092; 24908400,0.008663;
        24912000,0.00243; 24915600,0.002831; 24919200,0.005967; 24922800,
        0.002964; 24926400,0.002515; 24930000,0.007219; 24933600,0.00581;
        24937200,0.003008; 24940800,0.003032; 24944400,0.001897; 24948000,
        0.003063; 24951600,0.006903; 24955200,0.011885; 24958800,0.005944;
        24962400,0.002567; 24966000,0.004205; 24969600,0.000743; 24973200,
        0.000301; 24976800,0.005217; 24980400,0.003414; 24984000,0.002965;
        24987600,0.002044; 24991200,0.005208; 24994800,0.00812; 24998400,
        0.002723; 25002000,0.002817; 25005600,0.00472; 25009200,0.003353;
        25012800,0.003195; 25016400,0.007876; 25020000,0.00579; 25023600,
        0.002236; 25027200,0.003061; 25030800,0.003193; 25034400,0.002273;
        25038000,0.006926; 25041600,0.011861; 25045200,0.005818; 25048800,
        0.004095; 25052400,0.006127; 25056000,0.002167; 25059600,0.003372;
        25063200,0.008087; 25066800,0.008601; 25070400,0.007537; 25074000,
        0.00299; 25077600,0.005616; 25081200,0.011002; 25084800,0.011148;
        25088400,0.010095; 25092000,0.006792; 25095600,0.002913; 25099200,
        0.004843; 25102800,0.009642; 25106400,0.007336; 25110000,0.005607;
        25113600,0.00534; 25117200,0.003496; 25120800,0.003159; 25124400,
        0.006195; 25128000,0.011871; 25131600,0.006739; 25135200,0.002612;
        25138800,0.00443; 25142400,0.000145; 25146000,0.000371; 25149600,
        0.004718; 25153200,0.00307; 25156800,0.002634; 25160400,0.002044;
        25164000,0.006014; 25167600,0.008123; 25171200,0.003547; 25174800,
        0.004754; 25178400,0.007035; 25182000,0.004283; 25185600,0.005197;
        25189200,0.009527; 25192800,0.007408; 25196400,0.005154; 25200000,
        0.004708; 25203600,0.003583; 25207200,0.00295; 25210800,0.004929;
        25214400,0.012963; 25218000,0.007471; 25221600,0.00308; 25225200,
        0.004978; 25228800,0.002572; 25232400,0.002451; 25236000,0.005674;
        25239600,0.003844; 25243200,0.003663; 25246800,0.002851; 25250400,
        0.006446; 25254000,0.008897; 25257600,0.003514; 25261200,0.003299;
        25264800,0.006159; 25268400,0.004324; 25272000,0.005722; 25275600,
        0.011497; 25279200,0.006508; 25282800,0.003035; 25286400,0.003461;
        25290000,0.002475; 25293600,0.002604; 25297200,0.006717; 25300800,
        0.009721; 25304400,0.006404; 25308000,0.003985; 25311600,0.005459;
        25315200,0.001609; 25318800,0.002776; 25322400,0.006069; 25326000,
        0.004827; 25329600,0.007543; 25333200,0.005084; 25336800,0.005846;
        25340400,0.011699; 25344000,0.009798; 25347600,0.006865; 25351200,
        0.006983; 25354800,0.002909; 25358400,0.002485; 25362000,0.008072;
        25365600,0.006832; 25369200,0.003411; 25372800,0.004178; 25376400,
        0.003008; 25380000,0.002852; 25383600,0.005209; 25387200,0.010211;
        25390800,0.007423; 25394400,0.004336; 25398000,0.006074; 25401600,
        0.004412; 25405200,0.006649; 25408800,0.012647; 25412400,0.013321;
        25416000,0.012916; 25419600,0.004358; 25423200,0.006991; 25426800,
        0.019477; 25430400,0.014297; 25434000,0.007621; 25437600,0.00764;
        25441200,0.004104; 25444800,0.002513; 25448400,0.009482; 25452000,
        0.008743; 25455600,0.005643; 25459200,0.006181; 25462800,0.004164;
        25466400,0.003588; 25470000,0.005191; 25473600,0.010463; 25477200,
        0.007154; 25480800,0.003958; 25484400,0.005864; 25488000,0.00329;
        25491600,0.007984; 25495200,0.01541; 25498800,0.012173; 25502400,
        0.01104; 25506000,0.007372; 25509600,0.008496; 25513200,0.011905;
        25516800,0.007099; 25520400,0.006611; 25524000,0.00817; 25527600,
        0.004325; 25531200,0.003646; 25534800,0.011036; 25538400,0.008511;
        25542000,0.003622; 25545600,0.006271; 25549200,0.006661; 25552800,
        0.004875; 25556400,0.005173; 25560000,0.010639; 25563600,0.007208;
        25567200,0.003935; 25570800,0.006636; 25574400,0.003483; 25578000,
        0.005106; 25581600,0.010869; 25585200,0.00981; 25588800,0.006204;
        25592400,0.00579; 25596000,0.007049; 25599600,0.010798; 25603200,
        0.005237; 25606800,0.005061; 25610400,0.008061; 25614000,0.004308;
        25617600,0.004324; 25621200,0.013554; 25624800,0.009151; 25628400,
        0.005211; 25632000,0.009196; 25635600,0.008337; 25639200,0.006435;
        25642800,0.00665; 25646400,0.014086; 25650000,0.008435; 25653600,
        0.006379; 25657200,0.008738; 25660800,0.005601; 25664400,0.005103;
        25668000,0.010734; 25671600,0.008548; 25675200,0.007125; 25678800,
        0.004906; 25682400,0.00676; 25686000,0.01323; 25689600,0.015431;
        25693200,0.016437; 25696800,0.011737; 25700400,0.005651; 25704000,
        0.008609; 25707600,0.013123; 25711200,0.00854; 25714800,0.00823;
        25718400,0.006589; 25722000,0.004299; 25725600,0.003182; 25729200,
        0.00694; 25732800,0.009227; 25736400,0.007293; 25740000,0.004055;
        25743600,0.006211; 25747200,0.00393; 25750800,0.006928; 25754400,
        0.011108; 25758000,0.009411; 25761600,0.007856; 25765200,0.004783;
        25768800,0.004697; 25772400,0.012077; 25776000,0.013992; 25779600,
        0.017129; 25783200,0.01885; 25786800,0.006811; 25790400,0.002836;
        25794000,0.009717; 25797600,0.00891; 25801200,0.005067; 25804800,
        0.005855; 25808400,0.004003; 25812000,0.003685; 25815600,0.007686;
        25819200,0.013232; 25822800,0.007248; 25826400,0.003911; 25830000,
        0.006191; 25833600,0.005884; 25837200,0.00865; 25840800,0.010194;
        25844400,0.006808; 25848000,0.007502; 25851600,0.001668; 25855200,
        0.007125; 25858800,0.010868; 25862400,0.012538; 25866000,0.012708;
        25869600,0.010011; 25873200,0.006217; 25876800,0.007668; 25880400,
        0.012278; 25884000,0.01117; 25887600,0.009141; 25891200,0.007126;
        25894800,0.004707; 25898400,0.003155; 25902000,0.006913; 25905600,
        0.01247; 25909200,0.007169; 25912800,0.004113; 25916400,0.005865;
        25920000,0.002369; 25923600,0.003439; 25927200,0.004291; 25930800,
        0.005125; 25934400,0.004717; 25938000,0.003261; 25941600,0.006071;
        25945200,0.011062; 25948800,0.007226; 25952400,0.009241; 25956000,
        0.009221; 25959600,0.004591; 25963200,0.003346; 25966800,0.009997;
        25970400,0.007725; 25974000,0.007268; 25977600,0.008433; 25981200,
        0.004507; 25984800,0.003159; 25988400,0.006456; 25992000,0.01096;
        25995600,0.007148; 25999200,0.005526; 26002800,0.006144; 26006400,
        0.001308; 26010000,0.001801; 26013600,0.008089; 26017200,0.005371;
        26020800,0.006666; 26024400,0.003763; 26028000,0.003701; 26031600,
        0.009272; 26035200,0.008164; 26038800,0.010188; 26042400,0.010258;
        26046000,0.0054; 26049600,0.006217; 26053200,0.011834; 26056800,0.00783;
        26060400,0.006068; 26064000,0.005759; 26067600,0.003916; 26071200,
        0.003346; 26074800,0.005903; 26078400,0.013656; 26082000,0.005825;
        26085600,0.004688; 26089200,0.005928; 26092800,0.003114; 26096400,
        0.005624; 26100000,0.009001; 26103600,0.006009; 26107200,0.007248;
        26110800,0.003686; 26114400,0.004147; 26118000,0.008899; 26121600,
        0.003443; 26125200,0.002419; 26128800,0.00654; 26132400,0.003679;
        26136000,0.002499; 26139600,0.007775; 26143200,0.004436; 26146800,
        0.004635; 26150400,0.006432; 26154000,0.007123; 26157600,0.004869;
        26161200,0.005131; 26164800,0.0128; 26168400,0.008045; 26172000,
        0.005543; 26175600,0.007503; 26179200,0.003171; 26182800,0.005127;
        26186400,0.009158; 26190000,0.008658; 26193600,0.00804; 26197200,
        0.00837; 26200800,0.004447; 26204400,0.005765; 26208000,0.010299;
        26211600,0.004432; 26215200,0.004563; 26218800,0.004726; 26222400,
        0.00385; 26226000,0.003211; 26229600,0.009701; 26233200,0.007176;
        26236800,0.005594; 26240400,0.007621; 26244000,0.006335; 26247600,
        0.005321; 26251200,0.007367; 26254800,0.014485; 26258400,0.010009;
        26262000,0.006657; 26265600,0.00854; 26269200,0.004562; 26272800,
        0.005961; 26276400,0.010858; 26280000,0.006798; 26283600,0.007908;
        26287200,0.00441; 26290800,0.004007; 26294400,0.009471; 26298000,
        0.008135; 26301600,0.012948; 26305200,0.01423; 26308800,0.005768;
        26312400,0.007858; 26316000,0.011526; 26319600,0.010401; 26323200,
        0.010867; 26326800,0.007775; 26330400,0.004794; 26334000,0.003601;
        26337600,0.007505; 26341200,0.012997; 26344800,0.007549; 26348400,
        0.005559; 26352000,0.007615; 26355600,0.002132; 26359200,0.002488;
        26362800,0.005501; 26366400,0.006467; 26370000,0.004958; 26373600,
        0.002933; 26377200,0.004199; 26380800,0.007661; 26384400,0.005226;
        26388000,0.008014; 26391600,0.006025; 26395200,0.005114; 26398800,
        0.003119; 26402400,0.009193; 26406000,0.007499; 26409600,0.003982;
        26413200,0.005171; 26416800,0.003751; 26420400,0.00293; 26424000,
        0.00525; 26427600,0.013189; 26431200,0.006553; 26434800,0.00443;
        26438400,0.006441; 26442000,0.00293; 26445600,0.002905; 26449200,
        0.003488; 26452800,0.00718; 26456400,0.008048; 26460000,0.002683;
        26463600,0.003226; 26467200,0.010787; 26470800,0.003717; 26474400,
        0.004669; 26478000,0.007047; 26481600,0.005694; 26485200,0.004861;
        26488800,0.009626; 26492400,0.008848; 26496000,0.006668; 26499600,
        0.005773; 26503200,0.004279; 26506800,0.002841; 26510400,0.005312;
        26514000,0.012411; 26517600,0.006574; 26521200,0.00406; 26524800,
        0.00641; 26528400,0.001962; 26532000,0.003958; 26535600,0.006838;
        26539200,0.005917; 26542800,0.005636; 26546400,0.004781; 26550000,
        0.00399; 26553600,0.009847; 26557200,0.005579; 26560800,0.008878;
        26564400,0.008682; 26568000,0.003159; 26571600,0.004597; 26575200,
        0.010399; 26578800,0.009589; 26582400,0.007019; 26586000,0.008307;
        26589600,0.003578; 26593200,0.002354; 26596800,0.007091; 26600400,
        0.009949; 26604000,0.007079; 26607600,0.005203; 26611200,0.006086;
        26614800,0.003354; 26618400,0.004239; 26622000,0.007972; 26625600,
        0.005503; 26629200,0.005292; 26632800,0.003366; 26636400,0.006187;
        26640000,0.007105; 26643600,0.006132; 26647200,0.009741; 26650800,
        0.011381; 26654400,0.009787; 26658000,0.00682; 26661600,0.011939;
        26665200,0.012879; 26668800,0.011411; 26672400,0.007189; 26676000,
        0.004955; 26679600,0.003637; 26683200,0.006572; 26686800,0.010332;
        26690400,0.008162; 26694000,0.005562; 26697600,0.006137; 26701200,
        0.002633; 26704800,0.005378; 26708400,0.007846; 26712000,0.009111;
        26715600,0.008728; 26719200,0.005668; 26722800,0.007559; 26726400,
        0.010856; 26730000,0.00439; 26733600,0.00361; 26737200,0.006073;
        26740800,0.003387; 26744400,0.002512; 26748000,0.005794; 26751600,
        0.007005; 26755200,0.004792; 26758800,0.007408; 26762400,0.006862;
        26766000,0.004424; 26769600,0.006886; 26773200,0.009752; 26776800,
        0.007178; 26780400,0.004712; 26784000,0.00767; 26787600,0.005013;
        26791200,0.004116; 26794800,0.00755; 26798400,0.003729; 26802000,
        0.004868; 26805600,0.006929; 26809200,0.004412; 26812800,0.008317;
        26816400,0.004705; 26820000,0.003745; 26823600,0.006951; 26827200,
        0.003822; 26830800,0.003233; 26834400,0.009853; 26838000,0.00751;
        26841600,0.005603; 26845200,0.008022; 26848800,0.008604; 26852400,
        0.004533; 26856000,0.00596; 26859600,0.011973; 26863200,0.00748;
        26866800,0.005345; 26870400,0.008375; 26874000,0.003831; 26877600,
        0.004945; 26881200,0.010731; 26884800,0.009641; 26888400,0.009986;
        26892000,0.00605; 26895600,0.006459; 26899200,0.015832; 26902800,
        0.013605; 26906400,0.011517; 26910000,0.004676; 26913600,0.00425;
        26917200,0.005719; 26920800,0.008539; 26924400,0.007348; 26928000,
        0.00649; 26931600,0.005598; 26935200,0.002972; 26938800,0.002204;
        26942400,0.004241; 26946000,0.011041; 26949600,0.006891; 26953200,
        0.004087; 26956800,0.006267; 26960400,0.005357; 26964000,0.00663;
        26967600,0.010296; 26971200,0.006094; 26974800,0.011633; 26978400,
        0.011406; 26982000,0.006411; 26985600,0.015868; 26989200,0.017227;
        26992800,0.012043; 26996400,0.005479; 27000000,0.003075; 27003600,
        0.005786; 27007200,0.009159; 27010800,0.007893; 27014400,0.00997;
        27018000,0.006442; 27021600,0.004158; 27025200,0.003576; 27028800,
        0.006523; 27032400,0.011719; 27036000,0.007163; 27039600,0.004895;
        27043200,0.00553; 27046800,0.002208; 27050400,0.005478; 27054000,
        0.009524; 27057600,0.00818; 27061200,0.004987; 27064800,0.003505;
        27068400,0.006822; 27072000,0.014355; 27075600,0.016433; 27079200,
        0.015466; 27082800,0.006053; 27086400,0.003517; 27090000,0.00267;
        27093600,0.008543; 27097200,0.007738; 27100800,0.00855; 27104400,
        0.007743; 27108000,0.008881; 27111600,0.005685; 27115200,0.00951;
        27118800,0.017652; 27122400,0.01477; 27126000,0.009524; 27129600,
        0.007466; 27133200,0.010567; 27136800,0.0075; 27140400,0.004864;
        27144000,0.004968; 27147600,0.005439; 27151200,0.004309; 27154800,
        0.00481; 27158400,0.011078; 27162000,0.011887; 27165600,0.010611;
        27169200,0.010242; 27172800,0.004885; 27176400,0.007463; 27180000,
        0.008404; 27183600,0.009163; 27187200,0.005477; 27190800,0.008332;
        27194400,0.004642; 27198000,0.002866; 27201600,0.004486; 27205200,
        0.0126; 27208800,0.008114; 27212400,0.005735; 27216000,0.00601;
        27219600,0.00618; 27223200,0.006073; 27226800,0.007721; 27230400,
        0.00811; 27234000,0.010104; 27237600,0.003215; 27241200,0.004808;
        27244800,0.009958; 27248400,0.006467; 27252000,0.007496; 27255600,
        0.007567; 27259200,0.00589; 27262800,0.005723; 27266400,0.009348;
        27270000,0.009105; 27273600,0.006803; 27277200,0.006257; 27280800,
        0.00422; 27284400,0.003698; 27288000,0.007023; 27291600,0.012297;
        27295200,0.008689; 27298800,0.005075; 27302400,0.006209; 27306000,
        0.003797; 27309600,0.005805; 27313200,0.007786; 27316800,0.009412;
        27320400,0.007347; 27324000,0.005625; 27327600,0.006194; 27331200,
        0.009657; 27334800,0.005689; 27338400,0.004049; 27342000,0.006865;
        27345600,0.003926; 27349200,0.003478; 27352800,0.007423; 27356400,
        0.008651; 27360000,0.00315; 27363600,0.007856; 27367200,0.007203;
        27370800,0.006277; 27374400,0.008237; 27378000,0.012259; 27381600,
        0.008424; 27385200,0.006671; 27388800,0.008706; 27392400,0.005031;
        27396000,0.005077; 27399600,0.009439; 27403200,0.008767; 27406800,
        0.006975; 27410400,0.004578; 27414000,0.005093; 27417600,0.009766;
        27421200,0.005683; 27424800,0.005014; 27428400,0.008387; 27432000,
        0.004451; 27435600,0.005096; 27439200,0.013058; 27442800,0.009476;
        27446400,0.007293; 27450000,0.012475; 27453600,0.011296; 27457200,
        0.007568; 27460800,0.004721; 27464400,0.013627; 27468000,0.007723;
        27471600,0.005977; 27475200,0.009141; 27478800,0.00317; 27482400,
        0.004595; 27486000,0.011666; 27489600,0.007989; 27493200,0.004602;
        27496800,0.004356; 27500400,0.005158; 27504000,0.009527; 27507600,
        0.011212; 27511200,0.013765; 27514800,0.015902; 27518400,0.007911;
        27522000,0.009789; 27525600,0.014181; 27529200,0.01088; 27532800,
        0.012329; 27536400,0.013508; 27540000,0.006294; 27543600,0.003064;
        27547200,0.006924; 27550800,0.011598; 27554400,0.009521; 27558000,
        0.011566; 27561600,0.013787; 27565200,0.015212; 27568800,0.015052;
        27572400,0.020038; 27576000,0.015927; 27579600,0.018815; 27583200,
        0.013538; 27586800,0.007323; 27590400,0.026596; 27594000,0.030627;
        27597600,0.026038; 27601200,0.011673; 27604800,0.005684; 27608400,
        0.005868; 27612000,0.008688; 27615600,0.009347; 27619200,0.013889;
        27622800,0.013222; 27626400,0.013204; 27630000,0.010728; 27633600,
        0.014034; 27637200,0.023755; 27640800,0.023666; 27644400,0.016599;
        27648000,0.004523; 27651600,0.021029; 27655200,0.030327; 27658800,
        0.019485; 27662400,0.013291; 27666000,0.014935; 27669600,0.005245;
        27673200,0.00499; 27676800,0.018437; 27680400,0.024128; 27684000,
        0.030164; 27687600,0.026312; 27691200,0.009634; 27694800,0.014085;
        27698400,0.023377; 27702000,0.020658; 27705600,0.020923; 27709200,
        0.021073; 27712800,0.006646; 27716400,0.005462; 27720000,0.0081;
        27723600,0.011862; 27727200,0.009493; 27730800,0.009136; 27734400,
        0.009296; 27738000,0.010449; 27741600,0.011522; 27745200,0.015807;
        27748800,0.017357; 27752400,0.009911; 27756000,0.004219; 27759600,
        0.006822; 27763200,0.014316; 27766800,0.021809; 27770400,0.024862;
        27774000,0.01455; 27777600,0.007813; 27781200,0.009772; 27784800,
        0.009997; 27788400,0.017799; 27792000,0.015443; 27795600,0.018549;
        27799200,0.011841; 27802800,0.004394; 27806400,0.008764; 27810000,
        0.014985; 27813600,0.013288; 27817200,0.015735; 27820800,0.018536;
        27824400,0.022682; 27828000,0.018914; 27831600,0.014849; 27835200,
        0.012921; 27838800,0.016692; 27842400,0.014959; 27846000,0.009155;
        27849600,0.021289; 27853200,0.024728; 27856800,0.021736; 27860400,
        0.007507; 27864000,0.006697; 27867600,0.006563; 27871200,0.008801;
        27874800,0.007988; 27878400,0.008123; 27882000,0.007576; 27885600,
        0.004829; 27889200,0.00466; 27892800,0.005513; 27896400,0.012461;
        27900000,0.010523; 27903600,0.008033; 27907200,0.008762; 27910800,
        0.012994; 27914400,0.012057; 27918000,0.02385; 27921600,0.026431;
        27925200,0.012072; 27928800,0.014212; 27932400,0.025886; 27936000,
        0.029172; 27939600,0.022537; 27943200,0.017884; 27946800,0.00875;
        27950400,0.003784; 27954000,0.007552; 27957600,0.016061; 27961200,
        0.010207; 27964800,0.013954; 27968400,0.024037; 27972000,0.037668;
        27975600,0.034067; 27979200,0.025102; 27982800,0.021035; 27986400,
        0.026455; 27990000,0.031521; 27993600,0.03161; 27997200,0.019683;
        28000800,0.022084; 28004400,0.032195; 28008000,0.02359; 28011600,
        0.022195; 28015200,0.022662; 28018800,0.017259; 28022400,0.029006;
        28026000,0.020544; 28029600,0.013641; 28033200,0.007858; 28036800,
        0.000834; 28040400,0.004301; 28044000,0.005539; 28047600,0.00547;
        28051200,0.004612; 28054800,0.005501; 28058400,0.004417; 28062000,
        0.003977; 28065600,0.007235; 28069200,0.010945; 28072800,0.006082;
        28076400,0.005366; 28080000,0.005259; 28083600,0.001501; 28087200,
        0.001501; 28090800,0.005851; 28094400,0.003069; 28098000,0.003625;
        28101600,0.001442; 28105200,0.004784; 28108800,0.008766; 28112400,
        0.006232; 28116000,0.005744; 28119600,0.004394; 28123200,0.005041;
        28126800,0.005734; 28130400,0.006825; 28134000,0.007676; 28137600,
        0.008154; 28141200,0.006036; 28144800,0.002839; 28148400,0.004081;
        28152000,0.006039; 28155600,0.011429; 28159200,0.006171; 28162800,
        0.004754; 28166400,0.005595; 28170000,0.003426; 28173600,0.003522;
        28177200,0.005182; 28180800,0.003941; 28184400,0.004997; 28188000,
        0.002875; 28191600,0.004295; 28195200,0.00797; 28198800,0.005821;
        28202400,0.006797; 28206000,0.008716; 28209600,0.002869; 28213200,
        0.004352; 28216800,0.008413; 28220400,0.007295; 28224000,0.010572;
        28227600,0.004638; 28231200,0.005152; 28234800,0.004145; 28238400,
        0.005777; 28242000,0.011808; 28245600,0.007482; 28249200,0.004854;
        28252800,0.006561; 28256400,0.002511; 28260000,0.003769; 28263600,
        0.007003; 28267200,0.006692; 28270800,0.008229; 28274400,0.003867;
        28278000,0.005784; 28281600,0.008946; 28285200,0.007752; 28288800,
        0.005814; 28292400,0.006995; 28296000,0.004817; 28299600,0.007133;
        28303200,0.009384; 28306800,0.007239; 28310400,0.009874; 28314000,
        0.006362; 28317600,0.002889; 28321200,0.00396; 28324800,0.00611;
        28328400,0.011529; 28332000,0.005588; 28335600,0.004611; 28339200,
        0.004931; 28342800,0.003752; 28346400,0.002855; 28350000,0.006997;
        28353600,0.006202; 28357200,0.005909; 28360800,0.003391; 28364400,
        0.004297; 28368000,0.007693; 28371600,0.00513; 28375200,0.007241;
        28378800,0.008822; 28382400,0.006168; 28386000,0.005905; 28389600,
        0.011031; 28393200,0.009501; 28396800,0.009512; 28400400,0.006526;
        28404000,0.004056; 28407600,0.004075; 28411200,0.006055; 28414800,
        0.01093; 28418400,0.006079; 28422000,0.005819; 28425600,0.005539;
        28429200,0.003508; 28432800,0.004557; 28436400,0.007572; 28440000,
        0.004461; 28443600,0.005065; 28447200,0.003576; 28450800,0.004329;
        28454400,0.007854; 28458000,0.007091; 28461600,0.012419; 28465200,
        0.012079; 28468800,0.007317; 28472400,0.006136; 28476000,0.011118;
        28479600,0.010786; 28483200,0.010616; 28486800,0.007866; 28490400,
        0.004039; 28494000,0.003825; 28497600,0.006382; 28501200,0.011321;
        28504800,0.00549; 28508400,0.003477; 28512000,0.006493; 28515600,
        0.00522; 28519200,0.005296; 28522800,0.007013; 28526400,0.00425;
        28530000,0.00551; 28533600,0.006375; 28537200,0.005755; 28540800,
        0.007837; 28544400,0.003508; 28548000,0.00345; 28551600,0.005688;
        28555200,0.004568; 28558800,0.002367; 28562400,0.008249; 28566000,
        0.006791; 28569600,0.004914; 28573200,0.005124; 28576800,0.006246;
        28580400,0.003453; 28584000,0.005828; 28587600,0.012425; 28591200,
        0.008026; 28594800,0.005096; 28598400,0.006837; 28602000,0.004186;
        28605600,0.003264; 28609200,0.006868; 28612800,0.004979; 28616400,
        0.006062; 28620000,0.006313; 28623600,0.006233; 28627200,0.010104;
        28630800,0.004619; 28634400,0.003407; 28638000,0.005426; 28641600,
        0.004508; 28645200,0.001907; 28648800,0.008962; 28652400,0.006106;
        28656000,0.005222; 28659600,0.008676; 28663200,0.005855; 28666800,
        0.001802; 28670400,0.007843; 28674000,0.011501; 28677600,0.005541;
        28681200,0.005808; 28684800,0.006158; 28688400,0.003094; 28692000,
        0.002273; 28695600,0.007678; 28699200,0.008713; 28702800,0.004211;
        28706400,0.00316; 28710000,0.004182; 28713600,0.008362; 28717200,
        0.009366; 28720800,0.013238; 28724400,0.011817; 28728000,0.009072;
        28731600,0.005333; 28735200,0.009392; 28738800,0.010401; 28742400,
        0.011279; 28746000,0.012476; 28749600,0.00903; 28753200,0.004453;
        28756800,0.007493; 28760400,0.011882; 28764000,0.00849; 28767600,
        0.007255; 28771200,0.006385; 28774800,0.006876; 28778400,0.007238;
        28782000,0.008452; 28785600,0.007129; 28789200,0.008558; 28792800,
        0.00331; 28796400,0.005762; 28800000,0.00988; 28803600,0.0107; 28807200,
        0.011458; 28810800,0.007214; 28814400,0.004775; 28818000,0.006022;
        28821600,0.006982; 28825200,0.008873; 28828800,0.010921; 28832400,
        0.005973; 28836000,0.003183; 28839600,0.003618; 28843200,0.004456;
        28846800,0.011793; 28850400,0.005555; 28854000,0.005712; 28857600,
        0.007652; 28861200,0.003015; 28864800,0.005125; 28868400,0.008138;
        28872000,0.006879; 28875600,0.008296; 28879200,0.002976; 28882800,
        0.006343; 28886400,0.009036; 28890000,0.009146; 28893600,0.012319;
        28897200,0.012695; 28900800,0.007687; 28904400,0.011563; 28908000,
        0.013769; 28911600,0.008922; 28915200,0.010846; 28918800,0.010764;
        28922400,0.003971; 28926000,0.003222; 28929600,0.006609; 28933200,
        0.011694; 28936800,0.005927; 28940400,0.005532; 28944000,0.005853;
        28947600,0.006046; 28951200,0.00619; 28954800,0.008316; 28958400,
        0.006968; 28962000,0.009725; 28965600,0.004354; 28969200,0.006321;
        28972800,0.010367; 28976400,0.010059; 28980000,0.013732; 28983600,
        0.010477; 28987200,0.007993; 28990800,0.008026; 28994400,0.009773;
        28998000,0.011329; 29001600,0.013269; 29005200,0.011331; 29008800,
        0.003127; 29012400,0.004022; 29016000,0.005894; 29019600,0.011038;
        29023200,0.006724; 29026800,0.004372; 29030400,0.00491; 29034000,
        0.004186; 29037600,0.004886; 29041200,0.006525; 29044800,0.005684;
        29048400,0.008025; 29052000,0.003693; 29055600,0.005211; 29059200,
        0.007904; 29062800,0.008898; 29066400,0.011294; 29070000,0.011951;
        29073600,0.008368; 29077200,0.005082; 29080800,0.014188; 29084400,
        0.01381; 29088000,0.013613; 29091600,0.009577; 29095200,0.00434;
        29098800,0.004216; 29102400,0.007346; 29106000,0.012241; 29109600,
        0.008168; 29113200,0.006959; 29116800,0.008387; 29120400,0.008158;
        29124000,0.013418; 29127600,0.019643; 29131200,0.010519; 29134800,
        0.012786; 29138400,0.011655; 29142000,0.004251; 29145600,0.010293;
        29149200,0.010339; 29152800,0.012752; 29156400,0.013259; 29160000,
        0.00525; 29163600,0.007068; 29167200,0.015346; 29170800,0.012722;
        29174400,0.015941; 29178000,0.028032; 29181600,0.025214; 29185200,
        0.015784; 29188800,0.015336; 29192400,0.014784; 29196000,0.012084;
        29199600,0.012602; 29203200,0.013743; 29206800,0.009352; 29210400,
        0.009617; 29214000,0.014152; 29217600,0.010138; 29221200,0.006832;
        29224800,0.003828; 29228400,0.005037; 29232000,0.007644; 29235600,
        0.003102; 29239200,0.002921; 29242800,0.004594; 29246400,0.003865;
        29250000,0.003001; 29253600,0.005203; 29257200,0.006697; 29260800,
        0.004154; 29264400,0.005741; 29268000,0.00361; 29271600,0.001217;
        29275200,0.00741; 29278800,0.011169; 29282400,0.005644; 29286000,
        0.004492; 29289600,0.006783; 29293200,0.001619; 29296800,0.000794;
        29300400,0.006362; 29304000,0.003184; 29307600,0.004074; 29311200,
        0.002318; 29314800,0.004987; 29318400,0.00831; 29322000,0.006209;
        29325600,0.005896; 29329200,0.007909; 29332800,0.007004; 29336400,
        0.00736; 29340000,0.009131; 29343600,0.00996; 29347200,0.011115;
        29350800,0.009008; 29354400,0.004371; 29358000,0.004142; 29361600,
        0.004903; 29365200,0.011616; 29368800,0.006576; 29372400,0.004359;
        29376000,0.00718; 29379600,0.004229; 29383200,0.001805; 29386800,
        0.00803; 29390400,0.007479; 29394000,0.005325; 29397600,0.003771;
        29401200,0.004314; 29404800,0.008308; 29408400,0.008528; 29412000,
        0.009067; 29415600,0.00898; 29419200,0.008217; 29422800,0.006968;
        29426400,0.011444; 29430000,0.01497; 29433600,0.011526; 29437200,
        0.006815; 29440800,0.004441; 29444400,0.003832; 29448000,0.005271;
        29451600,0.01133; 29455200,0.006644; 29458800,0.004436; 29462400,
        0.00648; 29466000,0.004685; 29469600,0.005822; 29473200,0.00824;
        29476800,0.004758; 29480400,0.007257; 29484000,0.003539; 29487600,
        0.006123; 29491200,0.009904; 29494800,0.007601; 29498400,0.011793;
        29502000,0.01247; 29505600,0.00515; 29509200,0.006703; 29512800,
        0.009072; 29516400,0.010631; 29520000,0.014084; 29523600,0.011037;
        29527200,0.005516; 29530800,0.004372; 29534400,0.003569; 29538000,
        0.012438; 29541600,0.008896; 29545200,0.007763; 29548800,0.009199;
        29552400,0.010138; 29556000,0.010394; 29559600,0.006953; 29563200,
        0.006587; 29566800,0.008441; 29570400,0.003146; 29574000,0.006147;
        29577600,0.011119; 29581200,0.010858; 29584800,0.016445; 29588400,
        0.018945; 29592000,0.010591; 29595600,0.010429; 29599200,0.013345;
        29602800,0.010388; 29606400,0.013816; 29610000,0.009743; 29613600,
        0.003992; 29617200,0.002835; 29620800,0.005738; 29624400,0.012324;
        29628000,0.006862; 29631600,0.004417; 29635200,0.006114; 29638800,
        0.003643; 29642400,0.005849; 29646000,0.006637; 29649600,0.006525;
        29653200,0.006945; 29656800,0.003042; 29660400,0.005563; 29664000,
        0.00877; 29667600,0.009912; 29671200,0.013165; 29674800,0.015609;
        29678400,0.006962; 29682000,0.008802; 29685600,0.015279; 29689200,
        0.011687; 29692800,0.011866; 29696400,0.010587; 29700000,0.004131;
        29703600,0.003639; 29707200,0.00386; 29710800,0.012161; 29714400,
        0.006243; 29718000,0.00508; 29721600,0.0064; 29725200,0.006925;
        29728800,0.006751; 29732400,0.008125; 29736000,0.008899; 29739600,
        0.011734; 29743200,0.007673; 29746800,0.009091; 29750400,0.015988;
        29754000,0.008891; 29757600,0.003503; 29761200,0.00939; 29764800,
        0.004629; 29768400,0.005346; 29772000,0.014399; 29775600,0.00949;
        29779200,0.008281; 29782800,0.011296; 29786400,0.012918; 29790000,
        0.008363; 29793600,0.016244; 29797200,0.012953; 29800800,0.009012;
        29804400,0.014146; 29808000,0.014133; 29811600,0.011873; 29815200,
        0.019529; 29818800,0.018639; 29822400,0.013328; 29826000,0.018587;
        29829600,0.023494; 29833200,0.014325; 29836800,0.021108; 29840400,
        0.021249; 29844000,0.017689; 29847600,0.011784; 29851200,0.006366;
        29854800,0.009878; 29858400,0.014998; 29862000,0.014416; 29865600,
        0.022723; 29869200,0.02854; 29872800,0.030025; 29876400,0.015529;
        29880000,0.00991; 29883600,0.020195; 29887200,0.016039; 29890800,
        0.015215; 29894400,0.025719; 29898000,0.011928; 29901600,0.005936;
        29905200,0.025007; 29908800,0.019218; 29912400,0.00557; 29916000,
        0.009384; 29919600,0.008606; 29923200,0.01705; 29926800,0.026876;
        29930400,0.03426; 29934000,0.026154; 29937600,0.01668; 29941200,
        0.015377; 29944800,0.022164; 29948400,0.023851; 29952000,0.024245;
        29955600,0.020195; 29959200,0.011161; 29962800,0.006564; 29966400,
        0.008584; 29970000,0.016499; 29973600,0.015395; 29977200,0.014475;
        29980800,0.018415; 29984400,0.01956; 29988000,0.015079; 29991600,
        0.020837; 29995200,0.020316; 29998800,0.015182; 30002400,0.013425;
        30006000,0.008795; 30009600,0.021263; 30013200,0.02845; 30016800,
        0.038289; 30020400,0.020137; 30024000,0.009535; 30027600,0.013157;
        30031200,0.016444; 30034800,0.019709; 30038400,0.024342; 30042000,
        0.017521; 30045600,0.0079; 30049200,0.008065; 30052800,0.014379;
        30056400,0.023259; 30060000,0.020031; 30063600,0.014269; 30067200,
        0.019378; 30070800,0.022739; 30074400,0.021619; 30078000,0.014038;
        30081600,0.012736; 30085200,0.013173; 30088800,0.008688; 30092400,
        0.008956; 30096000,0.01912; 30099600,0.024745; 30103200,0.027014;
        30106800,0.015411; 30110400,0.012273; 30114000,0.011383; 30117600,
        0.014324; 30121200,0.01724; 30124800,0.024715; 30128400,0.025587;
        30132000,0.014812; 30135600,0.009579; 30139200,0.009523; 30142800,
        0.018942; 30146400,0.022093; 30150000,0.021638; 30153600,0.01186;
        30157200,0.018433; 30160800,0.023645; 30164400,0.018879; 30168000,
        0.018361; 30171600,0.020951; 30175200,0.011514; 30178800,0.014119;
        30182400,0.030895; 30186000,0.036135; 30189600,0.033225; 30193200,
        0.024676; 30196800,0.020521; 30200400,0.021668; 30204000,0.022111;
        30207600,0.028106; 30211200,0.027694; 30214800,0.016478; 30218400,
        0.008184; 30222000,0.008198; 30225600,0.006573; 30229200,0.015781;
        30232800,0.013122; 30236400,0.011688; 30240000,0.011806; 30243600,
        0.015074; 30247200,0.019512; 30250800,0.029339; 30254400,0.021858;
        30258000,0.009106; 30261600,0.006238; 30265200,0.006836; 30268800,
        0.014606; 30272400,0.02414; 30276000,0.027575; 30279600,0.013183;
        30283200,0.013277; 30286800,0.010548; 30290400,0.009097; 30294000,
        0.015124; 30297600,0.022919; 30301200,0.024157; 30304800,0.014439;
        30308400,0.007588; 30312000,0.008914; 30315600,0.019458; 30319200,
        0.015814; 30322800,0.009163; 30326400,0.012099; 30330000,0.02023;
        30333600,0.016568; 30337200,0.025764; 30340800,0.024029; 30344400,
        0.012856; 30348000,0.024124; 30351600,0.019904; 30355200,0.016453;
        30358800,0.022497; 30362400,0.024215; 30366000,0.015411; 30369600,
        0.00811; 30373200,0.015006; 30376800,0.022264; 30380400,0.025572;
        30384000,0.02521; 30387600,0.026883; 30391200,0.029687; 30394800,
        0.018526; 30398400,0.008898; 30402000,0.017365; 30405600,0.018854;
        30409200,0.020414; 30412800,0.02782; 30416400,0.020158; 30420000,
        0.011656; 30423600,0.025743; 30427200,0.023698; 30430800,0.015008;
        30434400,0.022293; 30438000,0.022311; 30441600,0.026405; 30445200,
        0.027294; 30448800,0.026783; 30452400,0.019114; 30456000,0.013131;
        30459600,0.015506; 30463200,0.018179; 30466800,0.014066; 30470400,
        0.024722; 30474000,0.037267; 30477600,0.035635; 30481200,0.019841;
        30484800,0.016736; 30488400,0.018114; 30492000,0.023689; 30495600,
        0.028105; 30499200,0.026524; 30502800,0.019985; 30506400,0.025976;
        30510000,0.031441; 30513600,0.023861; 30517200,0.025894; 30520800,0.015;
        30524400,0.013583; 30528000,0.032708; 30531600,0.035474; 30535200,
        0.033733; 30538800,0.026253; 30542400,0.008639; 30546000,0.010343;
        30549600,0.013937; 30553200,0.016292; 30556800,0.022308; 30560400,
        0.021406; 30564000,0.01937; 30567600,0.008704; 30571200,0.008313;
        30574800,0.01592; 30578400,0.017758; 30582000,0.018156; 30585600,
        0.016035; 30589200,0.022247; 30592800,0.024921; 30596400,0.026851;
        30600000,0.023819; 30603600,0.023084; 30607200,0.007822; 30610800,
        0.007185; 30614400,0.024156; 30618000,0.027716; 30621600,0.04024;
        30625200,0.032444; 30628800,0.012957; 30632400,0.016069; 30636000,
        0.021478; 30639600,0.021491; 30643200,0.035641; 30646800,0.033002;
        30650400,0.019576; 30654000,0.008008; 30657600,0.012935; 30661200,
        0.026213; 30664800,0.025579; 30668400,0.018395; 30672000,0.019567;
        30675600,0.018484; 30679200,0.014809; 30682800,0.026289; 30686400,
        0.022627; 30690000,0.009936; 30693600,0.010616; 30697200,0.011233;
        30700800,0.020667; 30704400,0.025615; 30708000,0.030445; 30711600,
        0.0321; 30715200,0.018706; 30718800,0.019928; 30722400,0.019894;
        30726000,0.020683; 30729600,0.01875; 30733200,0.016852; 30736800,
        0.008017; 30740400,0.003646; 30744000,0.007878; 30747600,0.013754;
        30751200,0.008261; 30754800,0.006563; 30758400,0.008982; 30762000,
        0.009046; 30765600,0.008405; 30769200,0.012857; 30772800,0.011244;
        30776400,0.009885; 30780000,0.006522; 30783600,0.005301; 30787200,
        0.012977; 30790800,0.019367; 30794400,0.027464; 30798000,0.024751;
        30801600,0.01717; 30805200,0.018174; 30808800,0.023057; 30812400,
        0.023961; 30816000,0.022715; 30819600,0.018609; 30823200,0.007054;
        30826800,0.006898; 30830400,0.007782; 30834000,0.016759; 30837600,
        0.016519; 30841200,0.013587; 30844800,0.015496; 30848400,0.018872;
        30852000,0.015291; 30855600,0.020082; 30859200,0.016846; 30862800,
        0.007801; 30866400,0.007391; 30870000,0.005662; 30873600,0.010107;
        30877200,0.010539; 30880800,0.007213; 30884400,0.006966; 30888000,
        0.00705; 30891600,0.004711; 30895200,0.011205; 30898800,0.010686;
        30902400,0.010845; 30906000,0.006173; 30909600,0.003039; 30913200,
        0.003214; 30916800,0.006746; 30920400,0.01099; 30924000,0.005679;
        30927600,0.004049; 30931200,0.004868; 30934800,0.002769; 30938400,
        0.005286; 30942000,0.006707; 30945600,0.009031; 30949200,0.008095;
        30952800,0.006776; 30956400,0.005652; 30960000,0.010598; 30963600,
        0.007721; 30967200,0.007408; 30970800,0.009459; 30974400,0.006425;
        30978000,0.009185; 30981600,0.0153; 30985200,0.013392; 30988800,
        0.009565; 30992400,0.015995; 30996000,0.014005; 30999600,0.005996;
        31003200,0.00714; 31006800,0.012421; 31010400,0.006628; 31014000,
        0.006235; 31017600,0.009059; 31021200,0.004055; 31024800,0.006145;
        31028400,0.01057; 31032000,0.008107; 31035600,0.00754; 31039200,
        0.005309; 31042800,0.008704; 31046400,0.016347; 31050000,0.006492;
        31053600,0.003176; 31057200,0.006813; 31060800,0.005521; 31064400,
        0.005738; 31068000,0.00992; 31071600,0.007668; 31075200,0.008028;
        31078800,0.010988; 31082400,0.008645; 31086000,0.007788; 31089600,
        0.009436; 31093200,0.012379; 31096800,0.007343; 31100400,0.007935;
        31104000,0.007899; 31107600,0.002767; 31111200,0.005092; 31114800,
        0.008598; 31118400,0.006013; 31122000,0.0048; 31125600,0.006572;
        31129200,0.004911; 31132800,0.009128; 31136400,0.011113; 31140000,
        0.015656; 31143600,0.01881; 31147200,0.007849; 31150800,0.007295;
        31154400,0.014285; 31158000,0.012827; 31161600,0.007605; 31165200,
        0.006856; 31168800,0.003519; 31172400,0.003074; 31176000,0.006677;
        31179600,0.011806; 31183200,0.005994; 31186800,0.002982; 31190400,
        0.006828; 31194000,0.004077; 31197600,0.004631; 31201200,0.009301;
        31204800,0.009739; 31208400,0.005133; 31212000,0.005462; 31215600,
        0.005125; 31219200,0.009615; 31222800,0.009181; 31226400,0.017693;
        31230000,0.01411; 31233600,0.00948; 31237200,0.008516; 31240800,
        0.013005; 31244400,0.011439; 31248000,0.014213; 31251600,0.009712;
        31255200,0.004338; 31258800,0.004117; 31262400,0.006319; 31266000,
        0.012162; 31269600,0.008; 31273200,0.004722; 31276800,0.006258;
        31280400,0.004399; 31284000,0.003975; 31287600,0.008761; 31291200,
        0.008468; 31294800,0.00719; 31298400,0.004267; 31302000,0.005274;
        31305600,0.008816; 31309200,0.006066; 31312800,0.009593; 31316400,
        0.009855; 31320000,0.011112; 31323600,0.010366; 31327200,0.012477;
        31330800,0.009887; 31334400,0.010322; 31338000,0.006554; 31341600,
        0.004636; 31345200,0.00258; 31348800,0.006729; 31352400,0.012638;
        31356000,0.007208; 31359600,0.006307; 31363200,0.006835; 31366800,
        0.006323; 31370400,0.005792; 31374000,0.009266; 31377600,0.008938;
        31381200,0.008306; 31384800,0.003837; 31388400,0.005622; 31392000,
        0.011707; 31395600,0.010363; 31399200,0.016806; 31402800,0.021129;
        31406400,0.003246; 31410000,0.005449; 31413600,0.01189; 31417200,
        0.009186; 31420800,0.010183; 31424400,0.010228; 31428000,0.004236;
        31431600,0.003415; 31435200,0.006973; 31438800,0.012456; 31442400,
        0.008143; 31446000,0.007071; 31449600,0.006696; 31453200,0.004162;
        31456800,0.008026; 31460400,0.008125; 31464000,0.006757; 31467600,
        0.008742; 31471200,0.002573; 31474800,0.00538; 31478400,0.010784;
        31482000,0.011458; 31485600,0.023366; 31489200,0.01554; 31492800,
        0.003792; 31496400,0.005019; 31500000,0.009923; 31503600,0.009034;
        31507200,0.013903; 31510800,0.017452; 31514400,0.009991; 31518000,
        0.006733; 31521600,0.010446; 31525200,0.019261; 31528800,0.016423;
        31532400,0.016873; 31536000,0.017709])
    annotation (Placement(transformation(extent={{172,-6},{150,16}})));
  Modelica.Blocks.Sources.CombiTimeTable
    combiTimeTable_Bottom_source_water_pump(table=[0,0.5; 3600,0.5; 7200,0.5;
        10800,0.5; 14400,0.5; 18000,0.5; 21600,0.5; 25200,0.5; 28800,0.5; 32400,
        0.5; 36000,0.5; 39600,0.5; 43200,0.5; 46800,0.5; 50400,0.5; 54000,0.5;
        57600,0.5; 61200,0.5; 64800,0.5; 68400,0.5; 72000,0.5; 75600,0.5; 79200,
        0.5; 82800,0.5; 86400,0.5; 90000,0.5; 93600,0.5; 97200,0.5; 100800,0.5;
        104400,0.5; 108000,0.5; 111600,0.5; 115200,0.5; 118800,0.5; 122400,0.5;
        126000,0.5; 129600,0.5; 133200,0.5; 136800,0.5; 140400,0.5; 144000,0.5;
        147600,0.5; 151200,0.5; 154800,0.5; 158400,0.5; 162000,0.5; 165600,0.5;
        169200,0.5; 172800,0.5; 176400,0.5; 180000,0.5; 183600,0.5; 187200,0.5;
        190800,0.5; 194400,0.5; 198000,0.5; 201600,0.5; 205200,0.5; 208800,0.5;
        212400,0.5; 216000,0.5; 219600,0.5; 223200,0.5; 226800,0.5; 230400,0.5;
        234000,0.5; 237600,0.5; 241200,0.5; 244800,0.5; 248400,0.5; 252000,0.5;
        255600,0.5; 259200,0.5; 262800,0.5; 266400,0.5; 270000,0.5; 273600,0.5;
        277200,0.5; 280800,0.5; 284400,0.5; 288000,0.5; 291600,0.5; 295200,0.5;
        298800,0.5; 302400,0.5; 306000,0.5; 309600,0.5; 313200,0.5; 316800,0.5;
        320400,0.5; 324000,0.5; 327600,0.5; 331200,0.5; 334800,0.5; 338400,0.5;
        342000,0.5; 345600,0.5; 349200,0.5; 352800,0.5; 356400,0.5; 360000,0.5;
        363600,0.5; 367200,0.5; 370800,0.5; 374400,0.5; 378000,0.5; 381600,0.5;
        385200,0.5; 388800,0.5; 392400,0.5; 396000,0.5; 399600,0.5; 403200,0.5;
        406800,0.5; 410400,0.5; 414000,0.5; 417600,0.5; 421200,0.5; 424800,0.5;
        428400,0.5; 432000,0.5; 435600,0.5; 439200,0.5; 442800,0.5; 446400,0.5;
        450000,0.5; 453600,0.5; 457200,0.5; 460800,0.5; 464400,0.5; 468000,0.5;
        471600,0.5; 475200,0.5; 478800,0.5; 482400,0.5; 486000,0.5; 489600,0.5;
        493200,0.5; 496800,0.5; 500400,0.5; 504000,0.5; 507600,0.5; 511200,0.5;
        514800,0.5; 518400,0.5; 522000,0.5; 525600,0.5; 529200,0.5; 532800,0.5;
        536400,0.5; 540000,0.5; 543600,0.5; 547200,0.5; 550800,0.5; 554400,0.5;
        558000,0.5; 561600,0.5; 565200,0.5; 568800,0.5; 572400,0.5; 576000,0.5;
        579600,0.5; 583200,0.5; 586800,0.5; 590400,0.5; 594000,0.5; 597600,0.5;
        601200,0.5; 604800,0.5; 608400,0.5; 612000,0.5; 615600,0.5; 619200,0.5;
        622800,0.5; 626400,0.5; 630000,0.5; 633600,0.5; 637200,0.5; 640800,0.5;
        644400,0.5; 648000,0.5; 651600,0.5; 655200,0.5; 658800,0.5; 662400,0.5;
        666000,0.5; 669600,0.5; 673200,0.5; 676800,0.5; 680400,0.5; 684000,0.5;
        687600,0.5; 691200,0.5; 694800,0.5; 698400,0.5; 702000,0.5; 705600,0.5;
        709200,0.5; 712800,0.5; 716400,0.5; 720000,0.5; 723600,0.5; 727200,0.5;
        730800,0.5; 734400,0.5; 738000,0.5; 741600,0.5; 745200,0.5; 748800,0.5;
        752400,0.5; 756000,0.5; 759600,0.5; 763200,0.5; 766800,0.5; 770400,0.5;
        774000,0.5; 777600,0.5; 781200,0.5; 784800,0.5; 788400,0.5; 792000,0.5;
        795600,0.5; 799200,0.5; 802800,0.5; 806400,0.5; 810000,0.5; 813600,0.5;
        817200,0.5; 820800,0.5; 824400,0.5; 828000,0.5; 831600,0.5; 835200,0.5;
        838800,0.5; 842400,0.5; 846000,0.5; 849600,0.5; 853200,0.5; 856800,0.5;
        860400,0.5; 864000,0.5; 867600,0.5; 871200,0.5; 874800,0.5; 878400,0.5;
        882000,0.5; 885600,0.5; 889200,0.5; 892800,0.5; 896400,0.5; 900000,0.5;
        903600,0.5; 907200,0.5; 910800,0.5; 914400,0.5; 918000,0.5; 921600,0.5;
        925200,0.5; 928800,0.5; 932400,0.5; 936000,0.5; 939600,0.5; 943200,0.5;
        946800,0.5; 950400,0.5; 954000,0.5; 957600,0.5; 961200,0.5; 964800,0.5;
        968400,0.5; 972000,0.5; 975600,0.5; 979200,0.5; 982800,0.5; 986400,0.5;
        990000,0.5; 993600,0.5; 997200,0.5; 1000800,0.5; 1004400,0.5; 1008000,
        0.5; 1011600,0.5; 1015200,0.5; 1018800,0.5; 1022400,0.5; 1026000,0.5;
        1029600,0.5; 1033200,0.5; 1036800,0.5; 1040400,0.5; 1044000,0.5;
        1047600,0.5; 1051200,0.5; 1054800,0.5; 1058400,0.5; 1062000,0.5;
        1065600,0.5; 1069200,0.5; 1072800,0.5; 1076400,0.5; 1080000,0.5;
        1083600,0.5; 1087200,0.5; 1090800,0.5; 1094400,0.5; 1098000,0.5;
        1101600,0.5; 1105200,0.5; 1108800,0.5; 1112400,0.5; 1116000,0.5;
        1119600,0.5; 1123200,0.5; 1126800,0.5; 1130400,0.5; 1134000,0.5;
        1137600,0.5; 1141200,0.5; 1144800,0.5; 1148400,0.5; 1152000,0.5;
        1155600,0.5; 1159200,0.5; 1162800,0.5; 1166400,0.5; 1170000,0.5;
        1173600,0.5; 1177200,0.5; 1180800,0.5; 1184400,0.5; 1188000,0.5;
        1191600,0.5; 1195200,0.5; 1198800,0.5; 1202400,0.5; 1206000,0.5;
        1209600,0.5; 1213200,0.5; 1216800,0.5; 1220400,0.5; 1224000,0.5;
        1227600,0.5; 1231200,0.5; 1234800,0.5; 1238400,0.5; 1242000,0.5;
        1245600,0.5; 1249200,0.5; 1252800,0.5; 1256400,0.5; 1260000,0.5;
        1263600,0.5; 1267200,0.5; 1270800,0.5; 1274400,0.5; 1278000,0.5;
        1281600,0.5; 1285200,0.5; 1288800,0.5; 1292400,0.5; 1296000,0.5;
        1299600,0.5; 1303200,0.5; 1306800,0.5; 1310400,0.5; 1314000,0.5;
        1317600,0.5; 1321200,0.5; 1324800,0.5; 1328400,0.5; 1332000,0.5;
        1335600,0.5; 1339200,0.5; 1342800,0.5; 1346400,0.5; 1350000,0.5;
        1353600,0.5; 1357200,0.5; 1360800,0.5; 1364400,0.5; 1368000,0.5;
        1371600,0.5; 1375200,0.5; 1378800,0.5; 1382400,0.5; 1386000,0.5;
        1389600,0.5; 1393200,0.5; 1396800,0.5; 1400400,0.5; 1404000,0.5;
        1407600,0.5; 1411200,0.5; 1414800,0.5; 1418400,0.5; 1422000,0.5;
        1425600,0.5; 1429200,0.5; 1432800,0.5; 1436400,0.5; 1440000,0.5;
        1443600,0.5; 1447200,0.5; 1450800,0.5; 1454400,0.5; 1458000,0.5;
        1461600,0.5; 1465200,0.5; 1468800,0.5; 1472400,0.5; 1476000,0.5;
        1479600,0.5; 1483200,0.5; 1486800,0.5; 1490400,0.5; 1494000,0.5;
        1497600,0.5; 1501200,0.5; 1504800,0.5; 1508400,0.5; 1512000,0.5;
        1515600,0.5; 1519200,0.5; 1522800,0.5; 1526400,0.5; 1530000,0.5;
        1533600,0.5; 1537200,0.5; 1540800,0.5; 1544400,0.5; 1548000,0.5;
        1551600,0.5; 1555200,0.5; 1558800,0.5; 1562400,0.5; 1566000,0.5;
        1569600,0.5; 1573200,0.5; 1576800,0.5; 1580400,0.5; 1584000,0.5;
        1587600,0.5; 1591200,0.5; 1594800,0.5; 1598400,0.5; 1602000,0.5;
        1605600,0.5; 1609200,0.5; 1612800,0.5; 1616400,0.5; 1620000,0.5;
        1623600,0.5; 1627200,0.5; 1630800,0.5; 1634400,0.5; 1638000,0.5;
        1641600,0.5; 1645200,0.5; 1648800,0.5; 1652400,0.5; 1656000,0.5;
        1659600,0.5; 1663200,0.5; 1666800,0.5; 1670400,0.5; 1674000,0.5;
        1677600,0.5; 1681200,0.5; 1684800,0.5; 1688400,0.5; 1692000,0.5;
        1695600,0.5; 1699200,0.5; 1702800,0.5; 1706400,0.5; 1710000,0.5;
        1713600,0.5; 1717200,0.5; 1720800,0.5; 1724400,0.5; 1728000,0.5;
        1731600,0.5; 1735200,0.5; 1738800,0.5; 1742400,0.5; 1746000,0.5;
        1749600,0.5; 1753200,0.5; 1756800,0.5; 1760400,0.5; 1764000,0.5;
        1767600,0.5; 1771200,0.5; 1774800,0.5; 1778400,0.5; 1782000,0.5;
        1785600,0.5; 1789200,0.5; 1792800,0.5; 1796400,0.5; 1800000,0.5;
        1803600,0.5; 1807200,0.5; 1810800,0.5; 1814400,0.5; 1818000,0.5;
        1821600,0.5; 1825200,0.5; 1828800,0.5; 1832400,0.5; 1836000,0.5;
        1839600,0.5; 1843200,0.5; 1846800,0.5; 1850400,0.5; 1854000,0.5;
        1857600,0.5; 1861200,0.5; 1864800,0.5; 1868400,0.5; 1872000,0.5;
        1875600,0.5; 1879200,0.5; 1882800,0.5; 1886400,0.5; 1890000,0.5;
        1893600,0.5; 1897200,0.5; 1900800,0.5; 1904400,0.5; 1908000,0.5;
        1911600,0.5; 1915200,0.5; 1918800,0.5; 1922400,0.5; 1926000,0.5;
        1929600,0.5; 1933200,0.5; 1936800,0.5; 1940400,0.5; 1944000,0.5;
        1947600,0.5; 1951200,0.5; 1954800,0.5; 1958400,0.5; 1962000,0.5;
        1965600,0.5; 1969200,0.5; 1972800,0.5; 1976400,0.5; 1980000,0.5;
        1983600,0.5; 1987200,0.5; 1990800,0.5; 1994400,0.5; 1998000,0.5;
        2001600,0.5; 2005200,0.5; 2008800,0.5; 2012400,0.5; 2016000,0.5;
        2019600,0.5; 2023200,0.5; 2026800,0.5; 2030400,0.5; 2034000,0.5;
        2037600,0.5; 2041200,0.5; 2044800,0.5; 2048400,0.5; 2052000,0.5;
        2055600,0.5; 2059200,0.5; 2062800,0.5; 2066400,0.5; 2070000,0.5;
        2073600,0.5; 2077200,0.5; 2080800,0.5; 2084400,0.5; 2088000,0.5;
        2091600,0.5; 2095200,0.5; 2098800,0.5; 2102400,0.5; 2106000,0.5;
        2109600,0.5; 2113200,0.5; 2116800,0.5; 2120400,0.5; 2124000,0.5;
        2127600,0.5; 2131200,0.5; 2134800,0.5; 2138400,0.5; 2142000,0.5;
        2145600,0.5; 2149200,0.5; 2152800,0.5; 2156400,0.5; 2160000,0.5;
        2163600,0.5; 2167200,0.5; 2170800,0.5; 2174400,0.5; 2178000,0.5;
        2181600,0.5; 2185200,0.5; 2188800,0.5; 2192400,0.5; 2196000,0.5;
        2199600,0.5; 2203200,0.5; 2206800,0.5; 2210400,0.5; 2214000,0.5;
        2217600,0.5; 2221200,0.5; 2224800,0.5; 2228400,0.5; 2232000,0.5;
        2235600,0.5; 2239200,0.5; 2242800,0.5; 2246400,0.5; 2250000,0.5;
        2253600,0.5; 2257200,0.5; 2260800,0.5; 2264400,0.5; 2268000,0.5;
        2271600,0.5; 2275200,0.5; 2278800,0.5; 2282400,0.5; 2286000,0.5;
        2289600,0.5; 2293200,0.5; 2296800,0.5; 2300400,0.5; 2304000,0.5;
        2307600,0.5; 2311200,0.5; 2314800,0.5; 2318400,0.5; 2322000,0.5;
        2325600,0.5; 2329200,0.5; 2332800,0.5; 2336400,0.5; 2340000,0.5;
        2343600,0.5; 2347200,0.5; 2350800,0.5; 2354400,0.5; 2358000,0.5;
        2361600,0.5; 2365200,0.5; 2368800,0.5; 2372400,0.5; 2376000,0.5;
        2379600,0.5; 2383200,0.5; 2386800,0.5; 2390400,0.5; 2394000,0.5;
        2397600,0.5; 2401200,0.5; 2404800,0.5; 2408400,0.5; 2412000,0.5;
        2415600,0.5; 2419200,0.5; 2422800,0.5; 2426400,0.5; 2430000,0.5;
        2433600,0.5; 2437200,0.5; 2440800,0.5; 2444400,0.5; 2448000,0.5;
        2451600,0.5; 2455200,0.5; 2458800,0.5; 2462400,0.5; 2466000,0.5;
        2469600,0.5; 2473200,0.5; 2476800,0.5; 2480400,0.5; 2484000,0.5;
        2487600,0.5; 2491200,0.5; 2494800,0.5; 2498400,0.5; 2502000,0.5;
        2505600,0.5; 2509200,0.5; 2512800,0.5; 2516400,0.5; 2520000,0.5;
        2523600,0.5; 2527200,0.5; 2530800,0.5; 2534400,0.5; 2538000,0.5;
        2541600,0.5; 2545200,0.5; 2548800,0.5; 2552400,0.5; 2556000,0.5;
        2559600,0.5; 2563200,0.5; 2566800,0.5; 2570400,0.5; 2574000,0.5;
        2577600,0.5; 2581200,0.5; 2584800,0.5; 2588400,0.5; 2592000,0.5;
        2595600,0.5; 2599200,0.5; 2602800,0.5; 2606400,0.5; 2610000,0.5;
        2613600,0.5; 2617200,0.5; 2620800,0.5; 2624400,0.5; 2628000,0.5;
        2631600,0.5; 2635200,0.5; 2638800,0.5; 2642400,0.5; 2646000,0.5;
        2649600,0.5; 2653200,0.5; 2656800,0.5; 2660400,0.5; 2664000,0.5;
        2667600,0.5; 2671200,0.5; 2674800,0.5; 2678400,0.5; 2682000,0.5;
        2685600,0.5; 2689200,0.5; 2692800,0.5; 2696400,0.5; 2700000,0.5;
        2703600,0.5; 2707200,0.5; 2710800,0.5; 2714400,0.5; 2718000,0.5;
        2721600,0.5; 2725200,0.5; 2728800,0.5; 2732400,0.5; 2736000,0.5;
        2739600,0.5; 2743200,0.5; 2746800,0.5; 2750400,0.5; 2754000,0.5;
        2757600,0.5; 2761200,0.5; 2764800,0.5; 2768400,0.5; 2772000,0.5;
        2775600,0.5; 2779200,0.5; 2782800,0.5; 2786400,0.5; 2790000,0.5;
        2793600,0.5; 2797200,0.5; 2800800,0.5; 2804400,0.5; 2808000,0.5;
        2811600,0.5; 2815200,0.5; 2818800,0.5; 2822400,0.5; 2826000,0.5;
        2829600,0.5; 2833200,0.5; 2836800,0.5; 2840400,0.5; 2844000,0.5;
        2847600,0.5; 2851200,0.5; 2854800,0.5; 2858400,0.5; 2862000,0.5;
        2865600,0.5; 2869200,0.5; 2872800,0.5; 2876400,0.5; 2880000,0.5;
        2883600,0.5; 2887200,0.5; 2890800,0.5; 2894400,0.5; 2898000,0.5;
        2901600,0.5; 2905200,0.5; 2908800,0.5; 2912400,0.5; 2916000,0.5;
        2919600,0.5; 2923200,0.5; 2926800,0.5; 2930400,0.5; 2934000,0.5;
        2937600,0.5; 2941200,0.5; 2944800,0.5; 2948400,0.5; 2952000,0.5;
        2955600,0.5; 2959200,0.5; 2962800,0.5; 2966400,0.5; 2970000,0.5;
        2973600,0.5; 2977200,0.5; 2980800,0.5; 2984400,0.5; 2988000,0.5;
        2991600,0.5; 2995200,0.5; 2998800,0.5; 3002400,0.5; 3006000,0.5;
        3009600,0.5; 3013200,0.5; 3016800,0.5; 3020400,0.5; 3024000,0.5;
        3027600,0.5; 3031200,0.5; 3034800,0.5; 3038400,0.5; 3042000,0.5;
        3045600,0.5; 3049200,0.5; 3052800,0.5; 3056400,0.5; 3060000,0.5;
        3063600,0.5; 3067200,0.5; 3070800,0.5; 3074400,0.5; 3078000,0.5;
        3081600,0.5; 3085200,0.5; 3088800,0.5; 3092400,0.5; 3096000,0.5;
        3099600,0.5; 3103200,0.5; 3106800,0.5; 3110400,0.5; 3114000,0.5;
        3117600,0.5; 3121200,0.5; 3124800,0.5; 3128400,0.5; 3132000,0.5;
        3135600,0.5; 3139200,0.5; 3142800,0.5; 3146400,0.5; 3150000,0.5;
        3153600,0.5; 3157200,0.5; 3160800,0.5; 3164400,0.5; 3168000,0.5;
        3171600,0.5; 3175200,0.5; 3178800,0.5; 3182400,0.5; 3186000,0.5;
        3189600,0.5; 3193200,0.5; 3196800,0.5; 3200400,0.5; 3204000,0.5;
        3207600,0.5; 3211200,0.5; 3214800,0.5; 3218400,0.5; 3222000,0.5;
        3225600,0.5; 3229200,0.5; 3232800,0.5; 3236400,0.5; 3240000,0.5;
        3243600,0.5; 3247200,0.5; 3250800,0.5; 3254400,0.5; 3258000,0.5;
        3261600,0.5; 3265200,0.5; 3268800,0.5; 3272400,0.5; 3276000,0.5;
        3279600,0.5; 3283200,0.5; 3286800,0.5; 3290400,0.5; 3294000,0.5;
        3297600,0.5; 3301200,0.5; 3304800,0.5; 3308400,0.5; 3312000,0.5;
        3315600,0.5; 3319200,0.5; 3322800,0.5; 3326400,0.5; 3330000,0.5;
        3333600,0.5; 3337200,0.5; 3340800,0.5; 3344400,0.5; 3348000,0.5;
        3351600,0.5; 3355200,0.5; 3358800,0.5; 3362400,0.5; 3366000,0.5;
        3369600,0.5; 3373200,0.5; 3376800,0.5; 3380400,0.5; 3384000,0.5;
        3387600,0.5; 3391200,0.5; 3394800,0.5; 3398400,0.5; 3402000,0.5;
        3405600,0.5; 3409200,0.5; 3412800,0.5; 3416400,0.5; 3420000,0.5;
        3423600,0.5; 3427200,0.5; 3430800,0.5; 3434400,0.5; 3438000,0.5;
        3441600,0.5; 3445200,0.5; 3448800,0.5; 3452400,0.5; 3456000,0.5;
        3459600,0.5; 3463200,0.5; 3466800,0.5; 3470400,0.5; 3474000,0.5;
        3477600,0.5; 3481200,0.5; 3484800,0.5; 3488400,0.5; 3492000,0.5;
        3495600,0.5; 3499200,0.5; 3502800,0.5; 3506400,0.5; 3510000,0.5;
        3513600,0.5; 3517200,0.5; 3520800,0.5; 3524400,0.5; 3528000,0.5;
        3531600,0.5; 3535200,0.5; 3538800,0.5; 3542400,0.5; 3546000,0.5;
        3549600,0.5; 3553200,0.5; 3556800,0.5; 3560400,0.5; 3564000,0.5;
        3567600,0.5; 3571200,0.5; 3574800,0.5; 3578400,0.5; 3582000,0.5;
        3585600,0.5; 3589200,0.5; 3592800,0.5; 3596400,0.5; 3600000,0.5;
        3603600,0.5; 3607200,0.5; 3610800,0.5; 3614400,0.5; 3618000,0.5;
        3621600,0.5; 3625200,0.5; 3628800,0.5; 3632400,0.5; 3636000,0.5;
        3639600,0.5; 3643200,0.5; 3646800,0.5; 3650400,0.5; 3654000,0.5;
        3657600,0.5; 3661200,0.5; 3664800,0.5; 3668400,0.5; 3672000,0.5;
        3675600,0.5; 3679200,0.5; 3682800,0.5; 3686400,0.5; 3690000,0.5;
        3693600,0.5; 3697200,0.5; 3700800,0.5; 3704400,0.5; 3708000,0.5;
        3711600,0.5; 3715200,0.5; 3718800,0.5; 3722400,0.5; 3726000,0.5;
        3729600,0.5; 3733200,0.5; 3736800,0.5; 3740400,0.5; 3744000,0.5;
        3747600,0.5; 3751200,0.5; 3754800,0.5; 3758400,0.5; 3762000,0.5;
        3765600,0.5; 3769200,0.5; 3772800,0.5; 3776400,0.5; 3780000,0.5;
        3783600,0.5; 3787200,0.5; 3790800,0.5; 3794400,0.5; 3798000,0.5;
        3801600,0.5; 3805200,0.5; 3808800,0.5; 3812400,0.5; 3816000,0.5;
        3819600,0.5; 3823200,0.5; 3826800,0.5; 3830400,0.5; 3834000,0.5;
        3837600,0.5; 3841200,0.5; 3844800,0.5; 3848400,0.5; 3852000,0.5;
        3855600,0.5; 3859200,0.5; 3862800,0.5; 3866400,0.5; 3870000,0.5;
        3873600,0.5; 3877200,0.5; 3880800,0.5; 3884400,0.5; 3888000,0.5;
        3891600,0.5; 3895200,0.5; 3898800,0.5; 3902400,0.5; 3906000,0.5;
        3909600,0.5; 3913200,0.5; 3916800,0.5; 3920400,0.5; 3924000,0.5;
        3927600,0.5; 3931200,0.5; 3934800,0.5; 3938400,0.5; 3942000,0.5;
        3945600,0.5; 3949200,0.5; 3952800,0.5; 3956400,0.5; 3960000,0.5;
        3963600,0.5; 3967200,0.5; 3970800,0.5; 3974400,0.5; 3978000,0.5;
        3981600,0.5; 3985200,0.5; 3988800,0.5; 3992400,0.5; 3996000,0.5;
        3999600,0.5; 4003200,0.5; 4006800,0.5; 4010400,0.5; 4014000,0.5;
        4017600,0.5; 4021200,0.5; 4024800,0.5; 4028400,0.5; 4032000,0.5;
        4035600,0.5; 4039200,0.5; 4042800,0.5; 4046400,0.5; 4050000,0.5;
        4053600,0.5; 4057200,0.5; 4060800,0.5; 4064400,0.5; 4068000,0.5;
        4071600,0.5; 4075200,0.5; 4078800,0.5; 4082400,0.5; 4086000,0.5;
        4089600,0.5; 4093200,0.5; 4096800,0.5; 4100400,0.5; 4104000,0.5;
        4107600,0.5; 4111200,0.5; 4114800,0.5; 4118400,0.5; 4122000,0.5;
        4125600,0.5; 4129200,0.5; 4132800,0.5; 4136400,0.5; 4140000,0.5;
        4143600,0.5; 4147200,0.5; 4150800,0.5; 4154400,0.5; 4158000,0.5;
        4161600,0.5; 4165200,0.5; 4168800,0.5; 4172400,0.5; 4176000,0.5;
        4179600,0.5; 4183200,0.5; 4186800,0.5; 4190400,0.5; 4194000,0.5;
        4197600,0.5; 4201200,0.5; 4204800,0.5; 4208400,0.5; 4212000,0.5;
        4215600,0.5; 4219200,0.5; 4222800,0.5; 4226400,0.5; 4230000,0.5;
        4233600,0.5; 4237200,0.5; 4240800,0.5; 4244400,0.5; 4248000,0.5;
        4251600,0.5; 4255200,0.5; 4258800,0.5; 4262400,0.5; 4266000,0.5;
        4269600,0.5; 4273200,0.5; 4276800,0.5; 4280400,0.5; 4284000,0.5;
        4287600,0.5; 4291200,0.5; 4294800,0.5; 4298400,0.5; 4302000,0.5;
        4305600,0.5; 4309200,0.5; 4312800,0.5; 4316400,0.5; 4320000,0.5;
        4323600,0.5; 4327200,0.5; 4330800,0.5; 4334400,0.5; 4338000,0.5;
        4341600,0.5; 4345200,0.5; 4348800,0.5; 4352400,0.5; 4356000,0.5;
        4359600,0.5; 4363200,0.5; 4366800,0.5; 4370400,0.5; 4374000,0.5;
        4377600,0.5; 4381200,0.5; 4384800,0.5; 4388400,0.5; 4392000,0.5;
        4395600,0.5; 4399200,0.5; 4402800,0.5; 4406400,0.5; 4410000,0.5;
        4413600,0.5; 4417200,0.5; 4420800,0.5; 4424400,0.5; 4428000,0.5;
        4431600,0.5; 4435200,0.5; 4438800,0.5; 4442400,0.5; 4446000,0.5;
        4449600,0.5; 4453200,0.5; 4456800,0.5; 4460400,0.5; 4464000,0.5;
        4467600,0.5; 4471200,0.5; 4474800,0.5; 4478400,0.5; 4482000,0.5;
        4485600,0.5; 4489200,0.5; 4492800,0.5; 4496400,0.5; 4500000,0.5;
        4503600,0.5; 4507200,0.5; 4510800,0.5; 4514400,0.5; 4518000,0.5;
        4521600,0.5; 4525200,0.5; 4528800,0.5; 4532400,0.5; 4536000,0.5;
        4539600,0.5; 4543200,0.5; 4546800,0.5; 4550400,0.5; 4554000,0.5;
        4557600,0.5; 4561200,0.5; 4564800,0.5; 4568400,0.5; 4572000,0.5;
        4575600,0.5; 4579200,0.5; 4582800,0.5; 4586400,0.5; 4590000,0.5;
        4593600,0.5; 4597200,0.5; 4600800,0.5; 4604400,0.5; 4608000,0.5;
        4611600,0.5; 4615200,0.5; 4618800,0.5; 4622400,0.5; 4626000,0.5;
        4629600,0.5; 4633200,0.5; 4636800,0.5; 4640400,0.5; 4644000,0.5;
        4647600,0.5; 4651200,0.5; 4654800,0.5; 4658400,0.5; 4662000,0.5;
        4665600,0.5; 4669200,0.5; 4672800,0.5; 4676400,0.5; 4680000,0.5;
        4683600,0.5; 4687200,0.5; 4690800,0.5; 4694400,0.5; 4698000,0.5;
        4701600,0.5; 4705200,0.5; 4708800,0.5; 4712400,0.5; 4716000,0.5;
        4719600,0.5; 4723200,0.5; 4726800,0.5; 4730400,0.5; 4734000,0.5;
        4737600,0.5; 4741200,0.5; 4744800,0.5; 4748400,0.5; 4752000,0.5;
        4755600,0.5; 4759200,0.5; 4762800,0.5; 4766400,0.5; 4770000,0.5;
        4773600,0.5; 4777200,0.5; 4780800,0.5; 4784400,0.5; 4788000,0.5;
        4791600,0.5; 4795200,0.5; 4798800,0.5; 4802400,0.5; 4806000,0.5;
        4809600,0.5; 4813200,0.5; 4816800,0.5; 4820400,0.5; 4824000,0.5;
        4827600,0.5; 4831200,0.5; 4834800,0.5; 4838400,0.5; 4842000,0.5;
        4845600,0.5; 4849200,0.5; 4852800,0.5; 4856400,0.5; 4860000,0.5;
        4863600,0.5; 4867200,0.5; 4870800,0.5; 4874400,0.5; 4878000,0.5;
        4881600,0.5; 4885200,0.5; 4888800,0.5; 4892400,0.5; 4896000,0.5;
        4899600,0.5; 4903200,0.5; 4906800,0.5; 4910400,0.5; 4914000,0.5;
        4917600,0.5; 4921200,0.5; 4924800,0.5; 4928400,0.5; 4932000,0.5;
        4935600,0.5; 4939200,0.5; 4942800,0.5; 4946400,0.5; 4950000,0.5;
        4953600,0.5; 4957200,0.5; 4960800,0.5; 4964400,0.5; 4968000,0.5;
        4971600,0.5; 4975200,0.5; 4978800,0.5; 4982400,0.5; 4986000,0.5;
        4989600,0.5; 4993200,0.5; 4996800,0.5; 5000400,0.5; 5004000,0.5;
        5007600,0.5; 5011200,0.5; 5014800,0.5; 5018400,0.5; 5022000,0.5;
        5025600,0.5; 5029200,0.5; 5032800,0.5; 5036400,0.5; 5040000,0.5;
        5043600,0.5; 5047200,0.5; 5050800,0.5; 5054400,0.5; 5058000,0.5;
        5061600,0.5; 5065200,0.5; 5068800,0.5; 5072400,0.5; 5076000,0.5;
        5079600,0.5; 5083200,0.5; 5086800,0.5; 5090400,0.5; 5094000,0.5;
        5097600,0.5; 5101200,0.5; 5104800,0.5; 5108400,0.5; 5112000,0.5;
        5115600,0.5; 5119200,0.5; 5122800,0.5; 5126400,0.5; 5130000,0.5;
        5133600,0.5; 5137200,0.5; 5140800,0.5; 5144400,0.5; 5148000,0.5;
        5151600,0.5; 5155200,0.5; 5158800,0.5; 5162400,0.5; 5166000,0.5;
        5169600,0.5; 5173200,0.5; 5176800,0.5; 5180400,0.5; 5184000,0.5;
        5187600,0.5; 5191200,0.5; 5194800,0.5; 5198400,0.5; 5202000,0.5;
        5205600,0.5; 5209200,0.5; 5212800,0.5; 5216400,0.5; 5220000,0.5;
        5223600,0.5; 5227200,0.5; 5230800,0.5; 5234400,0.5; 5238000,0.5;
        5241600,0.5; 5245200,0.5; 5248800,0.5; 5252400,0.5; 5256000,0.5;
        5259600,0.5; 5263200,0.5; 5266800,0.5; 5270400,0.5; 5274000,0.5;
        5277600,0.5; 5281200,0.5; 5284800,0.5; 5288400,0.5; 5292000,0.5;
        5295600,0.5; 5299200,0.5; 5302800,0.5; 5306400,0.5; 5310000,0.5;
        5313600,0.5; 5317200,0.5; 5320800,0.5; 5324400,0.5; 5328000,0.5;
        5331600,0.5; 5335200,0.5; 5338800,0.5; 5342400,0.5; 5346000,0.5;
        5349600,0.5; 5353200,0.5; 5356800,0.5; 5360400,0.5; 5364000,0.5;
        5367600,0.5; 5371200,0.5; 5374800,0.5; 5378400,0.5; 5382000,0.5;
        5385600,0.5; 5389200,0.5; 5392800,0.5; 5396400,0.5; 5400000,0.5;
        5403600,0.5; 5407200,0.5; 5410800,0.5; 5414400,0.5; 5418000,0.5;
        5421600,0.5; 5425200,0.5; 5428800,0.5; 5432400,0.5; 5436000,0.5;
        5439600,0.5; 5443200,0.5; 5446800,0.5; 5450400,0.5; 5454000,0.5;
        5457600,0.5; 5461200,0.5; 5464800,0.5; 5468400,0.5; 5472000,0.5;
        5475600,0.5; 5479200,0.5; 5482800,0.5; 5486400,0.5; 5490000,0.5;
        5493600,0.5; 5497200,0.5; 5500800,0.5; 5504400,0.5; 5508000,0.5;
        5511600,0.5; 5515200,0.5; 5518800,0.5; 5522400,0.5; 5526000,0.5;
        5529600,0.5; 5533200,0.5; 5536800,0.5; 5540400,0.5; 5544000,0.5;
        5547600,0.5; 5551200,0.5; 5554800,0.5; 5558400,0.5; 5562000,0.5;
        5565600,0.5; 5569200,0.5; 5572800,0.5; 5576400,0.5; 5580000,0.5;
        5583600,0.5; 5587200,0.5; 5590800,0.5; 5594400,0.5; 5598000,0.5;
        5601600,0.5; 5605200,0.5; 5608800,0.5; 5612400,0.5; 5616000,0.5;
        5619600,0.5; 5623200,0.5; 5626800,0.5; 5630400,0.5; 5634000,0.5;
        5637600,0.5; 5641200,0.5; 5644800,0.5; 5648400,0.5; 5652000,0.5;
        5655600,0.5; 5659200,0.5; 5662800,0.5; 5666400,0.5; 5670000,0.5;
        5673600,0.5; 5677200,0.5; 5680800,0.5; 5684400,0.5; 5688000,0.5;
        5691600,0.5; 5695200,0.5; 5698800,0.5; 5702400,0.5; 5706000,0.5;
        5709600,0.5; 5713200,0.5; 5716800,0.5; 5720400,0.5; 5724000,0.5;
        5727600,0.5; 5731200,0.5; 5734800,0.5; 5738400,0.5; 5742000,0.5;
        5745600,0.5; 5749200,0.5; 5752800,0.5; 5756400,0.5; 5760000,0.5;
        5763600,0.5; 5767200,0.5; 5770800,0.5; 5774400,0.5; 5778000,0.5;
        5781600,0.5; 5785200,0.5; 5788800,0.5; 5792400,0.5; 5796000,0.5;
        5799600,0.5; 5803200,0.5; 5806800,0.5; 5810400,0.5; 5814000,0.5;
        5817600,0.5; 5821200,0.5; 5824800,0.5; 5828400,0.5; 5832000,0.5;
        5835600,0.5; 5839200,0.5; 5842800,0.5; 5846400,0.5; 5850000,0.5;
        5853600,0.5; 5857200,0.5; 5860800,0.5; 5864400,0.5; 5868000,0.5;
        5871600,0.5; 5875200,0.5; 5878800,0.5; 5882400,0.5; 5886000,0.5;
        5889600,0.5; 5893200,0.5; 5896800,0.5; 5900400,0.5; 5904000,0.5;
        5907600,0.5; 5911200,0.5; 5914800,0.5; 5918400,0.5; 5922000,0.5;
        5925600,0.5; 5929200,0.5; 5932800,0.5; 5936400,0.5; 5940000,0.5;
        5943600,0.5; 5947200,0.5; 5950800,0.5; 5954400,0.5; 5958000,0.5;
        5961600,0.5; 5965200,0.5; 5968800,0.5; 5972400,0.5; 5976000,0.5;
        5979600,0.5; 5983200,0.5; 5986800,0.5; 5990400,0.5; 5994000,0.5;
        5997600,0.5; 6001200,0.5; 6004800,0.5; 6008400,0.5; 6012000,0.5;
        6015600,0.5; 6019200,0.5; 6022800,0.5; 6026400,0.5; 6030000,0.5;
        6033600,0.5; 6037200,0.5; 6040800,0.5; 6044400,0.5; 6048000,0.5;
        6051600,0.5; 6055200,0.5; 6058800,0.5; 6062400,0.5; 6066000,0.5;
        6069600,0.5; 6073200,0.5; 6076800,0.5; 6080400,0.5; 6084000,0.5;
        6087600,0.5; 6091200,0.5; 6094800,0.5; 6098400,0.5; 6102000,0.5;
        6105600,0.5; 6109200,0.5; 6112800,0.5; 6116400,0.5; 6120000,0.5;
        6123600,0.5; 6127200,0.5; 6130800,0.5; 6134400,0.5; 6138000,0.5;
        6141600,0.5; 6145200,0.5; 6148800,0.5; 6152400,0.5; 6156000,0.5;
        6159600,0.5; 6163200,0.5; 6166800,0.5; 6170400,0.5; 6174000,0.5;
        6177600,0.5; 6181200,0.5; 6184800,0.5; 6188400,0.5; 6192000,0.5;
        6195600,0.5; 6199200,0.5; 6202800,0.5; 6206400,0.5; 6210000,0.5;
        6213600,0.5; 6217200,0.5; 6220800,0.5; 6224400,0.5; 6228000,0.5;
        6231600,0.5; 6235200,0.5; 6238800,0.5; 6242400,0.5; 6246000,0.5;
        6249600,0.5; 6253200,0.5; 6256800,0.5; 6260400,0.5; 6264000,0.5;
        6267600,0.5; 6271200,0.5; 6274800,0.5; 6278400,0.5; 6282000,0.5;
        6285600,0.5; 6289200,0.5; 6292800,0.5; 6296400,0.5; 6300000,0.5;
        6303600,0.5; 6307200,0.5; 6310800,0.5; 6314400,0.5; 6318000,0.5;
        6321600,0.5; 6325200,0.5; 6328800,0.5; 6332400,0.5; 6336000,0.5;
        6339600,0.5; 6343200,0.5; 6346800,0.5; 6350400,0.5; 6354000,0.5;
        6357600,0.5; 6361200,0.5; 6364800,0.5; 6368400,0.5; 6372000,0.5;
        6375600,0.5; 6379200,0.5; 6382800,0.5; 6386400,0.5; 6390000,0.5;
        6393600,0.5; 6397200,0.5; 6400800,0.5; 6404400,0.5; 6408000,0.5;
        6411600,0.5; 6415200,0.5; 6418800,0.5; 6422400,0.5; 6426000,0.5;
        6429600,0.5; 6433200,0.5; 6436800,0.5; 6440400,0.5; 6444000,0.5;
        6447600,0.5; 6451200,0.5; 6454800,0.5; 6458400,0.5; 6462000,0.5;
        6465600,0.5; 6469200,0.5; 6472800,0.5; 6476400,0.5; 6480000,0.5;
        6483600,0.5; 6487200,0.5; 6490800,0.5; 6494400,0.5; 6498000,0.5;
        6501600,0.5; 6505200,0.5; 6508800,0.5; 6512400,0.5; 6516000,0.5;
        6519600,0.5; 6523200,0.5; 6526800,0.5; 6530400,0.5; 6534000,0.5;
        6537600,0.5; 6541200,0.5; 6544800,0.5; 6548400,0.5; 6552000,0.5;
        6555600,0.5; 6559200,0.5; 6562800,0.5; 6566400,0.5; 6570000,0.5;
        6573600,0.5; 6577200,0.5; 6580800,0.5; 6584400,0.5; 6588000,0.5;
        6591600,0.5; 6595200,0.5; 6598800,0.5; 6602400,0.5; 6606000,0.5;
        6609600,0.5; 6613200,0.5; 6616800,0.5; 6620400,0.5; 6624000,0.5;
        6627600,0.5; 6631200,0.5; 6634800,0.5; 6638400,0.5; 6642000,0.5;
        6645600,0.5; 6649200,0.5; 6652800,0.5; 6656400,0.5; 6660000,0.5;
        6663600,0.5; 6667200,0.5; 6670800,0.5; 6674400,0.5; 6678000,0.5;
        6681600,0.5; 6685200,0.5; 6688800,0.5; 6692400,0.5; 6696000,0.5;
        6699600,0.5; 6703200,0.5; 6706800,0.5; 6710400,0.5; 6714000,0.5;
        6717600,0.5; 6721200,0.5; 6724800,0.5; 6728400,0.5; 6732000,0.5;
        6735600,0.5; 6739200,0.5; 6742800,0.5; 6746400,0.5; 6750000,0.5;
        6753600,0.5; 6757200,0.5; 6760800,0.5; 6764400,0.5; 6768000,0.5;
        6771600,0.5; 6775200,0.5; 6778800,0.5; 6782400,0.5; 6786000,0.5;
        6789600,0.5; 6793200,0.5; 6796800,0.5; 6800400,0.5; 6804000,0.5;
        6807600,0.5; 6811200,0.5; 6814800,0.5; 6818400,0.5; 6822000,0.5;
        6825600,0.5; 6829200,0.5; 6832800,0.5; 6836400,0.5; 6840000,0.5;
        6843600,0.5; 6847200,0.5; 6850800,0.5; 6854400,0.5; 6858000,0.5;
        6861600,0.5; 6865200,0.5; 6868800,0.5; 6872400,0.5; 6876000,0.5;
        6879600,0.5; 6883200,0.5; 6886800,0.5; 6890400,0.5; 6894000,0.5;
        6897600,0.5; 6901200,0.5; 6904800,0.5; 6908400,0.5; 6912000,0.5;
        6915600,0.5; 6919200,0.5; 6922800,0.5; 6926400,0.5; 6930000,0.5;
        6933600,0.5; 6937200,0.5; 6940800,0.5; 6944400,0.5; 6948000,0.5;
        6951600,0.5; 6955200,0.5; 6958800,0.5; 6962400,0.5; 6966000,0.5;
        6969600,0.5; 6973200,0.5; 6976800,0.5; 6980400,0.5; 6984000,0.5;
        6987600,0.5; 6991200,0.5; 6994800,0.5; 6998400,0.5; 7002000,0.5;
        7005600,0.5; 7009200,0.5; 7012800,0.5; 7016400,0.5; 7020000,0.5;
        7023600,0.5; 7027200,0.5; 7030800,0.5; 7034400,0.5; 7038000,0.5;
        7041600,0.5; 7045200,0.5; 7048800,0.5; 7052400,0.5; 7056000,0.5;
        7059600,0.5; 7063200,0.5; 7066800,0.5; 7070400,0.5; 7074000,0.5;
        7077600,0.5; 7081200,0.5; 7084800,0.5; 7088400,0.5; 7092000,0.5;
        7095600,0.5; 7099200,0.5; 7102800,0.5; 7106400,0.5; 7110000,0.5;
        7113600,0.5; 7117200,0.5; 7120800,0.5; 7124400,0.5; 7128000,0.5;
        7131600,0.5; 7135200,0.5; 7138800,0.5; 7142400,0.5; 7146000,0.5;
        7149600,0.5; 7153200,0.5; 7156800,0.5; 7160400,0.5; 7164000,0.5;
        7167600,0.5; 7171200,0.5; 7174800,0.5; 7178400,0.5; 7182000,0.5;
        7185600,0.5; 7189200,0.5; 7192800,0.5; 7196400,0.5; 7200000,0.5;
        7203600,0.5; 7207200,0.5; 7210800,0.5; 7214400,0.5; 7218000,0.5;
        7221600,0.5; 7225200,0.5; 7228800,0.5; 7232400,0.5; 7236000,0.5;
        7239600,0.5; 7243200,0.5; 7246800,0.5; 7250400,0.5; 7254000,0.5;
        7257600,0.5; 7261200,0.5; 7264800,0.5; 7268400,0.5; 7272000,0.5;
        7275600,0.5; 7279200,0.5; 7282800,0.5; 7286400,0.5; 7290000,0.5;
        7293600,0.5; 7297200,0.5; 7300800,0.5; 7304400,0.5; 7308000,0.5;
        7311600,0.5; 7315200,0.5; 7318800,0.5; 7322400,0.5; 7326000,0.5;
        7329600,0.5; 7333200,0.5; 7336800,0.5; 7340400,0.5; 7344000,0.5;
        7347600,0.5; 7351200,0.5; 7354800,0.5; 7358400,0.5; 7362000,0.5;
        7365600,0.5; 7369200,0.5; 7372800,0.5; 7376400,0.5; 7380000,0.5;
        7383600,0.5; 7387200,0.5; 7390800,0.5; 7394400,0.5; 7398000,0.5;
        7401600,0.5; 7405200,0.5; 7408800,0.5; 7412400,0.5; 7416000,0.5;
        7419600,0.5; 7423200,0.5; 7426800,0.5; 7430400,0.5; 7434000,0.5;
        7437600,0.5; 7441200,0.5; 7444800,0.5; 7448400,0.5; 7452000,0.5;
        7455600,0.5; 7459200,0.5; 7462800,0.5; 7466400,0.5; 7470000,0.5;
        7473600,0.5; 7477200,0.5; 7480800,0.5; 7484400,0.5; 7488000,0.5;
        7491600,0.5; 7495200,0.5; 7498800,0.5; 7502400,0.5; 7506000,0.5;
        7509600,0.5; 7513200,0.5; 7516800,0.5; 7520400,0.5; 7524000,0.5;
        7527600,0.5; 7531200,0.5; 7534800,0.5; 7538400,0.5; 7542000,0.5;
        7545600,0.5; 7549200,0.5; 7552800,0.5; 7556400,0.5; 7560000,0.5;
        7563600,0.5; 7567200,0.5; 7570800,0.5; 7574400,0.5; 7578000,0.5;
        7581600,0.5; 7585200,0.5; 7588800,0.5; 7592400,0.5; 7596000,0.5;
        7599600,0.5; 7603200,0.5; 7606800,0.5; 7610400,0.5; 7614000,0.5;
        7617600,0.5; 7621200,0.5; 7624800,0.5; 7628400,0.5; 7632000,0.5;
        7635600,0.5; 7639200,0.5; 7642800,0.5; 7646400,0.5; 7650000,0.5;
        7653600,0.5; 7657200,0.5; 7660800,0.5; 7664400,0.5; 7668000,0.5;
        7671600,0.5; 7675200,0.5; 7678800,0.5; 7682400,0.5; 7686000,0.5;
        7689600,0.5; 7693200,0.5; 7696800,0.5; 7700400,0.5; 7704000,0.5;
        7707600,0.5; 7711200,0.5; 7714800,0.5; 7718400,0.5; 7722000,0.5;
        7725600,0.5; 7729200,0.5; 7732800,0.5; 7736400,0.5; 7740000,0.5;
        7743600,0.5; 7747200,0.5; 7750800,0.5; 7754400,0.5; 7758000,0.5;
        7761600,0.5; 7765200,0.5; 7768800,0.5; 7772400,0.5; 7776000,0.5;
        7779600,0.5; 7783200,0.5; 7786800,0.5; 7790400,0.5; 7794000,0.5;
        7797600,0.5; 7801200,0.5; 7804800,0.5; 7808400,0.5; 7812000,0.5;
        7815600,0.5; 7819200,0.5; 7822800,0.5; 7826400,0.5; 7830000,0.5;
        7833600,0.5; 7837200,0.5; 7840800,0.5; 7844400,0.5; 7848000,0.5;
        7851600,0.5; 7855200,0.5; 7858800,0.5; 7862400,0.5; 7866000,0.5;
        7869600,0.5; 7873200,0.5; 7876800,0.5; 7880400,0.5; 7884000,0.5;
        7887600,0.5; 7891200,0.5; 7894800,0.5; 7898400,0.5; 7902000,0.5;
        7905600,0.5; 7909200,0.5; 7912800,0.5; 7916400,0.5; 7920000,0.5;
        7923600,0.5; 7927200,0.5; 7930800,0.5; 7934400,0.5; 7938000,0.5;
        7941600,0.5; 7945200,0.5; 7948800,0.5; 7952400,0.5; 7956000,0.5;
        7959600,0.5; 7963200,0.5; 7966800,0.5; 7970400,0.5; 7974000,0.5;
        7977600,0.5; 7981200,0.5; 7984800,0.5; 7988400,0.5; 7992000,0.5;
        7995600,0.5; 7999200,0.5; 8002800,0.5; 8006400,0.5; 8010000,0.5;
        8013600,0.5; 8017200,0.5; 8020800,0.5; 8024400,0.5; 8028000,0.5;
        8031600,0.5; 8035200,0.5; 8038800,0.5; 8042400,0.5; 8046000,0.5;
        8049600,0.5; 8053200,0.5; 8056800,0.5; 8060400,0.5; 8064000,0.5;
        8067600,0.5; 8071200,0.5; 8074800,0.5; 8078400,0.5; 8082000,0.5;
        8085600,0.5; 8089200,0.5; 8092800,0.5; 8096400,0.5; 8100000,0.5;
        8103600,0.5; 8107200,0.5; 8110800,0.5; 8114400,0.5; 8118000,0.5;
        8121600,0.5; 8125200,0.5; 8128800,0.5; 8132400,0.5; 8136000,0.5;
        8139600,0.5; 8143200,0.5; 8146800,0.5; 8150400,0.5; 8154000,0.5;
        8157600,0.5; 8161200,0.5; 8164800,0.5; 8168400,0.5; 8172000,0.5;
        8175600,0.5; 8179200,0.5; 8182800,0.5; 8186400,0.5; 8190000,0.5;
        8193600,0.5; 8197200,0.5; 8200800,0.5; 8204400,0.5; 8208000,0.5;
        8211600,0.5; 8215200,0.5; 8218800,0.5; 8222400,0.5; 8226000,0.5;
        8229600,0.5; 8233200,0.5; 8236800,0.5; 8240400,0.5; 8244000,0.5;
        8247600,0.5; 8251200,0.5; 8254800,0.5; 8258400,0.5; 8262000,0.5;
        8265600,0.5; 8269200,0.5; 8272800,0.5; 8276400,0.5; 8280000,0.5;
        8283600,0.5; 8287200,0.5; 8290800,0.5; 8294400,0.5; 8298000,0.5;
        8301600,0.5; 8305200,0.5; 8308800,0.5; 8312400,0.5; 8316000,0.5;
        8319600,0.5; 8323200,0.5; 8326800,0.5; 8330400,0.5; 8334000,0.5;
        8337600,0.5; 8341200,0.5; 8344800,0.5; 8348400,0.5; 8352000,0.5;
        8355600,0.5; 8359200,0.5; 8362800,0.5; 8366400,0.5; 8370000,0.5;
        8373600,0.5; 8377200,0.5; 8380800,0.5; 8384400,0.5; 8388000,0.5;
        8391600,0.5; 8395200,0.5; 8398800,0.5; 8402400,0.5; 8406000,0.5;
        8409600,0.5; 8413200,0.5; 8416800,0.5; 8420400,0.5; 8424000,0.5;
        8427600,0.5; 8431200,0.5; 8434800,0.5; 8438400,0.5; 8442000,0.5;
        8445600,0.5; 8449200,0.5; 8452800,0.5; 8456400,0.5; 8460000,0.5;
        8463600,0.5; 8467200,0.5; 8470800,0.5; 8474400,0.5; 8478000,0.5;
        8481600,0.5; 8485200,0.5; 8488800,0.5; 8492400,0.5; 8496000,0.5;
        8499600,0.5; 8503200,0.5; 8506800,0.5; 8510400,0.5; 8514000,0.5;
        8517600,0.5; 8521200,0.5; 8524800,0.5; 8528400,0.5; 8532000,0.5;
        8535600,0.5; 8539200,0.5; 8542800,0.5; 8546400,0.5; 8550000,0.5;
        8553600,0.5; 8557200,0.5; 8560800,0.5; 8564400,0.5; 8568000,0.5;
        8571600,0.5; 8575200,0.5; 8578800,0.5; 8582400,0.5; 8586000,0.5;
        8589600,0.5; 8593200,0.5; 8596800,0.5; 8600400,0.5; 8604000,0.5;
        8607600,0.5; 8611200,0.5; 8614800,0.5; 8618400,0.5; 8622000,0.5;
        8625600,0.5; 8629200,0.5; 8632800,0.5; 8636400,0.5; 8640000,0.5;
        8643600,0.5; 8647200,0.5; 8650800,0.5; 8654400,0.5; 8658000,0.5;
        8661600,0.5; 8665200,0.5; 8668800,0.5; 8672400,0.5; 8676000,0.5;
        8679600,0.5; 8683200,0.5; 8686800,0.5; 8690400,0.5; 8694000,0.5;
        8697600,0.5; 8701200,0.5; 8704800,0.5; 8708400,0.5; 8712000,0.5;
        8715600,0.5; 8719200,0.5; 8722800,0.5; 8726400,0.5; 8730000,0.5;
        8733600,0.5; 8737200,0.5; 8740800,0.5; 8744400,0.5; 8748000,0.5;
        8751600,0.5; 8755200,0.5; 8758800,0.5; 8762400,0.5; 8766000,0.5;
        8769600,0.5; 8773200,0.5; 8776800,0.5; 8780400,0.5; 8784000,0.5;
        8787600,0.5; 8791200,0.5; 8794800,0.5; 8798400,0.5; 8802000,0.5;
        8805600,0.5; 8809200,0.5; 8812800,0.5; 8816400,0.5; 8820000,0.5;
        8823600,0.5; 8827200,0.5; 8830800,0.5; 8834400,0.5; 8838000,0.5;
        8841600,0.5; 8845200,0.5; 8848800,0.5; 8852400,0.5; 8856000,0.5;
        8859600,0.5; 8863200,0.5; 8866800,0.5; 8870400,0.5; 8874000,0.5;
        8877600,0.5; 8881200,0.5; 8884800,0.5; 8888400,0.5; 8892000,0.5;
        8895600,0.5; 8899200,0.5; 8902800,0.5; 8906400,0.5; 8910000,0.5;
        8913600,0.5; 8917200,0.5; 8920800,0.5; 8924400,0.5; 8928000,0.5;
        8931600,0.5; 8935200,0.5; 8938800,0.5; 8942400,0.5; 8946000,0.5;
        8949600,0.5; 8953200,0.5; 8956800,0.5; 8960400,0.5; 8964000,0.5;
        8967600,0.5; 8971200,0.5; 8974800,0.5; 8978400,0.5; 8982000,0.5;
        8985600,0.5; 8989200,0.5; 8992800,0.5; 8996400,0.5; 9000000,0.5;
        9003600,0.5; 9007200,0.5; 9010800,0.5; 9014400,0.5; 9018000,0.5;
        9021600,0.5; 9025200,0.5; 9028800,0.5; 9032400,0.5; 9036000,0.5;
        9039600,0.5; 9043200,0.5; 9046800,0.5; 9050400,0.5; 9054000,0.5;
        9057600,0.5; 9061200,0.5; 9064800,0.5; 9068400,0.5; 9072000,0.5;
        9075600,0.5; 9079200,0.5; 9082800,0.5; 9086400,0.5; 9090000,0.5;
        9093600,0.5; 9097200,0.5; 9100800,0.5; 9104400,0.5; 9108000,0.5;
        9111600,0.5; 9115200,0.5; 9118800,0.5; 9122400,0.5; 9126000,0.5;
        9129600,0.5; 9133200,0.5; 9136800,0.5; 9140400,0.5; 9144000,0.5;
        9147600,0.5; 9151200,0.5; 9154800,0.5; 9158400,0.5; 9162000,0.5;
        9165600,0.5; 9169200,0.5; 9172800,0.5; 9176400,0.5; 9180000,0.5;
        9183600,0.5; 9187200,0.5; 9190800,0.5; 9194400,0.5; 9198000,0.5;
        9201600,0.5; 9205200,0.5; 9208800,0.5; 9212400,0.5; 9216000,0.5;
        9219600,0.5; 9223200,0.5; 9226800,0.5; 9230400,0.5; 9234000,0.5;
        9237600,0.5; 9241200,0.5; 9244800,0.5; 9248400,0.5; 9252000,0.5;
        9255600,0.5; 9259200,0.5; 9262800,0.5; 9266400,0.5; 9270000,0.5;
        9273600,0.5; 9277200,0.5; 9280800,0.5; 9284400,0.5; 9288000,0.5;
        9291600,0.5; 9295200,0.5; 9298800,0.5; 9302400,0.5; 9306000,0.5;
        9309600,0.5; 9313200,0.5; 9316800,0.5; 9320400,0.5; 9324000,0.5;
        9327600,0.5; 9331200,0.5; 9334800,0.5; 9338400,0.5; 9342000,0.5;
        9345600,0.5; 9349200,0.5; 9352800,0.5; 9356400,0.5; 9360000,0.5;
        9363600,0.5; 9367200,0.5; 9370800,0.5; 9374400,0.5; 9378000,0.5;
        9381600,0.5; 9385200,0.5; 9388800,0.5; 9392400,0.5; 9396000,0.5;
        9399600,0.5; 9403200,0.5; 9406800,0.5; 9410400,0.5; 9414000,0.5;
        9417600,0.5; 9421200,0.5; 9424800,0.5; 9428400,0.5; 9432000,0.5;
        9435600,0.5; 9439200,0.5; 9442800,0.5; 9446400,0.5; 9450000,0.5;
        9453600,0.5; 9457200,0.5; 9460800,0.5; 9464400,0.5; 9468000,0.5;
        9471600,0.5; 9475200,0.5; 9478800,0.5; 9482400,0.5; 9486000,0.5;
        9489600,0.5; 9493200,0.5; 9496800,0.5; 9500400,0.5; 9504000,0.5;
        9507600,0.5; 9511200,0.5; 9514800,0.5; 9518400,0.5; 9522000,0.5;
        9525600,0.5; 9529200,0.5; 9532800,0.5; 9536400,0.5; 9540000,0.5;
        9543600,0.5; 9547200,0.5; 9550800,0.5; 9554400,0.5; 9558000,0.5;
        9561600,0.5; 9565200,0.5; 9568800,0.5; 9572400,0.5; 9576000,0.5;
        9579600,0.5; 9583200,0.5; 9586800,0.5; 9590400,0.5; 9594000,0.5;
        9597600,0.5; 9601200,0.5; 9604800,0.5; 9608400,0.5; 9612000,0.5;
        9615600,0.5; 9619200,0.5; 9622800,0.5; 9626400,0.5; 9630000,0.5;
        9633600,0.5; 9637200,0.5; 9640800,0.5; 9644400,0.5; 9648000,0.5;
        9651600,0.5; 9655200,0.5; 9658800,0.5; 9662400,0.5; 9666000,0.5;
        9669600,0.5; 9673200,0.5; 9676800,0.5; 9680400,0.5; 9684000,0.5;
        9687600,0.5; 9691200,0.5; 9694800,0.5; 9698400,0.5; 9702000,0.5;
        9705600,0.5; 9709200,0.5; 9712800,0.5; 9716400,0.5; 9720000,0.5;
        9723600,0.5; 9727200,0.5; 9730800,0.5; 9734400,0.5; 9738000,0.5;
        9741600,0.5; 9745200,0.5; 9748800,0.5; 9752400,0.5; 9756000,0.5;
        9759600,0.5; 9763200,0.5; 9766800,0.5; 9770400,0.5; 9774000,0.5;
        9777600,0.5; 9781200,0.5; 9784800,0.5; 9788400,0.5; 9792000,0.5;
        9795600,0.5; 9799200,0.5; 9802800,0.5; 9806400,0.5; 9810000,0.5;
        9813600,0.5; 9817200,0.5; 9820800,0.5; 9824400,0.5; 9828000,0.5;
        9831600,0.5; 9835200,0.5; 9838800,0.5; 9842400,0.5; 9846000,0.5;
        9849600,0.5; 9853200,0.5; 9856800,0.5; 9860400,0.5; 9864000,0.5;
        9867600,0.5; 9871200,0.5; 9874800,0.5; 9878400,0.5; 9882000,0.5;
        9885600,0.5; 9889200,0.5; 9892800,0.5; 9896400,0.5; 9900000,0.5;
        9903600,0.5; 9907200,0.5; 9910800,0.5; 9914400,0.5; 9918000,0.5;
        9921600,0.5; 9925200,0.5; 9928800,0.5; 9932400,0.5; 9936000,0.5;
        9939600,0.5; 9943200,0.5; 9946800,0.5; 9950400,0.5; 9954000,0.5;
        9957600,0.5; 9961200,0.5; 9964800,0.5; 9968400,0.5; 9972000,0.5;
        9975600,0.5; 9979200,0.5; 9982800,0.5; 9986400,0.5; 9990000,0.5;
        9993600,0.5; 9997200,0.5; 10000800,0.5; 10004400,0.5; 10008000,0.5;
        10011600,0.5; 10015200,0.5; 10018800,0.5; 10022400,0.5; 10026000,0.5;
        10029600,0.5; 10033200,0.5; 10036800,0.5; 10040400,0.5; 10044000,0.5;
        10047600,0.5; 10051200,0.5; 10054800,0.5; 10058400,0.5; 10062000,0.5;
        10065600,0.5; 10069200,0.5; 10072800,0.5; 10076400,0.5; 10080000,0.5;
        10083600,0.5; 10087200,0.5; 10090800,0.5; 10094400,0.5; 10098000,0.5;
        10101600,0.5; 10105200,0.5; 10108800,0.5; 10112400,0.5; 10116000,0.5;
        10119600,0.5; 10123200,0.5; 10126800,0.5; 10130400,0.5; 10134000,0.5;
        10137600,0.5; 10141200,0.5; 10144800,0.5; 10148400,0.5; 10152000,0.5;
        10155600,0.5; 10159200,0.5; 10162800,0.5; 10166400,0.5; 10170000,0.5;
        10173600,0.5; 10177200,0.5; 10180800,0.5; 10184400,0.5; 10188000,0.5;
        10191600,0.5; 10195200,0.5; 10198800,0.5; 10202400,0.5; 10206000,0.5;
        10209600,0.5; 10213200,0.5; 10216800,0.5; 10220400,0.5; 10224000,0.5;
        10227600,0.5; 10231200,0.5; 10234800,0.5; 10238400,0.5; 10242000,0.5;
        10245600,0.5; 10249200,0.5; 10252800,0.5; 10256400,0.5; 10260000,0.5;
        10263600,0.5; 10267200,0.5; 10270800,0.5; 10274400,0.5; 10278000,0.5;
        10281600,0.5; 10285200,0.5; 10288800,0.5; 10292400,0.5; 10296000,0.5;
        10299600,0.5; 10303200,0.5; 10306800,0.5; 10310400,0.5; 10314000,0.5;
        10317600,0.5; 10321200,0.5; 10324800,0.5; 10328400,0.5; 10332000,0.5;
        10335600,0.5; 10339200,0.5; 10342800,0.5; 10346400,0.5; 10350000,0.5;
        10353600,0.5; 10357200,0.5; 10360800,0.5; 10364400,0.5; 10368000,0.5;
        10371600,0.5; 10375200,0.5; 10378800,0.5; 10382400,0.5; 10386000,0.5;
        10389600,0.5; 10393200,0.5; 10396800,0.5; 10400400,0.5; 10404000,0.5;
        10407600,0.5; 10411200,0.5; 10414800,0.5; 10418400,0.5; 10422000,0.5;
        10425600,0.5; 10429200,0.5; 10432800,0.5; 10436400,0.5; 10440000,0.5;
        10443600,0.5; 10447200,0.5; 10450800,0.5; 10454400,0.5; 10458000,0.5;
        10461600,0.5; 10465200,0.5; 10468800,0.5; 10472400,0.5; 10476000,0.5;
        10479600,0.5; 10483200,0.5; 10486800,0.5; 10490400,0.5; 10494000,0.5;
        10497600,0.5; 10501200,0.5; 10504800,0.5; 10508400,0.5; 10512000,0.5;
        10515600,0.5; 10519200,0.5; 10522800,0.5; 10526400,0.5; 10530000,0.5;
        10533600,0.5; 10537200,0.5; 10540800,0.5; 10544400,0.5; 10548000,0.5;
        10551600,0.5; 10555200,0.5; 10558800,0.5; 10562400,0.5; 10566000,0.5;
        10569600,0.5; 10573200,0.5; 10576800,0.5; 10580400,0.5; 10584000,0.5;
        10587600,0.5; 10591200,0.5; 10594800,0.5; 10598400,0.5; 10602000,0.5;
        10605600,0.5; 10609200,0.5; 10612800,0.5; 10616400,0.5; 10620000,0.5;
        10623600,0.5; 10627200,0.5; 10630800,0.5; 10634400,0.5; 10638000,0.5;
        10641600,0.5; 10645200,0.5; 10648800,0.5; 10652400,0.5; 10656000,0.5;
        10659600,0.5; 10663200,0.5; 10666800,0.5; 10670400,0.5; 10674000,0.5;
        10677600,0.5; 10681200,0.5; 10684800,0.5; 10688400,0.5; 10692000,0.5;
        10695600,0.5; 10699200,0.5; 10702800,0.5; 10706400,0.5; 10710000,0.5;
        10713600,0.5; 10717200,0.5; 10720800,0.5; 10724400,0.5; 10728000,0.5;
        10731600,0.5; 10735200,0.5; 10738800,0.5; 10742400,0.5; 10746000,0.5;
        10749600,0.5; 10753200,0.5; 10756800,0.5; 10760400,0.5; 10764000,0.5;
        10767600,0.5; 10771200,0.5; 10774800,0.5; 10778400,0.5; 10782000,0.5;
        10785600,0.5; 10789200,0.5; 10792800,0.5; 10796400,0.5; 10800000,0.5;
        10803600,0.5; 10807200,0.5; 10810800,0.5; 10814400,0.5; 10818000,0.5;
        10821600,0.5; 10825200,0.5; 10828800,0.5; 10832400,0.5; 10836000,0.5;
        10839600,0.5; 10843200,0.5; 10846800,0.5; 10850400,0.5; 10854000,0.5;
        10857600,0.5; 10861200,0.5; 10864800,0.5; 10868400,0.5; 10872000,0.5;
        10875600,0.5; 10879200,0.5; 10882800,0.5; 10886400,0.5; 10890000,0.5;
        10893600,0.5; 10897200,0.5; 10900800,0.5; 10904400,0.5; 10908000,0.5;
        10911600,0.5; 10915200,0.5; 10918800,0.5; 10922400,0.5; 10926000,0.5;
        10929600,0.5; 10933200,0.5; 10936800,0.5; 10940400,0.5; 10944000,0.5;
        10947600,0.5; 10951200,0.5; 10954800,0.5; 10958400,0.5; 10962000,0.5;
        10965600,0.5; 10969200,0.5; 10972800,0.5; 10976400,0.5; 10980000,0.5;
        10983600,0.5; 10987200,0.5; 10990800,0.5; 10994400,0.5; 10998000,0.5;
        11001600,0.5; 11005200,0.5; 11008800,0.5; 11012400,0.5; 11016000,0.5;
        11019600,0.5; 11023200,0.5; 11026800,0.5; 11030400,0.5; 11034000,0.5;
        11037600,0.5; 11041200,0.5; 11044800,0.5; 11048400,0.5; 11052000,0.5;
        11055600,0.5; 11059200,0.5; 11062800,0.5; 11066400,0.5; 11070000,0.5;
        11073600,0.5; 11077200,0.5; 11080800,0.5; 11084400,0.5; 11088000,0.5;
        11091600,0.5; 11095200,0.5; 11098800,0.5; 11102400,0.5; 11106000,0.5;
        11109600,0.5; 11113200,0.5; 11116800,0.5; 11120400,0.5; 11124000,0.5;
        11127600,0.5; 11131200,0.5; 11134800,0.5; 11138400,0.5; 11142000,0.5;
        11145600,0.5; 11149200,0.5; 11152800,0.5; 11156400,0.5; 11160000,0.5;
        11163600,0.5; 11167200,0.5; 11170800,0.5; 11174400,0.5; 11178000,0.5;
        11181600,0.5; 11185200,0.5; 11188800,0.5; 11192400,0.5; 11196000,0.5;
        11199600,0.5; 11203200,0.5; 11206800,0.5; 11210400,0.5; 11214000,0.5;
        11217600,0.5; 11221200,0.5; 11224800,0.5; 11228400,0.5; 11232000,0.5;
        11235600,0.5; 11239200,0.5; 11242800,0.5; 11246400,0.5; 11250000,0.5;
        11253600,0.5; 11257200,0.5; 11260800,0.5; 11264400,0.5; 11268000,0.5;
        11271600,0.5; 11275200,0.5; 11278800,0.5; 11282400,0.5; 11286000,0.5;
        11289600,0.5; 11293200,0.5; 11296800,0.5; 11300400,0.5; 11304000,0.5;
        11307600,0.5; 11311200,0.5; 11314800,0.5; 11318400,0.5; 11322000,0.5;
        11325600,0.5; 11329200,0.5; 11332800,0.5; 11336400,0.5; 11340000,0.5;
        11343600,0.5; 11347200,0.5; 11350800,0.5; 11354400,0.5; 11358000,0.5;
        11361600,0.5; 11365200,0.5; 11368800,0.5; 11372400,0.5; 11376000,0.5;
        11379600,0.5; 11383200,0.5; 11386800,0.5; 11390400,0.5; 11394000,0.5;
        11397600,0.5; 11401200,0.5; 11404800,0.5; 11408400,0.5; 11412000,0.5;
        11415600,0.5; 11419200,0.5; 11422800,0.5; 11426400,0.5; 11430000,0.5;
        11433600,0.5; 11437200,0.5; 11440800,0.5; 11444400,0.5; 11448000,0.5;
        11451600,0.5; 11455200,0.5; 11458800,0.5; 11462400,0.5; 11466000,0.5;
        11469600,0.5; 11473200,0.5; 11476800,0.5; 11480400,0.5; 11484000,0.5;
        11487600,0.5; 11491200,0.5; 11494800,0.5; 11498400,0.5; 11502000,0.5;
        11505600,0.5; 11509200,0.5; 11512800,0.5; 11516400,0.5; 11520000,0.5;
        11523600,0.5; 11527200,0.5; 11530800,0.5; 11534400,0.5; 11538000,0.5;
        11541600,0.5; 11545200,0.5; 11548800,0.5; 11552400,0.5; 11556000,0.5;
        11559600,0.5; 11563200,0.5; 11566800,0.5; 11570400,0.5; 11574000,0.5;
        11577600,0.5; 11581200,0.5; 11584800,0.5; 11588400,0.5; 11592000,0.5;
        11595600,0.5; 11599200,0.5; 11602800,0.5; 11606400,0.5; 11610000,0.5;
        11613600,0.5; 11617200,0.5; 11620800,0.5; 11624400,0.5; 11628000,0.5;
        11631600,0.5; 11635200,0.5; 11638800,0.5; 11642400,0.5; 11646000,0.5;
        11649600,0.5; 11653200,0.5; 11656800,0.5; 11660400,0.5; 11664000,0.5;
        11667600,0.5; 11671200,0.5; 11674800,0.5; 11678400,0.5; 11682000,0.5;
        11685600,0.5; 11689200,0.5; 11692800,0.5; 11696400,0.5; 11700000,0.5;
        11703600,0.5; 11707200,0.5; 11710800,0.5; 11714400,0.5; 11718000,0.5;
        11721600,0.5; 11725200,0.5; 11728800,0.5; 11732400,0.5; 11736000,0.5;
        11739600,0.5; 11743200,0.5; 11746800,0.5; 11750400,0.5; 11754000,0.5;
        11757600,0.5; 11761200,0.5; 11764800,0.5; 11768400,0.5; 11772000,0.5;
        11775600,0.5; 11779200,0.5; 11782800,0.5; 11786400,0.5; 11790000,0.5;
        11793600,0.5; 11797200,0.5; 11800800,0.5; 11804400,0.5; 11808000,0.5;
        11811600,0.5; 11815200,0.5; 11818800,0.5; 11822400,0.5; 11826000,0.5;
        11829600,0.5; 11833200,0.5; 11836800,0.5; 11840400,0.5; 11844000,0.5;
        11847600,0.5; 11851200,0.5; 11854800,0.5; 11858400,0.5; 11862000,0.5;
        11865600,0.5; 11869200,0.5; 11872800,0.5; 11876400,0.5; 11880000,0.5;
        11883600,0.5; 11887200,0.5; 11890800,0.5; 11894400,0.5; 11898000,0.5;
        11901600,0.5; 11905200,0.5; 11908800,0.5; 11912400,0.5; 11916000,0.5;
        11919600,0.5; 11923200,0.5; 11926800,0.5; 11930400,0.5; 11934000,0.5;
        11937600,0.5; 11941200,0.5; 11944800,0.5; 11948400,0.5; 11952000,0.5;
        11955600,0.5; 11959200,0.5; 11962800,0.5; 11966400,0.5; 11970000,0.5;
        11973600,0.5; 11977200,0.5; 11980800,0.5; 11984400,0.5; 11988000,0.5;
        11991600,0.5; 11995200,0.5; 11998800,0.5; 12002400,0.5; 12006000,0.5;
        12009600,0.5; 12013200,0.5; 12016800,0.5; 12020400,0.5; 12024000,0.5;
        12027600,0.5; 12031200,0.5; 12034800,0.5; 12038400,0.5; 12042000,0.5;
        12045600,0.5; 12049200,0.5; 12052800,0.5; 12056400,0.5; 12060000,0.5;
        12063600,0.5; 12067200,0.5; 12070800,0.5; 12074400,0.5; 12078000,0.5;
        12081600,0.5; 12085200,0.5; 12088800,0.5; 12092400,0.5; 12096000,0.5;
        12099600,0.5; 12103200,0.5; 12106800,0.5; 12110400,0.5; 12114000,0.5;
        12117600,0.5; 12121200,0.5; 12124800,0.5; 12128400,0.5; 12132000,0.5;
        12135600,0.5; 12139200,0.5; 12142800,0.5; 12146400,0.5; 12150000,0.5;
        12153600,0.5; 12157200,0.5; 12160800,0.5; 12164400,0.5; 12168000,0.5;
        12171600,0.5; 12175200,0.5; 12178800,0.5; 12182400,0.5; 12186000,0.5;
        12189600,0.5; 12193200,0.5; 12196800,0.5; 12200400,0.5; 12204000,0.5;
        12207600,0.5; 12211200,0.5; 12214800,0.5; 12218400,0.5; 12222000,0.5;
        12225600,0.5; 12229200,0.5; 12232800,0.5; 12236400,0.5; 12240000,0.5;
        12243600,0.5; 12247200,0.5; 12250800,0.5; 12254400,0.5; 12258000,0.5;
        12261600,0.5; 12265200,0.5; 12268800,0.5; 12272400,0.5; 12276000,0.5;
        12279600,0.5; 12283200,0.5; 12286800,0.5; 12290400,0.5; 12294000,0.5;
        12297600,0.5; 12301200,0.5; 12304800,0.5; 12308400,0.5; 12312000,0.5;
        12315600,0.5; 12319200,0.5; 12322800,0.5; 12326400,0.5; 12330000,0.5;
        12333600,0.5; 12337200,0.5; 12340800,0.5; 12344400,0.5; 12348000,0.5;
        12351600,0.5; 12355200,0.5; 12358800,0.5; 12362400,0.5; 12366000,0.5;
        12369600,0.5; 12373200,0.5; 12376800,0.5; 12380400,0.5; 12384000,0.5;
        12387600,0.5; 12391200,0.5; 12394800,0.5; 12398400,0.5; 12402000,0.5;
        12405600,0.5; 12409200,0.5; 12412800,0.5; 12416400,0.5; 12420000,0.5;
        12423600,0.5; 12427200,0.5; 12430800,0.5; 12434400,0.5; 12438000,0.5;
        12441600,0.5; 12445200,0.5; 12448800,0.5; 12452400,0.5; 12456000,0.5;
        12459600,0.5; 12463200,0.5; 12466800,0.5; 12470400,0.5; 12474000,0.5;
        12477600,0.5; 12481200,0.5; 12484800,0.5; 12488400,0.5; 12492000,0.5;
        12495600,0.5; 12499200,0.5; 12502800,0.5; 12506400,0.5; 12510000,0.5;
        12513600,0.5; 12517200,0.5; 12520800,0.5; 12524400,0.5; 12528000,0.5;
        12531600,0.5; 12535200,0.5; 12538800,0.5; 12542400,0.5; 12546000,0.5;
        12549600,0.5; 12553200,0.5; 12556800,0.5; 12560400,0.5; 12564000,0.5;
        12567600,0.5; 12571200,0.5; 12574800,0.5; 12578400,0.5; 12582000,0.5;
        12585600,0.5; 12589200,0.5; 12592800,0.5; 12596400,0.5; 12600000,0.5;
        12603600,0.5; 12607200,0.5; 12610800,0.5; 12614400,0.5; 12618000,0.5;
        12621600,0.5; 12625200,0.5; 12628800,0.5; 12632400,0.5; 12636000,0.5;
        12639600,0.5; 12643200,0.5; 12646800,0.5; 12650400,0.5; 12654000,0.5;
        12657600,0.5; 12661200,0.5; 12664800,0.5; 12668400,0.5; 12672000,0.5;
        12675600,0.5; 12679200,0.5; 12682800,0.5; 12686400,0.5; 12690000,0.5;
        12693600,0.5; 12697200,0.5; 12700800,0.5; 12704400,0.5; 12708000,0.5;
        12711600,0.5; 12715200,0.5; 12718800,0.5; 12722400,0.5; 12726000,0.5;
        12729600,0.5; 12733200,0.5; 12736800,0.5; 12740400,0.5; 12744000,0.5;
        12747600,0.5; 12751200,0.5; 12754800,0.5; 12758400,0.5; 12762000,0.5;
        12765600,0.5; 12769200,0.5; 12772800,0.5; 12776400,0.5; 12780000,0.5;
        12783600,0.5; 12787200,0.5; 12790800,0.5; 12794400,0.5; 12798000,0.5;
        12801600,0.5; 12805200,0.5; 12808800,0.5; 12812400,0.5; 12816000,0.5;
        12819600,0.5; 12823200,0.5; 12826800,0.5; 12830400,0.5; 12834000,0.5;
        12837600,0.5; 12841200,0.5; 12844800,0.5; 12848400,0.5; 12852000,0.5;
        12855600,0.5; 12859200,0.5; 12862800,0.5; 12866400,0.5; 12870000,0.5;
        12873600,0.5; 12877200,0.5; 12880800,0.5; 12884400,0.5; 12888000,0.5;
        12891600,0.5; 12895200,0.5; 12898800,0.5; 12902400,0.5; 12906000,0.5;
        12909600,0.5; 12913200,0.5; 12916800,0.5; 12920400,0.5; 12924000,0.5;
        12927600,0.5; 12931200,0.5; 12934800,0.5; 12938400,0.5; 12942000,0.5;
        12945600,0.5; 12949200,0.5; 12952800,0.5; 12956400,0.5; 12960000,0.5;
        12963600,0.5; 12967200,0.5; 12970800,0.5; 12974400,0.5; 12978000,0.5;
        12981600,0.5; 12985200,0.5; 12988800,0.5; 12992400,0.5; 12996000,0.5;
        12999600,0.5; 13003200,0.5; 13006800,0.5; 13010400,0.5; 13014000,0.5;
        13017600,0.5; 13021200,0.5; 13024800,0.5; 13028400,0.5; 13032000,0.5;
        13035600,0.5; 13039200,0.5; 13042800,0.5; 13046400,0.5; 13050000,0.5;
        13053600,0.5; 13057200,0.5; 13060800,0.5; 13064400,0.5; 13068000,0.5;
        13071600,0.5; 13075200,0.5; 13078800,0.5; 13082400,0.5; 13086000,0.5;
        13089600,0.5; 13093200,0.5; 13096800,0.5; 13100400,0.5; 13104000,0.5;
        13107600,0.5; 13111200,0.5; 13114800,0.5; 13118400,0.5; 13122000,0.5;
        13125600,0.5; 13129200,0.5; 13132800,0.5; 13136400,0.5; 13140000,0.5;
        13143600,0.5; 13147200,0.5; 13150800,0.5; 13154400,0.5; 13158000,0.5;
        13161600,0.5; 13165200,0.5; 13168800,0.5; 13172400,0.5; 13176000,0.5;
        13179600,0.5; 13183200,0.5; 13186800,0.5; 13190400,0.5; 13194000,0.5;
        13197600,0.5; 13201200,0.5; 13204800,0.5; 13208400,0.5; 13212000,0.5;
        13215600,0.5; 13219200,0.5; 13222800,0.5; 13226400,0.5; 13230000,0.5;
        13233600,0.5; 13237200,0.5; 13240800,0.5; 13244400,0.5; 13248000,0.5;
        13251600,0.5; 13255200,0.5; 13258800,0.5; 13262400,0.5; 13266000,0.5;
        13269600,0.5; 13273200,0.5; 13276800,0.5; 13280400,0.5; 13284000,0.5;
        13287600,0.5; 13291200,0.5; 13294800,0.5; 13298400,0.5; 13302000,0.5;
        13305600,0.5; 13309200,0.5; 13312800,0.5; 13316400,0.5; 13320000,0.5;
        13323600,0.5; 13327200,0.5; 13330800,0.5; 13334400,0.5; 13338000,0.5;
        13341600,0.5; 13345200,0.5; 13348800,0.5; 13352400,0.5; 13356000,0.5;
        13359600,0.5; 13363200,0.5; 13366800,0.5; 13370400,0.5; 13374000,0.5;
        13377600,0.5; 13381200,0.5; 13384800,0.5; 13388400,0.5; 13392000,0.5;
        13395600,0.5; 13399200,0.5; 13402800,0.5; 13406400,0.5; 13410000,0.5;
        13413600,0.5; 13417200,0.5; 13420800,0.5; 13424400,0.5; 13428000,0.5;
        13431600,0.5; 13435200,0.5; 13438800,0.5; 13442400,0.5; 13446000,0.5;
        13449600,0.5; 13453200,0.5; 13456800,0.5; 13460400,0.5; 13464000,0.5;
        13467600,0.5; 13471200,0.5; 13474800,0.5; 13478400,0.5; 13482000,0.5;
        13485600,0.5; 13489200,0.5; 13492800,0.5; 13496400,0.5; 13500000,0.5;
        13503600,0.5; 13507200,0.5; 13510800,0.5; 13514400,0.5; 13518000,0.5;
        13521600,0.5; 13525200,0.5; 13528800,0.5; 13532400,0.5; 13536000,0.5;
        13539600,0.5; 13543200,0.5; 13546800,0.5; 13550400,0.5; 13554000,0.5;
        13557600,0.5; 13561200,0.5; 13564800,0.5; 13568400,0.5; 13572000,0.5;
        13575600,0.5; 13579200,0.5; 13582800,0.5; 13586400,0.5; 13590000,0.5;
        13593600,0.5; 13597200,0.5; 13600800,0.5; 13604400,0.5; 13608000,0.5;
        13611600,0.5; 13615200,0.5; 13618800,0.5; 13622400,0.5; 13626000,0.5;
        13629600,0.5; 13633200,0.5; 13636800,0.5; 13640400,0.5; 13644000,0.5;
        13647600,0.5; 13651200,0.5; 13654800,0.5; 13658400,0.5; 13662000,0.5;
        13665600,0.5; 13669200,0.5; 13672800,0.5; 13676400,0.5; 13680000,0.5;
        13683600,0.5; 13687200,0.5; 13690800,0.5; 13694400,0.5; 13698000,0.5;
        13701600,0.5; 13705200,0.5; 13708800,0.5; 13712400,0.5; 13716000,0.5;
        13719600,0.5; 13723200,0.5; 13726800,0.5; 13730400,0.5; 13734000,0.5;
        13737600,0.5; 13741200,0.5; 13744800,0.5; 13748400,0.5; 13752000,0.5;
        13755600,0.5; 13759200,0.5; 13762800,0.5; 13766400,0.5; 13770000,0.5;
        13773600,0.5; 13777200,0.5; 13780800,0.5; 13784400,0.5; 13788000,0.5;
        13791600,0.5; 13795200,0.5; 13798800,0.5; 13802400,0.5; 13806000,0.5;
        13809600,0.5; 13813200,0.5; 13816800,0.5; 13820400,0.5; 13824000,0.5;
        13827600,0.5; 13831200,0.5; 13834800,0.5; 13838400,0.5; 13842000,0.5;
        13845600,0.5; 13849200,0.5; 13852800,0.5; 13856400,0.5; 13860000,0.5;
        13863600,0.5; 13867200,0.5; 13870800,0.5; 13874400,0.5; 13878000,0.5;
        13881600,0.5; 13885200,0.5; 13888800,0.5; 13892400,0.5; 13896000,0.5;
        13899600,0.5; 13903200,0.5; 13906800,0.5; 13910400,0.5; 13914000,0.5;
        13917600,0.5; 13921200,0.5; 13924800,0.5; 13928400,0.5; 13932000,0.5;
        13935600,0.5; 13939200,0.5; 13942800,0.5; 13946400,0.5; 13950000,0.5;
        13953600,0.5; 13957200,0.5; 13960800,0.5; 13964400,0.5; 13968000,0.5;
        13971600,0.5; 13975200,0.5; 13978800,0.5; 13982400,0.5; 13986000,0.5;
        13989600,0.5; 13993200,0.5; 13996800,0.5; 14000400,0.5; 14004000,0.5;
        14007600,0.5; 14011200,0.5; 14014800,0.5; 14018400,0.5; 14022000,0.5;
        14025600,0.5; 14029200,0.5; 14032800,0.5; 14036400,0.5; 14040000,0.5;
        14043600,0.5; 14047200,0.5; 14050800,0.5; 14054400,0.5; 14058000,0.5;
        14061600,0.5; 14065200,0.5; 14068800,0.5; 14072400,0.5; 14076000,0.5;
        14079600,0.5; 14083200,0.5; 14086800,0.5; 14090400,0.5; 14094000,0.5;
        14097600,0.5; 14101200,0.5; 14104800,0.5; 14108400,0.5; 14112000,0.5;
        14115600,0.5; 14119200,0.5; 14122800,0.5; 14126400,0.5; 14130000,0.5;
        14133600,0.5; 14137200,0.5; 14140800,0.5; 14144400,0.5; 14148000,0.5;
        14151600,0.5; 14155200,0.5; 14158800,0.5; 14162400,0.5; 14166000,0.5;
        14169600,0.5; 14173200,0.5; 14176800,0.5; 14180400,0.5; 14184000,0.5;
        14187600,0.5; 14191200,0.5; 14194800,0.5; 14198400,0.5; 14202000,0.5;
        14205600,0.5; 14209200,0.5; 14212800,0.5; 14216400,0.5; 14220000,0.5;
        14223600,0.5; 14227200,0.5; 14230800,0.5; 14234400,0.5; 14238000,0.5;
        14241600,0.5; 14245200,0.5; 14248800,0.5; 14252400,0.5; 14256000,0.5;
        14259600,0.5; 14263200,0.5; 14266800,0.5; 14270400,0.5; 14274000,0.5;
        14277600,0.5; 14281200,0.5; 14284800,0.5; 14288400,0.5; 14292000,0.5;
        14295600,0.5; 14299200,0.5; 14302800,0.5; 14306400,0.5; 14310000,0.5;
        14313600,0.5; 14317200,0.5; 14320800,0.5; 14324400,0.5; 14328000,0.5;
        14331600,0.5; 14335200,0.5; 14338800,0.5; 14342400,0.5; 14346000,0.5;
        14349600,0.5; 14353200,0.5; 14356800,0.5; 14360400,0.5; 14364000,0.5;
        14367600,0.5; 14371200,0.5; 14374800,0.5; 14378400,0.5; 14382000,0.5;
        14385600,0.5; 14389200,0.5; 14392800,0.5; 14396400,0.5; 14400000,0.5;
        14403600,0.5; 14407200,0.5; 14410800,0.5; 14414400,0.5; 14418000,0.5;
        14421600,0.5; 14425200,0.5; 14428800,0.5; 14432400,0.5; 14436000,0.5;
        14439600,0.5; 14443200,0.5; 14446800,0.5; 14450400,0.5; 14454000,0.5;
        14457600,0.5; 14461200,0.5; 14464800,0.5; 14468400,0.5; 14472000,0.5;
        14475600,0.5; 14479200,0.5; 14482800,0.5; 14486400,0.5; 14490000,0.5;
        14493600,0.5; 14497200,0.5; 14500800,0.5; 14504400,0.5; 14508000,0.5;
        14511600,0.5; 14515200,0.5; 14518800,0.5; 14522400,0.5; 14526000,0.5;
        14529600,0.5; 14533200,0.5; 14536800,0.5; 14540400,0.5; 14544000,0.5;
        14547600,0.5; 14551200,0.5; 14554800,0.5; 14558400,0.5; 14562000,0.5;
        14565600,0.5; 14569200,0.5; 14572800,0.5; 14576400,0.5; 14580000,0.5;
        14583600,0.5; 14587200,0.5; 14590800,0.5; 14594400,0.5; 14598000,0.5;
        14601600,0.5; 14605200,0.5; 14608800,0.5; 14612400,0.5; 14616000,0.5;
        14619600,0.5; 14623200,0.5; 14626800,0.5; 14630400,0.5; 14634000,0.5;
        14637600,0.5; 14641200,0.5; 14644800,0.5; 14648400,0.5; 14652000,0.5;
        14655600,0.5; 14659200,0.5; 14662800,0.5; 14666400,0.5; 14670000,0.5;
        14673600,0.5; 14677200,0.5; 14680800,0.5; 14684400,0.5; 14688000,0.5;
        14691600,0.5; 14695200,0.5; 14698800,0.5; 14702400,0.5; 14706000,0.5;
        14709600,0.5; 14713200,0.5; 14716800,0.5; 14720400,0.5; 14724000,0.5;
        14727600,0.5; 14731200,0.5; 14734800,0.5; 14738400,0.5; 14742000,0.5;
        14745600,0.5; 14749200,0.5; 14752800,0.5; 14756400,0.5; 14760000,0.5;
        14763600,0.5; 14767200,0.5; 14770800,0.5; 14774400,0.5; 14778000,0.5;
        14781600,0.5; 14785200,0.5; 14788800,0.5; 14792400,0.5; 14796000,0.5;
        14799600,0.5; 14803200,0.5; 14806800,0.5; 14810400,0.5; 14814000,0.5;
        14817600,0.5; 14821200,0.5; 14824800,0.5; 14828400,0.5; 14832000,0.5;
        14835600,0.5; 14839200,0.5; 14842800,0.5; 14846400,0.5; 14850000,0.5;
        14853600,0.5; 14857200,0.5; 14860800,0.5; 14864400,0.5; 14868000,0.5;
        14871600,0.5; 14875200,0.5; 14878800,0.5; 14882400,0.5; 14886000,0.5;
        14889600,0.5; 14893200,0.5; 14896800,0.5; 14900400,0.5; 14904000,0.5;
        14907600,0.5; 14911200,0.5; 14914800,0.5; 14918400,0.5; 14922000,0.5;
        14925600,0.5; 14929200,0.5; 14932800,0.5; 14936400,0.5; 14940000,0.5;
        14943600,0.5; 14947200,0.5; 14950800,0.5; 14954400,0.5; 14958000,0.5;
        14961600,0.5; 14965200,0.5; 14968800,0.5; 14972400,0.5; 14976000,0.5;
        14979600,0.5; 14983200,0.5; 14986800,0.5; 14990400,0.5; 14994000,0.5;
        14997600,0.5; 15001200,0.5; 15004800,0.5; 15008400,0.5; 15012000,0.5;
        15015600,0.5; 15019200,0.5; 15022800,0.5; 15026400,0.5; 15030000,0.5;
        15033600,0.5; 15037200,0.5; 15040800,0.5; 15044400,0.5; 15048000,0.5;
        15051600,0.5; 15055200,0.5; 15058800,0.5; 15062400,0.5; 15066000,0.5;
        15069600,0.5; 15073200,0.5; 15076800,0.5; 15080400,0.5; 15084000,0.5;
        15087600,0.5; 15091200,0.5; 15094800,0.5; 15098400,0.5; 15102000,0.5;
        15105600,0.5; 15109200,0.5; 15112800,0.5; 15116400,0.5; 15120000,0.5;
        15123600,0.5; 15127200,0.5; 15130800,0.5; 15134400,0.5; 15138000,0.5;
        15141600,0.5; 15145200,0.5; 15148800,0.5; 15152400,0.5; 15156000,0.5;
        15159600,0.5; 15163200,0.5; 15166800,0.5; 15170400,0.5; 15174000,0.5;
        15177600,0.5; 15181200,0.5; 15184800,0.5; 15188400,0.5; 15192000,0.5;
        15195600,0.5; 15199200,0.5; 15202800,0.5; 15206400,0.5; 15210000,0.5;
        15213600,0.5; 15217200,0.5; 15220800,0.5; 15224400,0.5; 15228000,0.5;
        15231600,0.5; 15235200,0.5; 15238800,0.5; 15242400,0.5; 15246000,0.5;
        15249600,0.5; 15253200,0.5; 15256800,0.5; 15260400,0.5; 15264000,0.5;
        15267600,0.5; 15271200,0.5; 15274800,0.5; 15278400,0.5; 15282000,0.5;
        15285600,0.5; 15289200,0.5; 15292800,0.5; 15296400,0.5; 15300000,0.5;
        15303600,0.5; 15307200,0.5; 15310800,0.5; 15314400,0.5; 15318000,0.5;
        15321600,0.5; 15325200,0.5; 15328800,0.5; 15332400,0.5; 15336000,0.5;
        15339600,0.5; 15343200,0.5; 15346800,0.5; 15350400,0.5; 15354000,0.5;
        15357600,0.5; 15361200,0.5; 15364800,0.5; 15368400,0.5; 15372000,0.5;
        15375600,0.5; 15379200,0.5; 15382800,0.5; 15386400,0.5; 15390000,0.5;
        15393600,0.5; 15397200,0.5; 15400800,0.5; 15404400,0.5; 15408000,0.5;
        15411600,0.5; 15415200,0.5; 15418800,0.5; 15422400,0.5; 15426000,0.5;
        15429600,0.5; 15433200,0.5; 15436800,0.5; 15440400,0.5; 15444000,0.5;
        15447600,0.5; 15451200,0.5; 15454800,0.5; 15458400,0.5; 15462000,0.5;
        15465600,0.5; 15469200,0.5; 15472800,0.5; 15476400,0.5; 15480000,0.5;
        15483600,0.5; 15487200,0.5; 15490800,0.5; 15494400,0.5; 15498000,0.5;
        15501600,0.5; 15505200,0.5; 15508800,0.5; 15512400,0.5; 15516000,0.5;
        15519600,0.5; 15523200,0.5; 15526800,0.5; 15530400,0.5; 15534000,0.5;
        15537600,0.5; 15541200,0.5; 15544800,0.5; 15548400,0.5; 15552000,0.5;
        15555600,0.5; 15559200,0.5; 15562800,0.5; 15566400,0.5; 15570000,0.5;
        15573600,0.5; 15577200,0.5; 15580800,0.5; 15584400,0.5; 15588000,0.5;
        15591600,0.5; 15595200,0.5; 15598800,0.5; 15602400,0.5; 15606000,0.5;
        15609600,0.5; 15613200,0.5; 15616800,0.5; 15620400,0.5; 15624000,0.5;
        15627600,0.5; 15631200,0.5; 15634800,0.5; 15638400,0.5; 15642000,0.5;
        15645600,0.5; 15649200,0.5; 15652800,0.5; 15656400,0.5; 15660000,0.5;
        15663600,0.5; 15667200,0.5; 15670800,0.5; 15674400,0.5; 15678000,0.5;
        15681600,0.5; 15685200,0.5; 15688800,0.5; 15692400,0.5; 15696000,0.5;
        15699600,0.5; 15703200,0.5; 15706800,0.5; 15710400,0.5; 15714000,0.5;
        15717600,0.5; 15721200,0.5; 15724800,0.5; 15728400,0.5; 15732000,0.5;
        15735600,0.5; 15739200,0.5; 15742800,0.5; 15746400,0.5; 15750000,0.5;
        15753600,0.5; 15757200,0.5; 15760800,0.5; 15764400,0.5; 15768000,0.5;
        15771600,0.5; 15775200,0.5; 15778800,0.5; 15782400,0.5; 15786000,0.5;
        15789600,0.5; 15793200,0.5; 15796800,0.5; 15800400,0.5; 15804000,0.5;
        15807600,0.5; 15811200,0.5; 15814800,0.5; 15818400,0.5; 15822000,0.5;
        15825600,0.5; 15829200,0.5; 15832800,0.5; 15836400,0.5; 15840000,0.5;
        15843600,0.5; 15847200,0.5; 15850800,0.5; 15854400,0.5; 15858000,0.5;
        15861600,0.5; 15865200,0.5; 15868800,0.5; 15872400,0.5; 15876000,0.5;
        15879600,0.5; 15883200,0.5; 15886800,0.5; 15890400,0.5; 15894000,0.5;
        15897600,0.5; 15901200,0.5; 15904800,0.5; 15908400,0.5; 15912000,0.5;
        15915600,0.5; 15919200,0.5; 15922800,0.5; 15926400,0.5; 15930000,0.5;
        15933600,0.5; 15937200,0.5; 15940800,0.5; 15944400,0.5; 15948000,0.5;
        15951600,0.5; 15955200,0.5; 15958800,0.5; 15962400,0.5; 15966000,0.5;
        15969600,0.5; 15973200,0.5; 15976800,0.5; 15980400,0.5; 15984000,0.5;
        15987600,0.5; 15991200,0.5; 15994800,0.5; 15998400,0.5; 16002000,0.5;
        16005600,0.5; 16009200,0.5; 16012800,0.5; 16016400,0.5; 16020000,0.5;
        16023600,0.5; 16027200,0.5; 16030800,0.5; 16034400,0.5; 16038000,0.5;
        16041600,0.5; 16045200,0.5; 16048800,0.5; 16052400,0.5; 16056000,0.5;
        16059600,0.5; 16063200,0.5; 16066800,0.5; 16070400,0.5; 16074000,0.5;
        16077600,0.5; 16081200,0.5; 16084800,0.5; 16088400,0.5; 16092000,0.5;
        16095600,0.5; 16099200,0.5; 16102800,0.5; 16106400,0.5; 16110000,0.5;
        16113600,0.5; 16117200,0.5; 16120800,0.5; 16124400,0.5; 16128000,0.5;
        16131600,0.5; 16135200,0.5; 16138800,0.5; 16142400,0.5; 16146000,0.5;
        16149600,0.5; 16153200,0.5; 16156800,0.5; 16160400,0.5; 16164000,0.5;
        16167600,0.5; 16171200,0.5; 16174800,0.5; 16178400,0.5; 16182000,0.5;
        16185600,0.5; 16189200,0.5; 16192800,0.5; 16196400,0.5; 16200000,0.5;
        16203600,0.5; 16207200,0.5; 16210800,0.5; 16214400,0.5; 16218000,0.5;
        16221600,0.5; 16225200,0.5; 16228800,0.5; 16232400,0.5; 16236000,0.5;
        16239600,0.5; 16243200,0.5; 16246800,0.5; 16250400,0.5; 16254000,0.5;
        16257600,0.5; 16261200,0.5; 16264800,0.5; 16268400,0.5; 16272000,0.5;
        16275600,0.5; 16279200,0.5; 16282800,0.5; 16286400,0.5; 16290000,0.5;
        16293600,0.5; 16297200,0.5; 16300800,0.5; 16304400,0.5; 16308000,0.5;
        16311600,0.5; 16315200,0.5; 16318800,0.5; 16322400,0.5; 16326000,0.5;
        16329600,0.5; 16333200,0.5; 16336800,0.5; 16340400,0.5; 16344000,0.5;
        16347600,0.5; 16351200,0.5; 16354800,0.5; 16358400,0.5; 16362000,0.5;
        16365600,0.5; 16369200,0.5; 16372800,0.5; 16376400,0.5; 16380000,0.5;
        16383600,0.5; 16387200,0.5; 16390800,0.5; 16394400,0.5; 16398000,0.5;
        16401600,0.5; 16405200,0.5; 16408800,0.5; 16412400,0.5; 16416000,0.5;
        16419600,0.5; 16423200,0.5; 16426800,0.5; 16430400,0.5; 16434000,0.5;
        16437600,0.5; 16441200,0.5; 16444800,0.5; 16448400,0.5; 16452000,0.5;
        16455600,0.5; 16459200,0.5; 16462800,0.5; 16466400,0.5; 16470000,0.5;
        16473600,0.5; 16477200,0.5; 16480800,0.5; 16484400,0.5; 16488000,0.5;
        16491600,0.5; 16495200,0.5; 16498800,0.5; 16502400,0.5; 16506000,0.5;
        16509600,0.5; 16513200,0.5; 16516800,0.5; 16520400,0.5; 16524000,0.5;
        16527600,0.5; 16531200,0.5; 16534800,0.5; 16538400,0.5; 16542000,0.5;
        16545600,0.5; 16549200,0.5; 16552800,0.5; 16556400,0.5; 16560000,0.5;
        16563600,0.5; 16567200,0.5; 16570800,0.5; 16574400,0.5; 16578000,0.5;
        16581600,0.5; 16585200,0.5; 16588800,0.5; 16592400,0.5; 16596000,0.5;
        16599600,0.5; 16603200,0.5; 16606800,0.5; 16610400,0.5; 16614000,0.5;
        16617600,0.5; 16621200,0.5; 16624800,0.5; 16628400,0.5; 16632000,0.5;
        16635600,0.5; 16639200,0.5; 16642800,0.5; 16646400,0.5; 16650000,0.5;
        16653600,0.5; 16657200,0.5; 16660800,0.5; 16664400,0.5; 16668000,0.5;
        16671600,0.5; 16675200,0.5; 16678800,0.5; 16682400,0.5; 16686000,0.5;
        16689600,0.5; 16693200,0.5; 16696800,0.5; 16700400,0.5; 16704000,0.5;
        16707600,0.5; 16711200,0.5; 16714800,0.5; 16718400,0.5; 16722000,0.5;
        16725600,0.5; 16729200,0.5; 16732800,0.5; 16736400,0.5; 16740000,0.5;
        16743600,0.5; 16747200,0.5; 16750800,0.5; 16754400,0.5; 16758000,0.5;
        16761600,0.5; 16765200,0.5; 16768800,0.5; 16772400,0.5; 16776000,0.5;
        16779600,0.5; 16783200,0.5; 16786800,0.5; 16790400,0.5; 16794000,0.5;
        16797600,0.5; 16801200,0.5; 16804800,0.5; 16808400,0.5; 16812000,0.5;
        16815600,0.5; 16819200,0.5; 16822800,0.5; 16826400,0.5; 16830000,0.5;
        16833600,0.5; 16837200,0.5; 16840800,0.5; 16844400,0.5; 16848000,0.5;
        16851600,0.5; 16855200,0.5; 16858800,0.5; 16862400,0.5; 16866000,0.5;
        16869600,0.5; 16873200,0.5; 16876800,0.5; 16880400,0.5; 16884000,0.5;
        16887600,0.5; 16891200,0.5; 16894800,0.5; 16898400,0.5; 16902000,0.5;
        16905600,0.5; 16909200,0.5; 16912800,0.5; 16916400,0.5; 16920000,0.5;
        16923600,0.5; 16927200,0.5; 16930800,0.5; 16934400,0.5; 16938000,0.5;
        16941600,0.5; 16945200,0.5; 16948800,0.5; 16952400,0.5; 16956000,0.5;
        16959600,0.5; 16963200,0.5; 16966800,0.5; 16970400,0.5; 16974000,0.5;
        16977600,0.5; 16981200,0.5; 16984800,0.5; 16988400,0.5; 16992000,0.5;
        16995600,0.5; 16999200,0.5; 17002800,0.5; 17006400,0.5; 17010000,0.5;
        17013600,0.5; 17017200,0.5; 17020800,0.5; 17024400,0.5; 17028000,0.5;
        17031600,0.5; 17035200,0.5; 17038800,0.5; 17042400,0.5; 17046000,0.5;
        17049600,0.5; 17053200,0.5; 17056800,0.5; 17060400,0.5; 17064000,0.5;
        17067600,0.5; 17071200,0.5; 17074800,0.5; 17078400,0.5; 17082000,0.5;
        17085600,0.5; 17089200,0.5; 17092800,0.5; 17096400,0.5; 17100000,0.5;
        17103600,0.5; 17107200,0.5; 17110800,0.5; 17114400,0.5; 17118000,0.5;
        17121600,0.5; 17125200,0.5; 17128800,0.5; 17132400,0.5; 17136000,0.5;
        17139600,0.5; 17143200,0.5; 17146800,0.5; 17150400,0.5; 17154000,0.5;
        17157600,0.5; 17161200,0.5; 17164800,0.5; 17168400,0.5; 17172000,0.5;
        17175600,0.5; 17179200,0.5; 17182800,0.5; 17186400,0.5; 17190000,0.5;
        17193600,0.5; 17197200,0.5; 17200800,0.5; 17204400,0.5; 17208000,0.5;
        17211600,0.5; 17215200,0.5; 17218800,0.5; 17222400,0.5; 17226000,0.5;
        17229600,0.5; 17233200,0.5; 17236800,0.5; 17240400,0.5; 17244000,0.5;
        17247600,0.5; 17251200,0.5; 17254800,0.5; 17258400,0.5; 17262000,0.5;
        17265600,0.5; 17269200,0.5; 17272800,0.5; 17276400,0.5; 17280000,0.5;
        17283600,0.5; 17287200,0.5; 17290800,0.5; 17294400,0.5; 17298000,0.5;
        17301600,0.5; 17305200,0.5; 17308800,0.5; 17312400,0.5; 17316000,0.5;
        17319600,0.5; 17323200,0.5; 17326800,0.5; 17330400,0.5; 17334000,0.5;
        17337600,0.5; 17341200,0.5; 17344800,0.5; 17348400,0.5; 17352000,0.5;
        17355600,0.5; 17359200,0.5; 17362800,0.5; 17366400,0.5; 17370000,0.5;
        17373600,0.5; 17377200,0.5; 17380800,0.5; 17384400,0.5; 17388000,0.5;
        17391600,0.5; 17395200,0.5; 17398800,0.5; 17402400,0.5; 17406000,0.5;
        17409600,0.5; 17413200,0.5; 17416800,0.5; 17420400,0.5; 17424000,0.5;
        17427600,0.5; 17431200,0.5; 17434800,0.5; 17438400,0.5; 17442000,0.5;
        17445600,0.5; 17449200,0.5; 17452800,0.5; 17456400,0.5; 17460000,0.5;
        17463600,0.5; 17467200,0.5; 17470800,0.5; 17474400,0.5; 17478000,0.5;
        17481600,0.5; 17485200,0.5; 17488800,0.5; 17492400,0.5; 17496000,0.5;
        17499600,0.5; 17503200,0.5; 17506800,0.5; 17510400,0.5; 17514000,0.5;
        17517600,0.5; 17521200,0.5; 17524800,0.5; 17528400,0.5; 17532000,0.5;
        17535600,0.5; 17539200,0.5; 17542800,0.5; 17546400,0.5; 17550000,0.5;
        17553600,0.5; 17557200,0.5; 17560800,0.5; 17564400,0.5; 17568000,0.5;
        17571600,0.5; 17575200,0.5; 17578800,0.5; 17582400,0.5; 17586000,0.5;
        17589600,0.5; 17593200,0.5; 17596800,0.5; 17600400,0.5; 17604000,0.5;
        17607600,0.5; 17611200,0.5; 17614800,0.5; 17618400,0.5; 17622000,0.5;
        17625600,0.5; 17629200,0.5; 17632800,0.5; 17636400,0.5; 17640000,0.5;
        17643600,0.5; 17647200,0.5; 17650800,0.5; 17654400,0.5; 17658000,0.5;
        17661600,0.5; 17665200,0.5; 17668800,0.5; 17672400,0.5; 17676000,0.5;
        17679600,0.5; 17683200,0.5; 17686800,0.5; 17690400,0.5; 17694000,0.5;
        17697600,0.5; 17701200,0.5; 17704800,0.5; 17708400,0.5; 17712000,0.5;
        17715600,0.5; 17719200,0.5; 17722800,0.5; 17726400,0.5; 17730000,0.5;
        17733600,0.5; 17737200,0.5; 17740800,0.5; 17744400,0.5; 17748000,0.5;
        17751600,0.5; 17755200,0.5; 17758800,0.5; 17762400,0.5; 17766000,0.5;
        17769600,0.5; 17773200,0.5; 17776800,0.5; 17780400,0.5; 17784000,0.5;
        17787600,0.5; 17791200,0.5; 17794800,0.5; 17798400,0.5; 17802000,0.5;
        17805600,0.5; 17809200,0.5; 17812800,0.5; 17816400,0.5; 17820000,0.5;
        17823600,0.5; 17827200,0.5; 17830800,0.5; 17834400,0.5; 17838000,0.5;
        17841600,0.5; 17845200,0.5; 17848800,0.5; 17852400,0.5; 17856000,0.5;
        17859600,0.5; 17863200,0.5; 17866800,0.5; 17870400,0.5; 17874000,0.5;
        17877600,0.5; 17881200,0.5; 17884800,0.5; 17888400,0.5; 17892000,0.5;
        17895600,0.5; 17899200,0.5; 17902800,0.5; 17906400,0.5; 17910000,0.5;
        17913600,0.5; 17917200,0.5; 17920800,0.5; 17924400,0.5; 17928000,0.5;
        17931600,0.5; 17935200,0.5; 17938800,0.5; 17942400,0.5; 17946000,0.5;
        17949600,0.5; 17953200,0.5; 17956800,0.5; 17960400,0.5; 17964000,0.5;
        17967600,0.5; 17971200,0.5; 17974800,0.5; 17978400,0.5; 17982000,0.5;
        17985600,0.5; 17989200,0.5; 17992800,0.5; 17996400,0.5; 18000000,0.5;
        18003600,0.5; 18007200,0.5; 18010800,0.5; 18014400,0.5; 18018000,0.5;
        18021600,0.5; 18025200,0.5; 18028800,0.5; 18032400,0.5; 18036000,0.5;
        18039600,0.5; 18043200,0.5; 18046800,0.5; 18050400,0.5; 18054000,0.5;
        18057600,0.5; 18061200,0.5; 18064800,0.5; 18068400,0.5; 18072000,0.5;
        18075600,0.5; 18079200,0.5; 18082800,0.5; 18086400,0.5; 18090000,0.5;
        18093600,0.5; 18097200,0.5; 18100800,0.5; 18104400,0.5; 18108000,0.5;
        18111600,0.5; 18115200,0.5; 18118800,0.5; 18122400,0.5; 18126000,0.5;
        18129600,0.5; 18133200,0.5; 18136800,0.5; 18140400,0.5; 18144000,0.5;
        18147600,0.5; 18151200,0.5; 18154800,0.5; 18158400,0.5; 18162000,0.5;
        18165600,0.5; 18169200,0.5; 18172800,0.5; 18176400,0.5; 18180000,0.5;
        18183600,0.5; 18187200,0.5; 18190800,0.5; 18194400,0.5; 18198000,0.5;
        18201600,0.5; 18205200,0.5; 18208800,0.5; 18212400,0.5; 18216000,0.5;
        18219600,0.5; 18223200,0.5; 18226800,0.5; 18230400,0.5; 18234000,0.5;
        18237600,0.5; 18241200,0.5; 18244800,0.5; 18248400,0.5; 18252000,0.5;
        18255600,0.5; 18259200,0.5; 18262800,0.5; 18266400,0.5; 18270000,0.5;
        18273600,0.5; 18277200,0.5; 18280800,0.5; 18284400,0.5; 18288000,0.5;
        18291600,0.5; 18295200,0.5; 18298800,0.5; 18302400,0.5; 18306000,0.5;
        18309600,0.5; 18313200,0.5; 18316800,0.5; 18320400,0.5; 18324000,0.5;
        18327600,0.5; 18331200,0.5; 18334800,0.5; 18338400,0.5; 18342000,0.5;
        18345600,0.5; 18349200,0.5; 18352800,0.5; 18356400,0.5; 18360000,0.5;
        18363600,0.5; 18367200,0.5; 18370800,0.5; 18374400,0.5; 18378000,0.5;
        18381600,0.5; 18385200,0.5; 18388800,0.5; 18392400,0.5; 18396000,0.5;
        18399600,0.5; 18403200,0.5; 18406800,0.5; 18410400,0.5; 18414000,0.5;
        18417600,0.5; 18421200,0.5; 18424800,0.5; 18428400,0.5; 18432000,0.5;
        18435600,0.5; 18439200,0.5; 18442800,0.5; 18446400,0.5; 18450000,0.5;
        18453600,0.5; 18457200,0.5; 18460800,0.5; 18464400,0.5; 18468000,0.5;
        18471600,0.5; 18475200,0.5; 18478800,0.5; 18482400,0.5; 18486000,0.5;
        18489600,0.5; 18493200,0.5; 18496800,0.5; 18500400,0.5; 18504000,0.5;
        18507600,0.5; 18511200,0.5; 18514800,0.5; 18518400,0.5; 18522000,0.5;
        18525600,0.5; 18529200,0.5; 18532800,0.5; 18536400,0.5; 18540000,0.5;
        18543600,0.5; 18547200,0.5; 18550800,0.5; 18554400,0.5; 18558000,0.5;
        18561600,0.5; 18565200,0.5; 18568800,0.5; 18572400,0.5; 18576000,0.5;
        18579600,0.5; 18583200,0.5; 18586800,0.5; 18590400,0.5; 18594000,0.5;
        18597600,0.5; 18601200,0.5; 18604800,0.5; 18608400,0.5; 18612000,0.5;
        18615600,0.5; 18619200,0.5; 18622800,0.5; 18626400,0.5; 18630000,0.5;
        18633600,0.5; 18637200,0.5; 18640800,0.5; 18644400,0.5; 18648000,0.5;
        18651600,0.5; 18655200,0.5; 18658800,0.5; 18662400,0.5; 18666000,0.5;
        18669600,0.5; 18673200,0.5; 18676800,0.5; 18680400,0.5; 18684000,0.5;
        18687600,0.5; 18691200,0.5; 18694800,0.5; 18698400,0.5; 18702000,0.5;
        18705600,0.5; 18709200,0.5; 18712800,0.5; 18716400,0.5; 18720000,0.5;
        18723600,0.5; 18727200,0.5; 18730800,0.5; 18734400,0.5; 18738000,0.5;
        18741600,0.5; 18745200,0.5; 18748800,0.5; 18752400,0.5; 18756000,0.5;
        18759600,0.5; 18763200,0.5; 18766800,0.5; 18770400,0.5; 18774000,0.5;
        18777600,0.5; 18781200,0.5; 18784800,0.5; 18788400,0.5; 18792000,0.5;
        18795600,0.5; 18799200,0.5; 18802800,0.5; 18806400,0.5; 18810000,0.5;
        18813600,0.5; 18817200,0.5; 18820800,0.5; 18824400,0.5; 18828000,0.5;
        18831600,0.5; 18835200,0.5; 18838800,0.5; 18842400,0.5; 18846000,0.5;
        18849600,0.5; 18853200,0.5; 18856800,0.5; 18860400,0.5; 18864000,0.5;
        18867600,0.5; 18871200,0.5; 18874800,0.5; 18878400,0.5; 18882000,0.5;
        18885600,0.5; 18889200,0.5; 18892800,0.5; 18896400,0.5; 18900000,0.5;
        18903600,0.5; 18907200,0.5; 18910800,0.5; 18914400,0.5; 18918000,0.5;
        18921600,0.5; 18925200,0.5; 18928800,0.5; 18932400,0.5; 18936000,0.5;
        18939600,0.5; 18943200,0.5; 18946800,0.5; 18950400,0.5; 18954000,0.5;
        18957600,0.5; 18961200,0.5; 18964800,0.5; 18968400,0.5; 18972000,0.5;
        18975600,0.5; 18979200,0.5; 18982800,0.5; 18986400,0.5; 18990000,0.5;
        18993600,0.5; 18997200,0.5; 19000800,0.5; 19004400,0.5; 19008000,0.5;
        19011600,0.5; 19015200,0.5; 19018800,0.5; 19022400,0.5; 19026000,0.5;
        19029600,0.5; 19033200,0.5; 19036800,0.5; 19040400,0.5; 19044000,0.5;
        19047600,0.5; 19051200,0.5; 19054800,0.5; 19058400,0.5; 19062000,0.5;
        19065600,0.5; 19069200,0.5; 19072800,0.5; 19076400,0.5; 19080000,0.5;
        19083600,0.5; 19087200,0.5; 19090800,0.5; 19094400,0.5; 19098000,0.5;
        19101600,0.5; 19105200,0.5; 19108800,0.5; 19112400,0.5; 19116000,0.5;
        19119600,0.5; 19123200,0.5; 19126800,0.5; 19130400,0.5; 19134000,0.5;
        19137600,0.5; 19141200,0.5; 19144800,0.5; 19148400,0.5; 19152000,0.5;
        19155600,0.5; 19159200,0.5; 19162800,0.5; 19166400,0.5; 19170000,0.5;
        19173600,0.5; 19177200,0.5; 19180800,0.5; 19184400,0.5; 19188000,0.5;
        19191600,0.5; 19195200,0.5; 19198800,0.5; 19202400,0.5; 19206000,0.5;
        19209600,0.5; 19213200,0.5; 19216800,0.5; 19220400,0.5; 19224000,0.5;
        19227600,0.5; 19231200,0.5; 19234800,0.5; 19238400,0.5; 19242000,0.5;
        19245600,0.5; 19249200,0.5; 19252800,0.5; 19256400,0.5; 19260000,0.5;
        19263600,0.5; 19267200,0.5; 19270800,0.5; 19274400,0.5; 19278000,0.5;
        19281600,0.5; 19285200,0.5; 19288800,0.5; 19292400,0.5; 19296000,0.5;
        19299600,0.5; 19303200,0.5; 19306800,0.5; 19310400,0.5; 19314000,0.5;
        19317600,0.5; 19321200,0.5; 19324800,0.5; 19328400,0.5; 19332000,0.5;
        19335600,0.5; 19339200,0.5; 19342800,0.5; 19346400,0.5; 19350000,0.5;
        19353600,0.5; 19357200,0.5; 19360800,0.5; 19364400,0.5; 19368000,0.5;
        19371600,0.5; 19375200,0.5; 19378800,0.5; 19382400,0.5; 19386000,0.5;
        19389600,0.5; 19393200,0.5; 19396800,0.5; 19400400,0.5; 19404000,0.5;
        19407600,0.5; 19411200,0.5; 19414800,0.5; 19418400,0.5; 19422000,0.5;
        19425600,0.5; 19429200,0.5; 19432800,0.5; 19436400,0.5; 19440000,0.5;
        19443600,0.5; 19447200,0.5; 19450800,0.5; 19454400,0.5; 19458000,0.5;
        19461600,0.5; 19465200,0.5; 19468800,0.5; 19472400,0.5; 19476000,0.5;
        19479600,0.5; 19483200,0.5; 19486800,0.5; 19490400,0.5; 19494000,0.5;
        19497600,0.5; 19501200,0.5; 19504800,0.5; 19508400,0.5; 19512000,0.5;
        19515600,0.5; 19519200,0.5; 19522800,0.5; 19526400,0.5; 19530000,0.5;
        19533600,0.5; 19537200,0.5; 19540800,0.5; 19544400,0.5; 19548000,0.5;
        19551600,0.5; 19555200,0.5; 19558800,0.5; 19562400,0.5; 19566000,0.5;
        19569600,0.5; 19573200,0.5; 19576800,0.5; 19580400,0.5; 19584000,0.5;
        19587600,0.5; 19591200,0.5; 19594800,0.5; 19598400,0.5; 19602000,0.5;
        19605600,0.5; 19609200,0.5; 19612800,0.5; 19616400,0.5; 19620000,0.5;
        19623600,0.5; 19627200,0.5; 19630800,0.5; 19634400,0.5; 19638000,0.5;
        19641600,0.5; 19645200,0.5; 19648800,0.5; 19652400,0.5; 19656000,0.5;
        19659600,0.5; 19663200,0.5; 19666800,0.5; 19670400,0.5; 19674000,0.5;
        19677600,0.5; 19681200,0.5; 19684800,0.5; 19688400,0.5; 19692000,0.5;
        19695600,0.5; 19699200,0.5; 19702800,0.5; 19706400,0.5; 19710000,0.5;
        19713600,0.5; 19717200,0.5; 19720800,0.5; 19724400,0.5; 19728000,0.5;
        19731600,0.5; 19735200,0.5; 19738800,0.5; 19742400,0.5; 19746000,0.5;
        19749600,0.5; 19753200,0.5; 19756800,0.5; 19760400,0.5; 19764000,0.5;
        19767600,0.5; 19771200,0.5; 19774800,0.5; 19778400,0.5; 19782000,0.5;
        19785600,0.5; 19789200,0.5; 19792800,0.5; 19796400,0.5; 19800000,0.5;
        19803600,0.5; 19807200,0.5; 19810800,0.5; 19814400,0.5; 19818000,0.5;
        19821600,0.5; 19825200,0.5; 19828800,0.5; 19832400,0.5; 19836000,0.5;
        19839600,0.5; 19843200,0.5; 19846800,0.5; 19850400,0.5; 19854000,0.5;
        19857600,0.5; 19861200,0.5; 19864800,0.5; 19868400,0.5; 19872000,0.5;
        19875600,0.5; 19879200,0.5; 19882800,0.5; 19886400,0.5; 19890000,0.5;
        19893600,0.5; 19897200,0.5; 19900800,0.5; 19904400,0.5; 19908000,0.5;
        19911600,0.5; 19915200,0.5; 19918800,0.5; 19922400,0.5; 19926000,0.5;
        19929600,0.5; 19933200,0.5; 19936800,0.5; 19940400,0.5; 19944000,0.5;
        19947600,0.5; 19951200,0.5; 19954800,0.5; 19958400,0.5; 19962000,0.5;
        19965600,0.5; 19969200,0.5; 19972800,0.5; 19976400,0.5; 19980000,0.5;
        19983600,0.5; 19987200,0.5; 19990800,0.5; 19994400,0.5; 19998000,0.5;
        20001600,0.5; 20005200,0.5; 20008800,0.5; 20012400,0.5; 20016000,0.5;
        20019600,0.5; 20023200,0.5; 20026800,0.5; 20030400,0.5; 20034000,0.5;
        20037600,0.5; 20041200,0.5; 20044800,0.5; 20048400,0.5; 20052000,0.5;
        20055600,0.5; 20059200,0.5; 20062800,0.5; 20066400,0.5; 20070000,0.5;
        20073600,0.5; 20077200,0.5; 20080800,0.5; 20084400,0.5; 20088000,0.5;
        20091600,0.5; 20095200,0.5; 20098800,0.5; 20102400,0.5; 20106000,0.5;
        20109600,0.5; 20113200,0.5; 20116800,0.5; 20120400,0.5; 20124000,0.5;
        20127600,0.5; 20131200,0.5; 20134800,0.5; 20138400,0.5; 20142000,0.5;
        20145600,0.5; 20149200,0.5; 20152800,0.5; 20156400,0.5; 20160000,0.5;
        20163600,0.5; 20167200,0.5; 20170800,0.5; 20174400,0.5; 20178000,0.5;
        20181600,0.5; 20185200,0.5; 20188800,0.5; 20192400,0.5; 20196000,0.5;
        20199600,0.5; 20203200,0.5; 20206800,0.5; 20210400,0.5; 20214000,0.5;
        20217600,0.5; 20221200,0.5; 20224800,0.5; 20228400,0.5; 20232000,0.5;
        20235600,0.5; 20239200,0.5; 20242800,0.5; 20246400,0.5; 20250000,0.5;
        20253600,0.5; 20257200,0.5; 20260800,0.5; 20264400,0.5; 20268000,0.5;
        20271600,0.5; 20275200,0.5; 20278800,0.5; 20282400,0.5; 20286000,0.5;
        20289600,0.5; 20293200,0.5; 20296800,0.5; 20300400,0.5; 20304000,0.5;
        20307600,0.5; 20311200,0.5; 20314800,0.5; 20318400,0.5; 20322000,0.5;
        20325600,0.5; 20329200,0.5; 20332800,0.5; 20336400,0.5; 20340000,0.5;
        20343600,0.5; 20347200,0.5; 20350800,0.5; 20354400,0.5; 20358000,0.5;
        20361600,0.5; 20365200,0.5; 20368800,0.5; 20372400,0.5; 20376000,0.5;
        20379600,0.5; 20383200,0.5; 20386800,0.5; 20390400,0.5; 20394000,0.5;
        20397600,0.5; 20401200,0.5; 20404800,0.5; 20408400,0.5; 20412000,0.5;
        20415600,0.5; 20419200,0.5; 20422800,0.5; 20426400,0.5; 20430000,0.5;
        20433600,0.5; 20437200,0.5; 20440800,0.5; 20444400,0.5; 20448000,0.5;
        20451600,0.5; 20455200,0.5; 20458800,0.5; 20462400,0.5; 20466000,0.5;
        20469600,0.5; 20473200,0.5; 20476800,0.5; 20480400,0.5; 20484000,0.5;
        20487600,0.5; 20491200,0.5; 20494800,0.5; 20498400,0.5; 20502000,0.5;
        20505600,0.5; 20509200,0.5; 20512800,0.5; 20516400,0.5; 20520000,0.5;
        20523600,0.5; 20527200,0.5; 20530800,0.5; 20534400,0.5; 20538000,0.5;
        20541600,0.5; 20545200,0.5; 20548800,0.5; 20552400,0.5; 20556000,0.5;
        20559600,0.5; 20563200,0.5; 20566800,0.5; 20570400,0.5; 20574000,0.5;
        20577600,0.5; 20581200,0.5; 20584800,0.5; 20588400,0.5; 20592000,0.5;
        20595600,0.5; 20599200,0.5; 20602800,0.5; 20606400,0.5; 20610000,0.5;
        20613600,0.5; 20617200,0.5; 20620800,0.5; 20624400,0.5; 20628000,0.5;
        20631600,0.5; 20635200,0.5; 20638800,0.5; 20642400,0.5; 20646000,0.5;
        20649600,0.5; 20653200,0.5; 20656800,0.5; 20660400,0.5; 20664000,0.5;
        20667600,0.5; 20671200,0.5; 20674800,0.5; 20678400,0.5; 20682000,0.5;
        20685600,0.5; 20689200,0.5; 20692800,0.5; 20696400,0.5; 20700000,0.5;
        20703600,0.5; 20707200,0.5; 20710800,0.5; 20714400,0.5; 20718000,0.5;
        20721600,0.5; 20725200,0.5; 20728800,0.5; 20732400,0.5; 20736000,0.5;
        20739600,0.5; 20743200,0.5; 20746800,0.5; 20750400,0.5; 20754000,0.5;
        20757600,0.5; 20761200,0.5; 20764800,0.5; 20768400,0.5; 20772000,0.5;
        20775600,0.5; 20779200,0.5; 20782800,0.5; 20786400,0.5; 20790000,0.5;
        20793600,0.5; 20797200,0.5; 20800800,0.5; 20804400,0.5; 20808000,0.5;
        20811600,0.5; 20815200,0.5; 20818800,0.5; 20822400,0.5; 20826000,0.5;
        20829600,0.5; 20833200,0.5; 20836800,0.5; 20840400,0.5; 20844000,0.5;
        20847600,0.5; 20851200,0.5; 20854800,0.5; 20858400,0.5; 20862000,0.5;
        20865600,0.5; 20869200,0.5; 20872800,0.5; 20876400,0.5; 20880000,0.5;
        20883600,0.5; 20887200,0.5; 20890800,0.5; 20894400,0.5; 20898000,0.5;
        20901600,0.5; 20905200,0.5; 20908800,0.5; 20912400,0.5; 20916000,0.5;
        20919600,0.5; 20923200,0.5; 20926800,0.5; 20930400,0.5; 20934000,0.5;
        20937600,0.5; 20941200,0.5; 20944800,0.5; 20948400,0.5; 20952000,0.5;
        20955600,0.5; 20959200,0.5; 20962800,0.5; 20966400,0.5; 20970000,0.5;
        20973600,0.5; 20977200,0.5; 20980800,0.5; 20984400,0.5; 20988000,0.5;
        20991600,0.5; 20995200,0.5; 20998800,0.5; 21002400,0.5; 21006000,0.5;
        21009600,0.5; 21013200,0.5; 21016800,0.5; 21020400,0.5; 21024000,0.5;
        21027600,0.5; 21031200,0.5; 21034800,0.5; 21038400,0.5; 21042000,0.5;
        21045600,0.5; 21049200,0.5; 21052800,0.5; 21056400,0.5; 21060000,0.5;
        21063600,0.5; 21067200,0.5; 21070800,0.5; 21074400,0.5; 21078000,0.5;
        21081600,0.5; 21085200,0.5; 21088800,0.5; 21092400,0.5; 21096000,0.5;
        21099600,0.5; 21103200,0.5; 21106800,0.5; 21110400,0.5; 21114000,0.5;
        21117600,0.5; 21121200,0.5; 21124800,0.5; 21128400,0.5; 21132000,0.5;
        21135600,0.5; 21139200,0.5; 21142800,0.5; 21146400,0.5; 21150000,0.5;
        21153600,0.5; 21157200,0.5; 21160800,0.5; 21164400,0.5; 21168000,0.5;
        21171600,0.5; 21175200,0.5; 21178800,0.5; 21182400,0.5; 21186000,0.5;
        21189600,0.5; 21193200,0.5; 21196800,0.5; 21200400,0.5; 21204000,0.5;
        21207600,0.5; 21211200,0.5; 21214800,0.5; 21218400,0.5; 21222000,0.5;
        21225600,0.5; 21229200,0.5; 21232800,0.5; 21236400,0.5; 21240000,0.5;
        21243600,0.5; 21247200,0.5; 21250800,0.5; 21254400,0.5; 21258000,0.5;
        21261600,0.5; 21265200,0.5; 21268800,0.5; 21272400,0.5; 21276000,0.5;
        21279600,0.5; 21283200,0.5; 21286800,0.5; 21290400,0.5; 21294000,0.5;
        21297600,0.5; 21301200,0.5; 21304800,0.5; 21308400,0.5; 21312000,0.5;
        21315600,0.5; 21319200,0.5; 21322800,0.5; 21326400,0.5; 21330000,0.5;
        21333600,0.5; 21337200,0.5; 21340800,0.5; 21344400,0.5; 21348000,0.5;
        21351600,0.5; 21355200,0.5; 21358800,0.5; 21362400,0.5; 21366000,0.5;
        21369600,0.5; 21373200,0.5; 21376800,0.5; 21380400,0.5; 21384000,0.5;
        21387600,0.5; 21391200,0.5; 21394800,0.5; 21398400,0.5; 21402000,0.5;
        21405600,0.5; 21409200,0.5; 21412800,0.5; 21416400,0.5; 21420000,0.5;
        21423600,0.5; 21427200,0.5; 21430800,0.5; 21434400,0.5; 21438000,0.5;
        21441600,0.5; 21445200,0.5; 21448800,0.5; 21452400,0.5; 21456000,0.5;
        21459600,0.5; 21463200,0.5; 21466800,0.5; 21470400,0.5; 21474000,0.5;
        21477600,0.5; 21481200,0.5; 21484800,0.5; 21488400,0.5; 21492000,0.5;
        21495600,0.5; 21499200,0.5; 21502800,0.5; 21506400,0.5; 21510000,0.5;
        21513600,0.5; 21517200,0.5; 21520800,0.5; 21524400,0.5; 21528000,0.5;
        21531600,0.5; 21535200,0.5; 21538800,0.5; 21542400,0.5; 21546000,0.5;
        21549600,0.5; 21553200,0.5; 21556800,0.5; 21560400,0.5; 21564000,0.5;
        21567600,0.5; 21571200,0.5; 21574800,0.5; 21578400,0.5; 21582000,0.5;
        21585600,0.5; 21589200,0.5; 21592800,0.5; 21596400,0.5; 21600000,0.5;
        21603600,0.5; 21607200,0.5; 21610800,0.5; 21614400,0.5; 21618000,0.5;
        21621600,0.5; 21625200,0.5; 21628800,0.5; 21632400,0.5; 21636000,0.5;
        21639600,0.5; 21643200,0.5; 21646800,0.5; 21650400,0.5; 21654000,0.5;
        21657600,0.5; 21661200,0.5; 21664800,0.5; 21668400,0.5; 21672000,0.5;
        21675600,0.5; 21679200,0.5; 21682800,0.5; 21686400,0.5; 21690000,0.5;
        21693600,0.5; 21697200,0.5; 21700800,0.5; 21704400,0.5; 21708000,0.5;
        21711600,0.5; 21715200,0.5; 21718800,0.5; 21722400,0.5; 21726000,0.5;
        21729600,0.5; 21733200,0.5; 21736800,0.5; 21740400,0.5; 21744000,0.5;
        21747600,0.5; 21751200,0.5; 21754800,0.5; 21758400,0.5; 21762000,0.5;
        21765600,0.5; 21769200,0.5; 21772800,0.5; 21776400,0.5; 21780000,0.5;
        21783600,0.5; 21787200,0.5; 21790800,0.5; 21794400,0.5; 21798000,0.5;
        21801600,0.5; 21805200,0.5; 21808800,0.5; 21812400,0.5; 21816000,0.5;
        21819600,0.5; 21823200,0.5; 21826800,0.5; 21830400,0.5; 21834000,0.5;
        21837600,0.5; 21841200,0.5; 21844800,0.5; 21848400,0.5; 21852000,0.5;
        21855600,0.5; 21859200,0.5; 21862800,0.5; 21866400,0.5; 21870000,0.5;
        21873600,0.5; 21877200,0.5; 21880800,0.5; 21884400,0.5; 21888000,0.5;
        21891600,0.5; 21895200,0.5; 21898800,0.5; 21902400,0.5; 21906000,0.5;
        21909600,0.5; 21913200,0.5; 21916800,0.5; 21920400,0.5; 21924000,0.5;
        21927600,0.5; 21931200,0.5; 21934800,0.5; 21938400,0.5; 21942000,0.5;
        21945600,0.5; 21949200,0.5; 21952800,0.5; 21956400,0.5; 21960000,0.5;
        21963600,0.5; 21967200,0.5; 21970800,0.5; 21974400,0.5; 21978000,0.5;
        21981600,0.5; 21985200,0.5; 21988800,0.5; 21992400,0.5; 21996000,0.5;
        21999600,0.5; 22003200,0.5; 22006800,0.5; 22010400,0.5; 22014000,0.5;
        22017600,0.5; 22021200,0.5; 22024800,0.5; 22028400,0.5; 22032000,0.5;
        22035600,0.5; 22039200,0.5; 22042800,0.5; 22046400,0.5; 22050000,0.5;
        22053600,0.5; 22057200,0.5; 22060800,0.5; 22064400,0.5; 22068000,0.5;
        22071600,0.5; 22075200,0.5; 22078800,0.5; 22082400,0.5; 22086000,0.5;
        22089600,0.5; 22093200,0.5; 22096800,0.5; 22100400,0.5; 22104000,0.5;
        22107600,0.5; 22111200,0.5; 22114800,0.5; 22118400,0.5; 22122000,0.5;
        22125600,0.5; 22129200,0.5; 22132800,0.5; 22136400,0.5; 22140000,0.5;
        22143600,0.5; 22147200,0.5; 22150800,0.5; 22154400,0.5; 22158000,0.5;
        22161600,0.5; 22165200,0.5; 22168800,0.5; 22172400,0.5; 22176000,0.5;
        22179600,0.5; 22183200,0.5; 22186800,0.5; 22190400,0.5; 22194000,0.5;
        22197600,0.5; 22201200,0.5; 22204800,0.5; 22208400,0.5; 22212000,0.5;
        22215600,0.5; 22219200,0.5; 22222800,0.5; 22226400,0.5; 22230000,0.5;
        22233600,0.5; 22237200,0.5; 22240800,0.5; 22244400,0.5; 22248000,0.5;
        22251600,0.5; 22255200,0.5; 22258800,0.5; 22262400,0.5; 22266000,0.5;
        22269600,0.5; 22273200,0.5; 22276800,0.5; 22280400,0.5; 22284000,0.5;
        22287600,0.5; 22291200,0.5; 22294800,0.5; 22298400,0.5; 22302000,0.5;
        22305600,0.5; 22309200,0.5; 22312800,0.5; 22316400,0.5; 22320000,0.5;
        22323600,0.5; 22327200,0.5; 22330800,0.5; 22334400,0.5; 22338000,0.5;
        22341600,0.5; 22345200,0.5; 22348800,0.5; 22352400,0.5; 22356000,0.5;
        22359600,0.5; 22363200,0.5; 22366800,0.5; 22370400,0.5; 22374000,0.5;
        22377600,0.5; 22381200,0.5; 22384800,0.5; 22388400,0.5; 22392000,0.5;
        22395600,0.5; 22399200,0.5; 22402800,0.5; 22406400,0.5; 22410000,0.5;
        22413600,0.5; 22417200,0.5; 22420800,0.5; 22424400,0.5; 22428000,0.5;
        22431600,0.5; 22435200,0.5; 22438800,0.5; 22442400,0.5; 22446000,0.5;
        22449600,0.5; 22453200,0.5; 22456800,0.5; 22460400,0.5; 22464000,0.5;
        22467600,0.5; 22471200,0.5; 22474800,0.5; 22478400,0.5; 22482000,0.5;
        22485600,0.5; 22489200,0.5; 22492800,0.5; 22496400,0.5; 22500000,0.5;
        22503600,0.5; 22507200,0.5; 22510800,0.5; 22514400,0.5; 22518000,0.5;
        22521600,0.5; 22525200,0.5; 22528800,0.5; 22532400,0.5; 22536000,0.5;
        22539600,0.5; 22543200,0.5; 22546800,0.5; 22550400,0.5; 22554000,0.5;
        22557600,0.5; 22561200,0.5; 22564800,0.5; 22568400,0.5; 22572000,0.5;
        22575600,0.5; 22579200,0.5; 22582800,0.5; 22586400,0.5; 22590000,0.5;
        22593600,0.5; 22597200,0.5; 22600800,0.5; 22604400,0.5; 22608000,0.5;
        22611600,0.5; 22615200,0.5; 22618800,0.5; 22622400,0.5; 22626000,0.5;
        22629600,0.5; 22633200,0.5; 22636800,0.5; 22640400,0.5; 22644000,0.5;
        22647600,0.5; 22651200,0.5; 22654800,0.5; 22658400,0.5; 22662000,0.5;
        22665600,0.5; 22669200,0.5; 22672800,0.5; 22676400,0.5; 22680000,0.5;
        22683600,0.5; 22687200,0.5; 22690800,0.5; 22694400,0.5; 22698000,0.5;
        22701600,0.5; 22705200,0.5; 22708800,0.5; 22712400,0.5; 22716000,0.5;
        22719600,0.5; 22723200,0.5; 22726800,0.5; 22730400,0.5; 22734000,0.5;
        22737600,0.5; 22741200,0.5; 22744800,0.5; 22748400,0.5; 22752000,0.5;
        22755600,0.5; 22759200,0.5; 22762800,0.5; 22766400,0.5; 22770000,0.5;
        22773600,0.5; 22777200,0.5; 22780800,0.5; 22784400,0.5; 22788000,0.5;
        22791600,0.5; 22795200,0.5; 22798800,0.5; 22802400,0.5; 22806000,0.5;
        22809600,0.5; 22813200,0.5; 22816800,0.5; 22820400,0.5; 22824000,0.5;
        22827600,0.5; 22831200,0.5; 22834800,0.5; 22838400,0.5; 22842000,0.5;
        22845600,0.5; 22849200,0.5; 22852800,0.5; 22856400,0.5; 22860000,0.5;
        22863600,0.5; 22867200,0.5; 22870800,0.5; 22874400,0.5; 22878000,0.5;
        22881600,0.5; 22885200,0.5; 22888800,0.5; 22892400,0.5; 22896000,0.5;
        22899600,0.5; 22903200,0.5; 22906800,0.5; 22910400,0.5; 22914000,0.5;
        22917600,0.5; 22921200,0.5; 22924800,0.5; 22928400,0.5; 22932000,0.5;
        22935600,0.5; 22939200,0.5; 22942800,0.5; 22946400,0.5; 22950000,0.5;
        22953600,0.5; 22957200,0.5; 22960800,0.5; 22964400,0.5; 22968000,0.5;
        22971600,0.5; 22975200,0.5; 22978800,0.5; 22982400,0.5; 22986000,0.5;
        22989600,0.5; 22993200,0.5; 22996800,0.5; 23000400,0.5; 23004000,0.5;
        23007600,0.5; 23011200,0.5; 23014800,0.5; 23018400,0.5; 23022000,0.5;
        23025600,0.5; 23029200,0.5; 23032800,0.5; 23036400,0.5; 23040000,0.5;
        23043600,0.5; 23047200,0.5; 23050800,0.5; 23054400,0.5; 23058000,0.5;
        23061600,0.5; 23065200,0.5; 23068800,0.5; 23072400,0.5; 23076000,0.5;
        23079600,0.5; 23083200,0.5; 23086800,0.5; 23090400,0.5; 23094000,0.5;
        23097600,0.5; 23101200,0.5; 23104800,0.5; 23108400,0.5; 23112000,0.5;
        23115600,0.5; 23119200,0.5; 23122800,0.5; 23126400,0.5; 23130000,0.5;
        23133600,0.5; 23137200,0.5; 23140800,0.5; 23144400,0.5; 23148000,0.5;
        23151600,0.5; 23155200,0.5; 23158800,0.5; 23162400,0.5; 23166000,0.5;
        23169600,0.5; 23173200,0.5; 23176800,0.5; 23180400,0.5; 23184000,0.5;
        23187600,0.5; 23191200,0.5; 23194800,0.5; 23198400,0.5; 23202000,0.5;
        23205600,0.5; 23209200,0.5; 23212800,0.5; 23216400,0.5; 23220000,0.5;
        23223600,0.5; 23227200,0.5; 23230800,0.5; 23234400,0.5; 23238000,0.5;
        23241600,0.5; 23245200,0.5; 23248800,0.5; 23252400,0.5; 23256000,0.5;
        23259600,0.5; 23263200,0.5; 23266800,0.5; 23270400,0.5; 23274000,0.5;
        23277600,0.5; 23281200,0.5; 23284800,0.5; 23288400,0.5; 23292000,0.5;
        23295600,0.5; 23299200,0.5; 23302800,0.5; 23306400,0.5; 23310000,0.5;
        23313600,0.5; 23317200,0.5; 23320800,0.5; 23324400,0.5; 23328000,0.5;
        23331600,0.5; 23335200,0.5; 23338800,0.5; 23342400,0.5; 23346000,0.5;
        23349600,0.5; 23353200,0.5; 23356800,0.5; 23360400,0.5; 23364000,0.5;
        23367600,0.5; 23371200,0.5; 23374800,0.5; 23378400,0.5; 23382000,0.5;
        23385600,0.5; 23389200,0.5; 23392800,0.5; 23396400,0.5; 23400000,0.5;
        23403600,0.5; 23407200,0.5; 23410800,0.5; 23414400,0.5; 23418000,0.5;
        23421600,0.5; 23425200,0.5; 23428800,0.5; 23432400,0.5; 23436000,0.5;
        23439600,0.5; 23443200,0.5; 23446800,0.5; 23450400,0.5; 23454000,0.5;
        23457600,0.5; 23461200,0.5; 23464800,0.5; 23468400,0.5; 23472000,0.5;
        23475600,0.5; 23479200,0.5; 23482800,0.5; 23486400,0.5; 23490000,0.5;
        23493600,0.5; 23497200,0.5; 23500800,0.5; 23504400,0.5; 23508000,0.5;
        23511600,0.5; 23515200,0.5; 23518800,0.5; 23522400,0.5; 23526000,0.5;
        23529600,0.5; 23533200,0.5; 23536800,0.5; 23540400,0.5; 23544000,0.5;
        23547600,0.5; 23551200,0.5; 23554800,0.5; 23558400,0.5; 23562000,0.5;
        23565600,0.5; 23569200,0.5; 23572800,0.5; 23576400,0.5; 23580000,0.5;
        23583600,0.5; 23587200,0.5; 23590800,0.5; 23594400,0.5; 23598000,0.5;
        23601600,0.5; 23605200,0.5; 23608800,0.5; 23612400,0.5; 23616000,0.5;
        23619600,0.5; 23623200,0.5; 23626800,0.5; 23630400,0.5; 23634000,0.5;
        23637600,0.5; 23641200,0.5; 23644800,0.5; 23648400,0.5; 23652000,0.5;
        23655600,0.5; 23659200,0.5; 23662800,0.5; 23666400,0.5; 23670000,0.5;
        23673600,0.5; 23677200,0.5; 23680800,0.5; 23684400,0.5; 23688000,0.5;
        23691600,0.5; 23695200,0.5; 23698800,0.5; 23702400,0.5; 23706000,0.5;
        23709600,0.5; 23713200,0.5; 23716800,0.5; 23720400,0.5; 23724000,0.5;
        23727600,0.5; 23731200,0.5; 23734800,0.5; 23738400,0.5; 23742000,0.5;
        23745600,0.5; 23749200,0.5; 23752800,0.5; 23756400,0.5; 23760000,0.5;
        23763600,0.5; 23767200,0.5; 23770800,0.5; 23774400,0.5; 23778000,0.5;
        23781600,0.5; 23785200,0.5; 23788800,0.5; 23792400,0.5; 23796000,0.5;
        23799600,0.5; 23803200,0.5; 23806800,0.5; 23810400,0.5; 23814000,0.5;
        23817600,0.5; 23821200,0.5; 23824800,0.5; 23828400,0.5; 23832000,0.5;
        23835600,0.5; 23839200,0.5; 23842800,0.5; 23846400,0.5; 23850000,0.5;
        23853600,0.5; 23857200,0.5; 23860800,0.5; 23864400,0.5; 23868000,0.5;
        23871600,0.5; 23875200,0.5; 23878800,0.5; 23882400,0.5; 23886000,0.5;
        23889600,0.5; 23893200,0.5; 23896800,0.5; 23900400,0.5; 23904000,0.5;
        23907600,0.5; 23911200,0.5; 23914800,0.5; 23918400,0.5; 23922000,0.5;
        23925600,0.5; 23929200,0.5; 23932800,0.5; 23936400,0.5; 23940000,0.5;
        23943600,0.5; 23947200,0.5; 23950800,0.5; 23954400,0.5; 23958000,0.5;
        23961600,0.5; 23965200,0.5; 23968800,0.5; 23972400,0.5; 23976000,0.5;
        23979600,0.5; 23983200,0.5; 23986800,0.5; 23990400,0.5; 23994000,0.5;
        23997600,0.5; 24001200,0.5; 24004800,0.5; 24008400,0.5; 24012000,0.5;
        24015600,0.5; 24019200,0.5; 24022800,0.5; 24026400,0.5; 24030000,0.5;
        24033600,0.5; 24037200,0.5; 24040800,0.5; 24044400,0.5; 24048000,0.5;
        24051600,0.5; 24055200,0.5; 24058800,0.5; 24062400,0.5; 24066000,0.5;
        24069600,0.5; 24073200,0.5; 24076800,0.5; 24080400,0.5; 24084000,0.5;
        24087600,0.5; 24091200,0.5; 24094800,0.5; 24098400,0.5; 24102000,0.5;
        24105600,0.5; 24109200,0.5; 24112800,0.5; 24116400,0.5; 24120000,0.5;
        24123600,0.5; 24127200,0.5; 24130800,0.5; 24134400,0.5; 24138000,0.5;
        24141600,0.5; 24145200,0.5; 24148800,0.5; 24152400,0.5; 24156000,0.5;
        24159600,0.5; 24163200,0.5; 24166800,0.5; 24170400,0.5; 24174000,0.5;
        24177600,0.5; 24181200,0.5; 24184800,0.5; 24188400,0.5; 24192000,0.5;
        24195600,0.5; 24199200,0.5; 24202800,0.5; 24206400,0.5; 24210000,0.5;
        24213600,0.5; 24217200,0.5; 24220800,0.5; 24224400,0.5; 24228000,0.5;
        24231600,0.5; 24235200,0.5; 24238800,0.5; 24242400,0.5; 24246000,0.5;
        24249600,0.5; 24253200,0.5; 24256800,0.5; 24260400,0.5; 24264000,0.5;
        24267600,0.5; 24271200,0.5; 24274800,0.5; 24278400,0.5; 24282000,0.5;
        24285600,0.5; 24289200,0.5; 24292800,0.5; 24296400,0.5; 24300000,0.5;
        24303600,0.5; 24307200,0.5; 24310800,0.5; 24314400,0.5; 24318000,0.5;
        24321600,0.5; 24325200,0.5; 24328800,0.5; 24332400,0.5; 24336000,0.5;
        24339600,0.5; 24343200,0.5; 24346800,0.5; 24350400,0.5; 24354000,0.5;
        24357600,0.5; 24361200,0.5; 24364800,0.5; 24368400,0.5; 24372000,0.5;
        24375600,0.5; 24379200,0.5; 24382800,0.5; 24386400,0.5; 24390000,0.5;
        24393600,0.5; 24397200,0.5; 24400800,0.5; 24404400,0.5; 24408000,0.5;
        24411600,0.5; 24415200,0.5; 24418800,0.5; 24422400,0.5; 24426000,0.5;
        24429600,0.5; 24433200,0.5; 24436800,0.5; 24440400,0.5; 24444000,0.5;
        24447600,0.5; 24451200,0.5; 24454800,0.5; 24458400,0.5; 24462000,0.5;
        24465600,0.5; 24469200,0.5; 24472800,0.5; 24476400,0.5; 24480000,0.5;
        24483600,0.5; 24487200,0.5; 24490800,0.5; 24494400,0.5; 24498000,0.5;
        24501600,0.5; 24505200,0.5; 24508800,0.5; 24512400,0.5; 24516000,0.5;
        24519600,0.5; 24523200,0.5; 24526800,0.5; 24530400,0.5; 24534000,0.5;
        24537600,0.5; 24541200,0.5; 24544800,0.5; 24548400,0.5; 24552000,0.5;
        24555600,0.5; 24559200,0.5; 24562800,0.5; 24566400,0.5; 24570000,0.5;
        24573600,0.5; 24577200,0.5; 24580800,0.5; 24584400,0.5; 24588000,0.5;
        24591600,0.5; 24595200,0.5; 24598800,0.5; 24602400,0.5; 24606000,0.5;
        24609600,0.5; 24613200,0.5; 24616800,0.5; 24620400,0.5; 24624000,0.5;
        24627600,0.5; 24631200,0.5; 24634800,0.5; 24638400,0.5; 24642000,0.5;
        24645600,0.5; 24649200,0.5; 24652800,0.5; 24656400,0.5; 24660000,0.5;
        24663600,0.5; 24667200,0.5; 24670800,0.5; 24674400,0.5; 24678000,0.5;
        24681600,0.5; 24685200,0.5; 24688800,0.5; 24692400,0.5; 24696000,0.5;
        24699600,0.5; 24703200,0.5; 24706800,0.5; 24710400,0.5; 24714000,0.5;
        24717600,0.5; 24721200,0.5; 24724800,0.5; 24728400,0.5; 24732000,0.5;
        24735600,0.5; 24739200,0.5; 24742800,0.5; 24746400,0.5; 24750000,0.5;
        24753600,0.5; 24757200,0.5; 24760800,0.5; 24764400,0.5; 24768000,0.5;
        24771600,0.5; 24775200,0.5; 24778800,0.5; 24782400,0.5; 24786000,0.5;
        24789600,0.5; 24793200,0.5; 24796800,0.5; 24800400,0.5; 24804000,0.5;
        24807600,0.5; 24811200,0.5; 24814800,0.5; 24818400,0.5; 24822000,0.5;
        24825600,0.5; 24829200,0.5; 24832800,0.5; 24836400,0.5; 24840000,0.5;
        24843600,0.5; 24847200,0.5; 24850800,0.5; 24854400,0.5; 24858000,0.5;
        24861600,0.5; 24865200,0.5; 24868800,0.5; 24872400,0.5; 24876000,0.5;
        24879600,0.5; 24883200,0.5; 24886800,0.5; 24890400,0.5; 24894000,0.5;
        24897600,0.5; 24901200,0.5; 24904800,0.5; 24908400,0.5; 24912000,0.5;
        24915600,0.5; 24919200,0.5; 24922800,0.5; 24926400,0.5; 24930000,0.5;
        24933600,0.5; 24937200,0.5; 24940800,0.5; 24944400,0.5; 24948000,0.5;
        24951600,0.5; 24955200,0.5; 24958800,0.5; 24962400,0.5; 24966000,0.5;
        24969600,0.5; 24973200,0.5; 24976800,0.5; 24980400,0.5; 24984000,0.5;
        24987600,0.5; 24991200,0.5; 24994800,0.5; 24998400,0.5; 25002000,0.5;
        25005600,0.5; 25009200,0.5; 25012800,0.5; 25016400,0.5; 25020000,0.5;
        25023600,0.5; 25027200,0.5; 25030800,0.5; 25034400,0.5; 25038000,0.5;
        25041600,0.5; 25045200,0.5; 25048800,0.5; 25052400,0.5; 25056000,0.5;
        25059600,0.5; 25063200,0.5; 25066800,0.5; 25070400,0.5; 25074000,0.5;
        25077600,0.5; 25081200,0.5; 25084800,0.5; 25088400,0.5; 25092000,0.5;
        25095600,0.5; 25099200,0.5; 25102800,0.5; 25106400,0.5; 25110000,0.5;
        25113600,0.5; 25117200,0.5; 25120800,0.5; 25124400,0.5; 25128000,0.5;
        25131600,0.5; 25135200,0.5; 25138800,0.5; 25142400,0.5; 25146000,0.5;
        25149600,0.5; 25153200,0.5; 25156800,0.5; 25160400,0.5; 25164000,0.5;
        25167600,0.5; 25171200,0.5; 25174800,0.5; 25178400,0.5; 25182000,0.5;
        25185600,0.5; 25189200,0.5; 25192800,0.5; 25196400,0.5; 25200000,0.5;
        25203600,0.5; 25207200,0.5; 25210800,0.5; 25214400,0.5; 25218000,0.5;
        25221600,0.5; 25225200,0.5; 25228800,0.5; 25232400,0.5; 25236000,0.5;
        25239600,0.5; 25243200,0.5; 25246800,0.5; 25250400,0.5; 25254000,0.5;
        25257600,0.5; 25261200,0.5; 25264800,0.5; 25268400,0.5; 25272000,0.5;
        25275600,0.5; 25279200,0.5; 25282800,0.5; 25286400,0.5; 25290000,0.5;
        25293600,0.5; 25297200,0.5; 25300800,0.5; 25304400,0.5; 25308000,0.5;
        25311600,0.5; 25315200,0.5; 25318800,0.5; 25322400,0.5; 25326000,0.5;
        25329600,0.5; 25333200,0.5; 25336800,0.5; 25340400,0.5; 25344000,0.5;
        25347600,0.5; 25351200,0.5; 25354800,0.5; 25358400,0.5; 25362000,0.5;
        25365600,0.5; 25369200,0.5; 25372800,0.5; 25376400,0.5; 25380000,0.5;
        25383600,0.5; 25387200,0.5; 25390800,0.5; 25394400,0.5; 25398000,0.5;
        25401600,0.5; 25405200,0.5; 25408800,0.5; 25412400,0.5; 25416000,0.5;
        25419600,0.5; 25423200,0.5; 25426800,0.5; 25430400,0.5; 25434000,0.5;
        25437600,0.5; 25441200,0.5; 25444800,0.5; 25448400,0.5; 25452000,0.5;
        25455600,0.5; 25459200,0.5; 25462800,0.5; 25466400,0.5; 25470000,0.5;
        25473600,0.5; 25477200,0.5; 25480800,0.5; 25484400,0.5; 25488000,0.5;
        25491600,0.5; 25495200,0.5; 25498800,0.5; 25502400,0.5; 25506000,0.5;
        25509600,0.5; 25513200,0.5; 25516800,0.5; 25520400,0.5; 25524000,0.5;
        25527600,0.5; 25531200,0.5; 25534800,0.5; 25538400,0.5; 25542000,0.5;
        25545600,0.5; 25549200,0.5; 25552800,0.5; 25556400,0.5; 25560000,0.5;
        25563600,0.5; 25567200,0.5; 25570800,0.5; 25574400,0.5; 25578000,0.5;
        25581600,0.5; 25585200,0.5; 25588800,0.5; 25592400,0.5; 25596000,0.5;
        25599600,0.5; 25603200,0.5; 25606800,0.5; 25610400,0.5; 25614000,0.5;
        25617600,0.5; 25621200,0.5; 25624800,0.5; 25628400,0.5; 25632000,0.5;
        25635600,0.5; 25639200,0.5; 25642800,0.5; 25646400,0.5; 25650000,0.5;
        25653600,0.5; 25657200,0.5; 25660800,0.5; 25664400,0.5; 25668000,0.5;
        25671600,0.5; 25675200,0.5; 25678800,0.5; 25682400,0.5; 25686000,0.5;
        25689600,0.5; 25693200,0.5; 25696800,0.5; 25700400,0.5; 25704000,0.5;
        25707600,0.5; 25711200,0.5; 25714800,0.5; 25718400,0.5; 25722000,0.5;
        25725600,0.5; 25729200,0.5; 25732800,0.5; 25736400,0.5; 25740000,0.5;
        25743600,0.5; 25747200,0.5; 25750800,0.5; 25754400,0.5; 25758000,0.5;
        25761600,0.5; 25765200,0.5; 25768800,0.5; 25772400,0.5; 25776000,0.5;
        25779600,0.5; 25783200,0.5; 25786800,0.5; 25790400,0.5; 25794000,0.5;
        25797600,0.5; 25801200,0.5; 25804800,0.5; 25808400,0.5; 25812000,0.5;
        25815600,0.5; 25819200,0.5; 25822800,0.5; 25826400,0.5; 25830000,0.5;
        25833600,0.5; 25837200,0.5; 25840800,0.5; 25844400,0.5; 25848000,0.5;
        25851600,0.5; 25855200,0.5; 25858800,0.5; 25862400,0.5; 25866000,0.5;
        25869600,0.5; 25873200,0.5; 25876800,0.5; 25880400,0.5; 25884000,0.5;
        25887600,0.5; 25891200,0.5; 25894800,0.5; 25898400,0.5; 25902000,0.5;
        25905600,0.5; 25909200,0.5; 25912800,0.5; 25916400,0.5; 25920000,0.5;
        25923600,0.5; 25927200,0.5; 25930800,0.5; 25934400,0.5; 25938000,0.5;
        25941600,0.5; 25945200,0.5; 25948800,0.5; 25952400,0.5; 25956000,0.5;
        25959600,0.5; 25963200,0.5; 25966800,0.5; 25970400,0.5; 25974000,0.5;
        25977600,0.5; 25981200,0.5; 25984800,0.5; 25988400,0.5; 25992000,0.5;
        25995600,0.5; 25999200,0.5; 26002800,0.5; 26006400,0.5; 26010000,0.5;
        26013600,0.5; 26017200,0.5; 26020800,0.5; 26024400,0.5; 26028000,0.5;
        26031600,0.5; 26035200,0.5; 26038800,0.5; 26042400,0.5; 26046000,0.5;
        26049600,0.5; 26053200,0.5; 26056800,0.5; 26060400,0.5; 26064000,0.5;
        26067600,0.5; 26071200,0.5; 26074800,0.5; 26078400,0.5; 26082000,0.5;
        26085600,0.5; 26089200,0.5; 26092800,0.5; 26096400,0.5; 26100000,0.5;
        26103600,0.5; 26107200,0.5; 26110800,0.5; 26114400,0.5; 26118000,0.5;
        26121600,0.5; 26125200,0.5; 26128800,0.5; 26132400,0.5; 26136000,0.5;
        26139600,0.5; 26143200,0.5; 26146800,0.5; 26150400,0.5; 26154000,0.5;
        26157600,0.5; 26161200,0.5; 26164800,0.5; 26168400,0.5; 26172000,0.5;
        26175600,0.5; 26179200,0.5; 26182800,0.5; 26186400,0.5; 26190000,0.5;
        26193600,0.5; 26197200,0.5; 26200800,0.5; 26204400,0.5; 26208000,0.5;
        26211600,0.5; 26215200,0.5; 26218800,0.5; 26222400,0.5; 26226000,0.5;
        26229600,0.5; 26233200,0.5; 26236800,0.5; 26240400,0.5; 26244000,0.5;
        26247600,0.5; 26251200,0.5; 26254800,0.5; 26258400,0.5; 26262000,0.5;
        26265600,0.5; 26269200,0.5; 26272800,0.5; 26276400,0.5; 26280000,0.5;
        26283600,0.5; 26287200,0.5; 26290800,0.5; 26294400,0.5; 26298000,0.5;
        26301600,0.5; 26305200,0.5; 26308800,0.5; 26312400,0.5; 26316000,0.5;
        26319600,0.5; 26323200,0.5; 26326800,0.5; 26330400,0.5; 26334000,0.5;
        26337600,0.5; 26341200,0.5; 26344800,0.5; 26348400,0.5; 26352000,0.5;
        26355600,0.5; 26359200,0.5; 26362800,0.5; 26366400,0.5; 26370000,0.5;
        26373600,0.5; 26377200,0.5; 26380800,0.5; 26384400,0.5; 26388000,0.5;
        26391600,0.5; 26395200,0.5; 26398800,0.5; 26402400,0.5; 26406000,0.5;
        26409600,0.5; 26413200,0.5; 26416800,0.5; 26420400,0.5; 26424000,0.5;
        26427600,0.5; 26431200,0.5; 26434800,0.5; 26438400,0.5; 26442000,0.5;
        26445600,0.5; 26449200,0.5; 26452800,0.5; 26456400,0.5; 26460000,0.5;
        26463600,0.5; 26467200,0.5; 26470800,0.5; 26474400,0.5; 26478000,0.5;
        26481600,0.5; 26485200,0.5; 26488800,0.5; 26492400,0.5; 26496000,0.5;
        26499600,0.5; 26503200,0.5; 26506800,0.5; 26510400,0.5; 26514000,0.5;
        26517600,0.5; 26521200,0.5; 26524800,0.5; 26528400,0.5; 26532000,0.5;
        26535600,0.5; 26539200,0.5; 26542800,0.5; 26546400,0.5; 26550000,0.5;
        26553600,0.5; 26557200,0.5; 26560800,0.5; 26564400,0.5; 26568000,0.5;
        26571600,0.5; 26575200,0.5; 26578800,0.5; 26582400,0.5; 26586000,0.5;
        26589600,0.5; 26593200,0.5; 26596800,0.5; 26600400,0.5; 26604000,0.5;
        26607600,0.5; 26611200,0.5; 26614800,0.5; 26618400,0.5; 26622000,0.5;
        26625600,0.5; 26629200,0.5; 26632800,0.5; 26636400,0.5; 26640000,0.5;
        26643600,0.5; 26647200,0.5; 26650800,0.5; 26654400,0.5; 26658000,0.5;
        26661600,0.5; 26665200,0.5; 26668800,0.5; 26672400,0.5; 26676000,0.5;
        26679600,0.5; 26683200,0.5; 26686800,0.5; 26690400,0.5; 26694000,0.5;
        26697600,0.5; 26701200,0.5; 26704800,0.5; 26708400,0.5; 26712000,0.5;
        26715600,0.5; 26719200,0.5; 26722800,0.5; 26726400,0.5; 26730000,0.5;
        26733600,0.5; 26737200,0.5; 26740800,0.5; 26744400,0.5; 26748000,0.5;
        26751600,0.5; 26755200,0.5; 26758800,0.5; 26762400,0.5; 26766000,0.5;
        26769600,0.5; 26773200,0.5; 26776800,0.5; 26780400,0.5; 26784000,0.5;
        26787600,0.5; 26791200,0.5; 26794800,0.5; 26798400,0.5; 26802000,0.5;
        26805600,0.5; 26809200,0.5; 26812800,0.5; 26816400,0.5; 26820000,0.5;
        26823600,0.5; 26827200,0.5; 26830800,0.5; 26834400,0.5; 26838000,0.5;
        26841600,0.5; 26845200,0.5; 26848800,0.5; 26852400,0.5; 26856000,0.5;
        26859600,0.5; 26863200,0.5; 26866800,0.5; 26870400,0.5; 26874000,0.5;
        26877600,0.5; 26881200,0.5; 26884800,0.5; 26888400,0.5; 26892000,0.5;
        26895600,0.5; 26899200,0.5; 26902800,0.5; 26906400,0.5; 26910000,0.5;
        26913600,0.5; 26917200,0.5; 26920800,0.5; 26924400,0.5; 26928000,0.5;
        26931600,0.5; 26935200,0.5; 26938800,0.5; 26942400,0.5; 26946000,0.5;
        26949600,0.5; 26953200,0.5; 26956800,0.5; 26960400,0.5; 26964000,0.5;
        26967600,0.5; 26971200,0.5; 26974800,0.5; 26978400,0.5; 26982000,0.5;
        26985600,0.5; 26989200,0.5; 26992800,0.5; 26996400,0.5; 27000000,0.5;
        27003600,0.5; 27007200,0.5; 27010800,0.5; 27014400,0.5; 27018000,0.5;
        27021600,0.5; 27025200,0.5; 27028800,0.5; 27032400,0.5; 27036000,0.5;
        27039600,0.5; 27043200,0.5; 27046800,0.5; 27050400,0.5; 27054000,0.5;
        27057600,0.5; 27061200,0.5; 27064800,0.5; 27068400,0.5; 27072000,0.5;
        27075600,0.5; 27079200,0.5; 27082800,0.5; 27086400,0.5; 27090000,0.5;
        27093600,0.5; 27097200,0.5; 27100800,0.5; 27104400,0.5; 27108000,0.5;
        27111600,0.5; 27115200,0.5; 27118800,0.5; 27122400,0.5; 27126000,0.5;
        27129600,0.5; 27133200,0.5; 27136800,0.5; 27140400,0.5; 27144000,0.5;
        27147600,0.5; 27151200,0.5; 27154800,0.5; 27158400,0.5; 27162000,0.5;
        27165600,0.5; 27169200,0.5; 27172800,0.5; 27176400,0.5; 27180000,0.5;
        27183600,0.5; 27187200,0.5; 27190800,0.5; 27194400,0.5; 27198000,0.5;
        27201600,0.5; 27205200,0.5; 27208800,0.5; 27212400,0.5; 27216000,0.5;
        27219600,0.5; 27223200,0.5; 27226800,0.5; 27230400,0.5; 27234000,0.5;
        27237600,0.5; 27241200,0.5; 27244800,0.5; 27248400,0.5; 27252000,0.5;
        27255600,0.5; 27259200,0.5; 27262800,0.5; 27266400,0.5; 27270000,0.5;
        27273600,0.5; 27277200,0.5; 27280800,0.5; 27284400,0.5; 27288000,0.5;
        27291600,0.5; 27295200,0.5; 27298800,0.5; 27302400,0.5; 27306000,0.5;
        27309600,0.5; 27313200,0.5; 27316800,0.5; 27320400,0.5; 27324000,0.5;
        27327600,0.5; 27331200,0.5; 27334800,0.5; 27338400,0.5; 27342000,0.5;
        27345600,0.5; 27349200,0.5; 27352800,0.5; 27356400,0.5; 27360000,0.5;
        27363600,0.5; 27367200,0.5; 27370800,0.5; 27374400,0.5; 27378000,0.5;
        27381600,0.5; 27385200,0.5; 27388800,0.5; 27392400,0.5; 27396000,0.5;
        27399600,0.5; 27403200,0.5; 27406800,0.5; 27410400,0.5; 27414000,0.5;
        27417600,0.5; 27421200,0.5; 27424800,0.5; 27428400,0.5; 27432000,0.5;
        27435600,0.5; 27439200,0.5; 27442800,0.5; 27446400,0.5; 27450000,0.5;
        27453600,0.5; 27457200,0.5; 27460800,0.5; 27464400,0.5; 27468000,0.5;
        27471600,0.5; 27475200,0.5; 27478800,0.5; 27482400,0.5; 27486000,0.5;
        27489600,0.5; 27493200,0.5; 27496800,0.5; 27500400,0.5; 27504000,0.5;
        27507600,0.5; 27511200,0.5; 27514800,0.5; 27518400,0.5; 27522000,0.5;
        27525600,0.5; 27529200,0.5; 27532800,0.5; 27536400,0.5; 27540000,0.5;
        27543600,0.5; 27547200,0.5; 27550800,0.5; 27554400,0.5; 27558000,0.5;
        27561600,0.5; 27565200,0.5; 27568800,0.5; 27572400,0.5; 27576000,0.5;
        27579600,0.5; 27583200,0.5; 27586800,0.5; 27590400,0.5; 27594000,0.5;
        27597600,0.5; 27601200,0.5; 27604800,0.5; 27608400,0.5; 27612000,0.5;
        27615600,0.5; 27619200,0.5; 27622800,0.5; 27626400,0.5; 27630000,0.5;
        27633600,0.5; 27637200,0.5; 27640800,0.5; 27644400,0.5; 27648000,0.5;
        27651600,0.5; 27655200,0.5; 27658800,0.5; 27662400,0.5; 27666000,0.5;
        27669600,0.5; 27673200,0.5; 27676800,0.5; 27680400,0.5; 27684000,0.5;
        27687600,0.5; 27691200,0.5; 27694800,0.5; 27698400,0.5; 27702000,0.5;
        27705600,0.5; 27709200,0.5; 27712800,0.5; 27716400,0.5; 27720000,0.5;
        27723600,0.5; 27727200,0.5; 27730800,0.5; 27734400,0.5; 27738000,0.5;
        27741600,0.5; 27745200,0.5; 27748800,0.5; 27752400,0.5; 27756000,0.5;
        27759600,0.5; 27763200,0.5; 27766800,0.5; 27770400,0.5; 27774000,0.5;
        27777600,0.5; 27781200,0.5; 27784800,0.5; 27788400,0.5; 27792000,0.5;
        27795600,0.5; 27799200,0.5; 27802800,0.5; 27806400,0.5; 27810000,0.5;
        27813600,0.5; 27817200,0.5; 27820800,0.5; 27824400,0.5; 27828000,0.5;
        27831600,0.5; 27835200,0.5; 27838800,0.5; 27842400,0.5; 27846000,0.5;
        27849600,0.5; 27853200,0.5; 27856800,0.5; 27860400,0.5; 27864000,0.5;
        27867600,0.5; 27871200,0.5; 27874800,0.5; 27878400,0.5; 27882000,0.5;
        27885600,0.5; 27889200,0.5; 27892800,0.5; 27896400,0.5; 27900000,0.5;
        27903600,0.5; 27907200,0.5; 27910800,0.5; 27914400,0.5; 27918000,0.5;
        27921600,0.5; 27925200,0.5; 27928800,0.5; 27932400,0.5; 27936000,0.5;
        27939600,0.5; 27943200,0.5; 27946800,0.5; 27950400,0.5; 27954000,0.5;
        27957600,0.5; 27961200,0.5; 27964800,0.5; 27968400,0.5; 27972000,0.5;
        27975600,0.5; 27979200,0.5; 27982800,0.5; 27986400,0.5; 27990000,0.5;
        27993600,0.5; 27997200,0.5; 28000800,0.5; 28004400,0.5; 28008000,0.5;
        28011600,0.5; 28015200,0.5; 28018800,0.5; 28022400,0.5; 28026000,0.5;
        28029600,0.5; 28033200,0.5; 28036800,0.5; 28040400,0.5; 28044000,0.5;
        28047600,0.5; 28051200,0.5; 28054800,0.5; 28058400,0.5; 28062000,0.5;
        28065600,0.5; 28069200,0.5; 28072800,0.5; 28076400,0.5; 28080000,0.5;
        28083600,0.5; 28087200,0.5; 28090800,0.5; 28094400,0.5; 28098000,0.5;
        28101600,0.5; 28105200,0.5; 28108800,0.5; 28112400,0.5; 28116000,0.5;
        28119600,0.5; 28123200,0.5; 28126800,0.5; 28130400,0.5; 28134000,0.5;
        28137600,0.5; 28141200,0.5; 28144800,0.5; 28148400,0.5; 28152000,0.5;
        28155600,0.5; 28159200,0.5; 28162800,0.5; 28166400,0.5; 28170000,0.5;
        28173600,0.5; 28177200,0.5; 28180800,0.5; 28184400,0.5; 28188000,0.5;
        28191600,0.5; 28195200,0.5; 28198800,0.5; 28202400,0.5; 28206000,0.5;
        28209600,0.5; 28213200,0.5; 28216800,0.5; 28220400,0.5; 28224000,0.5;
        28227600,0.5; 28231200,0.5; 28234800,0.5; 28238400,0.5; 28242000,0.5;
        28245600,0.5; 28249200,0.5; 28252800,0.5; 28256400,0.5; 28260000,0.5;
        28263600,0.5; 28267200,0.5; 28270800,0.5; 28274400,0.5; 28278000,0.5;
        28281600,0.5; 28285200,0.5; 28288800,0.5; 28292400,0.5; 28296000,0.5;
        28299600,0.5; 28303200,0.5; 28306800,0.5; 28310400,0.5; 28314000,0.5;
        28317600,0.5; 28321200,0.5; 28324800,0.5; 28328400,0.5; 28332000,0.5;
        28335600,0.5; 28339200,0.5; 28342800,0.5; 28346400,0.5; 28350000,0.5;
        28353600,0.5; 28357200,0.5; 28360800,0.5; 28364400,0.5; 28368000,0.5;
        28371600,0.5; 28375200,0.5; 28378800,0.5; 28382400,0.5; 28386000,0.5;
        28389600,0.5; 28393200,0.5; 28396800,0.5; 28400400,0.5; 28404000,0.5;
        28407600,0.5; 28411200,0.5; 28414800,0.5; 28418400,0.5; 28422000,0.5;
        28425600,0.5; 28429200,0.5; 28432800,0.5; 28436400,0.5; 28440000,0.5;
        28443600,0.5; 28447200,0.5; 28450800,0.5; 28454400,0.5; 28458000,0.5;
        28461600,0.5; 28465200,0.5; 28468800,0.5; 28472400,0.5; 28476000,0.5;
        28479600,0.5; 28483200,0.5; 28486800,0.5; 28490400,0.5; 28494000,0.5;
        28497600,0.5; 28501200,0.5; 28504800,0.5; 28508400,0.5; 28512000,0.5;
        28515600,0.5; 28519200,0.5; 28522800,0.5; 28526400,0.5; 28530000,0.5;
        28533600,0.5; 28537200,0.5; 28540800,0.5; 28544400,0.5; 28548000,0.5;
        28551600,0.5; 28555200,0.5; 28558800,0.5; 28562400,0.5; 28566000,0.5;
        28569600,0.5; 28573200,0.5; 28576800,0.5; 28580400,0.5; 28584000,0.5;
        28587600,0.5; 28591200,0.5; 28594800,0.5; 28598400,0.5; 28602000,0.5;
        28605600,0.5; 28609200,0.5; 28612800,0.5; 28616400,0.5; 28620000,0.5;
        28623600,0.5; 28627200,0.5; 28630800,0.5; 28634400,0.5; 28638000,0.5;
        28641600,0.5; 28645200,0.5; 28648800,0.5; 28652400,0.5; 28656000,0.5;
        28659600,0.5; 28663200,0.5; 28666800,0.5; 28670400,0.5; 28674000,0.5;
        28677600,0.5; 28681200,0.5; 28684800,0.5; 28688400,0.5; 28692000,0.5;
        28695600,0.5; 28699200,0.5; 28702800,0.5; 28706400,0.5; 28710000,0.5;
        28713600,0.5; 28717200,0.5; 28720800,0.5; 28724400,0.5; 28728000,0.5;
        28731600,0.5; 28735200,0.5; 28738800,0.5; 28742400,0.5; 28746000,0.5;
        28749600,0.5; 28753200,0.5; 28756800,0.5; 28760400,0.5; 28764000,0.5;
        28767600,0.5; 28771200,0.5; 28774800,0.5; 28778400,0.5; 28782000,0.5;
        28785600,0.5; 28789200,0.5; 28792800,0.5; 28796400,0.5; 28800000,0.5;
        28803600,0.5; 28807200,0.5; 28810800,0.5; 28814400,0.5; 28818000,0.5;
        28821600,0.5; 28825200,0.5; 28828800,0.5; 28832400,0.5; 28836000,0.5;
        28839600,0.5; 28843200,0.5; 28846800,0.5; 28850400,0.5; 28854000,0.5;
        28857600,0.5; 28861200,0.5; 28864800,0.5; 28868400,0.5; 28872000,0.5;
        28875600,0.5; 28879200,0.5; 28882800,0.5; 28886400,0.5; 28890000,0.5;
        28893600,0.5; 28897200,0.5; 28900800,0.5; 28904400,0.5; 28908000,0.5;
        28911600,0.5; 28915200,0.5; 28918800,0.5; 28922400,0.5; 28926000,0.5;
        28929600,0.5; 28933200,0.5; 28936800,0.5; 28940400,0.5; 28944000,0.5;
        28947600,0.5; 28951200,0.5; 28954800,0.5; 28958400,0.5; 28962000,0.5;
        28965600,0.5; 28969200,0.5; 28972800,0.5; 28976400,0.5; 28980000,0.5;
        28983600,0.5; 28987200,0.5; 28990800,0.5; 28994400,0.5; 28998000,0.5;
        29001600,0.5; 29005200,0.5; 29008800,0.5; 29012400,0.5; 29016000,0.5;
        29019600,0.5; 29023200,0.5; 29026800,0.5; 29030400,0.5; 29034000,0.5;
        29037600,0.5; 29041200,0.5; 29044800,0.5; 29048400,0.5; 29052000,0.5;
        29055600,0.5; 29059200,0.5; 29062800,0.5; 29066400,0.5; 29070000,0.5;
        29073600,0.5; 29077200,0.5; 29080800,0.5; 29084400,0.5; 29088000,0.5;
        29091600,0.5; 29095200,0.5; 29098800,0.5; 29102400,0.5; 29106000,0.5;
        29109600,0.5; 29113200,0.5; 29116800,0.5; 29120400,0.5; 29124000,0.5;
        29127600,0.5; 29131200,0.5; 29134800,0.5; 29138400,0.5; 29142000,0.5;
        29145600,0.5; 29149200,0.5; 29152800,0.5; 29156400,0.5; 29160000,0.5;
        29163600,0.5; 29167200,0.5; 29170800,0.5; 29174400,0.5; 29178000,0.5;
        29181600,0.5; 29185200,0.5; 29188800,0.5; 29192400,0.5; 29196000,0.5;
        29199600,0.5; 29203200,0.5; 29206800,0.5; 29210400,0.5; 29214000,0.5;
        29217600,0.5; 29221200,0.5; 29224800,0.5; 29228400,0.5; 29232000,0.5;
        29235600,0.5; 29239200,0.5; 29242800,0.5; 29246400,0.5; 29250000,0.5;
        29253600,0.5; 29257200,0.5; 29260800,0.5; 29264400,0.5; 29268000,0.5;
        29271600,0.5; 29275200,0.5; 29278800,0.5; 29282400,0.5; 29286000,0.5;
        29289600,0.5; 29293200,0.5; 29296800,0.5; 29300400,0.5; 29304000,0.5;
        29307600,0.5; 29311200,0.5; 29314800,0.5; 29318400,0.5; 29322000,0.5;
        29325600,0.5; 29329200,0.5; 29332800,0.5; 29336400,0.5; 29340000,0.5;
        29343600,0.5; 29347200,0.5; 29350800,0.5; 29354400,0.5; 29358000,0.5;
        29361600,0.5; 29365200,0.5; 29368800,0.5; 29372400,0.5; 29376000,0.5;
        29379600,0.5; 29383200,0.5; 29386800,0.5; 29390400,0.5; 29394000,0.5;
        29397600,0.5; 29401200,0.5; 29404800,0.5; 29408400,0.5; 29412000,0.5;
        29415600,0.5; 29419200,0.5; 29422800,0.5; 29426400,0.5; 29430000,0.5;
        29433600,0.5; 29437200,0.5; 29440800,0.5; 29444400,0.5; 29448000,0.5;
        29451600,0.5; 29455200,0.5; 29458800,0.5; 29462400,0.5; 29466000,0.5;
        29469600,0.5; 29473200,0.5; 29476800,0.5; 29480400,0.5; 29484000,0.5;
        29487600,0.5; 29491200,0.5; 29494800,0.5; 29498400,0.5; 29502000,0.5;
        29505600,0.5; 29509200,0.5; 29512800,0.5; 29516400,0.5; 29520000,0.5;
        29523600,0.5; 29527200,0.5; 29530800,0.5; 29534400,0.5; 29538000,0.5;
        29541600,0.5; 29545200,0.5; 29548800,0.5; 29552400,0.5; 29556000,0.5;
        29559600,0.5; 29563200,0.5; 29566800,0.5; 29570400,0.5; 29574000,0.5;
        29577600,0.5; 29581200,0.5; 29584800,0.5; 29588400,0.5; 29592000,0.5;
        29595600,0.5; 29599200,0.5; 29602800,0.5; 29606400,0.5; 29610000,0.5;
        29613600,0.5; 29617200,0.5; 29620800,0.5; 29624400,0.5; 29628000,0.5;
        29631600,0.5; 29635200,0.5; 29638800,0.5; 29642400,0.5; 29646000,0.5;
        29649600,0.5; 29653200,0.5; 29656800,0.5; 29660400,0.5; 29664000,0.5;
        29667600,0.5; 29671200,0.5; 29674800,0.5; 29678400,0.5; 29682000,0.5;
        29685600,0.5; 29689200,0.5; 29692800,0.5; 29696400,0.5; 29700000,0.5;
        29703600,0.5; 29707200,0.5; 29710800,0.5; 29714400,0.5; 29718000,0.5;
        29721600,0.5; 29725200,0.5; 29728800,0.5; 29732400,0.5; 29736000,0.5;
        29739600,0.5; 29743200,0.5; 29746800,0.5; 29750400,0.5; 29754000,0.5;
        29757600,0.5; 29761200,0.5; 29764800,0.5; 29768400,0.5; 29772000,0.5;
        29775600,0.5; 29779200,0.5; 29782800,0.5; 29786400,0.5; 29790000,0.5;
        29793600,0.5; 29797200,0.5; 29800800,0.5; 29804400,0.5; 29808000,0.5;
        29811600,0.5; 29815200,0.5; 29818800,0.5; 29822400,0.5; 29826000,0.5;
        29829600,0.5; 29833200,0.5; 29836800,0.5; 29840400,0.5; 29844000,0.5;
        29847600,0.5; 29851200,0.5; 29854800,0.5; 29858400,0.5; 29862000,0.5;
        29865600,0.5; 29869200,0.5; 29872800,0.5; 29876400,0.5; 29880000,0.5;
        29883600,0.5; 29887200,0.5; 29890800,0.5; 29894400,0.5; 29898000,0.5;
        29901600,0.5; 29905200,0.5; 29908800,0.5; 29912400,0.5; 29916000,0.5;
        29919600,0.5; 29923200,0.5; 29926800,0.5; 29930400,0.5; 29934000,0.5;
        29937600,0.5; 29941200,0.5; 29944800,0.5; 29948400,0.5; 29952000,0.5;
        29955600,0.5; 29959200,0.5; 29962800,0.5; 29966400,0.5; 29970000,0.5;
        29973600,0.5; 29977200,0.5; 29980800,0.5; 29984400,0.5; 29988000,0.5;
        29991600,0.5; 29995200,0.5; 29998800,0.5; 30002400,0.5; 30006000,0.5;
        30009600,0.5; 30013200,0.5; 30016800,0.5; 30020400,0.5; 30024000,0.5;
        30027600,0.5; 30031200,0.5; 30034800,0.5; 30038400,0.5; 30042000,0.5;
        30045600,0.5; 30049200,0.5; 30052800,0.5; 30056400,0.5; 30060000,0.5;
        30063600,0.5; 30067200,0.5; 30070800,0.5; 30074400,0.5; 30078000,0.5;
        30081600,0.5; 30085200,0.5; 30088800,0.5; 30092400,0.5; 30096000,0.5;
        30099600,0.5; 30103200,0.5; 30106800,0.5; 30110400,0.5; 30114000,0.5;
        30117600,0.5; 30121200,0.5; 30124800,0.5; 30128400,0.5; 30132000,0.5;
        30135600,0.5; 30139200,0.5; 30142800,0.5; 30146400,0.5; 30150000,0.5;
        30153600,0.5; 30157200,0.5; 30160800,0.5; 30164400,0.5; 30168000,0.5;
        30171600,0.5; 30175200,0.5; 30178800,0.5; 30182400,0.5; 30186000,0.5;
        30189600,0.5; 30193200,0.5; 30196800,0.5; 30200400,0.5; 30204000,0.5;
        30207600,0.5; 30211200,0.5; 30214800,0.5; 30218400,0.5; 30222000,0.5;
        30225600,0.5; 30229200,0.5; 30232800,0.5; 30236400,0.5; 30240000,0.5;
        30243600,0.5; 30247200,0.5; 30250800,0.5; 30254400,0.5; 30258000,0.5;
        30261600,0.5; 30265200,0.5; 30268800,0.5; 30272400,0.5; 30276000,0.5;
        30279600,0.5; 30283200,0.5; 30286800,0.5; 30290400,0.5; 30294000,0.5;
        30297600,0.5; 30301200,0.5; 30304800,0.5; 30308400,0.5; 30312000,0.5;
        30315600,0.5; 30319200,0.5; 30322800,0.5; 30326400,0.5; 30330000,0.5;
        30333600,0.5; 30337200,0.5; 30340800,0.5; 30344400,0.5; 30348000,0.5;
        30351600,0.5; 30355200,0.5; 30358800,0.5; 30362400,0.5; 30366000,0.5;
        30369600,0.5; 30373200,0.5; 30376800,0.5; 30380400,0.5; 30384000,0.5;
        30387600,0.5; 30391200,0.5; 30394800,0.5; 30398400,0.5; 30402000,0.5;
        30405600,0.5; 30409200,0.5; 30412800,0.5; 30416400,0.5; 30420000,0.5;
        30423600,0.5; 30427200,0.5; 30430800,0.5; 30434400,0.5; 30438000,0.5;
        30441600,0.5; 30445200,0.5; 30448800,0.5; 30452400,0.5; 30456000,0.5;
        30459600,0.5; 30463200,0.5; 30466800,0.5; 30470400,0.5; 30474000,0.5;
        30477600,0.5; 30481200,0.5; 30484800,0.5; 30488400,0.5; 30492000,0.5;
        30495600,0.5; 30499200,0.5; 30502800,0.5; 30506400,0.5; 30510000,0.5;
        30513600,0.5; 30517200,0.5; 30520800,0.5; 30524400,0.5; 30528000,0.5;
        30531600,0.5; 30535200,0.5; 30538800,0.5; 30542400,0.5; 30546000,0.5;
        30549600,0.5; 30553200,0.5; 30556800,0.5; 30560400,0.5; 30564000,0.5;
        30567600,0.5; 30571200,0.5; 30574800,0.5; 30578400,0.5; 30582000,0.5;
        30585600,0.5; 30589200,0.5; 30592800,0.5; 30596400,0.5; 30600000,0.5;
        30603600,0.5; 30607200,0.5; 30610800,0.5; 30614400,0.5; 30618000,0.5;
        30621600,0.5; 30625200,0.5; 30628800,0.5; 30632400,0.5; 30636000,0.5;
        30639600,0.5; 30643200,0.5; 30646800,0.5; 30650400,0.5; 30654000,0.5;
        30657600,0.5; 30661200,0.5; 30664800,0.5; 30668400,0.5; 30672000,0.5;
        30675600,0.5; 30679200,0.5; 30682800,0.5; 30686400,0.5; 30690000,0.5;
        30693600,0.5; 30697200,0.5; 30700800,0.5; 30704400,0.5; 30708000,0.5;
        30711600,0.5; 30715200,0.5; 30718800,0.5; 30722400,0.5; 30726000,0.5;
        30729600,0.5; 30733200,0.5; 30736800,0.5; 30740400,0.5; 30744000,0.5;
        30747600,0.5; 30751200,0.5; 30754800,0.5; 30758400,0.5; 30762000,0.5;
        30765600,0.5; 30769200,0.5; 30772800,0.5; 30776400,0.5; 30780000,0.5;
        30783600,0.5; 30787200,0.5; 30790800,0.5; 30794400,0.5; 30798000,0.5;
        30801600,0.5; 30805200,0.5; 30808800,0.5; 30812400,0.5; 30816000,0.5;
        30819600,0.5; 30823200,0.5; 30826800,0.5; 30830400,0.5; 30834000,0.5;
        30837600,0.5; 30841200,0.5; 30844800,0.5; 30848400,0.5; 30852000,0.5;
        30855600,0.5; 30859200,0.5; 30862800,0.5; 30866400,0.5; 30870000,0.5;
        30873600,0.5; 30877200,0.5; 30880800,0.5; 30884400,0.5; 30888000,0.5;
        30891600,0.5; 30895200,0.5; 30898800,0.5; 30902400,0.5; 30906000,0.5;
        30909600,0.5; 30913200,0.5; 30916800,0.5; 30920400,0.5; 30924000,0.5;
        30927600,0.5; 30931200,0.5; 30934800,0.5; 30938400,0.5; 30942000,0.5;
        30945600,0.5; 30949200,0.5; 30952800,0.5; 30956400,0.5; 30960000,0.5;
        30963600,0.5; 30967200,0.5; 30970800,0.5; 30974400,0.5; 30978000,0.5;
        30981600,0.5; 30985200,0.5; 30988800,0.5; 30992400,0.5; 30996000,0.5;
        30999600,0.5; 31003200,0.5; 31006800,0.5; 31010400,0.5; 31014000,0.5;
        31017600,0.5; 31021200,0.5; 31024800,0.5; 31028400,0.5; 31032000,0.5;
        31035600,0.5; 31039200,0.5; 31042800,0.5; 31046400,0.5; 31050000,0.5;
        31053600,0.5; 31057200,0.5; 31060800,0.5; 31064400,0.5; 31068000,0.5;
        31071600,0.5; 31075200,0.5; 31078800,0.5; 31082400,0.5; 31086000,0.5;
        31089600,0.5; 31093200,0.5; 31096800,0.5; 31100400,0.5; 31104000,0.5;
        31107600,0.5; 31111200,0.5; 31114800,0.5; 31118400,0.5; 31122000,0.5;
        31125600,0.5; 31129200,0.5; 31132800,0.5; 31136400,0.5; 31140000,0.5;
        31143600,0.5; 31147200,0.5; 31150800,0.5; 31154400,0.5; 31158000,0.5;
        31161600,0.5; 31165200,0.5; 31168800,0.5; 31172400,0.5; 31176000,0.5;
        31179600,0.5; 31183200,0.5; 31186800,0.5; 31190400,0.5; 31194000,0.5;
        31197600,0.5; 31201200,0.5; 31204800,0.5; 31208400,0.5; 31212000,0.5;
        31215600,0.5; 31219200,0.5; 31222800,0.5; 31226400,0.5; 31230000,0.5;
        31233600,0.5; 31237200,0.5; 31240800,0.5; 31244400,0.5; 31248000,0.5;
        31251600,0.5; 31255200,0.5; 31258800,0.5; 31262400,0.5; 31266000,0.5;
        31269600,0.5; 31273200,0.5; 31276800,0.5; 31280400,0.5; 31284000,0.5;
        31287600,0.5; 31291200,0.5; 31294800,0.5; 31298400,0.5; 31302000,0.5;
        31305600,0.5; 31309200,0.5; 31312800,0.5; 31316400,0.5; 31320000,0.5;
        31323600,0.5; 31327200,0.5; 31330800,0.5; 31334400,0.5; 31338000,0.5;
        31341600,0.5; 31345200,0.5; 31348800,0.5; 31352400,0.5; 31356000,0.5;
        31359600,0.5; 31363200,0.5; 31366800,0.5; 31370400,0.5; 31374000,0.5;
        31377600,0.5; 31381200,0.5; 31384800,0.5; 31388400,0.5; 31392000,0.5;
        31395600,0.5; 31399200,0.5; 31402800,0.5; 31406400,0.5; 31410000,0.5;
        31413600,0.5; 31417200,0.5; 31420800,0.5; 31424400,0.5; 31428000,0.5;
        31431600,0.5; 31435200,0.5; 31438800,0.5; 31442400,0.5; 31446000,0.5;
        31449600,0.5; 31453200,0.5; 31456800,0.5; 31460400,0.5; 31464000,0.5;
        31467600,0.5; 31471200,0.5; 31474800,0.5; 31478400,0.5; 31482000,0.5;
        31485600,0.5; 31489200,0.5; 31492800,0.5; 31496400,0.5; 31500000,0.5;
        31503600,0.5; 31507200,0.5; 31510800,0.5; 31514400,0.5; 31518000,0.5;
        31521600,0.5; 31525200,0.5; 31528800,0.5; 31532400,0.5; 31536000,0.5],
      smoothness=Modelica.Blocks.Types.Smoothness.ContinuousDerivative)
    annotation (Placement(transformation(extent={{-122,-82},{-102,-62}})));
  Modelica.Blocks.Sources.RealExpression time_table_compressor(y=max(
        combiTimeTable_compressor.y[1], 0.000001))
    annotation (Placement(transformation(extent={{180,-26},{140,-10}})));
  Modelica.Blocks.Sources.RealExpression time_table_SH_Mass_Flow(y=max(
        combiTimeTable_SH_Mass_Flow.y[1], 0.000001))
    annotation (Placement(transformation(extent={{40,162},{80,178}})));
  Modelica.Blocks.Sources.RealExpression time_table_compressor1(y=max(
        combiTimeTable_DHW_Mass_Flow.y[1], 0.000001))
    annotation (Placement(transformation(extent={{254,86},{214,102}})));
  Modelica.Blocks.Sources.RealExpression time_table_SH_temperature_in(y=max(
        combiTimeTable_SH_temperature_in.y[1], 0.000001))
    annotation (Placement(transformation(extent={{-122,134},{-82,150}})));
  Modelica.Blocks.Sources.RealExpression time_table_Bottom_source_water_pump(y=max(
        combiTimeTable_Bottom_source_water_pump.y[1], 0.000001))
    annotation (Placement(transformation(extent={{-130,-100},{-90,-84}})));
equation
  connect(statePoint5.sensorPort, expansionValve.portA) annotation (Line(
      points={{-55.5,-16.0001},{-80,-16.0001},{-80,-22}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(statePoint8.sensorPort, separator.portGas) annotation (Line(
      points={{65,-44},{65,-50},{57,-50}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));

  connect(expansionValve.portA, SLHX_before_evaporation.portB) annotation (Line(
      points={{-80,-22},{-80,4}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(separator.portGas, SLHX_after_evaporation.portB) annotation (Line(
      points={{57,-50},{80,-50},{80,-28}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(SLHX_before_evaporation.heatPort, SLHX_after_evaporation.heatPort)
    annotation (Line(
      points={{-78,12},{-30,12},{-30,-20},{78,-20}},
      color={204,0,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(pressureState_lp.portA, separator.portInlet) annotation (Line(
      points={{40,-50},{47,-50}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(statePoint9.sensorPort, SLHX_after_evaporation.portA) annotation (
      Line(
      points={{51,-4},{80,-4},{80,-12}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(PID2.y, expansionValve.effectiveFlowArea_in) annotation (Line(points=
          {{-105.1,-31},{-95.55,-31},{-85,-31}}, color={0,0,127}));
  connect(pressureState_hp.portA, Reheater_DHW.portB_a) annotation (Line(
      points={{80,34},{80,34},{80,38},{138,38},{138,76},{118,76}},
      color={153,204,0},
      thickness=0.5));
  connect(statePoint1.sensorPort, Reheater_DHW.portB_a) annotation (Line(
      points={{107,44},{102,44},{102,38},{138,38},{138,76},{118,76}},
      color={153,204,0},
      thickness=0.5));
  connect(statePoint4.sensorPort, SLHX_before_evaporation.portA) annotation (
      Line(
      points={{-151,106},{-158,106},{-158,76},{-172,76},{-172,22},{-80,22},{-80,
          20}},
      color={153,204,0},
      thickness=0.5));
  connect(Preheater_DHW.portA_a, SLHX_before_evaporation.portA) annotation (
      Line(
      points={{-112,70},{-152,70},{-152,76},{-158,76},{-172,76},{-172,22},{-80,
          22},{-80,20}},
      color={153,204,0},
      thickness=0.5));
  connect(t_gas_coolers_out.port, SLHX_before_evaporation.portA) annotation (
      Line(
      points={{-173,88},{-172,88},{-172,22},{-80,22},{-80,20}},
      color={153,204,0},
      thickness=0.5));
  connect(Preheater_DHW.portB_a, GasCooler_SHW.portB_a) annotation (Line(
      points={{-84,70},{-70,70},{-70,40},{-20,40},{-20,68},{-12,68}},
      color={153,204,0},
      thickness=0.5));
  connect(statePoint3.sensorPort, GasCooler_SHW.portB_a) annotation (Line(
      points={{-43,48},{-44,48},{-44,40},{-20,40},{-20,68},{-12,68}},
      color={153,204,0},
      thickness=0.5));
  connect(Reheater_DHW.portA_a, GasCooler_SHW.portA_a) annotation (Line(
      points={{90,76},{80,76},{80,52},{32,52},{32,68},{16,68}},
      color={153,204,0},
      thickness=0.5));
  connect(Real_value_DHW_T_out.y, PID4.u_m) annotation (Line(points={{27.6,243},
          {16,243},{16,248},{2,248}},  color={0,0,127}));
  connect(sensor_T_degC4.port, Preheater_DHW.portA_b) annotation (Line(
      points={{-117,94},{-124,94},{-124,86},{-112,86}},
      color={0,170,238},
      thickness=0.5));
  connect(PID4.y, rotatoryBoundary2.n_in)
    annotation (Line(points={{-9,260},{-9,252},{-24,252}},  color={0,0,127}));
  connect(PID4.u_s, sensor_T2.sensorValue) annotation (Line(points={{14,260},{
          14,254},{164,254},{164,129}}, color={0,0,127}));
  connect(PID5.u_m, Real_value_SH_T_out.y)
    annotation (Line(points={{-10,152},{-10,149},{6,149}}, color={0,0,127}));
  connect(sensor_T3.sensorValue,PID5. u_s)
    annotation (Line(points={{66,115},{66,164},{2,164}}, color={0,0,127}));
  connect(rotatoryBoundary3.rotatoryFlange, pump2ndOrder2.rotatoryFlange)
    annotation (Line(
      points={{-34,158},{-34,152}},
      color={135,135,135},
      thickness=0.5));
  connect(PID5.y, rotatoryBoundary3.n_in)
    annotation (Line(points={{-21,164},{-34,164},{-34,162}}, color={0,0,127}));
  connect(rotatoryBoundary2.rotatoryFlange, pump2ndOrder1.rotatoryFlange)
    annotation (Line(
      points={{-24,248},{-24,245},{-24,242}},
      color={135,135,135},
      thickness=0.5));
  connect(evaporator.portB_a, pressureState_lp.portB) annotation (Line(
      points={{4,-50},{16,-50},{28,-50}},
      color={153,204,0},
      thickness=0.5));
  connect(evaporator.portA_a, expansionValve.portB) annotation (Line(
      points={{-24,-50},{-52,-50},{-80,-50},{-80,-40}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_T.port, expansionValve.portB) annotation (Line(
      points={{-92,-50},{-80,-50},{-80,-40}},
      color={153,204,0},
      thickness=0.5));
  connect(statePoint6.sensorPort, expansionValve.portB) annotation (Line(
      points={{-32,-44},{-36,-44},{-36,-50},{-80,-50},{-80,-40}},
      color={153,204,0},
      thickness=0.5));
  connect(statePoint7.sensorPort, pressureState_lp.portB) annotation (Line(
      points={{14,-44},{12,-44},{12,-50},{28,-50}},
      color={153,204,0},
      thickness=0.5));
  connect(evaporator.portA_b, boundary3.port) annotation (Line(
      points={{-24,-66},{-40,-66},{-40,-78},{-54,-78}},
      color={0,170,238},
      thickness=0.5));
  connect(Preheater_DHW.portB_b, Reheater_DHW.portA_b) annotation (Line(
      points={{-84,86},{-82,86},{-82,204},{90,204},{90,92}},
      color={0,170,238},
      thickness=0.5));
  connect(sensor_T_degC9.port, Reheater_DHW.portA_b) annotation (Line(
      points={{32,208},{32,204},{90,204},{90,92}},
      color={0,170,238},
      thickness=0.5));
  connect(sensor_T_degC10.port, GasCooler_SHW.portB_b) annotation (Line(
      points={{-26,94},{-26,94},{-26,84},{-12,84}},
      color={0,170,238},
      thickness=0.5));
  connect(sensor_p.port, SLHX_before_evaporation.portA) annotation (Line(
      points={{-106,2},{-104,2},{-104,22},{-80,22},{-80,20}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_p.sensorValue, PID2.u_s) annotation (Line(points={{-106,-4.2},
          {-134,-4.2},{-134,-31},{-125.8,-31}}, color={0,0,127}));
  connect(t_evaporation.port, expansionValve.portB) annotation (Line(
      points={{-57,-44},{-52,-44},{-52,-50},{-80,-50},{-80,-40}},
      color={153,204,0},
      thickness=0.5));
  connect(realExpression1.y, PID2.u_m) annotation (Line(points={{-130.5,-51},{
          -115,-51},{-115,-41.8}}, color={0,0,127}));
  connect(DHW_inlet.port, junction.portA) annotation (Line(
      points={{-158,218},{-136,218},{-136,217}},
      color={0,170,238},
      thickness=0.5));
  connect(sensor_T_degC12.port, junction.portA) annotation (Line(
      points={{-150,226},{-150,218},{-136,218},{-136,217}},
      color={0,170,238},
      thickness=0.5));
  connect(pump2ndOrder1.portA, junction.portB) annotation (Line(
      points={{-32,234},{-84,234},{-84,232},{-131,232},{-131,222}},
      color={0,170,238},
      thickness=0.5));
  connect(junction.portC, Preheater_DHW.portA_b) annotation (Line(
      points={{-131,212},{-132,212},{-132,86},{-112,86}},
      color={0,170,238},
      thickness=0.5));
  connect(sensor_T_degC7.port, junction.portB) annotation (Line(
      points={{-64,242},{-62,242},{-62,234},{-84,234},{-84,232},{-131,232},{
          -131,222}},
      color={0,170,238},
      thickness=0.5));
  connect(junction1.portC, GasCooler_SHW.portB_b) annotation (Line(
      points={{-44,84},{-28,84},{-12,84}},
      color={0,170,238},
      thickness=0.5));
  connect(SH_inlet.port, junction1.portB) annotation (Line(
      points={{-70,84},{-62,84},{-52,84}},
      color={0,170,238},
      thickness=0.5));
  connect(pump2ndOrder2.portA, junction1.portA) annotation (Line(
      points={{-42,144},{-48,144},{-48,88}},
      color={0,170,238},
      thickness=0.5));
  connect(sensor_T_degC8.port, junction1.portA) annotation (Line(
      points={{-48,166},{-48,166},{-48,134},{-48,88}},
      color={0,170,238},
      thickness=0.5));
  connect(sensor_T_degC2.port, junction1.portB) annotation (Line(
      points={{-57,94},{-64,94},{-64,84},{-52,84}},
      color={0,170,238},
      thickness=0.5));
  connect(junction3.portB, Reheater_DHW.portB_b) annotation (Line(
      points={{144,92},{118,92}},
      color={0,170,238},
      thickness=0.5));
  connect(junction3.portC, DHW_outlet.port) annotation (Line(
      points={{152,92},{169,92},{186,92}},
      color={0,170,238},
      thickness=0.5));
  connect(pump2ndOrder1.portB, junction3.portA) annotation (Line(
      points={{-16,234},{62,234},{62,236},{148,236},{148,96}},
      color={0,170,238},
      thickness=0.5));
  connect(sensor_T2.port, DHW_outlet.port) annotation (Line(
      points={{164,120},{164,92},{186,92}},
      color={0,170,238},
      thickness=0.5));
  connect(sensor_T_degC6.port, DHW_outlet.port) annotation (Line(
      points={{182,102},{182,92},{186,92}},
      color={0,170,238},
      thickness=0.5));
  connect(sensor_T_degC11.port, Reheater_DHW.portB_b) annotation (Line(
      points={{132,108},{134,108},{134,92},{118,92}},
      color={0,170,238},
      thickness=0.5));
  connect(SH_outlet.port, junction2.portC) annotation (Line(
      points={{76,92},{64,92},{52,92}},
      color={0,170,238},
      thickness=0.5));
  connect(GasCooler_SHW.portA_b, junction2.portB) annotation (Line(
      points={{16,84},{22,84},{24,84},{24,92},{44,92}},
      color={0,170,238},
      thickness=0.5));
  connect(pump2ndOrder2.portB, junction2.portA) annotation (Line(
      points={{-26,144},{48,144},{48,96}},
      color={0,170,238},
      thickness=0.5));
  connect(sensor_T_degC5.port, junction2.portB) annotation (Line(
      points={{30,106},{30,92},{44,92}},
      color={0,170,238},
      thickness=0.5));
  connect(sensor_T3.port, junction2.portC) annotation (Line(
      points={{66,106},{66,92},{52,92}},
      color={0,170,238},
      thickness=0.5));
  connect(statePoint2.sensorPort, GasCooler_SHW.portA_a) annotation (Line(
      points={{55,62},{54,62},{54,52},{32,52},{32,68},{16,68}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_T_degC1.port, Reheater_DHW.portB_a) annotation (Line(
      points={{167,44},{142,44},{142,38},{138,38},{138,76},{118,76}},
      color={153,204,0},
      thickness=0.5));
  connect(evaporator.portB_b, boundary6.port) annotation (Line(
      points={{4,-66},{12,-66},{12,-68},{18,-68},{18,-84},{66,-84}},
      color={0,170,238},
      thickness=0.5));
  connect(simpleCompressor.portB, pressureState_hp.portB) annotation (Line(
      points={{80,16},{80,19},{80,22}},
      color={153,204,0},
      thickness=0.5));
  connect(simpleCompressor.portA, SLHX_after_evaporation.portA) annotation (
      Line(
      points={{80,0},{80,0},{80,-12}},
      color={153,204,0},
      thickness=0.5));
  connect(time_table_compressor.y, simpleCompressor.m_flow_in) annotation (Line(
        points={{138,-18},{134,-18},{134,4},{134,2},{90,2}}, color={0,0,127}));
  connect(time_table_SH_Mass_Flow.y, SH_outlet.m_flow_in)
    annotation (Line(points={{82,170},{80,170},{80,94}}, color={0,0,127}));
  connect(time_table_compressor1.y, DHW_outlet.m_flow_in)
    annotation (Line(points={{212,94},{202,94},{190,94}}, color={0,0,127}));
  connect(time_table_SH_temperature_in.y, SH_inlet.T_in) annotation (Line(
        points={{-80,142},{-78,142},{-78,82},{-74,82}}, color={0,0,127}));
  connect(time_table_Bottom_source_water_pump.y, boundary3.m_flow_in)
    annotation (Line(points={{-88,-92},{-82,-92},{-72,-92},{-72,-76},{-58,-76}},
        color={0,0,127}));
  annotation (
    experiment(StopTime=600),
    experimentSetupOutput,
    Documentation(info="<html>
        <p>
        This CO2 cycle represents a typical air-water-heatpump for a building.
        The R744-heat pump has a tube and tube heat exchanger as gas cooler on the high pressure side.
        The gas cooler heats up the water for the building.
        On the low pressure level there is a fin and tube heat exchanger used as evaporator.
        The evaporator stands outside the building and takes the heat from the ambient air.
        This heat pump also has an internal heat exchanger, which is realized with two tubes and a heat port connection.
        </p>
        </html>"),
    uses(
      TIL(version="3.4.0"),
      TILMedia(version="3.4.0"),
      Modelica(version="3.2.1"),
      Hydraulics(version="4.3"),
      HydroPower(version="2.5")),
    Diagram(coordinateSystem(extent={{-360,-240},{540,360}})),
    Icon(coordinateSystem(extent={{-360,-240},{540,360}})));
end MY_FINAL_HEAT_PUMP;
